package com.wgmf.yxgj.module.bussiness.customtask.service

import android.util.Log
import com.google.gson.Gson
import com.wgmf.library.base.BaseRequest
import com.wgmf.library.base.BaseResponse
import com.wgmf.library.base.ResultData
import com.wgmf.yxgj.base.BaseService
import com.wgmf.yxgj.config.BusinessID
import com.wgmf.yxgj.global.NetworkParams
import com.wgmf.yxgj.utils.notNullAndEmpty
import java.lang.ref.WeakReference

/**
 * 自定义任务接口 Service
 */
class CustomTaskService private constructor() : BaseService() {

    companion object {
        @JvmStatic
        val instance: CustomTaskService by lazy(mode = LazyThreadSafetyMode.PUBLICATION) {
            CustomTaskService()
        }
    }

    /**
     * post /crm-api/common/customizeTask/create 创建自定义任务
     */
    fun requestCreateCustomTask(
        json: String,
        callback: ResultData.BusinessCallback
    ) {
        val request = BaseRequest().apply {
            this.taskID = BusinessID.CustomTask.MSG_ON_CREATE_CUSTOM_TASK
            this.callback = WeakReference(callback)
            this.url = NetworkParams.URL_CREATE_CUSTOM_TASK
            this.json = json
        }
        Log.d(TAG, "请求地址：" + request.url)
        sendPostJsonRequest(request)
    }

    /**
     * post /crm-api/common/customizeTask/page/list 分页查询自定义任务列表
     */
    fun requestQueryCustomTaskPageList(
        json: String,
        callback: ResultData.BusinessCallback
    ) {
        val request = BaseRequest().apply {
            this.taskID = BusinessID.CustomTask.MSG_ON_QUERY_CUSTOM_TASK_PAGE_LIST
            this.callback = WeakReference(callback)
            this.url = NetworkParams.URL_QUERY_CUSTOM_TASK_PAGE_LIST
            this.json = json
        }
        Log.d(TAG, "请求地址：" + request.url)
        sendPostJsonRequest(request)
    }

    /**
     *  post /crm-api/common/customizeTask/querySatisfyCustomizeTaskCount 查询满足条件的生成自定义任务客户数量
     */
    fun requestQuerySatisfyCustomTaskCount(
        json: String,
        callback: ResultData.BusinessCallback
    ) {
        val request = BaseRequest().apply {
            this.taskID = BusinessID.CustomTask.MSG_ON_QUERY_SATISFY_CUSTOM_TASK_COUNT
            this.callback = WeakReference(callback)
            this.url = NetworkParams.URL_QUERY_SATISFY_CUSTOM_TASK_COUNT
            this.json = json
        }
        Log.d(TAG, "请求地址：" + request.url)
        sendPostJsonRequest(request)
    }

    /**
     * post /crm-api/common/customizeTask/updateReferentialSpeech  编辑自定义任务参考话术
     */
    fun requestUpdateReferentialSpeech(
        json: String,
        callback: ResultData.BusinessCallback
    ) {
        val request = BaseRequest().apply {
            this.taskID = BusinessID.CustomTask.MSG_ON_UPDATE_REFERENTIAL_SPEECH
            this.callback = WeakReference(callback)
            this.url = NetworkParams.URL_UPDATE_REFERENTIAL_SPEECH
            this.json = json
        }
        Log.d(TAG, "请求地址：" + request.url)
        sendPostJsonRequest(request)
    }

    /**
     * post /crm-api/common/customizeTask/updateTaskStatus 更新任务状态
     */
    fun requesUpdateTaskStatus(
        json: String,
        callback: ResultData.BusinessCallback
    ) {
        val request = BaseRequest().apply {
            this.taskID = BusinessID.CustomTask.MSG_ON_UPDATE_TASK_STATUS
            this.callback = WeakReference(callback)
            this.url = NetworkParams.URL_UPDATE_TASK_STATUS
            this.json = json
        }
        Log.d(TAG, "请求地址：" + request.url)
        sendPostJsonRequest(request)
    }

    /**
     * get /product/offline 获取线下所有产品
     */
    fun requestProductOffline(
        callback: ResultData.BusinessCallback
    ) {
        val request = BaseRequest().apply {
            this.taskID = BusinessID.CustomTask.MSG_ON_PRODUCT_OFFLINE
            this.callback = WeakReference(callback)
            this.url = NetworkParams.URL_PRODUCT_OFFLINE
        }
        Log.d(TAG, "请求地址：" + request.url)
        sendGetRequest(request)
    }

    /**
     * post /crm-api/basic/label/option/list 获取所有标签列表
     */
    fun requestQueryLabelOptionList(
        callback: ResultData.BusinessCallback
    ) {
        val request = BaseRequest().apply {
            this.taskID = BusinessID.CustomTask.MSG_ON_QUERY_LABEL_OPTION_LIST
            this.callback = WeakReference(callback)
            this.url = NetworkParams.URL_QUERY_LABEL_OPTION_LIST
            this.json = ""
        }
        Log.d(TAG, "请求地址：" + request.url)
        sendPostJsonRequest(request)
    }

    /**
     * post /baseDateOrgController/getSupermarketInfo 获取商超列表
     */
    fun requestSuperMarketInfo(json: String, callback: ResultData.BusinessCallback) {
        val request = BaseRequest().apply {
            this.taskID = BusinessID.CustomTask.MSG_ON_GET_SUPER_MARKET_INFO
            this.callback = WeakReference(callback)
            this.url = NetworkParams.URL_GET_SUPER_MARKET_IFNO
            this.json = json
        }
        Log.d(TAG, "请求地址：" + request.url)
        sendPostJsonRequest(request)
    }

    /**
     * get /baseDateOrgController/getOfficeInfoByOrgAndMarket  获取办事处  partnerId=&areaCode=MWA01&staffOrgCode=M
     */
    fun requestOfficeInfoByOrgAndMarket(
        areaCode: String?,
        callback: ResultData.BusinessCallback
    ) {
        val request = BaseRequest().apply {
            this.taskID = BusinessID.CustomTask.MSG_ON_GET_OFFICE_INFO_BY_ORG_AND_MARKET
            this.callback = WeakReference(callback)
            if (areaCode != null) {
                this.url =
                    NetworkParams.URL_GET_OFFICE_INFO_BY_ORG_AND_MARKET + "?partnerId=&areaCode=" + areaCode + "&staffOrgCode=M"
            } else {
                this.url =
                    NetworkParams.URL_GET_OFFICE_INFO_BY_ORG_AND_MARKET + "?partnerId=&staffOrgCode=M"
            }
        }
        Log.d(TAG, "请求地址：" + request.url)
        sendGetRequest(request)
    }

    /**
     * get  /saleOrg/shopInfoByByOrgAndMarket 获取所有门店  ?partnerId=&officeCode=MWA0102&managerCode=&staffOrgCode=
     */
    fun requestShopInfoByOrgAndMarket(officeCode: String?, callback: ResultData.BusinessCallback) {
        val request = BaseRequest().apply {
            this.taskID = BusinessID.CustomTask.MSG_ON_SHOP_INFO_BY_ORG_AND_MARKET
            this.callback = WeakReference(callback)
            if (officeCode != null) {
                this.url =
                    NetworkParams.URL_SHOP_INFO_BY_ORG_AND_MARKET + "?partnerId=&officeCode=" + officeCode + "&managerCode=&staffOrgCode="
            } else {
                this.url =
                    NetworkParams.URL_SHOP_INFO_BY_ORG_AND_MARKET + "?partnerId=&managerCode=&staffOrgCode="
            }
        }
        Log.d(TAG, "请求地址：" + request.url)
        sendGetRequest(request)
    }

    /**
     * post /crm-api/basic/shop/organization/queryActiveOrgList  查询活跃的门店销售组织数据（有客户购买过的门店）
     */
    fun requestQueryActiveOrgList(
        json: String,
        callback: ResultData.BusinessCallback
    ) {
        val request = BaseRequest().apply {
            this.taskID = BusinessID.CustomTask.MSG_ON_QUERY_ACTIVE_ORG_LIST
            this.callback = WeakReference(callback)
            this.url = NetworkParams.URL_QUERY_ACTIVE_ORG_LIST
            this.json = json
        }
        Log.d(TAG, "请求地址：" + request.url)
        sendPostJsonRequest(request)
    }

    /**
     * get /crm-api/order-api/basic/coupon/option/list 优惠券基础下拉列表
     */
    fun requestBasicCouponOptionList(
        json:String,
        callback: ResultData.BusinessCallback
    ) {
        val request = BaseRequest().apply {
            this.taskID = BusinessID.CustomTask.MSG_ON_BASIC_COUPON_OPTION_LIST
            this.callback = WeakReference(callback)
            this.url = NetworkParams.URL_BASIC_COUPON_OPTION_LIST
            this.json = json
        }
        Log.d(TAG, "请求地址：" + request.url)
        sendPostJsonRequest(request)
    }

    override fun onTaskDone(data: ResultData?) {
        data?.let {
            when (it.taskID) {
                BusinessID.CustomTask.MSG_ON_CREATE_CUSTOM_TASK,
                BusinessID.CustomTask.MSG_ON_QUERY_CUSTOM_TASK_PAGE_LIST,
                BusinessID.CustomTask.MSG_ON_QUERY_SATISFY_CUSTOM_TASK_COUNT,
                BusinessID.CustomTask.MSG_ON_UPDATE_REFERENTIAL_SPEECH,
                BusinessID.CustomTask.MSG_ON_UPDATE_TASK_STATUS,
                BusinessID.CustomTask.MSG_ON_PRODUCT_OFFLINE,
                BusinessID.CustomTask.MSG_ON_QUERY_LABEL_OPTION_LIST,
                BusinessID.CustomTask.MSG_ON_GET_SUPER_MARKET_INFO,
                BusinessID.CustomTask.MSG_ON_GET_OFFICE_INFO_BY_ORG_AND_MARKET,
                BusinessID.CustomTask.MSG_ON_SHOP_INFO_BY_ORG_AND_MARKET,
                BusinessID.CustomTask.MSG_ON_QUERY_ACTIVE_ORG_LIST,
                BusinessID.CustomTask.MSG_ON_BASIC_COUPON_OPTION_LIST -> {
                    if (it.isSuccessed) {
                        val json = it.info
                        if (json.notNullAndEmpty()) {
                            val response = Gson().fromJson(
                                json,
                                BaseResponse::class.java
                            )
                            Log.d(TAG, "id:${it.taskID};mBaseResponse=$response")
                            it.resultCode = response.retCode
                            it.resultInfo = response.retInfo
                        }
                    }
                }
                else -> {
                }
            }
        }
    }
}