package com.wgmf.yxgj.module.bussiness.customtask.ui

import android.content.Intent
import android.os.Bundle
import android.support.v7.widget.LinearLayoutManager
import android.support.v7.widget.RecyclerView
import android.util.Log
import android.view.View
import android.widget.*
import com.alibaba.android.arouter.facade.annotation.Route
import com.chad.library.adapter.base.BaseQuickAdapter
import com.google.gson.Gson
import com.scwang.smartrefresh.layout.SmartRefreshLayout
import com.wgmf.library.base.BaseResponse
import com.wgmf.library.base.ResultData
import com.wgmf.yxgj.base.BaseParentAct
import com.wgmf.yxgj.config.BusinessID
import com.wgmf.yxgj.dialog.LoadWaitDominator
import com.wgmf.yxgj.global.AppConstants
import com.wgmf.yxgj.global.ConstantParams
import com.wgmf.yxgj.module.bussiness.customtask.R
import com.wgmf.yxgj.module.bussiness.customtask.model.CustomTaskRequest
import com.wgmf.yxgj.module.bussiness.customtask.model.QueryCustomTaskDetailsEntity
import com.wgmf.yxgj.module.bussiness.customtask.model.UpdateTaskStatusRequest
import com.wgmf.yxgj.module.bussiness.customtask.service.CustomTaskService
import com.wgmf.yxgj.module.bussiness.customtask.ui.adapter.CustomTaskListAdapter
import com.wgmf.yxgj.utils.DensityUtil
import com.wgmf.yxgj.utils.isNotNullOrSize
import com.wgmf.yxgj.widgets.decoration.SpacesItemDecoration
import com.xp.arouter.RouterParams

/**
 *  自定义任务: 自定义任务列表
 * @author LW
 */
@Route(path = RouterParams.URL_CUSTOM_TASK_ACTIVITY)
class CustomTaskActivity : BaseParentAct() {

    private var mPublicListViewRv: RecyclerView? = null

    private var mPublicRefreshView: SmartRefreshLayout? = null

    private var mCustomTaskListAdapter: CustomTaskListAdapter? = null

    private val mBranchTitle: String? by lazy {
        intent.getStringExtra("branchTitle")
    }

    private var mCustomTaskDetailsList: MutableList<QueryCustomTaskDetailsEntity.CustomTaskDetailsPage.CustomTaskDetailsBean> =
        mutableListOf()

    /**
     * 当前页码
     */
    private var mNextPage: Int = 1

    lateinit var mLoadWait: LoadWaitDominator

    private var mPosition: Int = -1

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        setContentView(R.layout.public_page_list_view)
        initTitle()
        initView()
    }

    override fun initTitle() {
        super.initTitle()
        homeTitleText.text = mBranchTitle
        homeTitleBackLl.visibility = View.VISIBLE
    }

    private fun initView() {
        mLoadWait = LoadWaitDominator(this, findViewById(R.id.public_container_fl)).apply {
//            setBackgroundColor(R.color.region_two_bg)
            setStatusImg(R.mipmap.icon_msg_empty_task)
        }
        mPublicRefreshView = findViewById<SmartRefreshLayout>(R.id.public_refresh_view).apply {
            //刷新
            setOnRefreshListener {
                queryCustomTaskPageList(1)
            }
            //加载更多
            setOnLoadmoreListener {
                queryCustomTaskPageList(mNextPage)
            }
        }

        mCustomTaskListAdapter = CustomTaskListAdapter(mCustomTaskDetailsList)
        mPublicListViewRv = findViewById<RecyclerView>(R.id.public_list_view_rv).apply {
            layoutManager = LinearLayoutManager(mContext)
            adapter = mCustomTaskListAdapter
            addItemDecoration(
                SpacesItemDecoration(
                    DensityUtil.dip2px(mContext, 10f),
                    adapter!!.itemCount,
                    true
                )
            )

        }
        BaseQuickAdapter.OnItemClickListener { adapter, view, pos -> //跳转到任务列表详情
            val customTaskDetailsBean =
                adapter?.getItem(pos) as QueryCustomTaskDetailsEntity.CustomTaskDetailsPage.CustomTaskDetailsBean
            jumpCustomTaskDetailsActivity(customTaskDetailsBean)
        }.also { mCustomTaskListAdapter?.onItemClickListener = it }

        mCustomTaskListAdapter?.onItemChildClickListener =
            BaseQuickAdapter.OnItemChildClickListener { adapter, view, pos ->
                val customTaskDetailsBean =
                    adapter?.getItem(pos) as QueryCustomTaskDetailsEntity.CustomTaskDetailsPage.CustomTaskDetailsBean
                customTaskDetailsBean.let {
                    this.mPosition = pos
                    if (it.taskState == ConstantParams.CONSTANT_STARTS_0 ||
                        it.taskState == ConstantParams.CONSTANT_STARTS_1
                    ) {
                        updateTaskStatus(it.id, ConstantParams.CONSTANT_STARTS_2)
                    } else if (it.taskState == ConstantParams.CONSTANT_STARTS_2) {
                        updateTaskStatus(it.id, ConstantParams.CONSTANT_STARTS_3)
                    }
                }
            }

        findViewById<LinearLayout>(R.id.report_content_confirm_ll).visibility = View.VISIBLE
        findViewById<Button>(R.id.report_content_confirm_btn).apply {
            text = getString(R.string.custom_task_create_task)
            setOnClickListener {
                //跳转到创建任务页面
                jumpCreateCustomTaskActivity()
            }
        }
    }


    /**
     * 分页查询自定义任务列表
     */
    private fun queryCustomTaskPageList(page: Int) {
        userInfo?.let {
            //if (page == ConstantParams.CONSTANT_STARTS_1) {
            //mLoadWait.show(LoadWaitDominator.LOADING)
            //showDialog()
            //}
            val json = Gson().toJson(CustomTaskRequest(it.staffId, page = page))
            CustomTaskService.instance.requestQueryCustomTaskPageList(
                json,
                this@CustomTaskActivity
            )
        }
    }

    /**
     * 更新任务状态
     */
    private fun updateTaskStatus(taskId: Int, status: Int) {
        showDialog()
        val json = Gson().toJson(UpdateTaskStatusRequest(taskId, status))
        CustomTaskService.instance.requesUpdateTaskStatus(
            json,
            this@CustomTaskActivity
        )
    }

    override fun onResume() {
        super.onResume()
        mPublicRefreshView?.autoRefresh()
    }

    override fun onBusinessResultAtMainThread(result: ResultData?) {
        super.onBusinessResultAtMainThread(result)
        dismissDialog()
        mLoadWait.dismissAll()

        mPublicRefreshView?.finishRefresh()
        mPublicRefreshView?.finishLoadmore()
        result?.let {
            if (it.taskID == BusinessID.CustomTask.MSG_ON_QUERY_CUSTOM_TASK_PAGE_LIST) {
                if (!isFinishing && it.isSuccessed) {
                    val entity = Gson().fromJson(it.info, QueryCustomTaskDetailsEntity::class.java)
                    Log.d(TAG, "QueryCustomTaskDetailsEntity=$entity")
                    if (ConstantParams.CONSTANT_PARAMS_0 == entity.retCode) {
                        val pageData = entity.payload
                        if (pageData.pages == ConstantParams.CONSTANT_STARTS_0) {
                            mLoadWait.showNoData(R.string.custom_task_not_task)
                            return
                        }
                        if (pageData.page <= pageData.pages) {
                            if (pageData.page == ConstantParams.CONSTANT_STARTS_1) {
                                refreshDataToView(pageData.data)
                            } else {
                                loadMoreDateToView(pageData.data)
                            }
                            this.mNextPage = pageData.page + 1
                        } else {
                            mPublicRefreshView?.resetNoMoreData()
                        }
                    } else {
                        mLoadWait.show(entity.retInfo)
                    }
                } else {
                    mLoadWait.showNetError()
                }
            } else if (it.taskID == BusinessID.CustomTask.MSG_ON_UPDATE_TASK_STATUS) {
                if (!isFinishing && it.isSuccessed) {
                    val entity = Gson().fromJson(it.info, BaseResponse::class.java)
                    Log.d(TAG, "BaseResponse=$entity")
                    if (ConstantParams.CONSTANT_PARAMS_0 == entity.retCode) {
                        refreshListData()
                    } else {
                        showMsg(entity.retInfo)
                    }
                } else {
                    showMsg(getString(R.string.request_data_fail))
                }
            } else {
            }
        }
    }

    private fun refreshListData() {
        if (mPosition >= 0) {
            val customTaskDetailsBean = mCustomTaskDetailsList[mPosition]
            customTaskDetailsBean.let {
                if (it.taskState == ConstantParams.CONSTANT_STARTS_0 ||
                    it.taskState == ConstantParams.CONSTANT_STARTS_1
                ) {
                    it.taskState = ConstantParams.CONSTANT_STARTS_2
                    mCustomTaskListAdapter?.notifyItemChanged(mPosition)
                } else if (it.taskState == ConstantParams.CONSTANT_STARTS_2) {
                    mCustomTaskDetailsList.removeAt(mPosition)
                    mCustomTaskListAdapter?.notifyItemRemoved(mPosition)
                } else {

                }
            }
        }
    }

    /**
     * 刷新数据更新到View
     */
    private fun refreshDataToView(list: List<QueryCustomTaskDetailsEntity.CustomTaskDetailsPage.CustomTaskDetailsBean>?) {
        if (list.isNotNullOrSize()) {
            mCustomTaskDetailsList.clear()
            mCustomTaskDetailsList.addAll(list!!)
            mCustomTaskListAdapter?.notifyDataSetChanged()
        } else {
            mLoadWait.showNoData(R.string.no_record)
        }
    }

    /**
     * 读取更多数据更新到View
     */
    private fun loadMoreDateToView(list: List<QueryCustomTaskDetailsEntity.CustomTaskDetailsPage.CustomTaskDetailsBean>?) {
        if (list.isNotNullOrSize()) {
            val position = mCustomTaskDetailsList.size
            mCustomTaskDetailsList.addAll(list!!)
            mCustomTaskListAdapter?.notifyItemInserted(position)
        }
    }

    /**
     * 跳转到 CustomTaskDetailsActivity
     */
    private fun jumpCustomTaskDetailsActivity(customTaskDetailsBean: QueryCustomTaskDetailsEntity.CustomTaskDetailsPage.CustomTaskDetailsBean) {
        val intent = Intent(mContext, CustomTaskDetailsActivity::class.java)
        intent.putExtra(AppConstants.ExtraKeys.CUSTOM_TASK_DETAILS, customTaskDetailsBean)
        startActivity(intent)
    }

    /**
     * 跳转到 CreateCustomTaskActivity
     */
    private fun jumpCreateCustomTaskActivity() {
        val intent = Intent(mContext, CreateCustomTaskActivity::class.java)
        startActivity(intent)
    }
}