package com.wgmf.yxgj.module.bussiness.customtask.ui

import android.os.Bundle
import android.support.v4.content.ContextCompat
import android.support.v7.widget.LinearLayoutManager
import android.support.v7.widget.RecyclerView
import android.util.Log
import android.view.View
import android.widget.*
import com.google.gson.Gson
import com.wgmf.library.base.BaseResponse
import com.wgmf.library.base.ResultData
import com.wgmf.library.utils.DateUtil
import com.wgmf.yxgj.base.BaseParentAct
import com.wgmf.yxgj.config.BusinessID
import com.wgmf.yxgj.dialog.PublicSelectBottomDialog
import com.wgmf.yxgj.global.AppConstants
import com.wgmf.yxgj.global.ConstantParams
import com.wgmf.yxgj.module.bussiness.customtask.R
import com.wgmf.yxgj.module.bussiness.customtask.model.CreateCustomTaskBean
import com.wgmf.yxgj.module.bussiness.customtask.model.ShopSalesOrgEntity
import com.wgmf.yxgj.module.bussiness.customtask.model.ShopSalesOrgRequest
import com.wgmf.yxgj.module.bussiness.customtask.service.CustomTaskService
import com.wgmf.yxgj.module.bussiness.customtask.ui.adapter.OfficeInfoByOrgAndMarketListAdapter
import com.wgmf.yxgj.module.bussiness.customtask.ui.view.ItemOptionLayout
import com.wgmf.yxgj.utils.MyToast
import com.wgmf.yxgj.utils.helper.DialogHelper
import com.wgmf.yxgj.utils.isNullOrEmpty
import com.wgmf.yxgj.utils.notNullAndEmpty
import com.wgmf.yxgj.widgets.decoration.DividerItemDecoration
import xp.timepicker.com.widget.bean.DateType
import java.util.*

/**
 *  自定义任务: 自定义任务确认
 * @author LW
 */
class CustomTaskConfirmActivity : BaseParentAct() {

    private var mStartTimeEt: EditText? = null
    private var mEndTimeEt: EditText? = null

    private var mListDescEt: EditText? = null

    private var mSuperSystemChooseCb: CheckBox? = null

    private var mChooseAreaOptionLayout: ItemOptionLayout? = null
    private var mChooseOfficesOptionLayout: ItemOptionLayout? = null
    private var mChooseStoreOptionLayout: ItemOptionLayout? = null

    private val mCreateCustomTaskBean: CreateCustomTaskBean? by lazy {
        intent.getSerializableExtra(AppConstants.ExtraKeys.CUSTOM_TASK_DATA) as CreateCustomTaskBean?
    }
    private val mCustomTaskCount: Int? by lazy {
        intent.getIntExtra(AppConstants.ExtraKeys.CUSTOM_TASK_COUNT, 0) as Int?
    }

    /**
     * 办事处选择Id
     */
    private var mAreaChooseId: String? = null

    /**
     * 办事处选择Id
     */
    private var mOfficeChooseId: String? = null

    /**
     * 办事处选择Id
     */
    private var mShopChooseId: String? = null

    /**
     * 大区
     */
    private var mAreaInfoByOrgAndMarketList: List<ShopSalesOrgEntity.ShopSalesOrgBean.OrgBean> =
        listOf()

    /**
     * 办事处
     */
    private var mOfficeInfoByOrgAndMarketList: List<ShopSalesOrgEntity.ShopSalesOrgBean.OrgBean> =
        listOf()

    /**
     * 门店
     */
    private var mShopInfoByOrgAndMarketList: List<ShopSalesOrgEntity.ShopSalesOrgBean.OrgBean> =
        listOf()

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        setContentView(R.layout.activity_custom_task_confirm)
        initTitle()
        initView()
    }

    override fun initTitle() {
        super.initTitle()
        homeTitleText.text = getString(R.string.custom_task_task_confirm)
        homeTitleBackLl.visibility = View.VISIBLE
    }

    private fun initView() {
        mStartTimeEt = findViewById<EditText>(R.id.custom_task_start_time_et)
            ?.apply {
                setText(DateUtil.getFormatCurrentDate(DateUtil.FORMATTIME))
                setOnClickListener {
                    DialogHelper.showDatePickDialog(
                        this@CustomTaskConfirmActivity,
                        DateType.TYPE_YMDHM,
                        this
                    )
                }
            }

        mEndTimeEt = findViewById<EditText>(R.id.custom_task_end_time_et)
            ?.apply {
                setText(
                    DateUtil.format(DateUtil.getCurrentLastDayDate(), DateUtil.FORMATTIME)
                )
                setOnClickListener {
                    DialogHelper.showDatePickDialog(
                        this@CustomTaskConfirmActivity,
                        DateType.TYPE_YMDHM,
                        this
                    )
                }
            }

        mListDescEt = findViewById(R.id.custom_task_list_desc_et)
        findViewById<TextView>(R.id.custiom_task_satisfy_condition_number).text =
            mCustomTaskCount.toString()

        mSuperSystemChooseCb = findViewById(R.id.custom_task_item_super_system_choose_cb)

        //大区
        findViewById<TextView>(R.id.custom_task_item_super_system_area_tv)
            ?.setOnClickListener {
                showSingleAreaDialog()
            }
        val chooseAreaLl = findViewById<LinearLayout>(R.id.custom_task_item_choose_area_ll)
        if (chooseAreaLl != null) {
            mChooseAreaOptionLayout = ItemOptionLayout(mContext, chooseAreaLl)
        }

        //办事处
        findViewById<TextView>(R.id.custom_task_item_super_system_offices_tv)
            ?.setOnClickListener {
                showSingleOfficesDialog()
            }
        val chooseOfficesLl = findViewById<LinearLayout>(R.id.custom_task_item_choose_offices_ll)
        if (chooseOfficesLl != null) {
            mChooseOfficesOptionLayout = ItemOptionLayout(mContext, chooseOfficesLl)
        }

        //门店
        findViewById<TextView>(R.id.custom_task_item_super_system_store_tv)
            ?.setOnClickListener {
                showSingleShopDialog()
            }
        val chooseStoreLl = findViewById<LinearLayout>(R.id.custom_task_item_choose_store_ll)
        if (chooseStoreLl != null) {
            mChooseStoreOptionLayout = ItemOptionLayout(mContext, chooseStoreLl)
        }

        findViewById<Button>(R.id.custom_task_confirm_btn).setOnClickListener {
            clickConfirmLogic()
        }

        queryShopInfoByOrgAndMarket()
    }

    /**
     * 显示底部大区列表选择框(单选、多选列表)
     */
    private fun showSingleAreaDialog() {
        val builder = PublicSelectBottomDialog.Companion.Builder(this)
        builder.isDataEntry(mAreaInfoByOrgAndMarketList.isNullOrEmpty())
        builder.setTitle(R.string.custom_task_dialog_choose_area_title)
        builder.setDialogListLoadDataListener(object :
            PublicSelectBottomDialog.OnDialogListLoadDataListener {
            override fun onListLoadData(dialog: PublicSelectBottomDialog, list: RecyclerView) {
                val officeInfoByOrgAndMarketListAdapter =
                    OfficeInfoByOrgAndMarketListAdapter(mAreaInfoByOrgAndMarketList)
                list.apply {
                    visibility = View.VISIBLE
                    layoutManager = LinearLayoutManager(mContext)
                    adapter = officeInfoByOrgAndMarketListAdapter
                    addItemDecoration(
                        DividerItemDecoration(
                            DividerItemDecoration.HORIZONTAL_LIST,
                            1,
                            ContextCompat.getColor(mContext, R.color.divider_line_deep_two)
                        )
                    )
                }
                officeInfoByOrgAndMarketListAdapter.setOnItemClickListener { baseQuickAdapter, view, position ->
                    val item =
                        baseQuickAdapter.getItem(position) as ShopSalesOrgEntity.ShopSalesOrgBean.OrgBean
                    mAreaChooseId = item.orgId
                    mOfficeChooseId = null
                    mShopChooseId = null
                    mChooseOfficesOptionLayout?.reset()
                    mChooseStoreOptionLayout?.reset()
                    mChooseAreaOptionLayout?.addView(
                        position,
                        item.orgName ?: "",
                        arrayOf(28, 2, 28, 0)
                    )
                    dialog.dismiss()
                    //获取指定大区下办事处数据
                    queryShopInfoByOrgAndMarket(mAreaChooseId)
                }
            }
        })
        builder.create().show()
    }

    /**
     * 显示底部办事处列表选择框(单选、多选列表)
     */
    private fun showSingleOfficesDialog() {
        val builder = PublicSelectBottomDialog.Companion.Builder(this)
        builder.isDataEntry(mOfficeInfoByOrgAndMarketList.isNullOrEmpty())
        builder.setTitle(R.string.custom_task_dialog_choose_offices_title)
        builder.setDialogListLoadDataListener(object :
            PublicSelectBottomDialog.OnDialogListLoadDataListener {
            override fun onListLoadData(dialog: PublicSelectBottomDialog, list: RecyclerView) {
                val officeInfoByOrgAndMarketListAdapter =
                    OfficeInfoByOrgAndMarketListAdapter(mOfficeInfoByOrgAndMarketList)
                list.apply {
                    visibility = View.VISIBLE
                    layoutManager = LinearLayoutManager(mContext)
                    adapter = officeInfoByOrgAndMarketListAdapter
                    addItemDecoration(
                        DividerItemDecoration(
                            DividerItemDecoration.HORIZONTAL_LIST,
                            1,
                            ContextCompat.getColor(mContext, R.color.divider_line_deep_two)
                        )
                    )
                }
                officeInfoByOrgAndMarketListAdapter.setOnItemClickListener { baseQuickAdapter, view, position ->
                    val item =
                        baseQuickAdapter.getItem(position) as ShopSalesOrgEntity.ShopSalesOrgBean.OrgBean
                    mOfficeChooseId = item.orgId
                    mShopChooseId = null
                    mChooseStoreOptionLayout?.reset()
                    mChooseOfficesOptionLayout?.addView(
                        position,
                        item.orgName ?: "",
                        arrayOf(28, 2, 28, 0)
                    )
                    dialog.dismiss()
                    //获取指定大区下办事处数据
                    queryShopInfoByOrgAndMarket(mAreaChooseId, mOfficeChooseId)
                }
            }
        })
        builder.create().show()
    }

    /**
     * 显示底部门店列表选择框(单选、多选列表)
     */
    private fun showSingleShopDialog() {
        val builder = PublicSelectBottomDialog.Companion.Builder(this)
        builder.isDataEntry(mShopInfoByOrgAndMarketList.isNullOrEmpty())
        builder.setTitle(R.string.custom_task_dialog_choose_store_single_title)
        builder.setDialogListLoadDataListener(object :
            PublicSelectBottomDialog.OnDialogListLoadDataListener {
            override fun onListLoadData(dialog: PublicSelectBottomDialog, list: RecyclerView) {
                val officeInfoByOrgAndMarketListAdapter =
                    OfficeInfoByOrgAndMarketListAdapter(mShopInfoByOrgAndMarketList)
                list.apply {
                    visibility = View.VISIBLE
                    layoutManager = LinearLayoutManager(mContext)
                    adapter = officeInfoByOrgAndMarketListAdapter
                    addItemDecoration(
                        DividerItemDecoration(
                            DividerItemDecoration.HORIZONTAL_LIST,
                            1,
                            ContextCompat.getColor(mContext, R.color.divider_line_deep_two)
                        )
                    )
                }
                officeInfoByOrgAndMarketListAdapter.setOnItemClickListener { baseQuickAdapter, view, position ->
                    val item =
                        baseQuickAdapter.getItem(position) as ShopSalesOrgEntity.ShopSalesOrgBean.OrgBean
                    mShopChooseId = item.orgId
                    mChooseStoreOptionLayout?.addView(
                        position,
                        item.orgName ?: "",
                        arrayOf(28, 2, 28, 0)
                    )
                    dialog.dismiss()
                }
            }
        })
        builder.create().show()
    }


    /**
     * 点击确定逻辑处理
     */
    private fun clickConfirmLogic() {
        mCreateCustomTaskBean?.apply {
            val startTime = mStartTimeEt?.text?.toString()
            if (startTime.notNullAndEmpty()) {
                careStartDate = "$startTime:59"
            } else {
                MyToast.show(mContext.getString(R.string.custom_task_start_time_tip))
                return
            }
            val endTime = mEndTimeEt?.text?.toString()
            if (endTime.notNullAndEmpty()) {
                careEndDate = "$endTime:59"
            } else {
                MyToast.show(mContext.getString(R.string.custom_task_end_time_tip))
                return
            }
            val desc = mListDescEt?.text?.toString()
            if (desc.notNullAndEmpty()) {
                taskName = desc
            } else {
                MyToast.show(mContext.getString(R.string.custio_task_list_desc_entry_tip))
                return
            }

            if (mSuperSystemChooseCb?.isChecked == true) {
                if (mShopChooseId.notNullAndEmpty()) {
                    designatedShopId = mShopChooseId
                } else {
                    MyToast.show(mContext.getString(R.string.custio_task_designated_shop_tip))
                    return
                }
            }
        }

        createCustomTask()
    }

    /**
     * 创建任务
     */
    private fun createCustomTask() {
        if (mCreateCustomTaskBean != null) {
            showDialog()
            //获取办事处列表数据
            val json = Gson().toJson(mCreateCustomTaskBean)
            CustomTaskService.instance.requestCreateCustomTask(
                json,
                this@CustomTaskConfirmActivity
            )
        }
    }

    /**
     * 查询活跃的门店销售组织数据（有客户购买过的门店）
     */
    private fun queryShopInfoByOrgAndMarket(regionId: String? = null, officeId: String? = null) {
        showDialog()
        val json = Gson().toJson(ShopSalesOrgRequest(regionId, officeId))
        CustomTaskService.instance.requestQueryActiveOrgList(
            json,
            this@CustomTaskConfirmActivity
        )
    }


    override fun onBusinessResultAtMainThread(result: ResultData?) {
        super.onBusinessResultAtMainThread(result)
        dismissDialog()
        result?.let {
            if (it.taskID == BusinessID.CustomTask.MSG_ON_CREATE_CUSTOM_TASK) {
                if (!isFinishing && it.isSuccessed) {
                    val entity = Gson().fromJson(it.info, BaseResponse::class.java)
                    Log.d(TAG, "BaseResponse=$entity")
                    if (ConstantParams.CONSTANT_PARAMS_0 == entity.retCode) {
                        this.finish()
                    } else {
                        MyToast.show(entity.retInfo)
                    }
                } else {
                    MyToast.show(getString(R.string.request_data_fail))
                }
            } else if (it.taskID == BusinessID.CustomTask.MSG_ON_QUERY_ACTIVE_ORG_LIST) {
                if (!isFinishing && it.isSuccessed) {
                    val entity =
                        Gson().fromJson(it.info, ShopSalesOrgEntity::class.java)
                    Log.d(TAG, "ShopSalesOrgEntity=$entity")
                    if (ConstantParams.CONSTANT_PARAMS_0 == entity.retCode) {
                        val shopSalesOrgBean = entity.payload
                        shopSalesOrgBean?.let {
                            if (mAreaChooseId == null) {
                                mAreaInfoByOrgAndMarketList = it.areaList ?: listOf()
                            }
                            if (mOfficeChooseId == null) {
                                mOfficeInfoByOrgAndMarketList = it.officeList ?: listOf()
                            }
                            if (mShopChooseId == null) {
                                mShopInfoByOrgAndMarketList = it.shopList ?: listOf()
                            }
                        }
                    }
                } else {
                    MyToast.show(getString(R.string.request_data_fail))
                }
            }
        }
    }
}