package com.wgmf.yxgj.module.bussiness.customtask.ui.view

import android.content.Context
import android.view.View
import android.widget.ImageView
import android.widget.LinearLayout
import android.widget.TextView
import com.wgmf.yxgj.module.bussiness.customtask.R
import com.wgmf.yxgj.module.bussiness.customtask.model.ItemOptionEntity
import org.jetbrains.anko.dip

/**
 * @author  LW
 */
class ItemOptionLayout(
    val context: Context,
    private val rootLayout: LinearLayout,
    val singleChoose: Boolean = true
) {


    /**
     * 所有数据
     */
    private var mItemOptionList: MutableList<ItemOptionEntity> = mutableListOf()

    init {
        reset()
    }

    fun getOptionList(): List<ItemOptionEntity> = mItemOptionList


    fun addView(
        pos: Int,
        title: String,
        margin: Array<Int>? = arrayOf(0, 0, 0, 0),
        paramWith: Int = LinearLayout.LayoutParams.MATCH_PARENT,
        paramHeight: Int = LinearLayout.LayoutParams.WRAP_CONTENT,
        listener: ((pos: Int) -> Unit)? = null
    ) {

        if (singleChoose) {
            reset()
        }
        val itemOptionEntity = ItemOptionEntity(pos, title)
        //把选择数据保存起来
        mItemOptionList.add(itemOptionEntity)
        val mItemOptionView: View = View.inflate(context, R.layout.item_list_choose_view, null)
        mItemOptionView.let {
            it.findViewById<TextView>(R.id.custom_task_item_choose_title_tv).text = title
            val deleteIv = it.findViewById<ImageView>(R.id.custom_task_item_choose_delete_iv)
            if (listener != null) {
                deleteIv.apply {
                    tag = itemOptionEntity
                    setOnClickListener {
                        if (it.tag != null) {
                            val item = it.tag as ItemOptionEntity
                            val clearIndex = mItemOptionList.indexOf(item)
                            //删除容器和数据，并回调角标
                            rootLayout.removeViewAt(clearIndex)
                            mItemOptionList.removeAt(clearIndex)
                            listener.invoke(item.position)
                        }
                    }
                }
                deleteIv.visibility = View.VISIBLE
            } else {
                deleteIv.visibility = View.GONE
            }
            addViewWithLayoutParams(mItemOptionView, margin, paramWith, paramHeight, true, listener)
        }
    }

    private fun addViewWithLayoutParams(
        view: View,
        margin: Array<Int>?,
        paramWith: Int,
        paramheight: Int,
        isExpand: Boolean,
        listener: ((pos: Int) -> Unit)?
    ) {

        rootLayout.addView(view.apply {
            layoutParams =
                LinearLayout.LayoutParams(paramWith, paramheight, if (isExpand) 1F else 0F).apply {
                    margin?.let {
                        if (margin.isNotEmpty() && margin.size == 4) {
                            setMargins(
                                dip(margin.get(0)),
                                dip(margin.get(1)),
                                dip(margin.get(2)),
                                dip(margin.get(3))
                            )
                        }
                    }
                }
        })
    }

    fun reset() {
        removeAllChild()
        clearAllList()
    }

    /**
     * 移除容器控件
     */
    fun removeAllChild() {
        rootLayout.removeAllViews()
    }

    /**
     * 清除所有数据
     */
    fun clearAllList() {
        mItemOptionList.clear()
    }

}