package com.wgmf.yxgj.module.business.employability.evaluation.service

import android.util.Log
import com.google.gson.Gson
import com.wgmf.library.base.BaseRequest
import com.wgmf.library.base.BaseResponse
import com.wgmf.library.base.ResultData
import com.wgmf.library.base.ResultData.BusinessCallback
import com.wgmf.yxgj.base.BaseService
import com.wgmf.yxgj.config.BusinessID
import com.wgmf.yxgj.global.NetworkParams
import com.wgmf.yxgj.utils.notNullAndEmpty
import java.lang.ref.WeakReference

/**
 * 顾客评价接口Service
 */
class EvaluationService private constructor() : BaseService() {

    companion object {
        @JvmStatic
        val instance: EvaluationService by lazy(mode = LazyThreadSafetyMode.PUBLICATION) {
            EvaluationService()
        }
    }

    /**
     * get /customerComment/queryShopWorkers  查询 门店下的顾客评价
     * @param shopId 门店Id
     */
    fun requestQueryShopWorkers(shopId: String, callback: BusinessCallback) {
        val request = BaseRequest().apply {
            this.taskID = BusinessID.Evaluation.MSG_ON_QUERY_SHOP_WORKERS
            this.callback = WeakReference(callback)
            this.url =
                NetworkParams.URL_QUERY_SHOP_WORKERS + "?shopId=" + shopId
        }
        Log.d(TAG, "请求地址：" + request.url)
        sendGetRequest(request)
    }

    /**
     * get  /customerComment/queryOrgWorkers查询 组织下的顾客评价
     * @param orgId 组织Id
     */
    fun requestQueryOrgWorkers(
        orgId: String,
        callback: BusinessCallback
    ) {
        val request = BaseRequest().apply {
            this.taskID = BusinessID.Evaluation.MSG_ON_QUERY_ORG_WORKERS
            this.callback = WeakReference(callback)
            this.url =
                NetworkParams.URL_QUERY_ORG_WORKERS + "?orgId=" + orgId
        }
        Log.d(TAG, "请求地址：" + request.url)
        sendGetRequest(request)
    }

    override fun onTaskDone(data: ResultData?) {
        data?.let {
                when (it.taskID) {
                    BusinessID.Evaluation.MSG_ON_QUERY_SHOP_WORKERS, BusinessID.Evaluation.MSG_ON_QUERY_ORG_WORKERS -> {
                        if (it.isSuccessed) {
                            val json = it.info
                            if (json.notNullAndEmpty()) {
                                val response = Gson().fromJson(
                                    json,
                                    BaseResponse::class.java
                                )
                                Log.d(TAG, "id:${it.taskID};mBaseResponse=$response")
                                it.resultCode = response.retCode
                                it.resultInfo = response.retInfo
                            }
                        }
                    }
                    else -> {
                    }
                }
        }
    }
}