package com.wgmf.yxgj.module.business.employability.evaluation.ui

import android.os.Bundle
import android.support.v4.app.FragmentTransaction
import android.view.View
import com.alibaba.android.arouter.facade.annotation.Route
import com.wgmf.yxgj.base.BackHandledInterface
import com.wgmf.yxgj.base.BaseBackHandledFragment
import com.wgmf.yxgj.base.BaseParentAct
import com.wgmf.yxgj.module.business.employability.R
import com.xp.arouter.RouterParams

/**
 * 顾客评价
 */
@Route(path = RouterParams.URL_EVALUATION_LIST_ACTIVITY)
class EvaluationListActivity : BaseParentAct(), BackHandledInterface {

    private var mBackHandedFragment: BaseBackHandledFragment? = null

    private val mBranchTitle: String by lazy {
        intent.getStringExtra("branchTitle")
    }

    private val mShopId: String by lazy {
        intent?.getStringExtra("shopId") ?: ""
    }

    private val mBranchID: Long by lazy {
        intent.getLongExtra("branchID", 0)
    }

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        setContentView(R.layout.activity_report_module_list)
        initTitle()
        if (mShopId.isNotEmpty()) {
            jumpPersonListFragment(mShopId)
        } else {
            jumpListFragment()
        }
    }

    override fun initTitle() {
        super.initTitle()
        homeTitleMoreLl.visibility = View.INVISIBLE
        homeTitleBackLl.visibility = View.VISIBLE
        homeTitleText.text = mBranchTitle
    }

    /**
     * 跳转到 EvaluationListFragment
     */
    private fun jumpListFragment() {
        val evaluationListFragment = EvaluationListFragment()
        val bundle = Bundle()
        bundle.putString("branchTitle", mBranchTitle)
        bundle.putLong("branchID", mBranchID)
        evaluationListFragment.arguments = bundle
        loadFragment("evaluationListFragment", evaluationListFragment)
    }

    /**
     * 跳转到 EvaluationPersonListFragment
     */
    private fun jumpPersonListFragment(shopId: String) {
        val evaluationPersonListFragment = EvaluationPersonListFragment()
        val bundle = Bundle()
        bundle.putString("branchTitle", mBranchTitle)
        bundle.putString("shopId", shopId)
        bundle.putLong("branchID", mBranchID)
        evaluationPersonListFragment.arguments = bundle
        loadFragment("evaluationPersonListFragment", evaluationPersonListFragment)
    }

    /**
     * 加载内容
     *
     * @param tag      标签
     * @param fragment 内容
     */
    fun loadFragment(tag: String, fragment: BaseBackHandledFragment) {
        val ft = supportFragmentManager.beginTransaction()
        ft.setTransition(FragmentTransaction.TRANSIT_FRAGMENT_OPEN)
        ft.replace(R.id.report_module_list_fl, fragment)
        ft.addToBackStack(tag)
        ft.commit()
    }


    override fun setSelectedFragment(selectedFragment: BaseBackHandledFragment?) {
        mBackHandedFragment = selectedFragment
    }

    override fun onBackPressed() {
        if (mBackHandedFragment == null || !mBackHandedFragment!!.onBackPressed()) {
            if (fragmentManager.backStackEntryCount == 0) {
                finish()
            } else {
                fragmentManager.popBackStack()
            }
        }
    }

    override fun back() {
        //使Fragment界面一级级返回
        onBackPressed()
    }
}