package com.wgmf.yxgj.module.business.employability.evaluation.ui

import android.os.Bundle
import android.support.v4.app.FragmentTransaction
import android.support.v4.content.ContextCompat
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import android.widget.ImageView
import android.widget.LinearLayout
import android.widget.TextView
import com.wgmf.yxgj.base.BaseBackHandledFragment
import com.wgmf.yxgj.module.business.employability.R
import org.jetbrains.anko.find

/**
 * 顾客评价
 */
class EvaluationListFragment : BaseBackHandledFragment(), View.OnClickListener {

    private val mBranchTitle: String by lazy {
        arguments?.getString("branchTitle") ?: ""
    }

    private val mBranchID: Long by lazy {
        arguments?.getLong("branchID", 0) ?: 0
    }

    /**
     * 当前选择反馈处理状态位置
     */
    private var mPosition = 0

    /**
     * 下标集合
     */
    private var mTextViews: MutableList<TextView> = mutableListOf()

    /**
     * tab集合
     */
    private var mImageViews: MutableList<ImageView> = mutableListOf()

    private var mReportContentConfirmLl: LinearLayout? = null

    private var mReportModuleByProjectTxt: TextView? = null

    private var mReportModuleByShopTxt: TextView? = null

    private var mReportModuleByProjectImg: ImageView? = null

    private var mReportModuleByShopImg: ImageView? = null

    private lateinit var mView: View

    override fun onCreateView(
        inflater: LayoutInflater,
        container: ViewGroup?,
        savedInstanceState: Bundle?
    ): View {
        mView = inflater.inflate(R.layout.fragment_report_module_list, container, false).apply {
            // 防止点击穿透，底层的fragment响应上层点击触摸事件
            isClickable = true
        }
        return mView
    }

    override fun onActivityCreated(savedInstanceState: Bundle?) {
        super.onActivityCreated(savedInstanceState)
        initView()
        initTab()
        refreshShopFragment()
    }

    /**
     * 加载内容
     *
     * @param tag      标签
     * @param fragment 内容
     */
    fun loadFragment(tag: String, fragment: BaseBackHandledFragment) {
        activity?.supportFragmentManager?.beginTransaction()?.apply {
            setTransition(FragmentTransaction.TRANSIT_FRAGMENT_OPEN)
            replace(R.id.report_module_list_search_fl, fragment)
            addToBackStack(tag)
        }?.commit()

    }

    private fun initView() {
        mReportContentConfirmLl =
            mView.find(R.id.report_content_confirm_ll)
        /*
         * 声明标题栏的tab
         */
        mReportModuleByProjectTxt = mView.find<TextView>(R.id.report_module_by_project_txt).apply {
            text = getString(R.string.employ_ability_by_shop)
        }
        mReportModuleByShopTxt = mView.find<TextView>(R.id.report_module_by_shop_txt).apply {
            text = getString(R.string.employ_ability_by_person)
        }
        /*
         * 标题栏的下标
         */
        mView.find<LinearLayout>(R.id.ll_report_module_by_project).setOnClickListener(this)
        mView.find<LinearLayout>(R.id.ll_report_module_by_shop).setOnClickListener(this)

        mReportModuleByProjectImg = mView.find(R.id.report_module_by_project_img)
        mReportModuleByShopImg = mView.find(R.id.report_module_by_shop_img)
        // 装载控件到集合
        mTextViews.clear()
        mTextViews.add(mReportModuleByProjectTxt!!)
        mTextViews.add(mReportModuleByShopTxt!!)
        mImageViews.clear()
        mImageViews.add(mReportModuleByProjectImg!!)
        mImageViews.add(mReportModuleByShopImg!!)
    }

    private fun initTab() {
        mTextViews[0].setTextColor(resources.getColor(R.color.normal_color))
        mImageViews[0].visibility = View.VISIBLE
        mImageViews[0].setImageResource(R.color.normal_color)
    }

    override fun onBackPressed(): Boolean {
        return false
    }

    private fun setSelectedItem(position: Int) {
        for (i in mImageViews.indices) {
            mImageViews[i].setImageResource(R.color.white)
            mTextViews[i].setTextColor(ContextCompat.getColor(activity!!, R.color.black))
            mImageViews[position].visibility = View.GONE
        }
        mImageViews[position].visibility = View.VISIBLE
        mImageViews[position].setImageResource(R.color.normal_color)
        mTextViews[position].setTextColor(ContextCompat.getColor(activity!!, R.color.normal_child))
        mTextViews[position].paint.isFakeBoldText = true
    }

    override fun onClick(view: View) {
        if (view.id == R.id.ll_report_module_by_project) {
            mPosition = 0
            setSelectedItem(mPosition)
            refreshShopFragment()
        } else if (view.id == R.id.ll_report_module_by_shop) {
            mPosition = 1
            setSelectedItem(mPosition)
            refreshPersonFragment()
        }
    }

    /**
     * 跳转到 EvaluationPersonListFragment
     */
    private fun refreshPersonFragment() {
        mReportContentConfirmLl?.visibility = View.GONE
        val evaluationPersonListFragment = EvaluationPersonListFragment()
        val bundle = Bundle()
        bundle.putString("branchTitle", mBranchTitle)
        bundle.putLong("branchID", mBranchID)
        evaluationPersonListFragment.arguments = bundle
        loadFragment("evaluationPersonListFragment", evaluationPersonListFragment)
    }

    /**
     *跳转到 EvaluationShopListFragment
     */
    private fun refreshShopFragment() {
        mReportContentConfirmLl?.visibility = View.GONE
        val evaluationShopListFragment = EvaluationShopListFragment(this)
        val bundle = Bundle()
        bundle.putString("branchTitle", mBranchTitle)
        bundle.putLong("branchID", mBranchID)
        evaluationShopListFragment.arguments = bundle
        loadFragment("evaluationShopListFragment", evaluationShopListFragment)
    }
}