package com.wgmf.yxgj.module.business.employability.evaluation.ui

import android.content.Intent
import android.os.Bundle
import android.support.v4.content.ContextCompat
import android.support.v7.widget.LinearLayoutManager
import android.support.v7.widget.RecyclerView
import android.text.Editable
import android.text.TextUtils
import android.text.TextWatcher
import android.util.Log
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import android.widget.FrameLayout
import android.widget.LinearLayout
import android.widget.TextView
import com.google.gson.Gson
import com.wgmf.library.base.ResultData
import com.wgmf.yxgj.base.BaseBackHandledFragment
import com.wgmf.yxgj.base.BaseParentFra
import com.wgmf.yxgj.basewebview.ui.HtmlActivity
import com.wgmf.yxgj.config.BusinessID
import com.wgmf.yxgj.dialog.LoadWaitDominator
import com.wgmf.yxgj.global.ConstantParams
import com.wgmf.yxgj.module.business.employability.R
import com.wgmf.yxgj.module.business.employability.evaluation.model.EvaluationBean
import com.wgmf.yxgj.module.business.employability.evaluation.model.EvaluationResponse
import com.wgmf.yxgj.module.business.employability.evaluation.service.EvaluationService
import com.wgmf.yxgj.widgets.EditText.ClearEditText
import com.wgmf.yxgj.widgets.decoration.DividerItemDecoration
import org.jetbrains.anko.find

class EvaluationPersonListFragment : BaseBackHandledFragment(),
    EvaluationPersonListAdapter.OnEvaluationPersonClickListener {

    private val mBranchTitle: String by lazy {
        arguments?.getString("branchTitle") ?: ""
    }

    private val mShopId: String by lazy {
        arguments?.getString("shopId") ?: ""
    }

    private val mBranchID: Long by lazy {
        arguments?.getLong("branchID") ?: 0
    }

    private var mFarAddHeaderTv: TextView? = null
    private var mFarAddHeaderLl: LinearLayout? = null
    private var mReportContentConfirmLl: LinearLayout? = null
    private var mStoreNameEt: ClearEditText? = null

    private var mRecyclerContentView: RecyclerView? = null

    private var mEvaluationPersonListAdapter: EvaluationPersonListAdapter? = null

    private var mEvaluationBeanList: MutableList<EvaluationBean> = mutableListOf()

    private var mEvaluationBeanListSearch: MutableList<EvaluationBean> = mutableListOf()

    private lateinit var mLoadWait: LoadWaitDominator

    private lateinit var mView: View

    override fun onCreateView(
        inflater: LayoutInflater,
        container: ViewGroup?,
        savedInstanceState: Bundle?
    ): View {
        mView =
            inflater.inflate(R.layout.fragment_news_report_module_project_list, container, false)
                .apply {
                    // 防止点击穿透，底层的fragment响应上层点击触摸事件
                    isClickable = true
                }

        return mView
    }

    override fun onActivityCreated(savedInstanceState: Bundle?) {
        super.onActivityCreated(savedInstanceState)
        initView()

        fetchQueryShopOrOrgWorkers()
    }

    private fun initView() {
        mLoadWait = LoadWaitDominator(mContext, mView.find(R.id.fl_container_root))
        mReportContentConfirmLl = mView.find<LinearLayout>(R.id.report_content_confirm_ll).apply {
            visibility = View.GONE
        }
        mFarAddHeaderLl = mView.find<LinearLayout>(R.id.far_add_header_ll).apply {
            visibility = View.VISIBLE
        }
        mFarAddHeaderTv = mView.find<TextView>(R.id.far_add_header_tv).apply {
            hint = getString(R.string.employ_ability_by_person_title)
        }
        mStoreNameEt = mView.find<ClearEditText>(R.id.store_name_et).apply {
            hint = getString(R.string.report_module_by_person_search)
            visibility = View.VISIBLE
        }

        mRecyclerContentView = mView.find(R.id.recycler_content_view)
        mEvaluationPersonListAdapter =
            EvaluationPersonListAdapter(mContext, mEvaluationBeanList, this)
        mRecyclerContentView!!.apply {
            layoutManager = LinearLayoutManager(mContext)
            addItemDecoration(
                DividerItemDecoration(
                    DividerItemDecoration.HORIZONTAL_LIST,
                    1,
                    ContextCompat.getColor(mContext, R.color.divider_line)
                )
            )
            adapter = mEvaluationPersonListAdapter
        }
        setListener()
    }

    protected fun setListener() {
        mStoreNameEt?.addTextChangedListener(object : TextWatcher {
            override fun onTextChanged(
                s: CharSequence, start: Int, before: Int,
                count: Int
            ) {
            }

            override fun beforeTextChanged(
                s: CharSequence, start: Int, count: Int,
                after: Int
            ) {
            }

            override fun afterTextChanged(s: Editable) {
                textChanged()
            }
        })
    }

    private fun textChanged() {
        val itemId = mStoreNameEt?.text.toString().trim { it <= ' ' }
        mEvaluationBeanListSearch.clear()
        if (TextUtils.isEmpty(itemId)) {
            mEvaluationBeanListSearch.addAll(
                mEvaluationBeanList
            )
        } else {
            for (bean in mEvaluationBeanList) {
                if (null != bean.workerStaffName) {
                    if (bean.workerStaffName.contains(itemId)) {
                        mEvaluationBeanListSearch.add(bean)
                    }
                }
            }
        }
        mEvaluationPersonListAdapter?.refreshDataList(mEvaluationBeanListSearch)
    }

    private fun fetchQueryShopOrOrgWorkers() {
        if (null != BaseParentFra.userInfo) {
            mLoadWait.show(LoadWaitDominator.LOADING)
            if (mShopId.isNotEmpty()) {
                EvaluationService.instance.requestQueryShopWorkers(
                    mShopId,
                    this
                )
            } else {
                EvaluationService.instance.requestQueryOrgWorkers(
                    BaseParentFra.userInfo.organizationId,
                    this
                )
            }
        }
    }

    override fun onBusinessResultAtMainThread(result: ResultData?) {
        super.onBusinessResultAtMainThread(result)
        mLoadWait.show(LoadWaitDominator.DISMISS)
        if (null != result) {
            val id = result.taskID
            if (id == BusinessID.Evaluation.MSG_ON_QUERY_ORG_WORKERS ||
                id == BusinessID.Evaluation.MSG_ON_QUERY_SHOP_WORKERS
            ) {
                val msg = result.info
                if (result.isSuccessed) {
                    val evaluationResponse = Gson().fromJson(
                        msg,
                        EvaluationResponse::class.java
                    )
                    Log.d(TAG, "evaluationResponse$evaluationResponse")
                    if (ConstantParams.CONSTANT_PARAMS_0 == evaluationResponse.retCode) {
                        if (evaluationResponse?.resultList?.size!! > 0) {
                            mEvaluationBeanList =
                                evaluationResponse.resultList as MutableList<EvaluationBean>
                            mEvaluationPersonListAdapter?.refreshDataList(mEvaluationBeanList)
                        } else {
                            mLoadWait.show(LoadWaitDominator.NO_DATA)
                        }
                    } else {
                        mLoadWait.show(evaluationResponse.retInfo)
                    }
                }
            }
        }
    }

    override fun onPersonAdapterClick(data: EvaluationBean?, postion: Int) {
        val branchUrl = ("/mkt-front/html/reportForms/consultantEvaluation.html?"
                + "staffId=" + data?.workerStaffId
                + "&staffName=" + data?.workerStaffName)
        val intent = Intent(activity, HtmlActivity::class.java)
        intent.putExtra("branchTitle", mBranchTitle)
        intent.putExtra("branchUrl", branchUrl)
        intent.putExtra("isShowClose", true)
        startActivity(intent)
    }

    override fun onBackPressed(): Boolean {
        return false
    }

    override fun onDestroy() {
        super.onDestroy()
        mLoadWait.show(LoadWaitDominator.DISMISS)
    }
}