package com.wgmf.yxgj.module.business.employability.evaluation.ui

import android.content.Context
import android.support.v7.widget.RecyclerView
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import android.widget.LinearLayout
import android.widget.TextView
import com.wgmf.yxgj.module.business.employability.R
import com.wgmf.yxgj.publics.model.ShopDataEntity
import org.jetbrains.anko.find

class EvaluationShopListAdapter(
    private val context: Context,
    private var shopDataBeanList: MutableList<ShopDataEntity> = mutableListOf(),
    private val clickListener: OnEvaluationShopClickListener
) : RecyclerView.Adapter<EvaluationShopListAdapter.EvaluationShopListHolder>() {

    /**
     * 修改列表数据
     * @param newList MutableList
     */
    fun refreshDataList(newList: MutableList<ShopDataEntity>?) {
        if (newList?.isNotEmpty() == true) {
            shopDataBeanList = newList
            notifyDataSetChanged()
        }
    }

    override fun onCreateViewHolder(
        parent: ViewGroup,
        viewType: Int
    ): EvaluationShopListHolder {
        return EvaluationShopListHolder(
            LayoutInflater.from(context)
                .inflate(R.layout.report_module_list_item, parent, false)
        )
    }

    override fun onBindViewHolder(holder: EvaluationShopListHolder, pos: Int) {
        val item = shopDataBeanList[pos]
        holder.apply {
            reportModuleListItemTitle.text = item.storeName
            reportModuleItemStatus.text = setDistanceUint(item.distance)
            reportModuleItemStatus.visibility = View.VISIBLE

            reportModuleListItemLl.setOnClickListener {
                clickListener.onShopAdapterClick(item, pos)
            }
        }
    }

    override fun getItemCount(): Int = shopDataBeanList.size

    /**
     * @param distance 距离单位米
     * @return 大于1千米显示单位为千米，否则单位为米
     */
    private fun setDistanceUint(distance: Double): String {
        return if (distance >= 1000) {
            (distance / 1000).toString() + "千米"
        } else {
            distance.toString() + "米"
        }
    }

    interface OnEvaluationShopClickListener {
        fun onShopAdapterClick(reportShopListEntity: ShopDataEntity?, position: Int)
    }

    class EvaluationShopListHolder(view: View) : RecyclerView.ViewHolder(view) {
        val reportModuleListItemLl: LinearLayout = view.find(R.id.report_module_list_item_ll)
        val reportModuleListItemTitle: TextView = view.find(R.id.report_module_list_item_title)
        val reportModuleListItemNecessary: TextView =
            view.find(R.id.report_module_list_item_necessary)
        val reportModuleItemStatus: TextView = view.find(R.id.report_module_item_status)
    }
}