package com.wgmf.yxgj.module.business.employability.evaluation.ui

import android.annotation.SuppressLint
import android.os.Bundle
import android.support.v4.content.ContextCompat
import android.support.v7.widget.LinearLayoutManager
import android.support.v7.widget.RecyclerView
import android.text.Editable
import android.text.TextUtils
import android.text.TextWatcher
import android.util.Log
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import android.widget.FrameLayout
import android.widget.LinearLayout
import android.widget.TextView
import android.widget.Toast
import com.google.gson.Gson
import com.wgmf.library.base.ResultData
import com.wgmf.library.global.LocationParams
import com.wgmf.library.utils.ToastUtil
import com.wgmf.yxgj.base.BaseBackHandledFragment
import com.wgmf.yxgj.base.BaseParentFra
import com.wgmf.yxgj.config.BusinessID
import com.wgmf.yxgj.dialog.LoadWaitDominator
import com.wgmf.yxgj.global.ConstantParams
import com.wgmf.yxgj.global.NetworkParams
import com.wgmf.yxgj.module.business.employability.R
import com.wgmf.yxgj.publics.model.ShopDataEntity
import com.wgmf.yxgj.publics.model.ShopDataListEntity
import com.wgmf.yxgj.publics.service.PublicService
import com.wgmf.yxgj.widgets.EditText.ClearEditText
import com.wgmf.yxgj.widgets.decoration.DividerItemDecoration
import com.xp.arouter.RouterCommonUtil
import com.xp.arouter.RouterParams
import org.jetbrains.anko.find

@SuppressLint("ValidFragment")
class EvaluationShopListFragment(val evaluationListFragment: EvaluationListFragment) :
    BaseBackHandledFragment(),
    EvaluationShopListAdapter.OnEvaluationShopClickListener {

    private val mBranchTitle: String by lazy {
        arguments?.getString("branchTitle") ?: ""
    }

    private val mBranchID: Long by lazy {
        arguments?.getLong("branchID") ?: 0
    }

    private var mFarAddHeaderTv: TextView? = null
    private var mFarAddHeaderLl: LinearLayout? = null
    private var mReportContentConfirmLl: LinearLayout? = null
    private var mStoreNameEt: ClearEditText? = null
    private var mRecyclerContentView: RecyclerView? = null

    private var mEvaluationShopListAdapter: EvaluationShopListAdapter? = null

    private var mShopDataBeanList: MutableList<ShopDataEntity> = mutableListOf()

    private var mShopDataBeanListSearch: MutableList<ShopDataEntity> = mutableListOf()

    private lateinit var mLoadWait: LoadWaitDominator

    private lateinit var mView: View

    override fun onCreateView(
        inflater: LayoutInflater,
        container: ViewGroup?,
        savedInstanceState: Bundle?
    ): View {
        mView =
            inflater.inflate(R.layout.fragment_news_report_module_project_list, container, false)
                .apply {
                    // 防止点击穿透，底层的fragment响应上层点击触摸事件
                    isClickable = true
                }
        return mView
    }

    override fun onActivityCreated(savedInstanceState: Bundle?) {
        super.onActivityCreated(savedInstanceState)
        initView()
        fetchShopData()
    }

    private fun initView() {
        mLoadWait =
            LoadWaitDominator(mContext, mView.find(R.id.fl_container_root))
        mReportContentConfirmLl = mView.find<LinearLayout>(R.id.report_content_confirm_ll).apply {
            visibility = View.GONE
        }
        mFarAddHeaderLl = mView.find<LinearLayout>(R.id.far_add_header_ll).apply {
            visibility = View.VISIBLE
        }
        mFarAddHeaderTv = mView.find<TextView>(R.id.far_add_header_tv).apply {
            hint = getString(R.string.employ_ability_by_shop_title)
        }
        mStoreNameEt = mView.find<ClearEditText>(R.id.store_name_et).apply {
            hint = getString(R.string.report_module_by_shop_search)
            visibility = View.VISIBLE
        }

        mRecyclerContentView = mView.find(R.id.recycler_content_view)

        mEvaluationShopListAdapter =
            EvaluationShopListAdapter(mContext, mShopDataBeanList, this)
        mRecyclerContentView!!.apply {
            layoutManager = LinearLayoutManager(mContext)
            addItemDecoration(
                DividerItemDecoration(
                    DividerItemDecoration.HORIZONTAL_LIST,
                    1,
                    ContextCompat.getColor(mContext, R.color.divider_line)
                )
            )
            adapter = mEvaluationShopListAdapter
        }
        setListener()
    }

    protected fun setListener() {
        mStoreNameEt?.addTextChangedListener(object : TextWatcher {
            override fun onTextChanged(
                s: CharSequence, start: Int, before: Int,
                count: Int
            ) {
            }

            override fun beforeTextChanged(
                s: CharSequence, start: Int, count: Int,
                after: Int
            ) {
            }

            override fun afterTextChanged(s: Editable) {
                textChanged()
            }
        })
    }

    private fun textChanged() {
        val itemId = mStoreNameEt?.text.toString().trim { it <= ' ' }
        mShopDataBeanListSearch.clear()
        if (TextUtils.isEmpty(itemId)) {
            mShopDataBeanListSearch.addAll(mShopDataBeanList)
        } else {
            for (p in mShopDataBeanList) {
                if (null != p.storeName) {
                    if (p.storeName.contains(itemId)) {
                        mShopDataBeanListSearch.add(p)
                    }
                }
            }
        }
        mEvaluationShopListAdapter?.refreshDataList(mShopDataBeanListSearch)
    }


    /**
     * 经理查询直属门店标识：1表示查询直属；不传表示全部
     */
    private fun fetchShopData() {
        if (null != BaseParentFra.userInfo) {
            if ("4" == BaseParentFra.userInfo.userPostLevel) {
                getNearestShopByZSFlag("", "1")
            } else {
                getNearestShopByZSFlag("", "")
            }
        }
    }

    private fun getNearestShopByZSFlag(keyWords: String, zsShopFlag: String) {
        mLoadWait.show(LoadWaitDominator.LOADING)
        val url = NetworkParams.URL_SHOP_GET_NEAREST
        val orgCode = BaseParentFra.userInfo.organizationCode
        val currentPage = "1"
        val pageSize = "10000"
        val lat = LocationParams.Latitude
        val lng = LocationParams.Longitude

        // 发送管理门店数据请求
        PublicService.getInstance().requestgetNearestShopByZSFlag(
            url,
            zsShopFlag,
            "",
            keyWords,
            orgCode,
            currentPage,
            pageSize,
            lng,
            lat,
            this
        )
    }

    override fun onBusinessResultAtMainThread(result: ResultData?) {
        super.onBusinessResultAtMainThread(result)
        mLoadWait.show(LoadWaitDominator.DISMISS)
        if (null != result) {
            val id = result.taskID
            if (id == BusinessID.Publics.MSG_ON_SHOP_GET_NEAREST) {
                val msg = result.info
                if (result.isSuccessed) {
                    val reportModuleShopResultEntity = Gson().fromJson(
                        msg,
                        ShopDataListEntity::class.java
                    )
                    Log.d(
                        TAG,
                        "reportModuleShopResultEntity$reportModuleShopResultEntity"
                    )
                    if (ConstantParams.CONSTANT_PARAMS_0 == reportModuleShopResultEntity.retCode) {
                        if (reportModuleShopResultEntity?.data?.size!! > 0) {
                            mShopDataBeanList = reportModuleShopResultEntity.data
                            mEvaluationShopListAdapter?.refreshDataList(mShopDataBeanList)
                        } else {
                            mLoadWait.show(LoadWaitDominator.NO_DATA)
                        }
                    } else {
                        mLoadWait.show(reportModuleShopResultEntity.retInfo)
                    }
                }
            }
        }
    }

    override fun onShopAdapterClick(reportShopListEntity: ShopDataEntity?, position: Int) {
        val storeId = reportShopListEntity?.storeId
        if (storeId?.isNotEmpty() == true) {
            val bundle = Bundle().apply {
                putString("branchTitle", mBranchTitle)
                putLong("branchID", mBranchID)
                putString("shopId", storeId)
            }
            RouterCommonUtil.startFunctionActivity(
                mContext,
                RouterParams.URL_EVALUATION_LIST_ACTIVITY,
                bundle
            )
        } else {
            ToastUtil.show(mContext, "门店数据为空!")
        }
    }

    override fun onBackPressed(): Boolean {
        return false
    }

    override fun onDestroy() {
        super.onDestroy()
        mLoadWait.show(LoadWaitDominator.DISMISS)
    }
}