package com.wgmf.yxgj.module.business.employability.newworkertrain.service;

import android.text.TextUtils;
import android.util.Log;

import com.google.gson.Gson;
import com.wgmf.library.base.BaseRequest;
import com.wgmf.library.base.BaseResponse;
import com.wgmf.library.base.ResultData;
import com.wgmf.library.utils.BaseSingleton;
import com.wgmf.yxgj.base.BaseService;
import com.wgmf.yxgj.config.BusinessID;
import com.wgmf.yxgj.global.NetworkParams;

import java.lang.ref.WeakReference;

public class NewWorkerTrainService extends BaseService {
    private static BaseSingleton<NewWorkerTrainService, Void> mMainService = new BaseSingleton<NewWorkerTrainService, Void>() {
        @Override
        protected NewWorkerTrainService create(Void var1) {
            return new NewWorkerTrainService();
        }
    };

    public static NewWorkerTrainService getInstance() {
        return mMainService.get(null);
    }

    private NewWorkerTrainService() {
    }

    /**
     * get /newWorkerTrain/queryWorkerTrainMain 入职培训导师分配顾问信息
     * trainStaffId 登录人工号 query 	string
     * saleOrgId 销售组织Id query 	long
     * code1 code1 query 	string
     * userPostLevel 岗位级别：1/总部人员，3/总监，4/经理 ，5/主管,100/无职位query
     */
    public void requestQueryWorkerTrainMain(final String trainStaffId, final String saleOrgId, final String code1, final String userPostLevel, ResultData.BusinessCallback callback) {
        BaseRequest request = new BaseRequest();
        request.taskID = BusinessID.EmployAbility.MSG_ON_QUERY_WORKER_TRAIN_MAIN;
        request.callback = new WeakReference<>(callback);
        request.url = NetworkParams.URL_SAVE_QUERY_WORKER_TRAIN_MAIN + "?" + "trainStaffId=" + trainStaffId + "&saleOrgId=" + saleOrgId + "&code1=" + code1 + "&userPostLevel=" + userPostLevel;
        Log.d(TAG, "请求地址：" + request.url);
        sendGetRequest(request);
    }

    /**
     * get /newWorkerTrain/queryWorkerTrainInfo 查询顾问培训记录及培训项目
     * ids 顾问培训记录id query 	long
     * trainStartTime 培训开始时间格式yyyy-MM-dd query 	string
     */
    public void requestQueryWorkerTrainInfo(final String params, ResultData.BusinessCallback callback) {
        BaseRequest request = new BaseRequest();
        request.taskID = BusinessID.EmployAbility.MSG_ON_QUERY_WORKER_TRAIN_INFO;
        request.callback = new WeakReference<>(callback);
        request.url = NetworkParams.URL_QUERY_WORKER_TRAIN_INFO_NEW + "?" + params;
        Log.d(TAG, "请求地址：" + request.url);
        sendGetRequest(request);
    }
    /**
     * get /newWorkerTrain/queryWorkerTrainInfoList 查询顾问评估-营销管家
     * ids 顾问培训记录id query 	long
     */
    public void requestQueryWorkerTrainInfoList(final String params, ResultData.BusinessCallback callback) {
        BaseRequest request = new BaseRequest();
        request.taskID = BusinessID.EmployAbility.MSG_ON_QUERY_WORKER_TRAIN_INFO_LIST;
        request.callback = new WeakReference<>(callback);
        request.url = NetworkParams.URL_QUERY_WORKER_TRAIN_INFO_LIST + "?" + params;
        Log.d(TAG, "请求地址：" + request.url);
        sendGetRequest(request);
    }

    /**
     * get /newWorkerTrain/queryNotEvaluatedUser 入职未评估用户信息
     * trainStaffId 登录人工号 query 	string
     */
    public void requestQueryNotEvaluatedUser(final String trainStaffId, ResultData.BusinessCallback callback) {
        BaseRequest request = new BaseRequest();
        request.taskID = BusinessID.EmployAbility.MSG_ON_QUERY_NOT_EVALUATED_USER;
        request.callback = new WeakReference<>(callback);
        request.url = NetworkParams.URL_SAVE_QUERY_NOT_EVALUATED_USER + "?" + "trainStaffId=" + trainStaffId;
        Log.d(TAG, "请求地址：" + request.url);
        sendGetRequest(request);
    }

    /**
     * get /newWorkerTrain/queryWorkerTrainContent 查询顾问培训内容
     */
    public void requestQueryWorkerTrainContent(ResultData.BusinessCallback callback) {
        BaseRequest request = new BaseRequest();
        request.taskID = BusinessID.EmployAbility.MSG_ON_QUERY_WORKER_TRAIN_CONTENT;
        request.callback = new WeakReference<>(callback);
        request.url = NetworkParams.URL_QUERY_WORKER_TRAIN_CONTENT;
        Log.d(TAG, "请求地址：" + request.url);
        sendGetRequest(request);
    }

    /**
     * post /newWorkerTrain/saveWorkerTrainBean 新增或修改顾问培训记录
     */
    public void requestSaveWorkerTrainBean(final String json, ResultData.BusinessCallback callback) {
        BaseRequest request = new BaseRequest();
        request.taskID = BusinessID.EmployAbility.MSG_ON_SAVE_WORKER_TRAIN_BEAN;
        request.callback = new WeakReference<>(callback);
        request.url = NetworkParams.URL_SAVE_WORKER_TRAIN_BEAN;
        request.json = json;
        Log.d(TAG, "请求地址：" + request.url);
        sendPostJsonRequest(request);
    }

    /**
     * post /newWorkerTrain/saveWorkerTrainEvaluation 顾问评估
     */
    public void requestSaveWorkerTrainEvaluation(final String json, ResultData.BusinessCallback callback) {
        BaseRequest request = new BaseRequest();
        request.taskID = BusinessID.EmployAbility.MSG_ON_SAVE_WORKER_TRAIN_EVALUATION;
        request.callback = new WeakReference<>(callback);
        request.url = NetworkParams.URL_SAVE_WORKER_TRAIN_EVALUATION;
        request.json = json;
        Log.d(TAG, "请求地址：" + request.url);
        sendPostJsonRequest(request);
    }

    @Override
    protected void onTaskDone(ResultData data) {
        if (null != data) {
            final int id = data.taskID;
            switch (id) {
                case BusinessID.EmployAbility.MSG_ON_QUERY_WORKER_TRAIN_MAIN:
                case BusinessID.EmployAbility.MSG_ON_QUERY_WORKER_TRAIN_INFO:
                case BusinessID.EmployAbility.MSG_ON_QUERY_WORKER_TRAIN_INFO_LIST:
                case BusinessID.EmployAbility.MSG_ON_QUERY_NOT_EVALUATED_USER:
                case BusinessID.EmployAbility.MSG_ON_QUERY_WORKER_TRAIN_CONTENT:
                case BusinessID.EmployAbility.MSG_ON_SAVE_WORKER_TRAIN_BEAN:
                case BusinessID.EmployAbility.MSG_ON_SAVE_WORKER_TRAIN_EVALUATION: {
                    if (data.isSuccessed()) {
                        final String json = data.getInfo();
                        if (!TextUtils.isEmpty(json)) {
                            BaseResponse mBaseResponse = new Gson().fromJson(json, BaseResponse.class);
                            Log.d(TAG, "id:" + id + ";mBaseResponse=" + mBaseResponse.toString());
                            data.setResultCode(mBaseResponse.retCode);
                            data.setResultInfo(mBaseResponse.retInfo);
                        }
                    }
                    break;
                }
                default:
                    break;
            }
        }
    }
}