package com.wgmf.yxgj.module.business.employability.newworkertrain.service.util;

import org.apache.log4j.LogManager;
import org.apache.log4j.Logger;

import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Calendar;
import java.util.Date;
import java.util.GregorianCalendar;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.xml.datatype.DatatypeConfigurationException;
import javax.xml.datatype.DatatypeFactory;
import javax.xml.datatype.XMLGregorianCalendar;

/**
 * <p>
 * 根据SimpleDateFormat 来处理日期
 * </p>
 * 
 * @author longpingping
 *
 */
public class DateUtil {

	private static final Logger LOG = LogManager.getLogger(DateUtil.class);

	private static final String LOG_ERROR_INFO = "error info ";

	private DateUtil() {

	}

	/**
	 * <p>
	 * yyyy-MM 转换成 yyyyMM
	 * </p>
	 * 
	 * @param d
	 * @return
	 */
	public static String dateFormat(String d) {
		SimpleDateFormat df = new SimpleDateFormat(
				Constants.DATE_FORMAT_YYYY_MM);
		SimpleDateFormat todf = new SimpleDateFormat(
				Constants.DATE_FORMAT_YYYYMM);
		Date date = null;
		try {
			date = df.parse(d);
		} catch (Exception e) {
//			throw new SystemException(e);
		}
		Calendar c = Calendar.getInstance();
		c.setTime(date);
		return todf.format(date);
	}

	/**
	 * <p>
	 * yyyy-MM-dd 转换成 yyyyMMdd
	 * </p>
	 * 
	 * @param d
	 * @return
	 */
	public static String dateYearMonthDayFormat(String d) {
		SimpleDateFormat df = new SimpleDateFormat(
				Constants.DATE_FORMAT_YYYY_MM_DD);
		SimpleDateFormat todf = new SimpleDateFormat(
				Constants.DATE_FORMAT_YYYYMMDD);
		Date date = null;
		try {
			date = df.parse(d);
		} catch (Exception e) {
//			throw new SystemException(e);
		}
		Calendar c = Calendar.getInstance();
		c.setTime(date);
		return todf.format(date);
	}

	/**
	 * 时间字符串格式转换
	 * 
	 * 例子：yyyyMM 201803 转换 MM/yyyy 03/2018
	 * 
	 * @param dateTime
	 * @param inputDateFormat
	 * @param dateFormat
	 * @return
	 */
	public static String strDatetimeToFormat(String dateTime,
			String inputDateFormat, String dateFormat) {
		SimpleDateFormat inputdf = new SimpleDateFormat(inputDateFormat);
		SimpleDateFormat df = new SimpleDateFormat(dateFormat);
		Date date = null;
		try {
			date = inputdf.parse(dateTime);
		} catch (Exception e) {
//			throw new SystemException(e);
		}
		Calendar c = Calendar.getInstance();
		c.setTime(date);
		return df.format(date);
	}

	/**
	 * 增加一个月
	 * 
	 * @param d
	 * @return
	 */
	public static String addOneMonth(String d) {

		SimpleDateFormat df = new SimpleDateFormat(Constants.DATE_FORMAT_YYYYMM);
		Date date = null;
		try {
			date = df.parse(d);
		} catch (Exception e) {
//			throw new SystemException(e);
		}
		Calendar c = Calendar.getInstance();
		c.setTime(date);
		int day = c.get(Calendar.MONTH);
		c.set(Calendar.MONTH, day + 1);
		return df.format(c.getTime());

	}

	/**
	 * 增加或者减少月份
	 * 
	 * @param dateTime
	 *            时间
	 * @param dateType
	 *            要转的类型
	 * @param num
	 *            增加或者减少的天数
	 * @return
	 */
	public static String addOrDelMonth(String dateTime, String dateType, int num) {
		SimpleDateFormat df = new SimpleDateFormat(dateType);
		Date date = null;
		try {
			date = df.parse(dateTime);
		} catch (Exception e) {
//			throw new SystemException(e);
		}
		Calendar c = Calendar.getInstance();
		c.setTime(date);
		int day = c.get(Calendar.MONTH);
		c.set(Calendar.MONTH, day + num);
		return df.format(c.getTime());
	}

	/**
	 * 增加或减少年份
	 * 
	 * @param dateTime
	 *            时间
	 * @param dateType
	 *            时间格式
	 * @param num
	 *            增加或减少的年数
	 * @return
	 */
	public static String addOrDelYear(String dateTime, String dateType, int num) {
		SimpleDateFormat df = new SimpleDateFormat(dateType);
		Date date = null;
		try {
			date = df.parse(dateTime);
		} catch (Exception e) {
//			throw new SystemException(e);
		}
		Calendar c = Calendar.getInstance();
		c.setTime(date);
		int day = c.get(Calendar.YEAR);
		c.set(Calendar.YEAR, day + num);
		return df.format(c.getTime());
	}

	/**
	 * 增加月份
	 * 
	 * @param d
	 *            传入的时间
	 * @param monthNum
	 *            多少个月
	 * @return
	 */
	public static String addMonth(String d, int monthNum) {

		SimpleDateFormat df = new SimpleDateFormat(
				Constants.DATE_FORMAT_YYYY_MM_DD);
		Date date = null;
		try {
			date = df.parse(d);
		} catch (Exception e) {
//			throw new SystemException(e);
		}
		Calendar c = Calendar.getInstance();
		c.setTime(date);
		int day = c.get(Calendar.MONTH);
		c.set(Calendar.MONTH, day + monthNum);
		return df.format(c.getTime());

	}

	/**
	 * 增加月份
	 * 
	 * @param dateTime
	 * @param index
	 * @return
	 */
	public static Date addOrDelMonthToDate(Date dateTime, int index) {
		Calendar c = Calendar.getInstance();
		c.setTime(dateTime);
		int day = c.get(Calendar.MONTH);
		c.set(Calendar.MONTH, day + index);
		return c.getTime();

	}

	/**
	 * 获取上个月1号
	 * 
	 * @return
	 */
	public static Date getLastMonthFirstDay() {
		Date date = new Date();
		Calendar cal = Calendar.getInstance();
		cal.setTime(date);
		cal.add(Calendar.MONTH, -1);
		cal.set(Calendar.DAY_OF_MONTH,
				cal.getActualMinimum(Calendar.DAY_OF_MONTH));
		return cal.getTime();
	}

	/**
	 * 获取上个月1号不带时分秒的
	 * 
	 * @return
	 */
	public static Date getLastMonthFirstDay2() {
		SimpleDateFormat df = new SimpleDateFormat(
				Constants.DATE_FORMAT_YYYY_MM_DD);
		Date date = new Date();
		Calendar cal = Calendar.getInstance();
		cal.setTime(date);
		cal.add(Calendar.MONTH, -1);
		cal.set(Calendar.DAY_OF_MONTH,
				cal.getActualMinimum(Calendar.DAY_OF_MONTH));
		String strTime = df.format(cal.getTime());
		Date date2 = null;
		try {
			date2 = df.parse(strTime);
		} catch (Exception e) {
			LOG.error(LOG_ERROR_INFO + " " + e.getMessage(), e);
//			throw new SystemException(e);
		}
		return date2;
	}

	/**
	 * 减多少天
	 * 
	 * @param dayNum
	 * @return
	 */
	public static Date delTime(int dayNum) {
		Calendar c = Calendar.getInstance();
		c.setTime(new Date());
		int day = c.get(Calendar.DATE);
		c.set(Calendar.DATE, day - dayNum);
		return c.getTime();

	}

	/**
	 * 获取当前月的第一天
	 * 
	 * @return
	 */
	public static String getThisMonthFirstDay() {
		SimpleDateFormat sdf = new SimpleDateFormat(
				Constants.DATE_FORMAT_YYYY_MM_DD);
		Calendar caldar = Calendar.getInstance();
		caldar.add(Calendar.MONTH, 0);
		caldar.set(Calendar.DAY_OF_MONTH, 1);
		return sdf.format(caldar.getTime());
	}

	/**
	 * 获取当前月的第几天
	 * 
	 * @return
	 */
	public static String getThisMonthDay(int n) {
		SimpleDateFormat sdf = new SimpleDateFormat(
				Constants.DATE_FORMAT_YYYY_MM_DD);
		Calendar caldar = Calendar.getInstance();
		caldar.add(Calendar.MONTH, 0);
		caldar.set(Calendar.DAY_OF_MONTH, n);
		return sdf.format(caldar.getTime());
	}

	/**
	 * 取得当前时间（格式为：yyyy-MM-dd）
	 * 
	 * @return String
	 */
	public static String getDateBy8bit() {
		SimpleDateFormat sdf = createSimpleDateFormat(Constants.DATE_FORMAT_YYYY_MM_DD);
		return sdf.format(new Date());
	}

	/**
	 * @return
	 */
	public static String getDate() {
		SimpleDateFormat sdf = createSimpleDateFormat(Constants.DATE_FORMAT_YYYY_MM_DD_HHMMSS);
		return sdf.format(new Date());
	}

	/**
	 * 获取当前时间
	 * 
	 * @param type
	 *            时间格式
	 * @return
	 */
	public static String getDateByType(String type) {
		SimpleDateFormat sdf = createSimpleDateFormat(type);
		return sdf.format(new Date());
	}

	/**
	 * 获取当前日期
	 * 
	 * @return
	 */
	public static Date getDate2() {
		SimpleDateFormat sdf = createSimpleDateFormat(Constants.DATE_FORMAT_YYYY_MM_DD_HHMMSS);
		Date date = new Date();
		String sDate = sdf.format(new Date());
		try {
			date = sdf.parse(sDate);
		} catch (ParseException e) {
			LOG.error(LOG_ERROR_INFO + " " + e.getMessage(), e);
		}
		return date;
	}

	/**
	 * 获取当前日期
	 * 
	 * @param time
	 * @return
	 */
	public static Date getDate3(String time) {
		SimpleDateFormat format = createSimpleDateFormat(Constants.DATE_FORMAT_YYYY_MM_DD);
		Date date = null;
		try {
			date = format.parse(time);

		} catch (Exception e) {
			LOG.error(LOG_ERROR_INFO + " " + e.getMessage(), e);
//			throw new SystemException(e);
		}

		return date;
	}

	/**
	 * 获取日期 Date 格式yyyy-MM-dd
	 * 
	 * @return
	 */
	public static Date getDateFormat() {
		SimpleDateFormat sdf = createSimpleDateFormat(Constants.DATE_FORMAT_YYYY_MM_DD);
		Date date = new Date();
		String sDate = sdf.format(new Date());
		try {
			date = sdf.parse(sDate);
		} catch (ParseException e) {
			LOG.error(LOG_ERROR_INFO + " " + e.getMessage(), e);
		}
		return date;
	}

	/**
	 * 不带时分秒
	 * 
	 * @return
	 */
	public static Date getDateFormat2() {
		SimpleDateFormat sdf = createSimpleDateFormat(Constants.DATE_FORMAT_YYYY_MM_DD);
		Date date = new Date();
		Calendar cal = Calendar.getInstance();
		cal.setTime(date);
		String strTime = sdf.format(cal.getTime());
		Date date2 = null;
		try {
			date2 = sdf.parse(strTime);
		} catch (ParseException e) {
			LOG.error(LOG_ERROR_INFO + " " + e.getMessage(), e);
		}
		return date2;
	}

	/**
	 * 根据毫秒值获取日期格式 yyyy-MM-dd
	 * 
	 * @param mesc
	 */
	public static String getDateStringFromMesc(long mesc) {

		SimpleDateFormat format = createSimpleDateFormat(Constants.DATE_FORMAT_YYYY_MM_DD);

		Calendar calendar = Calendar.getInstance();
		calendar.setTimeInMillis(mesc);
		return format.format(calendar.getTime());
	}

	/**
	 * 传入一个yyyy-MM-dd-HH-mm-ss的时间字符串， 返回日期
	 * 
	 * @param time
	 * @return
	 */
	public static Date getDateFromYYYYMMDDHHMMSS(String time) {

		SimpleDateFormat format = createSimpleDateFormat(Constants.DATE_FORMAT_YYYY_MM_DD_HHMMSS);

		Date date = null;

		try {
			date = format.parse(time);

		} catch (Exception e) {
			LOG.error(LOG_ERROR_INFO + " " + e.getMessage(), e);
//			throw new SystemException(e);
		}

		return date;
	}

	/**
	 * 传入一个Date返回一个要转的格式
	 * 
	 * @param date
	 * @return
	 */
	public static String getTimeStrFromDate(Date date, String dateFormat) {

		SimpleDateFormat format = createSimpleDateFormat(dateFormat);
		return format.format(date);
	}

	/**
	 * /** 传入一个Date返回一个yyyy-MM-dd-HH-mm-ss-SSS
	 * 
	 * @param date
	 * @return
	 */
	public static String getTimeStrFromDateToMesc(Date date) {

		SimpleDateFormat format = createSimpleDateFormat("yyyy-MM-dd-HH-mm-ss-SSS");
		return format.format(date);
	}

	/**
	 * 根据yyyy-MM-dd获取Date对象
	 * 
	 * @param dayStr
	 * @return
	 * @throws ParseException
	 */
	public static Date getDateFromStr(String dayStr, String dateFormType) {

		SimpleDateFormat format = createSimpleDateFormat(dateFormType);
		Date returnStr = null;
		try {
			returnStr = format.parse(dayStr);
		} catch (Exception e) {
//			throw new SystemException(e);
		}

		return returnStr;
	}

	/**
	 * 按照格式输出日期
	 * 
	 * @param dayStr
	 * @return
	 */
	public static Date getDateFromyyyyMMdd(String dayStr) {

		Date date = null;
		try {
			date = getDateFromStr(dayStr, Constants.DATE_FORMAT_YYYY_MM_DD);
		} catch (Exception e) {
			LOG.error(LOG_ERROR_INFO + " " + e.getMessage(), e);
//			throw new SystemException(e);
		}

		return date;
	}

	/**
	 * 根据date类型返回它的一个时间毫秒值
	 * 
	 * @param date
	 * @return
	 */
	public static long getTimeStampFromDate(Date date) {

		return date.getTime();
	}

	/**
	 * 返回月份字符串，yyyy-MM
	 * 
	 * @param date
	 *            日期对象
	 * @return
	 */
	public static String getYearMonthFromDate(Date date) {

		SimpleDateFormat sdf = createSimpleDateFormat("yyyy-MM");
		return sdf.format(date);
	}

	/**
	 * 根据年月，获取这个月的最大天数
	 * 
	 * @param year
	 *            年份
	 * @param month
	 *            月份
	 * @return
	 */
	public static int getMaxDayByYearMonth(int year, int month) {
		int maxDay;
		int day = 1;
		/**
		 * 与其他语言环境敏感类一样，Calendar 提供了一个类方法 getInstance， 以获得此类型的一个通用的对象。Calendar 的
		 * getInstance 方法返回一 个 Calendar 对象，其日历字段已由当前日期和时间初始化：
		 */
		Calendar calendar = Calendar.getInstance();
		/**
		 * 实例化日历各个字段,这里的day为实例化使用
		 */
		calendar.set(year, month - 1, day);
		/**
		 * Calendar.Date:表示一个月中的某天 calendar.getActualMaximum(int
		 * field):返回指定日历字段可能拥有的最大值
		 */
		maxDay = calendar.getActualMaximum(Calendar.DATE);
		return maxDay;
	}

	/**
	 * 传入Date返回一个 yyyy-MM-dd
	 * 
	 * @param date
	 * @return
	 */
	public static String getStringyyyyMMdd(Date date) {

		if (date == null) {
			return "";
		}
		SimpleDateFormat sdf = createSimpleDateFormat(Constants.DATE_FORMAT_YYYY_MM_DD);

		return sdf.format(date);
	}

	/**
	 * 对日期进行增减天数
	 * 
	 * @param d
	 *            YYYY-mm-dd日期字符串
	 * @param type
	 *            z:增加 j:减少
	 * @param dayNum
	 *            增减的天数
	 * @return
	 */
	public static String addOrDelTime(String formatStyle, String d,
			String type, int dayNum) {

		SimpleDateFormat df = createSimpleDateFormat(formatStyle);
		Date date = null;
		try {
			date = df.parse(d);
		} catch (Exception e) {
//			throw new SystemException(e);
		}
		Calendar c = Calendar.getInstance();
		c.setTime(date);
		int day = c.get(Calendar.DATE);

		if ("z".equals(type)) {

			c.set(Calendar.DATE, day + dayNum);

		} else if ("j".equals(type)) {

			c.set(Calendar.DATE, day - dayNum);
		}

		return df.format(c.getTime());

	}

	/**
	 * 获得昨天日期
	 *
	 *            20130330
	 * @return
	 */
	public static String getyessDate() {
		Calendar c = Calendar.getInstance();
		c.setTime(new Date());
		int day = c.get(Calendar.DATE);
		c.set(Calendar.DATE, day - 1);
		return new SimpleDateFormat(Constants.YEAR_MONTH_DAY_YYYY_MM_DD)
				.format(c.getTime());
	}

	/**
	 * 获取当前年月
	 * 
	 * @return
	 */
	public static String getYearMonth() {
		SimpleDateFormat sdf = new SimpleDateFormat("yyyyMM");
		return sdf.format(new Date());
	}

	/**
	 * 获取当前年月
	 * 
	 * @return
	 */
	public static String getYearMonth2() {
		SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM");
		return sdf.format(new Date());
	}

	/**
	 * 获取当前时间的上个月
	 * 
	 * @return
	 */
	public static String getLastMonth() {
		SimpleDateFormat sdf = new SimpleDateFormat("yyyyMM");
		Calendar c = Calendar.getInstance();
		c.setTime(new Date());
		int day = c.get(Calendar.MONTH);
		c.set(Calendar.MONTH, day - 1);
		return sdf.format(c.getTime());
	}

	/**
	 * 获取当前年
	 * 
	 * @return
	 */
	public static String getYear() {
		SimpleDateFormat sdf = new SimpleDateFormat("yyyy");
		return sdf.format(new Date());
	}

	/**
	 * 格式处理
	 * 
	 * @param format
	 * @return
	 */
	public static SimpleDateFormat createSimpleDateFormat(String format) {
		return new SimpleDateFormat(format);
	}

	/**
	 * 根据时间获取时间是在周几
	 * 
	 * @param d
	 *            d是时间
	 * @return
	 */
	public static int getWeekOfDate(String d) {
		SimpleDateFormat sdf = createSimpleDateFormat(Constants.DATE_FORMAT_YYYY_MM_DD);
		Date dt = null;
		try {
			dt = sdf.parse(d);
		} catch (Exception e) {
//			throw new SystemException(e);
		}
		int[] weekDays = { Constants.NUM_SENVEN, Constants.NUM_ONE,
				Constants.NUM_TWO, Constants.NUM_THREE, Constants.NUM_FOUR,
				Constants.NUM_FIVE, Constants.NUM_SIX };
		Calendar cal = Calendar.getInstance();
		cal.setTime(dt);
		int w = cal.get(Calendar.DAY_OF_WEEK) - 1;
		return weekDays[w];
	}

	/**
	 * 根据周几加天数得周几
	 * 
	 * @param weekDay
	 *            周几
	 * @param num
	 *            要加的天数
	 * @return
	 */
	public static int getWeekOfAddDays(int weekDay, int num) {
		int numMod = num % Constants.NUM_SENVEN;
		if (numMod == Constants.NUM_ZERO) {
			return weekDay;
		} else {
			return getWeekDayCommon(weekDay, numMod);
		}
	}

	/**
	 * 周加天
	 * 
	 * @param weekDay
	 * @param num
	 * @return
	 */
	public static int getWeekDayCommon(int weekDay, int num) {
		boolean conditionFirst;
		boolean conditionSecond;
		int conditonFirstValue;
		int conditonSecondValue;
		int conditonThirdValue;
		if (Constants.NUM_FIVE == num) {
			conditionFirst = Constants.NUM_TWO == weekDay;
			conditionSecond = Constants.NUM_ONE == weekDay;
			conditonFirstValue = Constants.NUM_SENVEN;
			conditonSecondValue = Constants.NUM_SIX;
			conditonThirdValue = weekDay - Constants.NUM_TWO;
		} else if (Constants.NUM_FOUR == num) {
			conditionFirst = Constants.NUM_THREE == weekDay;
			conditionSecond = Constants.NUM_TWO == weekDay;
			conditonFirstValue = Constants.NUM_SENVEN;
			conditonSecondValue = Constants.NUM_SIX;
			conditonThirdValue = weekDay - Constants.NUM_THREE;
		} else if (Constants.NUM_SIX == num) {
			conditionFirst = Constants.NUM_ONE == weekDay;
			conditionSecond = true;
			conditonFirstValue = Constants.NUM_SENVEN;
			conditonSecondValue = weekDay - Constants.NUM_ONE;
			conditonThirdValue = conditonSecondValue;
		} else if (Constants.NUM_TWO == num) {
			conditionFirst = Constants.NUM_SIX == weekDay;
			conditionSecond = Constants.NUM_SENVEN == weekDay;
			conditonFirstValue = Constants.NUM_ONE;
			conditonSecondValue = Constants.NUM_TWO;
			conditonThirdValue = weekDay + Constants.NUM_TWO;
		} else if (Constants.NUM_THREE == num) {
			conditionFirst = Constants.NUM_FIVE == weekDay;
			conditionSecond = Constants.NUM_SIX == weekDay;
			conditonFirstValue = Constants.NUM_ONE;
			conditonSecondValue = Constants.NUM_TWO;
			conditonThirdValue = getWeekDayCommon2(weekDay);
		} else {
			conditionFirst = Constants.NUM_SENVEN == weekDay;
			conditionSecond = true;
			conditonFirstValue = Constants.NUM_ONE;
			conditonSecondValue = weekDay + Constants.NUM_ONE;
			conditonThirdValue = conditonSecondValue;
		}
		return conditionFirst ? conditonFirstValue
				: conditionSecond ? conditonSecondValue : conditonThirdValue;
	}

	/**
	 * 周处理
	 * 
	 * @param weekDay
	 * @return
	 */
	public static int getWeekDayCommon2(int weekDay) {
		int weekDay2 = Constants.NUM_THREE;
		if (Constants.NUM_SENVEN != weekDay) {
			weekDay2 = weekDay2 + weekDay;
		}
		return weekDay2;
	}

	/**
	 * 获取小时
	 * 
	 * @param date
	 * @return
	 */
	public static int getHoursByStirngDate(Date date) {
		SimpleDateFormat sdf = new SimpleDateFormat(
				Constants.DATE_FORMAT_YYYY_MM_DD_HHMMSS);
		String dateFormat = sdf.format(date);
		return Integer.parseInt(dateFormat.substring(Constants.NUM_ELEVEN,
				Constants.NUM_THIRTEEN));
	}

	/**
	 * 把时间格式 yyyy-MM-dd'T'HH:mm:ss
	 * 
	 * 转换成 传入的格式
	 * 
	 * @param date
	 *            传入的时间
	 * @param dateFormat
	 *            要转换的时间格式
	 * @return
	 */
	public static String doTimeSimplet(String date, String dateFormat) {
		SimpleDateFormat format = new SimpleDateFormat("yyyy-MM-dd'T'HH:mm:ss");// 注意格式化的表达式
		SimpleDateFormat sdf = new SimpleDateFormat(dateFormat);
		Date d = null;
		try {
			d = format.parse(date);

		} catch (Exception e) {
			LOG.error(LOG_ERROR_INFO + " " + e.getMessage(), e);
//			throw new SystemException(e);
		}
		return sdf.format(d);
	}

	/**
	 * 获取前当前和前三个月及去年同期的月份/时间
	 * 
	 * @return
	 */
	public static Map<String, Object> getMonths(String dateType) {
		List<String> yearMonthList = new ArrayList<>();
		Map<String, Object> map = new HashMap<>();
		String thisMonth = DateUtil.getDateByType(dateType);
		String firstMonth = DateUtil.addOrDelMonth(thisMonth, dateType,
				-Constants.NUM_ONE);
		String secondMonth = DateUtil.addOrDelMonth(thisMonth, dateType,
				-Constants.NUM_TWO);
		String thirdMonth = DateUtil.addOrDelMonth(thisMonth, dateType,
				-Constants.NUM_THREE);
		String forthMonth = DateUtil.addOrDelMonth(thisMonth, dateType,
				-Constants.NUM_FOUR);
		String lastSameMonth = DateUtil.addOrDelMonth(thisMonth, dateType,
				-Constants.NUM_TWELEV);
		yearMonthList.add(thisMonth);
		yearMonthList.add(firstMonth);
		yearMonthList.add(secondMonth);
		yearMonthList.add(thirdMonth);
		yearMonthList.add(forthMonth);
		yearMonthList.add(lastSameMonth);
		map.put(Constants.ALL_LIST_MONTH, yearMonthList);
		return map;
	}

	/**
	 * 1月份到当前年月的集合
	 * 
	 * @param yearMonth
	 * @param yearMonthList
	 */
	public static void getSearachYearMonthList(String yearMonth,
			List<String> yearMonthList) {
		// 要查询的月份
		String chearchMonth = yearMonth.substring(4, 6);
		// 查询年
		String chearchYear = yearMonth.substring(0, 4);
		int month = Integer.parseInt(chearchMonth);
		for (int i = 1; i <= month; i++) {
			String yearMonth2 = chearchYear + numDataToMonthData(i);
			yearMonthList.add(yearMonth2);
		}

	}

	/**
	 * 把数字转换成两位数的月份
	 * 
	 * @param i
	 * @return
	 */
	public static String numDataToMonthData(int i) {
		String month;
		if (i < Constants.NUM_TEN) {
			month = Constants.ZERO + String.valueOf(i);
		} else {
			month = String.valueOf(i);
		}
		return month;
	}

	/**
	 * 当前时间周五
	 * 
	 * @return
	 */
	public static String getCurrentFriday() {
		Calendar c = Calendar.getInstance();
		c.set(Calendar.DAY_OF_WEEK, Constants.NUM_SIX);
		Date date = c.getTime();
		return new SimpleDateFormat(Constants.DATE_FORMAT_YYYY_MM_DD)
				.format(date);
	}

	/**
	 * 当前时间上周六
	 * 
	 * @return
	 */
	public static String getCurrentSaturday() {
		Calendar c = Calendar.getInstance();
		c.set(Calendar.DAY_OF_WEEK, Constants.NUM_SENVEN);
		Date date = c.getTime();
		return DateUtil
				.addOrDelTime(Constants.DATE_FORMAT_YYYY_MM_DD,
						new SimpleDateFormat(Constants.DATE_FORMAT_YYYY_MM_DD)
								.format(date), Constants.DEL_TIME,
						Constants.NUM_SENVEN);
	}

	/**
	 * 当前时间月份的第一天
	 * 
	 * @return
	 */
	public static String getMonthFirstDay() {
		SimpleDateFormat format = new SimpleDateFormat(
				Constants.DATE_FORMAT_YYYY_MM_DD);
		Calendar calendar = Calendar.getInstance();
		calendar.set(Calendar.DAY_OF_MONTH,
				calendar.getActualMinimum(Calendar.DAY_OF_MONTH));
		return format.format(calendar.getTime());
	}

	/**
	 * 当前月的最后一天
	 * 
	 * @return
	 */
	public static String getMonthLastDay() {
		SimpleDateFormat format = new SimpleDateFormat(
				Constants.DATE_FORMAT_YYYY_MM_DD);
		Calendar calendar = Calendar.getInstance();
		calendar.set(Calendar.DAY_OF_MONTH,
				calendar.getActualMaximum(Calendar.DAY_OF_MONTH));
		return format.format(calendar.getTime());
	}

	/**
	 * 传入一个时间与当前系统时间的时间差(秒数)
	 * 
	 * @param date
	 * @return
	 * @throws ParseException
	 */
	public static long getSeconds(Date date) throws ParseException {
		SimpleDateFormat simpleFormat = new SimpleDateFormat(
				Constants.DATE_FORMAT_YYYY_MM_DD_HHMMSS);
		String fromDate = simpleFormat.format(date);
		String newDate = simpleFormat.format(new Date());
		long from = simpleFormat.parse(fromDate).getTime();
		long to = simpleFormat.parse(newDate).getTime();
		return (to - from) / 1000;
	}

	/**
	 * 根据系统时间获取ymd
	 * 
	 * @return
	 */
	public static String getYmd() {
		SimpleDateFormat simpleFormat = new SimpleDateFormat(
				Constants.DATE_FORMAT_YYYYMMDD);
		return simpleFormat.format(new Date());
	}

	/**
	 * 根据系统时间获取ym
	 * 
	 * @return
	 */
	public static String getYm() {
		SimpleDateFormat simpleFormat = new SimpleDateFormat(
				Constants.DATE_FORMAT_YYYYMM);
		return simpleFormat.format(new Date());
	}

	/**
	 * 获取未来 第 past 天的日期
	 * 
	 * @param past
	 * @return
	 */
	public static List<String> getFetureDate(int past) {
		List<String> list = new ArrayList<>();
		for (int i = 0; i < past; i++) {
			Calendar calendar = Calendar.getInstance();
			calendar.set(Calendar.DAY_OF_YEAR,
					calendar.get(Calendar.DAY_OF_YEAR) + i);
			Date today = calendar.getTime();
			SimpleDateFormat format = new SimpleDateFormat("yyyy-MM-dd");
			String result = format.format(today);
			list.add(result);
		}

		return list;
	}

	/**
	 * 将Date类型转换成getXMLGregorianCalendar类型
	 * 
	 * @param date
	 * @return
	 */
	public static XMLGregorianCalendar getXMLGregorianCalendar(Date date) {
		GregorianCalendar cal = new GregorianCalendar();
		cal.setTime(date);
		XMLGregorianCalendar xmlGregCal = null;
		try {
			xmlGregCal = DatatypeFactory.newInstance().newXMLGregorianCalendar(
					cal);
		} catch (DatatypeConfigurationException e) {
			throw new MktException("将Date类型转换成getXMLGregorianCalendar类型异常", e);
		}
		return xmlGregCal;
	}

	public static Date xmlDateToDate(XMLGregorianCalendar cal) {
		return cal.toGregorianCalendar().getTime();
	}

	/**
	 * 获取当前月
	 * 
	 * @return
	 */
	public static int getCurrentMonth() {
		Calendar cale = null;
		cale = Calendar.getInstance();
		int month = cale.get(Calendar.MONTH) + 1;
		return month;
	}

	/**
	 * 获取当天是这个月的第几天
	 * 
	 * @return
	 */
	public static Integer getDd() {
		SimpleDateFormat sdf = new SimpleDateFormat("dd");
		return Integer.parseInt(sdf.format(new Date()));
	}

	/**
	 * 获取月份有多少天
	 * 
	 * @param date
	 * @return
	 */
	public static int getDaysOfTheMonth(Date date) {// 获取当月天数
		Calendar rightNow = Calendar.getInstance();
		rightNow.setTime(date); // 要计算你想要的月份，改变这里即可
		int days = rightNow.getActualMaximum(Calendar.DAY_OF_MONTH);
		return days;
	}
	
	
	/**
	 * 获取日期是当年份的第几天
	 * 
	 * @param time
	 * @return
	 */
	public static int getYearDayNum(String time) {
		SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd");
		int day = 0;
		try {
			Date date = sdf.parse(time);
			Calendar c = Calendar.getInstance();
			c.setTime(date);
			day = c.get(Calendar.DAY_OF_YEAR);
		} catch (Exception e) {
			LOG.error(LOG_ERROR_INFO + " " + e.getMessage(), e);
//			throw new SystemException(e);
		}
		
		return day;
	}
	
	 /**
	  * 获取两个时间相减的天数
	  * 
	 * @param oldDate
	 * @param nowDate
	 * @return
	 */
	public static int comparePastDate(String oldDate,String nowDate, String dateFormat){
	        SimpleDateFormat sdf = new SimpleDateFormat(dateFormat);
	        Calendar calendar = Calendar.getInstance();
	        Date old;
	        int day=0;
	        try {
	            old = sdf.parse(oldDate);
	            calendar.setTime(old);
	            Long oTime = calendar.getTimeInMillis();

	            Date now = sdf.parse(nowDate);
	            calendar.setTime(now);
	            Long nTime = calendar.getTimeInMillis();

	            day=(int) ((nTime - oTime)/(3600F * 1000 * 24));
	        } catch (ParseException e) {
	        	LOG.error(LOG_ERROR_INFO + " " + e.getMessage(), e);
//				throw new SystemException(e);
	        }
	        return day;
	    }
}
