package com.wgmf.yxgj.module.business.employability.oldworkertrain.service;

import android.text.TextUtils;
import android.util.Log;

import com.google.gson.Gson;
import com.wgmf.library.base.BaseRequest;
import com.wgmf.library.base.BaseResponse;
import com.wgmf.library.base.ResultData;
import com.wgmf.library.utils.BaseSingleton;
import com.wgmf.yxgj.base.BaseService;
import com.wgmf.yxgj.config.BusinessID;
import com.wgmf.yxgj.global.NetworkParams;

import java.lang.ref.WeakReference;

public class EmployAbilityService extends BaseService {
    private static BaseSingleton<EmployAbilityService, Void> mMainService = new BaseSingleton<EmployAbilityService, Void>() {
        @Override
        protected EmployAbilityService create(Void var1) {
            return new EmployAbilityService();
        }
    };

    public static EmployAbilityService getInstance() {
        return mMainService.get(null);
    }

    private EmployAbilityService() {
    }

    /**
     * get /employAbility/findUserList 查询营养顾问信息
     * saleOrgId 销售组织Id query 	long
     * code1 code1 query 	string
     */
    public void requestFindUserList(final String saleOrgId, final String code1, final String userPostLevel, ResultData.BusinessCallback callback) {
        BaseRequest request = new BaseRequest();
        request.taskID = BusinessID.EmployAbility.MSG_ON_FIND_USER_LIST;
        request.callback = new WeakReference<>(callback);
        request.url = NetworkParams.URL_FIND_USER_LIST + "?" + "saleOrgId=" + saleOrgId + "&code1=" + code1 + "&userPostLevel=" + userPostLevel;
        Log.d(TAG, "请求地址：" + request.url);
        sendGetRequest(request);
    }

    /**
     * get /employAbility/findInStoreUserList 查询驻店营养顾问信息
     * shopId 门店编号 query 	string
     */
    public void requestFindInStoreUserList(final String shopId, ResultData.BusinessCallback callback) {
        BaseRequest request = new BaseRequest();
        request.taskID = BusinessID.EmployAbility.MSG_ON_FIND_INSTORE_USER_LIST;
        request.callback = new WeakReference<>(callback);
        request.url = NetworkParams.URL_FIND_INSTORE_USER_LIST + "?" + "shopId=" + shopId;
        Log.d(TAG, "请求地址：" + request.url);
        sendGetRequest(request);
    }

    /**
     * get /employAbility/findEmployAbility 员工能力评估查询
     * staffId 顾问工号 query 	string
     * abilityLevel 能力等级：1初级；2中级；3高级 query 	string
     */
    public void requestFindEmployAbility(final String params, ResultData.BusinessCallback callback) {
        BaseRequest request = new BaseRequest();
        request.taskID = BusinessID.EmployAbility.MSG_ON_FIND_EMPLOY_ABILITY;
        request.callback = new WeakReference<>(callback);
        request.url = NetworkParams.URL_FIND_EMPLOY_ABILITY + "?" + params;
        Log.d(TAG, "请求地址：" + request.url);
        sendGetRequest(request);
    }

    /**
     * get /employAbility/findEmployItemsTrainRecords 项目培训记录查询
     * staffId 顾问工号 query 	string
     * itemsId 项目Id
     */
    public void requestFindEmployItemsTrainRecords(final String staffId, final String itemsId, final String titleName, ResultData.BusinessCallback callback) {
        BaseRequest request = new BaseRequest();
        request.taskID = BusinessID.EmployAbility.MSG_ON_FIND_EMPLOY_ITEMS_TRAIN_RECORDS;
        request.callback = new WeakReference<>(callback);
        request.url = NetworkParams.URL_FIND_EMPLOY_ITEMS_TRAIN_RECORDS + "?" + "staffId=" + staffId + "&itemsId=" + itemsId + "&titleName=" + titleName;
        Log.d(TAG, "请求地址：" + request.url);
        sendGetRequest(request);
    }

    /**
     * get /employAbility/findEmpAbilityQualifiedAndUn 员工能力项合格和不合格查询
     * staffId 顾问工号 query 	string
     */
    public void requestFindEmpAbilityQualifiedAndUn(final String staffId,final String titleName, ResultData.BusinessCallback callback) {
        BaseRequest request = new BaseRequest();
        request.taskID = BusinessID.EmployAbility.MSG_ON_FIND_EMPABILITY_QUALIFIED_ANDUN;
        request.callback = new WeakReference<>(callback);
        request.url = NetworkParams.URL_FIND_EMPABILITY_QUALIFIED_ANDUN + "?" + "staffId=" + staffId + "&titleName=" + titleName;
        Log.d(TAG, "请求地址：" + request.url);
        sendGetRequest(request);
    }

    /**
     * post /employAbility/saveEmployAbilityBean 新增或修改能力评估
     */
    public void requestSaveEmployAbilityBean(final String json, ResultData.BusinessCallback callback) {
        BaseRequest request = new BaseRequest();
        request.taskID = BusinessID.EmployAbility.MSG_ON_SAVE_EMPLOY_ABILITY_BEAN;
        request.callback = new WeakReference<>(callback);
        request.url = NetworkParams.URL_SAVE_EMPLOY_ABILITY_BEAN;
        request.json = json;
        Log.d(TAG, "请求地址：" + request.url);
        sendPostJsonRequest(request);
    }

    /**
     * post /employAbility/saveEmployItemsTrainRecords 新增项目培训记录
     */
    public void requestSaveEmployItemsTrainRecords(final String json, ResultData.BusinessCallback callback) {
        BaseRequest request = new BaseRequest();
        request.taskID = BusinessID.EmployAbility.MSG_ON_SAVE_EMPLOY_ITEMS_TRAIN_RECORDS;
        request.callback = new WeakReference<>(callback);
        request.url = NetworkParams.URL_SAVE_EMPLOY_ITEMS_TRAIN_RECORDS;
        request.json = json;
        Log.d(TAG, "请求地址：" + request.url);
        sendPostJsonRequest(request);
    }

    /**
     * get /employAbility/findEmployAbilityTitle 员工能力评估查询一级菜单
     * staffId 顾问工号 query 	string
     */
    public void requestFindEmployAbilityTitle(final String staffId, ResultData.BusinessCallback callback) {
        BaseRequest request = new BaseRequest();
        request.taskID = BusinessID.EmployAbility.MSG_ON_FIND_EMPLOY_ABILITY_TITLE;
        request.callback = new WeakReference<>(callback);
        request.url = NetworkParams.URL_FIND_EMPLOY_ABILITY_TITLE + "?" + "staffId=" + staffId;
        Log.d(TAG, "请求地址：" + request.url);
        sendGetRequest(request);
    }

    @Override
    protected void onTaskDone(ResultData data) {
        if (null != data) {
            final int id = data.taskID;
            switch (id) {
                case BusinessID.EmployAbility.MSG_ON_FIND_EMPLOY_ABILITY_TITLE:
                case BusinessID.EmployAbility.MSG_ON_FIND_USER_LIST:
                case BusinessID.EmployAbility.MSG_ON_FIND_INSTORE_USER_LIST:
                case BusinessID.EmployAbility.MSG_ON_FIND_EMPLOY_ABILITY:
                case BusinessID.EmployAbility.MSG_ON_SAVE_EMPLOY_ABILITY_BEAN:
                case BusinessID.EmployAbility.MSG_ON_FIND_EMPLOY_ITEMS_TRAIN_RECORDS:
                case BusinessID.EmployAbility.MSG_ON_FIND_EMPABILITY_QUALIFIED_ANDUN:
                case BusinessID.EmployAbility.MSG_ON_SAVE_EMPLOY_ITEMS_TRAIN_RECORDS: {
                    if (data.isSuccessed()) {
                        final String json = data.getInfo();
                        if (!TextUtils.isEmpty(json)) {
                            BaseResponse mBaseResponse = new Gson().fromJson(json, BaseResponse.class);
                            Log.d(TAG, "id:" + id + ";mBaseResponse=" + mBaseResponse.toString());
                            data.setResultCode(mBaseResponse.retCode);
                            data.setResultInfo(mBaseResponse.retInfo);
                        }
                    }
                    break;
                }
                default:
                    break;
            }
        }
    }
}