package com.wgmf.yxgj.module.business.employability.starslights.service;

import android.text.TextUtils;
import android.util.Log;

import com.google.gson.Gson;
import com.wgmf.library.base.BaseRequest;
import com.wgmf.library.base.BaseResponse;
import com.wgmf.library.base.ResultData;
import com.wgmf.library.utils.BaseSingleton;
import com.wgmf.yxgj.base.BaseService;
import com.wgmf.yxgj.config.BusinessID;
import com.wgmf.yxgj.global.NetworkParams;

import java.lang.ref.WeakReference;

public class StarsLightsService extends BaseService {
    private static BaseSingleton<StarsLightsService, Void> mMainService = new BaseSingleton<StarsLightsService, Void>() {
        @Override
        protected StarsLightsService create(Void var1) {
            return new StarsLightsService();
        }
    };

    public static StarsLightsService getInstance() {
        return mMainService.get(null);
    }

    private StarsLightsService() {
    }

    /**
     * get /starsLights/findShopWorkersStarsLights 查询 门店下的顾问点灯记录
     */
    public void requestFindInStoreUserList(final String yearMonth, final String shopId, ResultData.BusinessCallback callback) {
        BaseRequest request = new BaseRequest();
        request.taskID = BusinessID.StarsLights.MSG_ON_FIND_SHOP_WORKERS_STARS_LIGHTS;
        request.callback = new WeakReference<>(callback);
        request.url = NetworkParams.URL_FIND_SHOP_WORKERS_STARS_LIGHTS + "?" + "yearMonth=" + yearMonth + "&shopId=" + shopId;
        Log.d(TAG, "请求地址：" + request.url);
        sendGetRequest(request);
    }

    /**
     * get /starsLights/findOrgWorkersStarsLights 查询 组织下的顾问点灯记录
     */
    public void requestFindOrgWorkersStarsLights(final String yearMonth, final String orgId, ResultData.BusinessCallback callback) {
        BaseRequest request = new BaseRequest();
        request.taskID = BusinessID.StarsLights.MSG_ON_FIND_ORG_WORKERS_STARS_LIGHTS;
        request.callback = new WeakReference<>(callback);
        request.url = NetworkParams.URL_FIND_ORG_WORKERS_STARS_LIGHTS + "?" + "yearMonth=" + yearMonth + "&orgId=" + orgId;
        Log.d(TAG, "请求地址：" + request.url);
        sendGetRequest(request);
    }

    @Override
    protected void onTaskDone(ResultData data) {
        if (null != data) {
            final int id = data.taskID;
            switch (id) {
                case BusinessID.StarsLights.MSG_ON_FIND_SHOP_WORKERS_STARS_LIGHTS:
                case BusinessID.StarsLights.MSG_ON_FIND_ORG_WORKERS_STARS_LIGHTS: {
                    if (data.isSuccessed()) {
                        final String json = data.getInfo();
                        if (!TextUtils.isEmpty(json)) {
                            BaseResponse mBaseResponse = new Gson().fromJson(json, BaseResponse.class);
                            Log.d(TAG, "id:" + id + ";mBaseResponse=" + mBaseResponse.toString());
                            data.setResultCode(mBaseResponse.retCode);
                            data.setResultInfo(mBaseResponse.retInfo);
                        }
                    }
                    break;
                }
                default:
                    break;
            }
        }
    }
}