package com.wgmf.yxgj.module.business.employability.talentstrain.service;

import android.text.TextUtils;
import android.util.Log;

import com.google.gson.Gson;
import com.wgmf.library.base.BaseRequest;
import com.wgmf.library.base.BaseResponse;
import com.wgmf.library.base.ResultData;
import com.wgmf.library.utils.BaseSingleton;
import com.wgmf.yxgj.base.BaseService;
import com.wgmf.yxgj.config.BusinessID;
import com.wgmf.yxgj.global.NetworkParams;

import java.lang.ref.WeakReference;

public class EmployTalentsService extends BaseService {
    private static BaseSingleton<EmployTalentsService, Void> mMainService = new BaseSingleton<EmployTalentsService, Void>() {
        @Override
        protected EmployTalentsService create(Void var1) {
            return new EmployTalentsService();
        }
    };

    public static EmployTalentsService getInstance() {
        return mMainService.get(null);
    }

    private EmployTalentsService() {
    }

    /**
     * get /employAbility/findUserList 查询营养顾问信息
     * saleOrgId 销售组织Id query 	long
     * code1 code1 query 	string
     */
    public void requestFindUserList(final String saleOrgId, final String code1, final String userPostLevel, ResultData.BusinessCallback callback) {
        BaseRequest request = new BaseRequest();
        request.taskID = BusinessID.EmployTalents.MSG_ON_FIND_WORKER_TALENT_USER_LIST;
        request.callback = new WeakReference<>(callback);
        request.url = NetworkParams.URL_FIND_WORKER_TALENT_USER_LIST + "?" + "saleOrgId=" + saleOrgId + "&code1=" + code1 + "&userPostLevel=" + userPostLevel;
        Log.d(TAG, "请求地址：" + request.url);
        sendGetRequest(request);
    }

    /**
     * get /employAbility/findInStoreUserList 查询驻店营养顾问信息
     * shopId 门店编号 query 	string
     */
    public void requestFindInStoreUserList(final String shopId, ResultData.BusinessCallback callback) {
        BaseRequest request = new BaseRequest();
        request.taskID = BusinessID.EmployTalents.MSG_ON_FIND_IN_STORE_USER_LIST;
        request.callback = new WeakReference<>(callback);
        request.url = NetworkParams.URL_FIND_IN_STORE_USER_LIST + "?" + "shopId=" + shopId;
        Log.d(TAG, "请求地址：" + request.url);
        sendGetRequest(request);
    }

    /**
     * post /employAbility/saveEmployItemsTrainRecords 新增项目培训记录
     */
    public void requestSaveEmployItemsTrainRecords(final String json, ResultData.BusinessCallback callback) {
        BaseRequest request = new BaseRequest();
        request.taskID = BusinessID.EmployTalents.MSG_ON_SAVE_WORKER_TALENT_EVALUATE;
        request.callback = new WeakReference<>(callback);
        request.url = NetworkParams.URL_SAVE_WORKER_TALENT_EVALUATE;
        request.json = json;
        Log.d(TAG, "请求地址：" + request.url);
        sendPostJsonRequest(request);
    }

    @Override
    protected void onTaskDone(ResultData data) {
        if (null != data) {
            final int id = data.taskID;
            switch (id) {
                case BusinessID.EmployTalents.MSG_ON_FIND_WORKER_TALENT_USER_LIST:
                case BusinessID.EmployTalents.MSG_ON_FIND_IN_STORE_USER_LIST:
                case BusinessID.EmployTalents.MSG_ON_SAVE_WORKER_TALENT_EVALUATE: {
                    if (data.isSuccessed()) {
                        final String json = data.getInfo();
                        if (!TextUtils.isEmpty(json)) {
                            BaseResponse mBaseResponse = new Gson().fromJson(json, BaseResponse.class);
                            Log.d(TAG, "id:" + id + ";mBaseResponse=" + mBaseResponse.toString());
                            data.setResultCode(mBaseResponse.retCode);
                            data.setResultInfo(mBaseResponse.retInfo);
                        }
                    }
                    break;
                }
                default:
                    break;
            }
        }
    }
}