package com.wgmf.yxgj.module.business.managecapital.ui

import android.content.Intent
import android.os.Bundle
import android.support.v4.content.ContextCompat
import android.support.v7.widget.LinearLayoutManager
import android.support.v7.widget.RecyclerView
import android.util.Log
import android.view.Gravity
import android.view.View
import android.widget.*
import com.google.gson.Gson
import com.wgmf.library.base.BaseResponse
import com.wgmf.library.base.ResultData
import com.wgmf.yxgj.base.BaseParentAct
import com.wgmf.yxgj.config.BusinessID
import com.wgmf.yxgj.dialog.LoadWaitDominator
import com.wgmf.yxgj.global.ConstantParams
import com.wgmf.yxgj.module.business.managecapital.R
import com.wgmf.yxgj.module.business.managecapital.model.CapitalReceiptsDetailsEntity
import com.wgmf.yxgj.module.business.managecapital.model.CapitalReceiptsUploadEntity
import com.wgmf.yxgj.module.business.managecapital.service.CapitalManagerService
import com.wgmf.yxgj.module.business.managecapital.ui.adapter.CapitalReceiptsDetailsAdapter
import com.wgmf.yxgj.pop.GoodsReceiptsSuccessPop
import com.wgmf.yxgj.pop.GoodsReceiptsSuccessPop.GoodsReceiptsSuccessPopListener
import com.wgmf.yxgj.pop.PublicThreeSecondsPop.ThreeSecondsPopListener
import com.wgmf.yxgj.utils.ActivityTaskManager
import com.wgmf.yxgj.utils.DensityUtil
import com.wgmf.yxgj.utils.isNotNullOrSize
import com.wgmf.yxgj.widgets.decoration.DividerItemDecoration
import com.xp.arouter.RouterCommonUtil

/**
 * 资产收货:（第二页） 资产收货详情页
 *
 * @author LW
 */
class CapitalReceiptsDetailsActivity : BaseParentAct(), ThreeSecondsPopListener,
    GoodsReceiptsSuccessPopListener {

    private var mGoodsReceiptsSuccessPop: GoodsReceiptsSuccessPop? = null

    private var mCapitalReceiptsDetailsAdapter: CapitalReceiptsDetailsAdapter? = null

    private var mCapitalReceiptsDetailsList: MutableList<CapitalReceiptsDetailsEntity.CapitalReceiptsDetailsBean> =
        mutableListOf()

    lateinit var mLoadWait: LoadWaitDominator

    private val mCreateUserName: String by lazy {
        intent.getStringExtra("createUserName")
    }

    private val mStoreNo: String by lazy {
        intent.getStringExtra("shopId")
    }

    private val mStoreName: String by lazy {
        intent.getStringExtra("storeName")
    }

    private val mIsNotOeDBFlag: String by lazy {
        intent.getStringExtra("isNotOeDBFlag")
    }

    private val mZcshid: Int by lazy {
        intent.getIntExtra("zcshid", -1)
    }

    private val mSource: String by lazy {
        intent.getStringExtra("source")
    }

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        setContentView(R.layout.public_list_view)
        initTitle()
        initView()
        findCapitalReceipts()
    }

    override fun initTitle() {
        super.initTitle()

        if (CapitalReceiptsListActivity.FLAG_OTHER == mIsNotOeDBFlag) {  //配送收货
            homeTitleText.text = mContext.getString(R.string.receipts_goods_header_shop_tv1)
        } else {
            homeTitleText.text = mContext.getString(R.string.receipts_goods_header_shop_tv2)
        }

        homeTitleMoreLl.visibility = View.INVISIBLE
        homeTitleBackLl.visibility = View.VISIBLE
    }

    private fun initView() {
        mLoadWait = LoadWaitDominator(this, findViewById<FrameLayout>(R.id.public_container_fl))
        mCapitalReceiptsDetailsAdapter =
            CapitalReceiptsDetailsAdapter(mContext, mSource, mCapitalReceiptsDetailsList)

        findViewById<LinearLayout>(R.id.onclick_title_ll).visibility = View.VISIBLE
        findViewById<TextView>(R.id.onclick_name).apply {
            visibility = View.VISIBLE
            text = mContext.getString(R.string.goods_receipts_name)
            gravity = Gravity.CENTER
        }
        findViewById<TextView>(R.id.onclick_title).apply {
            visibility = View.VISIBLE
            setPadding(0, 0, DensityUtil.dip2px(mContext, 40f), 0)
            text = mContext.getString(R.string.number)
        }

        findViewById<ListView>(R.id.public_list_view_lv).visibility = View.GONE
        findViewById<RecyclerView>(R.id.public_list_view_rv).apply {
            visibility = View.VISIBLE
            layoutManager = LinearLayoutManager(mContext)
            addItemDecoration(
                DividerItemDecoration(
                    DividerItemDecoration.HORIZONTAL_LIST,
                    1,
                    ContextCompat.getColor(mContext, R.color.divider_line_deep)
                )
            )
            adapter = mCapitalReceiptsDetailsAdapter
        }

        findViewById<LinearLayout>(R.id.report_content_confirm_ll).visibility = View.VISIBLE

        findViewById<Button>(R.id.report_content_confirm_btn).apply {
            text = mContext.getString(R.string.confirm_receipt)
            setOnClickListener {
                //提交数据
                submitCapitalReceipts()
            }
        }
        findViewById<TextView>(R.id.report_content_comfirm_tip_txt).apply {
            text = getString(R.string.allot_tip)
            visibility = View.VISIBLE
        }
    }

    /**
     * 查询数据
     */
    private fun findCapitalReceipts() {
        showDialog()
        mLoadWait.show(LoadWaitDominator.LOADING)
        CapitalManagerService.getInstance()
            .requestFindCapitalReceiptsDetail(mZcshid, mSource, this@CapitalReceiptsDetailsActivity)
    }

    /**
     * 提交数据
     */
    private fun submitCapitalReceipts() {
        userInfo?.let {
            val content = Gson().toJson(
                CapitalReceiptsUploadEntity(
                    it.staffId,
                    mSource,
                    mZcshid,
                    mCapitalReceiptsDetailsList
                )
            )
            Log.d(TAG, "CapitalReceiptsUploadEntity=$content")

            showDialog()
            CapitalManagerService.getInstance()
                .requestUpdateCapitalReceipts(
                    content,
                    this@CapitalReceiptsDetailsActivity
                )
        }
    }


    override fun onBusinessResultAtMainThread(result: ResultData?) {
        super.onBusinessResultAtMainThread(result)
        dismissDialog()
        mLoadWait.show(LoadWaitDominator.DISMISS)
        result?.let {
            if (it.taskID == BusinessID.CapitalManager.MSG_ON_FIND_CAPITAL_RECEIPTS_DETAIL) {
                if (!isFinishing && it.isSuccessed) {
                    val entity = Gson().fromJson(it.info, CapitalReceiptsDetailsEntity::class.java)
                    Log.d(TAG, "CapitalReceiptsListEntity=$entity")
                    if (ConstantParams.CONSTANT_PARAMS_0 == entity.retCode) {
                        val list = entity.resultList
                        if (list.isNotNullOrSize()) {
                            mLoadWait.show(LoadWaitDominator.DISMISS)
                            refreshDataToView(list!!)
                        } else {
                            mLoadWait.show(LoadWaitDominator.NO_DATA)
                        }
                    } else {
                        mLoadWait.show(entity.retInfo)
                    }
                } else {
                    mLoadWait.show(LoadWaitDominator.NET_ERROR)
                }
            } else if (it.taskID == BusinessID.CapitalManager.MSG_ON_UPDATE_CAPITAL_RECEIPTS) {
                if (!isFinishing && it.isSuccessed) {
                    val entity = Gson().fromJson(it.info, BaseResponse::class.java)
                    showMsg(entity.retInfo)
                    if (ConstantParams.CONSTANT_PARAMS_0 == entity.retCode) {
                        //showSuccessWindow()
                        ActivityTaskManager.getInstance()
                            .finishActivity(CapitalReceiptsListActivity::class.java)
                        this.finish()
                    }
                }
            }
        }
    }

    /**
     * 数据更新到View
     */
    private fun refreshDataToView(list: List<CapitalReceiptsDetailsEntity.CapitalReceiptsDetailsBean>) {
        mCapitalReceiptsDetailsList = list.toMutableList()
        mCapitalReceiptsDetailsAdapter?.setNewData(mCapitalReceiptsDetailsList)
    }

    /**
     * 弹出跳转选项窗
     */
    private fun showSuccessWindow() {
        if (null == mGoodsReceiptsSuccessPop) {
            mGoodsReceiptsSuccessPop = GoodsReceiptsSuccessPop(mContext, this)
        }
        if (!mGoodsReceiptsSuccessPop!!.isShowing()) {
            mGoodsReceiptsSuccessPop?.show(findViewById<View>(R.id.title))
        }
    }


    override fun onTimingFinish() {
        showSuccessWindow()
    }

    override fun toReportFeedback() {
        val bundle = Bundle()
        bundle.putString("branchTitle", "反馈直通车")
        RouterCommonUtil.startFunctionActivity(mContext, 0, 66L, bundle)
        finish()
    }

    override fun toGoodsLibQuery() {
        jumpCapitalStockDetailsActivity()
    }

    override fun backToHomepage() {
        RouterCommonUtil.startFunctionActivity(mContext, -3, 0L, Bundle())
        this.finish()
    }

    /**
     * 跳转到 CapitalStockDetailsActivity
     */
    private fun jumpCapitalStockDetailsActivity() {
        startActivity(Intent(mContext, CapitalStockDetailsActivity::class.java).apply {
            putExtra("branchTitle", "")
            putExtra("branchID", 0L)
            putExtra("storeNo", mStoreNo)
            putExtra("storeName", mStoreName)
        })
        this.finish()
    }
}