package com.wgmf.yxgj.module.business.managecapital.ui

import android.content.Intent
import android.os.Bundle
import android.support.v4.content.ContextCompat
import android.support.v7.widget.LinearLayoutManager
import android.support.v7.widget.RecyclerView
import android.util.Log
import android.view.View
import android.widget.ListView
import android.widget.TextView
import com.alibaba.android.arouter.facade.annotation.Route
import com.gavin.com.library.PowerfulStickyDecoration
import com.gavin.com.library.listener.PowerGroupListener
import com.google.gson.Gson
import com.wgmf.library.base.ResultData
import com.wgmf.yxgj.base.BaseParentAct
import com.wgmf.yxgj.config.BusinessID
import com.wgmf.yxgj.dialog.LoadWaitDominator
import com.wgmf.yxgj.global.ConstantParams
import com.wgmf.yxgj.module.business.managecapital.R
import com.wgmf.yxgj.module.business.managecapital.model.CapitalReceiptsListEntity
import com.wgmf.yxgj.module.business.managecapital.service.CapitalManagerService
import com.wgmf.yxgj.module.business.managecapital.ui.adapter.CapitalReceiptsListAdapter
import com.wgmf.yxgj.utils.DensityUtil
import com.wgmf.yxgj.widgets.decoration.DividerItemDecoration
import com.xp.arouter.RouterParams

/**
 * 资产收货:（第一页） 资产收货门店列表
 * @author LW
 */
@Route(path = RouterParams.URL_CAPITALRECEIPTSLISTACTIVITY)
class CapitalReceiptsListActivity : BaseParentAct(),
    CapitalReceiptsListAdapter.OnAdapterItemListener {

    lateinit var mLoadWait: LoadWaitDominator

    private var mCapitalReceiptsList: MutableList<CapitalReceiptsListEntity.CapitalReceiptsBean> =
        mutableListOf()

    private var mCapitalReceiptsListAdapter: CapitalReceiptsListAdapter? = null

    companion object {
        const val FLAG_OTHER: String = "other"
    }

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        setContentView(R.layout.public_list_view)
        initTitle()
        initView()
        findCapitalReceipts()
    }

    override fun initTitle() {
        super.initTitle()
        val branchTitle = intent.getStringExtra("branchTitle")
        homeTitleText.text = branchTitle
        homeTitleMoreLl.visibility = View.INVISIBLE
        homeTitleBackLl.visibility = View.VISIBLE
    }

    private fun findCapitalReceipts() {
        userInfo?.let {
            showDialog()
            mLoadWait.show(LoadWaitDominator.LOADING)
            CapitalManagerService.getInstance()
                .requestFindCapitalReceipts(it.staffId, this@CapitalReceiptsListActivity)
        }
    }

    private fun initView() {
        mLoadWait = LoadWaitDominator(this, findViewById(R.id.public_container_fl))
        mCapitalReceiptsListAdapter =
            CapitalReceiptsListAdapter(mContext, mCapitalReceiptsList, this)

        findViewById<ListView>(R.id.public_list_view_lv).visibility = View.GONE
        findViewById<RecyclerView>(R.id.public_list_view_rv).apply {
            visibility = View.VISIBLE
            layoutManager = LinearLayoutManager(mContext)
            addItemDecoration(
                DividerItemDecoration(
                    DividerItemDecoration.HORIZONTAL_LIST,
                    1,
                    ContextCompat.getColor(mContext, R.color.divider_line_deep)
                )
            )
            addItemDecoration(
                PowerfulStickyDecoration.Builder
                    .init(object : PowerGroupListener {
                        override fun getGroupName(position: Int): String? {
                            //获取组名，用于判断是否是同一组
                            return if (mCapitalReceiptsList.size > position) {
                                mCapitalReceiptsList[position].groupTitle
                            } else null
                        }

                        override fun getGroupView(position: Int): View? {
                            //获取自定定义的组View
                            return if (mCapitalReceiptsList.size > position) {
                                val view: View =
                                    layoutInflater.inflate(
                                        R.layout.item_capital_receipts_title,
                                        null,
                                        false
                                    )
                                (view.findViewById<View>(R.id.title_tv) as TextView).text =
                                    mCapitalReceiptsList[position].groupTitle
                                view
                            } else {
                                null
                            }
                        }
                    }).setGroupHeight(DensityUtil.dip2px(mContext, 35f)) //设置高度
                    .setGroupBackground(
                        ContextCompat.getColor(
                            mContext,
                            R.color.region_bg
                        )
                    ) //背景色
                    .build()
            )
            adapter = mCapitalReceiptsListAdapter
        }
    }

    override fun onBusinessResultAtMainThread(result: ResultData?) {
        super.onBusinessResultAtMainThread(result)
        dismissDialog()
        mLoadWait.show(LoadWaitDominator.DISMISS)
        result?.let {
            if (it.taskID == BusinessID.CapitalManager.MSG_ON_FIND_CAPITAL_RECEIPTS) {
                if (!isFinishing && it.isSuccessed) {
                    val entity = Gson().fromJson(it.info, CapitalReceiptsListEntity::class.java)
                    Log.d(TAG, "CapitalReceiptsEntity=$entity")
                    if (ConstantParams.CONSTANT_PARAMS_0 == entity.retCode) {
                        val list = entity.resultList
                        if (null != list && list.isNotEmpty()) {
                            mLoadWait.show(LoadWaitDominator.DISMISS)
                            refreshDataToView(list)
                        } else {
                            mLoadWait.show(LoadWaitDominator.NO_DATA)
                        }
                    } else {
                        mLoadWait.show(entity.retInfo)
                    }
                } else {
                    mLoadWait.show(LoadWaitDominator.NET_ERROR)
                }
            }
        }
    }

    /**
     * 解析网络数据，并显示数据
     * @param entity CapitalReceiptsEntity
     */
    private fun refreshDataToView(entity: List<CapitalReceiptsListEntity.CapitalReceiptsBean>) {
        mCapitalReceiptsList.clear()
        entity.forEach {
            if (FLAG_OTHER == it.isNotOeDBFlag) {  //配送收货
                it.groupTitle = mContext.getString(R.string.receipts_goods_header_shop_tv1)
            } else {  //配送收货
                it.groupTitle = mContext.getString(R.string.receipts_goods_header_shop_tv2)
            }
        }

        entity.groupBy { it.isNotOeDBFlag == FLAG_OTHER }.entries.forEach {
            mCapitalReceiptsList.addAll(it.value)
        }
        mCapitalReceiptsListAdapter?.refreshData(mCapitalReceiptsList)
    }

    override fun onAdapterItemClick(bean: CapitalReceiptsListEntity.CapitalReceiptsBean?) {
        //跳转到资产收获详情页
        startActivity(Intent(mContext, CapitalReceiptsDetailsActivity::class.java).apply {
            putExtra("zcshid", bean?.zcshid)
            putExtra("source", bean?.source)
            putExtra("shopId", bean?.storeNo)
            putExtra("createUserName", bean?.createUserName)
            putExtra("storeName", bean?.storeName)
            putExtra("isNotOeDBFlag", bean?.isNotOeDBFlag)
        })
    }
}