package com.wgmf.yxgj.module.business.managecapital.ui

import android.content.Intent
import android.os.Bundle
import android.util.Log
import android.view.View
import android.widget.Button
import android.widget.LinearLayout
import android.widget.TextView
import com.alibaba.android.arouter.facade.annotation.Route
import com.google.gson.Gson
import com.jakewharton.rxbinding.view.RxView
import com.wgmf.library.base.BaseResponse
import com.wgmf.library.base.ResultData
import com.wgmf.yxgj.base.BaseParentAct
import com.wgmf.yxgj.config.BusinessID
import com.wgmf.yxgj.dialog.LoadWaitDominator
import com.wgmf.yxgj.global.ConstantParams
import com.wgmf.yxgj.model.FixedProductListEntity
import com.wgmf.yxgj.module.business.managecapital.R
import com.wgmf.yxgj.module.business.managecapital.model.CapitalStockDetailsEntity
import com.wgmf.yxgj.module.business.managecapital.model.ProductTransferredInAndOutNumListEntity
import com.wgmf.yxgj.module.business.managecapital.model.ProductTransferredInAndOutNumLists
import com.wgmf.yxgj.module.business.managecapital.service.CapitalManagerService
import com.wgmf.yxgj.module.business.managecapital.ui.adapter.CapitalTransferredInOrOutAdapter
import com.wgmf.yxgj.pop.PublicThreeSecondsPop
import com.wgmf.yxgj.pop.PublicThreeSecondsPop.ThreeSecondsPopListener
import com.wgmf.yxgj.publics.ui.SelectorStoreGetNearestActivity
import com.wgmf.yxgj.utils.isNotNullOrSize
import com.wgmf.yxgj.utils.isNullOrEmpty
import com.wgmf.yxgj.widgets.ListView.SlideDeleteListView
import com.xp.arouter.RouterParams
import java.io.Serializable
import java.util.concurrent.TimeUnit

/**
 * 资材调入调出
 * @author LW
 */
@Route(path = RouterParams.URL_CAPITALTRANSFERREDINOROUTACTIVITY)
class CapitalTransferredInOrOutActivity : BaseParentAct(),
    ThreeSecondsPopListener {

    private var mStoreIdOut: String? = null
    private var mStoreIdIn: String? = null

    /**
     * 资材调入调出功能选择门店,暂定为产品调入调出ID
     */
    private var mBranchID: Long? = null
    private var mTransferOutShopNameTv: TextView? = null
    private var mTransferInShopNameTv: TextView? = null
    private var mTransferGoodsSubmitBtn: Button? = null

    /**
     * 已选择的调拨数据
     */
    private var mCapitalStockDetailsList: MutableList<CapitalStockDetailsEntity> = mutableListOf()
    private var mCapitalTransferredInOrOutAdapter: CapitalTransferredInOrOutAdapter? = null
    private var mSlideDeleteListView: SlideDeleteListView? = null

    private lateinit var mLoadWait: LoadWaitDominator

    companion object {
        /**
         * 选择资材
         */
        private const val SELECT_CAPITAL = 0
        /**
         * 调出门店
         */
        private const val TRANSFER_OUT_SHOP = 1
        /**
         * 调入门店
         */
        private const val TRANSFER_IN_SHOP = 2
    }

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        setContentView(R.layout.activity_transfer_goods)
        initTitle()
        initView()
        initContent()
    }

    private fun initContent() {
        mSlideDeleteListView =
            findViewById<SlideDeleteListView>(R.id.transfer_goods_list_lv).apply {
                mCapitalTransferredInOrOutAdapter = CapitalTransferredInOrOutAdapter(
                    mCapitalStockDetailsList,
                    this@CapitalTransferredInOrOutActivity
                )
                adapter = mCapitalTransferredInOrOutAdapter
            }

        //3秒钟之内只取一个点击事件，防抖操作
        RxView.clicks(findViewById<Button>(R.id.transfer_goods_submit_btn))
            .throttleFirst(3, TimeUnit.SECONDS).subscribe {
                if (mStoreIdOut.isNullOrEmpty()) {
                    showMsg("请选择调出门店")
                } else if (mStoreIdIn.isNullOrEmpty()) {
                    showMsg("请先选择调入门店")
                } else if (mStoreIdIn == mStoreIdOut) {
                    showMsg("调入调出门店不能相同")
                } else {
                    submitCapitalData() //提交数据
                }
            }
    }

    override fun initTitle() {
        super.initTitle()
        homeTitleText.text = intent.getStringExtra("branchTitle")
        mBranchID = intent.getLongExtra("branchID", 0)
        homeTitleBackLl.visibility = View.VISIBLE
    }

    private fun initView() {
        mLoadWait = LoadWaitDominator(mContext, findViewById(R.id.transfer_goods_container_fl))

        findViewById<LinearLayout>(R.id.transfer_out_shop_name_ll).apply {
            setOnClickListener {
                startActivityForResult(Intent().apply {
                    //调出门店
                    setClass(
                        this@CapitalTransferredInOrOutActivity,
                        SelectorStoreGetNearestActivity::class.java
                    )
                    putExtra("branchTitle", "选择门店")
                    putExtra("branchID", mBranchID)
                }, TRANSFER_OUT_SHOP)
            }
        }
        findViewById<LinearLayout>(R.id.transfer_in_shop_name_ll).apply {
            setOnClickListener {
                startActivityForResult(Intent().apply {
                    //调入门店
                    setClass(
                        this@CapitalTransferredInOrOutActivity,
                        SelectorStoreGetNearestActivity::class.java
                    )
                    putExtra("branchTitle", "选择门店")
                    putExtra("branchID", mBranchID)
                }, TRANSFER_IN_SHOP)
            }
        }

        mTransferOutShopNameTv = findViewById(R.id.transfer_out_shop_name_tv)
        mTransferInShopNameTv = findViewById(R.id.transfer_in_shop_name_tv)
        mTransferGoodsSubmitBtn = findViewById(R.id.transfer_goods_submit_btn)
        findViewById<TextView>(R.id.transfer_goods_products_tv).apply {
            text = "选择资材"
            setOnClickListener {
                //选择产品
                if (mStoreIdOut.isNullOrEmpty()) {
                    showMsg("请先选择调出门店")
                } else {
                    startActivityForResult(Intent().apply {
                        setClass(
                            this@CapitalTransferredInOrOutActivity,
                            CapitalTransferredInOrOutCapitalListActivity::class.java
                        )
                        putExtra("storeNo", mStoreIdOut)
                        putExtra("listData", mCapitalStockDetailsList as Serializable)
                    }, SELECT_CAPITAL)
                }
            }
        }
    }

    override fun onActivityResult(requestCode: Int, resultCode: Int, data: Intent?) {
        super.onActivityResult(requestCode, resultCode, data)
        data?.let {
            when(requestCode){
                TRANSFER_OUT_SHOP ->{
                    try {
                        mStoreIdOut = it
                            .getStringExtra("shopId")
                        val shopNameOut = it
                            .getStringExtra("shopName")
                        mTransferOutShopNameTv?.text = shopNameOut
                        mCapitalStockDetailsList.clear()
                        mCapitalTransferredInOrOutAdapter?.setNewData(mCapitalStockDetailsList)
                    } catch (e: Exception) {
                        Log.e(TAG, "onActivityResult: data.getStringExtra error ")
                    }
                }
                TRANSFER_IN_SHOP ->{
                    try {
                        mStoreIdIn = it
                            .getStringExtra("shopId")
                        val shopNameIn = it
                            .getStringExtra("shopName")
                        mTransferInShopNameTv?.text = shopNameIn
                        mCapitalStockDetailsList.clear()
                        mCapitalTransferredInOrOutAdapter?.setNewData(mCapitalStockDetailsList)
                    } catch (e: Exception) {
                        Log.e(TAG, "onActivityResult: data.getStringExtra error ")
                    }
                }
                SELECT_CAPITAL->{
                    try {
                        mCapitalStockDetailsList =
                            it.getSerializableExtra("listData") as MutableList<CapitalStockDetailsEntity>
                        if (mCapitalStockDetailsList.isNotNullOrSize()) {
                            mLoadWait.dismissAll()
                            mTransferGoodsSubmitBtn?.visibility = View.VISIBLE
                            mCapitalTransferredInOrOutAdapter?.setNewData(mCapitalStockDetailsList)
                        } else {
                            mLoadWait.show(LoadWaitDominator.NO_DATA)
                            mTransferGoodsSubmitBtn?.visibility = View.GONE
                        }

                    } catch (e: Exception) {
                        Log.e(TAG, "onActivityResult: data.getStringExtra error ")
                    }
                }
                else ->{

                }

            }
        }
    }

    /**
     * 提交资产数据
     */
    private fun submitCapitalData() {
        showDialog()
        val productTransferredInAndOutNumLists: MutableList<ProductTransferredInAndOutNumListEntity> =
            mutableListOf()
        mCapitalStockDetailsList.forEach {
            if (it.orderNum > 0) {
                //如果调入调出数量>0，则提交
                productTransferredInAndOutNumLists.add(
                    ProductTransferredInAndOutNumListEntity().apply {
                        //调入调出数量
                        transferredInAndOutNum = it.orderNum

                        //产品BillCode/资材调拨时用
                        productBillCode = it.capitalReceiptProductBillCode
                        //产品库存
                        productSock = it.productNum
                        val fixedProductListEntity = FixedProductListEntity()
                        //产品编码
                        fixedProductListEntity.productCode = it.fixedProduct.productCode
                        //产品名称
                        fixedProductListEntity.productName = it.fixedProduct.productName
                        fixedProduct = fixedProductListEntity

                    }
                )
            }
        }

        val json = Gson().toJson(ProductTransferredInAndOutNumLists().apply {
            userInfo = BaseParentAct.userInfo
            transferredInStoreId = mStoreIdIn
            transferredOutStoreId = mStoreIdOut
            productTransferredInAndOutNumList = productTransferredInAndOutNumLists
        })
        Log.d(TAG, json)
        CapitalManagerService.getInstance()
            .requestSaveCapitalStockTransferred(json, this@CapitalTransferredInOrOutActivity)
    }

    override fun onBusinessResultAtMainThread(result: ResultData?) {
        super.onBusinessResultAtMainThread(result)
        dismissDialog()
        result?.let {
            if (it.taskID == BusinessID.CapitalManager.MSG_ON_SAVE_CAPITAL_STOCK_TRANSFERRED) {
                if (!isFinishing && it.isSuccessed) {
                    val entity = Gson().fromJson(it.info, BaseResponse::class.java)
                    Log.d(TAG, "BaseResponse=$entity")
                    if (ConstantParams.CONSTANT_PARAMS_0 == entity.retCode) {
                        //弹出提示进度条,等待OE返回
                        showPublicThreeSecondsPop()
                    } else {
                        showMsg(entity.retInfo)
                    }
                } else {
                    showMsg(getString(R.string.request_data_fail))
                }
            }
        }
    }

    override fun onTimingFinish() {
        this@CapitalTransferredInOrOutActivity.finish()
    }

    /**
     * 弹出延时窗
     */
    private fun showPublicThreeSecondsPop() {
        val publicThreeSecondsPop = PublicThreeSecondsPop(mContext, this)
        if (!publicThreeSecondsPop.isShowing) {
            publicThreeSecondsPop.show(this.findViewById(R.id.title))
        }
    }
}