package com.wgmf.yxgj.module.business.manageka.service;

import android.text.TextUtils;
import android.util.Log;

import com.google.gson.Gson;
import com.wgmf.library.base.BaseRequest;
import com.wgmf.library.base.BaseResponse;
import com.wgmf.library.base.ResultData;
import com.wgmf.library.utils.BaseSingleton;
import com.wgmf.yxgj.base.BaseService;
import com.wgmf.yxgj.config.BusinessID;
import com.wgmf.yxgj.global.NetworkParams;

import java.lang.ref.WeakReference;

/**
 * KA客户管理网络请求服务
 *
 * @author XiePing
 */
@SuppressWarnings("all")
public class KAManagerService extends BaseService {
    private static BaseSingleton<KAManagerService, Void> mMainService = new BaseSingleton<KAManagerService, Void>() {
        @Override
        protected KAManagerService create(Void var1) {
            return new KAManagerService();
        }
    };

    public static KAManagerService getInstance() {
        return mMainService.get(null);
    }

    private KAManagerService() {
    }

    /**
     * GET /kacusmanager/findCustomerVisit 客户拜访查询
     */
    public void requestFindCustomerVisit(final String staffId, final String yearMonth,
                                         ResultData.BusinessCallback callback) {
        BaseRequest request = new BaseRequest();
        request.taskID = BusinessID.KAManager.MSG_ON_FIND_CUSTOMER_VISIT;
        request.callback = new WeakReference<>(callback);
        request.url = NetworkParams.URL_GET_FIND_CUSTOMER_VISIT + "?" + "yearMonth=" + yearMonth + "&staffId=" + staffId;
        Log.d(TAG, "请求地址：" + request.url);
        sendGetRequest(request);
    }

    /**
     * GET /kacusmanager/findSupermarketAndPoistion 查询商超系统和客户职位
     */
    public void requestFindSupermarketAndPoistion(final String staffId, ResultData.BusinessCallback callback) {
        BaseRequest request = new BaseRequest();
        request.taskID = BusinessID.KAManager.MSG_ON_FIND_SUPERMARKET_AND_POISTION;
        request.callback = new WeakReference<>(callback);
        request.url = NetworkParams.URL_GET_FIND_SUPERMARKET_AND_POISTION + "?" + "staffId=" + staffId;
        Log.d(TAG, "请求地址：" + request.url);
        sendGetRequest(request);
    }

    /**
     * POST /kacusmanager/saveCustomerVisit 客户拜访
     */
    public void requestSaveCustomerVisit(final String json, ResultData.BusinessCallback callback) {
        BaseRequest request = new BaseRequest();
        request.taskID = BusinessID.KAManager.MSG_ON_SAVE_CUSTOMER_VISIT;
        request.callback = new WeakReference<>(callback);
        request.url = NetworkParams.URL_SAVE_CUSTOMER_VISIT;
        request.json = json;
        Log.d(TAG, "请求地址：" + request.url);
        sendPostJsonRequest(request);
    }

    @Override
    protected void onTaskDone(ResultData data) {
        if (null != data) {
            final int id = data.taskID;
            switch (id) {
                case BusinessID.KAManager.MSG_ON_SAVE_CUSTOMER_VISIT:
                case BusinessID.KAManager.MSG_ON_FIND_SUPERMARKET_AND_POISTION: {
                    if (data.isSuccessed()) {
                        final String json = data.getInfo();
                        if (!TextUtils.isEmpty(json)) {
                            BaseResponse mBaseResponse = new Gson().fromJson(json, BaseResponse.class);
                            Log.d(TAG, "id:" + id + ";mBaseResponse=" + mBaseResponse.toString());
                            data.setResultCode(mBaseResponse.retCode);
                            data.setResultInfo(mBaseResponse.retInfo);
                        }
                    }
                    break;
                }
                default:
                    break;
            }
        }
    }
}