package com.wgmf.yxgj.module.business.manageka.ui.customerVisit;

import android.support.annotation.NonNull;
import android.util.Log;

import com.google.gson.Gson;
import com.wgmf.library.base.BaseResponse;
import com.wgmf.library.base.ResultData;
import com.wgmf.yxgj.base.BaseParentAct;
import com.wgmf.yxgj.config.BusinessID;
import com.wgmf.yxgj.model.CommonUserinfoBean;
import com.wgmf.yxgj.module.business.manageka.model.CustomerPositionList;
import com.wgmf.yxgj.module.business.manageka.model.CustomerVisitEntity;
import com.wgmf.yxgj.module.business.manageka.model.SupermarketAndPoistionEntity;
import com.wgmf.yxgj.module.business.manageka.model.SupermarketAndPoistionList;
import com.wgmf.yxgj.module.business.manageka.model.SupermarketList;
import com.wgmf.yxgj.module.business.manageka.service.KAManagerService;
import com.wgmf.yxgj.publics.model.BaseSelectorEntity;

import java.util.ArrayList;
import java.util.List;

/**
 * @author XiePing on 2017/9/4 17:13
 *         邮箱：2975837870@qq.com
 */
@SuppressWarnings("all")
public class CustomerVisitPresenter {
    private static final String TAG = "CustomerVisitPresenter";

    private List<BaseSelectorEntity> supermarketNames = new ArrayList<>();
    private List<BaseSelectorEntity> cusPositions = new ArrayList<>();

    private CustomerVisitView customerVisitView;

    public CustomerVisitPresenter(@NonNull CustomerVisitView customerVisitView) {
        this.customerVisitView = customerVisitView;
    }

    List<BaseSelectorEntity> getSupermarketNames() {
        return supermarketNames;
    }

    List<BaseSelectorEntity> getCusPositions() {
        return cusPositions;
    }

    /**
     * 获取商超系统和职位信息
     *
     * @param userInfo 用户信息
     */
    void getData(CommonUserinfoBean userInfo) {
        if (null != userInfo) {
            String staffId = userInfo.getStaffId();
            KAManagerService.getInstance().requestFindSupermarketAndPoistion(staffId, (BaseParentAct) customerVisitView);
        }
    }

    /**
     * 设置商超系统和职位数据
     *
     * @param mSupermarketAndPoistionList 商超系统和职位信息
     */
    void setData(SupermarketAndPoistionList mSupermarketAndPoistionList) {
        if (!mSupermarketAndPoistionList.getResultList().isEmpty()) {
            List<SupermarketAndPoistionEntity> supermarketAndPoistionEntitys = mSupermarketAndPoistionList.getResultList();

            List<CustomerPositionList> customerPositionList = new ArrayList<>();
            List<SupermarketList> supermarketList = new ArrayList<>();

            for (SupermarketAndPoistionEntity supermarketAndPoistionEntity : supermarketAndPoistionEntitys) {
                customerPositionList = supermarketAndPoistionEntity.getCustomerPositionList();
                supermarketList = supermarketAndPoistionEntity.getSupermarketList();
            }
            for (CustomerPositionList customerPosition : customerPositionList) {
                BaseSelectorEntity mModel = new BaseSelectorEntity();
                mModel.setSelectorName(customerPosition.getPositionName());
                mModel.setSelectorId(customerPosition.getAddPositionId());
                cusPositions.add(mModel);
            }
            for (SupermarketList supermarket : supermarketList) {
                BaseSelectorEntity mModel = new BaseSelectorEntity();
                mModel.setSelectorName(supermarket.getSupermarketName());
                mModel.setSelectorId(supermarket.getSupermarketId());
                supermarketNames.add(mModel);
            }
        }
    }

    /**
     * 客户拜访数据提交
     *
     * @param mCustomerVisitEntity 客户拜访数据
     */
    void uploadData(CustomerVisitEntity mCustomerVisitEntity) {
        String content = new Gson().toJson(mCustomerVisitEntity);
        Log.d(TAG, content);
        KAManagerService.getInstance().requestSaveCustomerVisit(content, (BaseParentAct) customerVisitView);
    }

    /**
     * 根据接口返回数据进行服务切换
     *
     * @param result 服务器返回数据
     */
    void switchService(ResultData result) {
        if (null != result) {
            final int id = result.taskID;
            switch (id) {
                case BusinessID.KAManager.MSG_ON_FIND_SUPERMARKET_AND_POISTION: {
                    final String msg = result.getInfo();
                    if (result.isSuccessed()) {
                        SupermarketAndPoistionList mSupermarketAndPoistionList = new Gson().fromJson(msg, SupermarketAndPoistionList.class);
                        Log.d(TAG, "mSupermarketAndPoistionList=" + mSupermarketAndPoistionList.toString());
                        setData(mSupermarketAndPoistionList);
                    }
                }
                break;
                case BusinessID.KAManager.MSG_ON_SAVE_CUSTOMER_VISIT: {
                    final String msg = result.getInfo();
                    if (result.isSuccessed()) {
                        BaseResponse mBaseResponse = new Gson().fromJson(msg, BaseResponse.class);
                        Log.d(TAG, "mBaseResponse=" + mBaseResponse.toString());
                        customerVisitView.saveSuccessed(result.getResultInfo());
                    }
                }
                break;
                default:
                    break;
            }
        }
    }
}
