package com.wgmf.yxgj.module.business.manageproduct.service;

import android.text.TextUtils;
import android.util.Log;

import com.google.gson.Gson;
import com.wgmf.library.base.BaseRequest;
import com.wgmf.library.base.BaseResponse;
import com.wgmf.library.base.ResultData;
import com.wgmf.library.utils.BaseSingleton;
import com.wgmf.yxgj.base.BaseService;
import com.wgmf.yxgj.config.BusinessID;
import com.wgmf.yxgj.global.NetworkParams;

import java.lang.ref.SoftReference;
import java.lang.ref.WeakReference;

/**
 * 货品管理网络请求服务
 *
 * @author XiePing
 */
public class GoodsManagerService extends BaseService {
    private static BaseSingleton<GoodsManagerService, Void> mMainService = new BaseSingleton<GoodsManagerService, Void>() {
        @Override
        protected GoodsManagerService create(Void var1) {
            return new GoodsManagerService();
        }
    };

    public static GoodsManagerService getInstance() {
        return mMainService.get(null);
    }

    private GoodsManagerService() {
    }

    /**
     * GET /productManagement/findOrderGoodsAuditStore 订货审核门店
     */
    public void requestFindOrderGoodsAuditStore(final String staffId, final String saleOrgId, ResultData.BusinessCallback callback) {
        BaseRequest request = new BaseRequest();
        request.taskID = BusinessID.GoodsManager.MSG_ON_FIND_ORDERGOODS_AUDIT_STORE;
        request.callback = new WeakReference<>(callback);
        request.url = NetworkParams.URL_FIND_ORDERGOODS_AUDITSTORE_NEW + "?staffId=" + staffId + "&saleOrgId=" + saleOrgId;
        Log.d(TAG, "请求地址：" + request.url);
        sendGetRequest(request);
    }

    /**
     * GET /productManagement/findAddOrderStore  订货加单门店
     */
    public void requestAddOrderStores(final String staffId, final String saleOrgId, ResultData.BusinessCallback callback) {
        BaseRequest request = new BaseRequest();
//        request.taskID = BusinessID.GoodsManager.MSG_ON_FIND_ORDERGOODS_AUDIT_STORE;
        request.callback = new WeakReference<>(callback);
        request.url = NetworkParams.URL_FIND_ADD_ORDER_STORE + "?staffId=" + staffId + "&saleOrgId=" + saleOrgId;
        Log.d(TAG, "请求地址：" + request.url);
        sendGetRequest(request);
    }

    /**
     * GET /productManagement/findAddOrderProductList  订货加单 - 查询产品
     */
    public void requestAddOrderProductList(final String staffId, String storeNo, String brandId, ResultData.BusinessCallback callback) {
        BaseRequest request = new BaseRequest();
//        request.taskID = BusinessID.GoodsManager.MSG_ON_FIND_ORDERGOODS_AUDIT_STORE;
        request.callback = new WeakReference<>(callback);
        request.url = NetworkParams.URL_FIND_ADD_ORDER_PRODUCT_LIST + "?staffId=" + staffId + "&storeNo=" + storeNo + "&brandId=" + brandId;
        Log.d(TAG, "请求地址：" + request.url);
        sendGetRequest(request);
    }


    /**
     * POST /productManagement/saveOrderGoodsAuditions  订货加单 - 提交订货
     */
    public void requestSaveOrderGoodsAuditions(final String json, ResultData.BusinessCallback callback) {
        BaseRequest request = new BaseRequest();
//        request.taskID = BusinessID.GoodsManager.MSG_ON_FIND_ORDERGOODS_AUDIT_STORE;
        request.callback = new WeakReference<>(callback);
        request.url = NetworkParams.URL_SAVE_ADD_ORDER_PRODUCT_LIST;
        request.json = json;
        Log.d(TAG, "请求地址：" + request.url);
        sendPostJsonRequest(request);
    }

    /**
     * GET /homeBusinessController/findProduct  到家业务 - 查询产品
     */
    public void requestHomeBusinessFindProduct(String productCode, ResultData.BusinessCallback callback) {
        if (TextUtils.isEmpty(productCode)) return;
        BaseRequest request = new BaseRequest();
//        request.taskID = BusinessID.GoodsManager.MSG_ON_FIND_ORDERGOODS_AUDIT_STORE;
        request.callback = new WeakReference<>(callback);
        request.url = NetworkParams.URL_FINDPRODUCT + "?productCode=" + productCode;
        Log.d(TAG, "请求地址：" + request.url);
        sendGetRequest(request);
    }

    /**
     * GET /homeBusinessController/findMarkeName 到家业务 - 查询商超
     */
    public void requestHomeBusinessFindMarke(ResultData.BusinessCallback callback) {
        BaseRequest request = new BaseRequest();
//        request.taskID = BusinessID.GoodsManager.MSG_ON_FIND_ORDERGOODS_AUDIT_STORE;
        request.callback = new WeakReference<>(callback);
        request.url = NetworkParams.URL_FINDMARKE;
        Log.d(TAG, "请求地址：" + request.url);
        sendGetRequest(request);
    }

    /**
     * GET /homeBusinessController/findHomeBusStockList 到家业务 - 查询库存明细
     */
    public void requestHomeBusinessFindStockList(String staffId, String marketName, String proCode, String orgCode, int orgLevel, ResultData.BusinessCallback callback) {
        BaseRequest request = new BaseRequest();
//        request.taskID = BusinessID.GoodsManager.MSG_ON_FIND_ORDERGOODS_AUDIT_STORE;
        request.callback = new WeakReference<>(callback);
        request.url = NetworkParams.URL_FINDSTOCKLIST + "?staffId=" + staffId + "&marketName=" + marketName + "&proCode=" + proCode + "&orgCode=" + orgCode + "&orgLevel=" + orgLevel;
        Log.d(TAG, "请求地址：" + request.url);
        sendGetRequest(request);
    }


    /**
     * GET /productManagement/findOrderGoodsAudit 订货审核
     */
    public void requestFindOrderGoodsAudit(final String type, final String storeNo, final Boolean isFzsjd, final String userName, final String userNameLevel, final String saleOrgId, ResultData.BusinessCallback callback) {
        BaseRequest request = new BaseRequest();
        request.taskID = BusinessID.GoodsManager.MSG_ON_FIND_ORDERGOODS_AUDIT;
        request.callback = new WeakReference<>(callback);
        request.url = NetworkParams.URL_FIND_ORDERGOODS_AUDIT + "?storeNo=" + storeNo + "&type=" + type + "&userName=" + userName + "&userNameLevel=" + userNameLevel + "&saleOrgId=" + saleOrgId + "&isFzsjd=" + isFzsjd;
        Log.d(TAG, "请求地址：" + request.url);
        sendGetRequest(request);
    }

    /**
     * GET /productManagement/findOrderGoodsAuditDeatil 订货审核明细
     */
    public void requestFindOrderGoodsAuditDeatil(final String orderGoodsAuditId,
                                                 ResultData.BusinessCallback callback) {
        BaseRequest request = new BaseRequest();
        request.taskID = BusinessID.GoodsManager.MSG_ON_FIND_ORDERGOODS_AUDIT_DEATIL;
        request.callback = new WeakReference<>(callback);
        request.url = NetworkParams.URL_FIND_ORDERGOODS_AUDIT_DEATIL + "?" + "orderGoodsAuditId=" + orderGoodsAuditId;
        Log.d(TAG, "请求地址：" + request.url);
        sendGetRequest(request);
    }

    /**
     * GET /productManagement/batchFindOrderGoodsDetail 订货批量审核明细
     */
    public void requestBatchFindOrderGoodsDetail(final String storeNo, final Boolean isFzsjd, final String userName, final String userNameLevel, final String saleOrgId, ResultData.BusinessCallback callback) {
        BaseRequest request = new BaseRequest();
        request.taskID = BusinessID.GoodsManager.MSG_ON_BATCH_FIND_ORDERGOODS_DEATIL;
        request.callback = new WeakReference<>(callback);
        request.url = NetworkParams.URL_BATCH_FIND_ORDERGOODS_DEATIL + "?userName=" + userName + "&userNameLevel=" + userNameLevel + "&storeNo=" + storeNo + "&saleOrgId=" + saleOrgId + "&isFzsjd=" + isFzsjd;
        Log.d(TAG, "请求地址：" + request.url);
        sendGetRequest(request);
    }

    /**
     * POST /productManagement/saveUpdateOrderGoodsAuditions 订货审核添加或修改
     */
    public void requestSaveUpdateOrderGoodsAuditions(final String json,
                                                     ResultData.BusinessCallback callback) {
        BaseRequest request = new BaseRequest();
        request.taskID = BusinessID.GoodsManager.MSG_ON_SAVE_UPDATE_ORDERGOODS_AUDITIONS;
        request.callback = new WeakReference<>(callback);
        request.url = NetworkParams.URL_SAVE_UPDATE_ORDERGOODS_AUDITIONS;
        request.json = json;
        Log.d(TAG, "请求地址：" + request.url);
        sendPostJsonRequest(request);
    }

    /**
     * POST /productManagement/batchSaveOrderGoodsAuditions 订货批量审核添加或修改
     */
    public void requestBatchSaveUpdateOrderGoodsAuditions(final String json,
                                                          ResultData.BusinessCallback callback) {
        BaseRequest request = new BaseRequest();
        request.taskID = BusinessID.GoodsManager.MSG_ON_BATCH_SAVE_UPDATE_ORDERGOODS_AUDITIONS;
        request.callback = new WeakReference<>(callback);
        request.url = NetworkParams.URL_BATCH_SAVE_UPDATE_ORDERGOODS_AUDITIONS;
        request.json = json;
        Log.d(TAG, "请求地址：" + request.url);
        sendPostJsonRequest(request);
    }


    /**
     * GET /productManagement/findProductList 订货产品查询
     */
    public void requestFindProductList(final String storeNo, final String type, final int orderBrandId, final String brandList,
                                       ResultData.BusinessCallback callback) {
        BaseRequest request = new BaseRequest();
        request.taskID = BusinessID.GoodsManager.MSG_ON_FIND_PRODUCT_LIST;
        request.callback = new WeakReference<>(callback);
        request.url = NetworkParams.URL_FIND_PRODUCT_LIST + "?" + "storeNo=" + storeNo + "&type=" + type + "&orderBrandId=" + orderBrandId;
        request.json = brandList;
        Log.d(TAG, "请求地址：" + request.url);
        sendPostJsonRequest(request);
    }

    /**
     * POST /productManagement/findInOutProductList 调入调出产品查询
     */
    public void requestFindInOutProductList(final String inStoreNo, final String outStoreNo, final String type, final String brandList,
                                            ResultData.BusinessCallback callback) {
        BaseRequest request = new BaseRequest();
        request.taskID = BusinessID.GoodsManager.MSG_ON_FIND_PRODUCT_LIST;
        request.callback = new WeakReference<>(callback);
        request.url = NetworkParams.URL_FIND_IN_OUT_PRODUCT_LIST + "?" + "inStoreNo=" + inStoreNo + "&outStoreNo=" + outStoreNo + "&type=" + type;
        request.json = brandList;
        Log.d(TAG, "请求地址：" + request.url);
        sendPostJsonRequest(request);
    }

    /**
     * GET /productManagement/findStockGoodsCheckStore 存货盘点门店
     */
    public void requestFindStockGoodsCheckStore(final String url, final String staffId, final String yearMonth, final String saleOrgId,
                                                ResultData.BusinessCallback callback) {
        BaseRequest request = new BaseRequest();
        request.taskID = BusinessID.GoodsManager.MSG_ON_FIND_STOCKGOODS_CHECK_STORE;
        request.callback = new WeakReference<>(callback);
        request.url = url + "?" + "staffId=" + staffId + "&yearMonth=" + yearMonth + "&saleOrgId=" + saleOrgId;
        Log.d(TAG, "请求地址：" + request.url);
        sendGetRequest(request);
    }

    /**
     * GET /productManagement/findStockGoodsCheckDeatils 存货盘点明细
     */
    public void requestFindStockGoodsCheckDeatils(final String url, final String pdId,
                                                  ResultData.BusinessCallback callback) {
        BaseRequest request = new BaseRequest();
        request.taskID = BusinessID.GoodsManager.MSG_ON_FIND_STOCKGOODS_CHECK_DEATILS;
        request.callback = new WeakReference<>(callback);
        request.url = url + "?" + "pdId=" + pdId;
        Log.d(TAG, "请求地址：" + request.url);
        sendGetRequest(request);
    }

    /**
     * POST /productManagement/rejectStockGoodsCheck反审存货盘点
     */
    public void requestRejectStockGoodsCheck(final String staffId, final String storeNo, final String yearMonth,final int pdId,
                                             ResultData.BusinessCallback callback) {
        BaseRequest request = new BaseRequest();
        request.taskID = BusinessID.GoodsManager.MSG_ON_REJECT_STOCKGOODS_CHECK;
        request.callback = new WeakReference<>(callback);
        request.url = NetworkParams.URL_REJECT_STOCKGOODS_CHECK + "?staffId=" + staffId + "&storeNo=" + storeNo + "&yearMonth=" + yearMonth+"&pdId="+pdId;
        request.json = "";
        Log.d(TAG, "请求地址：" + request.url);
        sendPostJsonRequest(request);
    }

    /**
     * POST /productManagement/updateStockGoodsCheck 修改存货盘点
     */
    public void requestUpdateStockGoodsCheck(final String json,
                                             ResultData.BusinessCallback callback) {
        BaseRequest request = new BaseRequest();
        request.taskID = BusinessID.GoodsManager.MSG_ON_UPDATE_STOCKGOODS_CHECK;
        request.callback = new WeakReference<>(callback);
        request.url = NetworkParams.URL_UPDATE_STOCKGOODS_CHECK;
        request.json = json;
        Log.d(TAG, "请求地址：" + request.url);
        sendPostJsonRequest(request);
    }

    /**
     * POST /productManagement/saveTransferredInOrOut 产品调入调出
     */
    public void requestSaveTransferredInOrOut(final String json,
                                              ResultData.BusinessCallback callback) {
        BaseRequest request = new BaseRequest();
        request.taskID = BusinessID.GoodsManager.MSG_ON_SAVE_TRANSFERRED_INOROUT;
        request.callback = new WeakReference<>(callback);
        request.url = NetworkParams.URL_SAVE_TRANSFERRED_INOROUT;
        request.json = json;
        Log.d(TAG, "请求地址：" + request.url);
        sendPostJsonRequest(request);
    }

    /**
     * GET /shopV2/queryDistance  查询门店距离
     */
    public void requestQueryDistance(final String shopIdA, final String shopIdB, ResultData.BusinessCallback callback) {
        BaseRequest request = new BaseRequest();
        request.taskID = BusinessID.GoodsManager.MSG_ON_QUERY_DISTANCE;
        request.callback = new WeakReference<>(callback);
        request.url = NetworkParams.URL_QUERY_DISTANCE + "?shopIdA=" + shopIdA + "&shopIdB=" + shopIdB;
        Log.d(TAG, "请求地址：" + request.url);
        sendGetRequest(request);
    }

    /**
     * GET /productManagement/findTransferredInAndOut 调入调出查询
     */
    public void requestFindTransferredInAndOut(final String url, String staffId, String startDate, String endDate,
                                               ResultData.BusinessCallback callback) {
        BaseRequest request = new BaseRequest();
        request.taskID = BusinessID.GoodsManager.MSG_ON_FIND_TRANSFERRED_INANDOUT;
        request.callback = new WeakReference<>(callback);
        request.url = url + "?" + "staffId=" + staffId + "&startDate=" + startDate + "&endDate=" + endDate;
        Log.d(TAG, "请求地址：" + request.url);
        sendGetRequest(request);
    }

    /**
     * GET /productManagement/findTransferredInAndOutDetail 调入调出查询明细
     */
    public void requestFindTransferredInAndOutDetail(String storeNo, String startDate, String endDate,
                                                     ResultData.BusinessCallback callback) {
        BaseRequest request = new BaseRequest();
        request.taskID = BusinessID.GoodsManager.MSG_ON_FIND_TRANSFERRED_INANDOUT_DETAIL;
        request.callback = new WeakReference<>(callback);
        request.url = NetworkParams.URL_FIND_TRANSFERRED_INANDOUT_DETAIL + "?storeNo=" + storeNo + "&startDate=" + startDate + "&endDate=" + endDate;
        Log.d(TAG, "请求地址：" + request.url);
        sendGetRequest(request);
    }

    /**
     * POST /storeAllot/confirmStoreAllot 门店确认收货
     */
    public void requestConfirmStoreAllot(final String dbBillCode, final int dbId, String userNo, int type,
                                         ResultData.BusinessCallback callback) {
        BaseRequest request = new BaseRequest();
        request.taskID = BusinessID.GoodsManager.MSG_ON_CONFIRM_STORE_ALLOT;
        request.callback = new WeakReference<>(callback);
        request.url = NetworkParams.URL_CONFIRM_STORE_ALLOT + "?dbBillCode=" + dbBillCode + "&dbId=" + dbId + "&userNo=" + userNo + "&type=" + type;
        request.json = "";
        Log.d(TAG, "请求地址：" + request.url);
        sendPostJsonRequest(request);
    }


    /**
     * POST /storeAllot/updateStoreAllot 修改调拨收货
     */
    public void requestUpdateStoreAllot(final String json,
                                        ResultData.BusinessCallback callback) {
        BaseRequest request = new BaseRequest();
        request.taskID = BusinessID.GoodsManager.MSG_ON_UPDATE_STORE_ALLOT;
        request.callback = new WeakReference<>(callback);
        request.url = NetworkParams.URL_UPDATE_STORE_ALLOT;
        request.json = json;
        Log.d(TAG, "请求地址：" + request.url);
        sendPostJsonRequest(request);
    }


    @Override
    protected void onTaskDone(ResultData data) {
        if (null != data) {
            final int id = data.taskID;
            switch (id) {
                case BusinessID.GoodsManager.MSG_ON_FIND_ORDERGOODS_AUDIT_STORE:
                case BusinessID.GoodsManager.MSG_ON_FIND_ORDERGOODS_AUDIT:
                case BusinessID.GoodsManager.MSG_ON_FIND_ORDERGOODS_AUDIT_DEATIL:
                case BusinessID.GoodsManager.MSG_ON_SAVE_UPDATE_ORDERGOODS_AUDITIONS:
                case BusinessID.GoodsManager.MSG_ON_FIND_PRODUCT_LIST:
                case BusinessID.GoodsManager.MSG_ON_BATCH_FIND_ORDERGOODS_DEATIL:
                case BusinessID.GoodsManager.MSG_ON_FIND_STOCKGOODS_CHECK_STORE:
                case BusinessID.GoodsManager.MSG_ON_FIND_STOCKGOODS_CHECK_DEATILS:
                case BusinessID.GoodsManager.MSG_ON_REJECT_STOCKGOODS_CHECK:
                case BusinessID.GoodsManager.MSG_ON_UPDATE_STOCKGOODS_CHECK:
                case BusinessID.GoodsManager.MSG_ON_SAVE_TRANSFERRED_INOROUT:
                case BusinessID.GoodsManager.MSG_ON_FIND_TRANSFERRED_INANDOUT:
                case BusinessID.GoodsManager.MSG_ON_FIND_TRANSFERRED_INANDOUT_DETAIL:
                case BusinessID.GoodsManager.MSG_ON_QUERY_DISTANCE:
                case BusinessID.GoodsManager.MSG_ON_CONFIRM_STORE_ALLOT:
                case BusinessID.GoodsManager.MSG_ON_UPDATE_STORE_ALLOT: {
                    if (data.isSuccessed()) {
                        final String json = data.getInfo();
                        if (!TextUtils.isEmpty(json)) {
                            BaseResponse mBaseResponse = new Gson().fromJson(json, BaseResponse.class);
                            Log.d(TAG, "id:" + id + ";mBaseResponse=" + mBaseResponse.toString());
                            data.setResultCode(mBaseResponse.retCode);
                            data.setResultInfo(mBaseResponse.retInfo);
                        }
                    }
                }
                break;
                default:
                    break;
            }
        }
    }
}