package com.wgmf.yxgj.module.business.manageproduct.ui

import android.app.Activity
import android.content.Intent
import android.os.Bundle
import android.support.v7.widget.LinearLayoutManager
import android.text.Editable
import android.text.TextUtils
import android.text.TextWatcher
import android.view.View
import android.widget.TextView
import com.alibaba.android.arouter.facade.annotation.Route
import com.google.gson.Gson
import com.wgmf.library.utils.JsonDominator
import com.wgmf.yxgj.base.BaseParentAct
import com.wgmf.yxgj.dialog.LoadWaitDominator
import com.wgmf.yxgj.module.business.manageproduct.R
import com.wgmf.yxgj.module.business.manageproduct.model.GoodsAddOrderStoreListEntity
import com.wgmf.yxgj.module.business.manageproduct.service.GoodsManagerService
import com.wgmf.yxgj.widgets.EditText.ClearEditText
import com.xp.arouter.RouterParams
import kotlinx.android.synthetic.main.activity_add_order_store.*
import org.jetbrains.anko.find
import java.util.*

/**
 * @author Sasuke on 2020-4-27 0027.
 * 货品管理-订货加单门店列表
 */
@Route(path = RouterParams.URL_GOODSADDORDERENTRYLISTACTIVITY)
class GoodsAddOrderEntryListActivity : BaseParentAct() {

    private val mBranchTitle by lazy { intent.getStringExtra("branchTitle") }

    lateinit var mLoadWait: LoadWaitDominator
    private var mListShow: MutableList<GoodsAddOrderStoreListEntity.ShopInfo> = mutableListOf()
    private var mListStore: List<GoodsAddOrderStoreListEntity.ShopInfo> = ArrayList()

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        setContentView(R.layout.activity_add_order_store)
        initTitle()
        initView()
        addOrderStores()
    }

    private fun addOrderStores() {
        mLoadWait.show(LoadWaitDominator.LOADING)
        userInfo?.let {
            GoodsManagerService.getInstance().requestAddOrderStores(it.staffId, it.organizationId) {
                mLoadWait.dismissAll()
                if (!isFinishing && it.isSuccessed) {
                    var entity = Gson().fromJson(it.info, GoodsAddOrderStoreListEntity::class.java)
                    JsonDominator.loadFromSD(GoodsAddOrderStoreListEntity::class.java)?.let {
                        entity = it
                    }
                    if (entity.resultList != null) {
                        mListStore = entity.resultList!!
                        addOrderStoreRv.adapter = GoodsAddOrderEntryAdapter(this, entity.resultList)
                    } else {
                        mLoadWait.show(LoadWaitDominator.NO_DATA)
                    }

                } else {
                    mLoadWait.show(LoadWaitDominator.NET_ERROR)
                }
            }
        }
    }

    private fun initView() {
        mLoadWait = LoadWaitDominator(this, containerLayout)
        addOrderStoreRv.layoutManager = LinearLayoutManager(this)
    }

    override fun initTitle() {
        super.initTitle()
        homeTitleText.text = mBranchTitle
        homeTitleBackLl.visibility = View.VISIBLE
        listTitleTv.find<TextView>(R.id.auditing_goods_header_tv2)
            .text = getString(R.string.add_order_shop_no)
        store_name_et.find(R.id.store_name_et) as ClearEditText
        store_name_et.visibility = View.VISIBLE
        store_name_et.addTextChangedListener(object : TextWatcher {
            override fun beforeTextChanged(s: CharSequence, start: Int, count: Int, after: Int) {

            }

            override fun onTextChanged(s: CharSequence, start: Int, before: Int, count: Int) {

            }

            override fun afterTextChanged(s: Editable) {
                textChanged()
            }
        })
    }

    fun textChanged() {
        val itemId = store_name_et.text.toString().trim { it <= ' ' }
        if (TextUtils.isEmpty(itemId)) {
            mListShow.clear()
            for (p in mListStore) {
                mListShow.add(p)
            }
        } else {
            mListShow.clear()
            for (p in mListStore) {
                if (null != p.shopName) {
                    if (p.shopName!!.contains(itemId)) {
                        mListShow.add(p)
                    }
                }
            }
        }
        if (null != addOrderStoreRv.adapter) {
            addOrderStoreRv.adapter = GoodsAddOrderEntryAdapter(this, mListShow)
        }
    }

    override fun onActivityResult(requestCode: Int, resultCode: Int, data: Intent?) {
        super.onActivityResult(requestCode, resultCode, data)
        when (resultCode) {
            Activity.RESULT_OK -> finish()
        }
    }
}