package com.wgmf.yxgj.module.business.manageproduct.ui

import android.os.Bundle
import android.support.design.widget.TabLayout
import android.support.v4.app.Fragment
import android.support.v4.content.ContextCompat
import android.support.v4.view.ViewPager
import android.util.Log
import android.view.View
import android.view.ViewGroup
import android.widget.Button
import android.widget.LinearLayout
import com.google.gson.Gson
import com.wgmf.library.base.ResultData
import com.wgmf.library.utils.StringUtil
import com.wgmf.library.utils.ThreadManager
import com.wgmf.yxgj.base.BaseParentAct
import com.wgmf.yxgj.config.BusinessID
import com.wgmf.yxgj.db.GreenDaoManager
import com.wgmf.yxgj.db.OrderGoodsAuditBatchDetailDao
import com.wgmf.yxgj.db.OrderGoodsAuditDetailDao
import com.wgmf.yxgj.dialog.LoadWaitDominator
import com.wgmf.yxgj.global.ConstantParams
import com.wgmf.yxgj.model.BatchOrderAuditBillCode
import com.wgmf.yxgj.model.OrderGoodsAuditBatchDetail
import com.wgmf.yxgj.model.OrderGoodsAuditDetail
import com.wgmf.yxgj.module.business.manageproduct.R
import com.wgmf.yxgj.module.business.manageproduct.model.ProductAndSuggestOrderGoodsList
import com.wgmf.yxgj.module.business.manageproduct.model.ProductParamEntity
import com.wgmf.yxgj.module.business.manageproduct.model.ProductParamListEntity
import com.wgmf.yxgj.module.business.manageproduct.service.GoodsManagerService
import com.wgmf.yxgj.utils.isNotNullOrSize
import com.wgmf.yxgj.widgets.EditText.ClearEditText
import kotlinx.android.synthetic.main.include_auditing_goods_info.*
import org.greenrobot.eventbus.EventBus
import org.greenrobot.eventbus.Subscribe
import java.io.Serializable

/**
 * 产品调入调出、订货审核选择产品
 */
class GoodsAuditingAddProductsActivity : BaseParentAct(), ViewPager.OnPageChangeListener,
    View.OnClickListener {

    /**
     * 订单审核数据
     */
    private var mOrderGoodsAuditDetailList: MutableList<OrderGoodsAuditDetail> = mutableListOf()

    private val mOrderGoodsAuditDetailDao: OrderGoodsAuditDetailDao by lazy {
        GreenDaoManager.getInstance().getDaoSession(this).orderGoodsAuditDetailDao
    }

    /**
     * 订单批量审核数据
     */
    private var mOrderGoodsAuditBatchDetailList: MutableList<OrderGoodsAuditBatchDetail> =
        mutableListOf()

    private val mOrderGoodsAuditBatchDetailDao: OrderGoodsAuditBatchDetailDao by lazy {
        GreenDaoManager.getInstance().getDaoSession(this).orderGoodsAuditBatchDetailDao
    }

    private var mViewPagerAdapter: AddProductsTabLayoutViewPagerAdapter? = null

    /**
     * 调出门店
     */
    private val mOutStoreNo: String by lazy {
        intent.getStringExtra("outStoreNo")
    }

    /**
     * 调入门店
     */
    private val mInStoreNo: String by lazy {
        intent.getStringExtra("inStoreNo")
    }

    /**
     * ype ='ZC' 表示固定资产，type='DH'表示订货审核的产品
     */
    private val mType: Int by lazy {
        intent.getIntExtra("type", ORDER_GOODS_AUDIT)
    }

    private val mOrderBrandId: Int by lazy {
        intent.getIntExtra("orderBrandId", -1)
    }

    private val mOrderGoodsAuditId: Int by lazy {
        intent.getIntExtra("orderGoodsAuditId", -1)
    }

    private val mOrderGoodsBillCode: String by lazy {
        intent.getStringExtra("orderGoodsBillCode")
    }

    private var mProductNameEt: ClearEditText? = null
    private var mProductNameQueryBtn: Button? = null

    private var mSalesCont: Button? = null
    private var mTablayout: TabLayout? = null
    private var mViewPager: ViewPager? = null

    private val mProductParamList: MutableList<ProductParamEntity> = ArrayList()

    private var mProductAndSuggestOrderGoodsList: List<ProductAndSuggestOrderGoodsList>? = null

    /**
     * TabLayout中的tab标题
     */
    private val mTitles: MutableList<String> = mutableListOf()

    /**
     * 填充到ViewPager中的Fragment
     */
    private val mFragmentList: MutableList<Fragment> = mutableListOf()

    lateinit var mLoadWait: LoadWaitDominator

    private var mInitCount = 0

    /**
     * tablayout选择角标
     */
    private var mTabSelectPostion = 0

    companion object {
        /**
         * 订货审核的产品
         */
        const val ORDER_GOODS_AUDIT: Int = 1

        /**
         * 订货批量审核的产品
         */
        const val ORDER_GOODS_AUDIT_BATCH: Int = 2

        /**
         * 固定资产
         */
        const val FIXED_ASSETS: Int = 3
    }

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        setContentView(R.layout.activity_tablayout)
        initTitle()
        initContent()
        findProductList()
    }

    override fun initTitle() {
        super.initTitle()
        homeTitleText.text = "继续添加"
        homeTitleBackLl.visibility = View.VISIBLE
    }

    private fun initContent() {
        EventBus.getDefault().register(this)

        mLoadWait = LoadWaitDominator(mContext, findViewById(R.id.public_container_fl))
        findViewById<ViewGroup>(R.id.public_search_edt_view).apply {
            mProductNameEt = findViewById<ClearEditText>(R.id.store_name_et).apply {
                setHint(R.string.goods_auditing_product_keyword_tip)
                visibility = View.VISIBLE
                setOnClearClickListener(object : ClearEditText.OnClearClickListener {
                    override fun onClear() {
                        setFragmentFilterCondition(mTabSelectPostion, "")
                    }
                })
            }

            mProductNameQueryBtn = findViewById<Button>(R.id.store_name_query_btn).apply {
                visibility = View.VISIBLE
                setOnClickListener {
                    val keyword = mProductNameEt?.text?.trim().toString()
                    setFragmentFilterCondition(mTabSelectPostion, keyword)
                }
            }
        }

        mTablayout = findViewById(R.id.tab_layout)
        mViewPager = findViewById(R.id.viewpager)
        mSalesCont = findViewById(R.id.public_comfirm_btn_total_left_btn)

        findViewById<LinearLayout>(R.id.public_comfirm_btn_total_ll).visibility = View.VISIBLE
        findViewById<Button>(R.id.public_comfirm_btn_total_right_btn).setOnClickListener(this)

        if (mType == ORDER_GOODS_AUDIT_BATCH) {
            mOrderGoodsAuditBatchDetailList =
                GreenDaoManager.getInstance()
                    .getDaoSession(this).orderGoodsAuditBatchDetailDao.loadAll()
            mInitCount = mOrderGoodsAuditBatchDetailList.size
        } else {
            mOrderGoodsAuditDetailList =
                GreenDaoManager.getInstance().getDaoSession(this).orderGoodsAuditDetailDao.loadAll()
            mInitCount = mOrderGoodsAuditDetailList.size
        }
    }

    /**
     * 设置Fragment过滤条件
     */
    private fun setFragmentFilterCondition(position: Int, keyword: String) {
        if (position < mFragmentList.size) {
            val fragment = mFragmentList.get(position)
            val addProductsTabLayoutListFragment =
                fragment as AddProductsTabLayoutListFragment
            addProductsTabLayoutListFragment.setDataFilterCondition(keyword)
        }
    }

    private fun findProductList() {
        userInfo?.let {
            showDialog()
            val brandLists = "{\"brandList\":" + Gson().toJson(brandList) + "}"
            if (mType == ORDER_GOODS_AUDIT || mType == ORDER_GOODS_AUDIT_BATCH) {
                //请求订货审核的产品数据 ype ='ZC' 表示固定资产，type='DH'表示订货审核的产品
                GoodsManagerService.getInstance().requestFindProductList(
                    mOutStoreNo,
                    "DH",
                    mOrderBrandId,
                    brandLists,
                    this@GoodsAuditingAddProductsActivity
                )
            } else {
                //请求调入调出的产品数据
                GoodsManagerService.getInstance().requestFindInOutProductList(
                    mInStoreNo,
                    mOutStoreNo,
                    "CPML",
                    brandLists,
                    this@GoodsAuditingAddProductsActivity
                )
            }
        }
    }

    private fun configViews() {
        // 初始化ViewPager的适配器，并设置给它
        mViewPagerAdapter = AddProductsTabLayoutViewPagerAdapter(
            supportFragmentManager, mTitles, mFragmentList
        )
        if (mViewPagerAdapter != null) {
            mViewPager?.adapter = mViewPagerAdapter
            // 设置ViewPager最大缓存的页面个数
            mViewPager?.offscreenPageLimit = 5
            // 给ViewPager添加页面动态监听器（为了让Toolbar中的Title可以变化相应的Tab的标题）
            mViewPager?.addOnPageChangeListener(this@GoodsAuditingAddProductsActivity)
            mTablayout?.tabMode = TabLayout.MODE_SCROLLABLE
            // 设置TabLayout的指示器高度为0，即达到了隐藏Indicator的目的
            mTablayout?.setSelectedTabIndicatorHeight(0)
            mTablayout?.setBackgroundColor(ContextCompat.getColor(mContext, R.color.normal_bg))
            // 将TabLayout和ViewPager进行关联，让两者联动起来
            mTablayout?.setupWithViewPager(mViewPager)
            // 设置Tablayout的Tab显示ViewPager的适配器中的getPageTitle函数获取到的标题
            mTablayout?.setTabsFromPagerAdapter(mViewPagerAdapter)
        }
    }

    override fun onPageSelected(position: Int) {
        this.mTabSelectPostion = position
        if (mTitles.isNotEmpty()) {
            mTablayout?.newTab()?.text = mTitles[position]
        }
    }

    override fun onPageScrolled(position: Int, positionOffset: Float, positionOffsetPixels: Int) {}

    override fun onPageScrollStateChanged(state: Int) {}

    /**
     * 已选添加审核产品数
     * @param item 产品列表
     */
    @Subscribe
    fun onEventMainThread(item: List<ProductAndSuggestOrderGoodsList>?) {
        this.mProductAndSuggestOrderGoodsList = item
    }

    /**
     * 增加审核批量数据到数据库中
     */
    private fun addSelectAuditBatchDetailDataToDb(item: List<ProductAndSuggestOrderGoodsList>?) {
        mOrderGoodsAuditBatchDetailList.clear()
        item?.let {
            if (it.isNotEmpty()) {
                for (i in it.indices) {
                    if (it[i].fixedProduct.isChoice()) {
                        // 审核提交的订货单
                        val orderGoodsAuditBatchDetail = OrderGoodsAuditBatchDetail().apply {
                            // 创建时间
                            //createTime = it[i].createTime
                            //产品BillCode/资材调拨时用
                            //productBillCode = it[i].productBillCode
                            //产品库存
                            //productCapitalReceiptsStock = it[i].productCapitalReceiptsStock

                            val productSuggestOrderGoodsNum = it[i].productSuggestOrderGoodsNum
                            if (null != productSuggestOrderGoodsNum) {

                                // 最大建议订货量
                                maxSuggestOrderGoodsNum =
                                    productSuggestOrderGoodsNum.productMaxSOrderGoodsNum
                                //产品前30天销售数量
                                productLastMonthSaleNum =
                                    productSuggestOrderGoodsNum.productLastMonthSaleNum
                                //产品库存数量
                                productStockNum =
                                    productSuggestOrderGoodsNum.productStockNum
                                //建议订货量
                                suggestOrderGoodsNum =
                                    productSuggestOrderGoodsNum.productSOrderGoodsNum
                                //已提交数量
                                productAlreadyOrderNum =
                                    productSuggestOrderGoodsNum.productAlreadyOrderNum
                                //产品在途数量
                                productFutureNum =
                                    productSuggestOrderGoodsNum.productFutureNum
                                //近30天已订货数量
                                productLastMonthOrderNum =
                                    productSuggestOrderGoodsNum.productLastMonthOrderNum
                                //产品大类父类
                                productBigFatherType =
                                    productSuggestOrderGoodsNum.productBigFatherType
                                //产品大类
                                productBigType =
                                    productSuggestOrderGoodsNum.productBigType
                                //产品图片
                                productImage =
                                    productSuggestOrderGoodsNum.productImage
                                //类型（是UPDATE =0 或 INSERT =1）
                                type = 1
                                //新添加的产品原订货数量为0
                                // 订货金额
                                orderGoodsAmount = "0"
                                //订货数量
                                orderGoodsNum = 0.0
                                //处理人工号
                                userNo = userInfo.staffId
                            }

                            batchOrderAuditBillCode = Gson().toJson(
                                listOf(
                                    BatchOrderAuditBillCode(
                                        mOrderGoodsBillCode,
                                        mOrderGoodsAuditId,
                                        0.0,
                                        productSuggestOrderGoodsNum?.orderGoodsAuditNum ?: 0.0,
                                        mOrderBrandId
                                    )
                                )
                            )

                            val fixedProduct = it[i].fixedProduct
                            if (null != fixedProduct) {
                                //类型（是UPDATE =0 或 INSERT =1）
                                type = 1
                                //产品箱装数量
                                productBoxNum = fixedProduct.productPack
                                //产品编码
                                productCode = fixedProduct.productCode
                                //产品Id
                                productId = fixedProduct.proId
                                //产品名称
                                productName = fixedProduct.productName
                                //产品价格
                                productPrice = fixedProduct.productPrice
                                //产品单位
                                productUnit = fixedProduct.productUnit
                                //产品单位Id
                                productUnitId = fixedProduct.productUnitId
                                //产品大类
                                //setProductBigType(fixedProduct.getProductBigType());
                                //产品大类父类
                                //setProductBigFatherType(fixedProduct.getProductBigFatherType());
                                //产品类别
                                //productType = fixedProduct.productType
                                //产品规格
                                //productPack = fixedProduct.productPack
                                //产品图片
                                productImage = fixedProduct.productImage
                            }
                        }
                        mOrderGoodsAuditBatchDetailDao.insertOrReplaceInTx(
                            orderGoodsAuditBatchDetail
                        )
                    } else {
                        mOrderGoodsAuditBatchDetailDao.deleteByKey(it[i].fixedProduct.proId)
                    }
                }
            }
        }

        mOrderGoodsAuditBatchDetailList = mOrderGoodsAuditBatchDetailDao.loadAll();
        val checkedCount = mOrderGoodsAuditBatchDetailList.size
        ThreadManager.runOnUiThread {
            //显示选中的条目数
            mSalesCont?.text = StringUtil.formatString(
                mContext.getString(R.string.select_count),
                checkedCount - mInitCount
            )
        }
    }

    /**
     * 增加审核数据到数据库中
     */
    private fun addSelectAuditDetailDataToDb(item: List<ProductAndSuggestOrderGoodsList>?) {
        mOrderGoodsAuditDetailList.clear()
        item?.let {
            if (it.isNotEmpty()) {
                for (i in it.indices) {
                    if (it[i].fixedProduct.isChoice()) {
                        // 审核提交的订货单
                        val orderGoodsAuditDetail = OrderGoodsAuditDetail().apply {
                            // 创建时间
                            createTime = it[i].createTime
                            //产品BillCode/资材调拨时用
                            productBillCode = it[i].productBillCode
                            //产品库存
                            productCapitalReceiptsStock = it[i].productCapitalReceiptsStock

                            val productSuggestOrderGoodsNum = it[i].productSuggestOrderGoodsNum
                            if (null != productSuggestOrderGoodsNum) {
                                //订货审核Id
                                orderGoodsAuditId = mOrderGoodsAuditId
                                // 最大建议订货量
                                maxSuggestOrderGoodsNum =
                                    productSuggestOrderGoodsNum.productMaxSOrderGoodsNum
                                // 审核数量
                                orderGoodsAuditNum =
                                    productSuggestOrderGoodsNum.orderGoodsAuditNum
                                //产品前30天销售数量
                                productLastMonthSaleNum =
                                    productSuggestOrderGoodsNum.productLastMonthSaleNum
                                //产品库存数量
                                productStockNum =
                                    productSuggestOrderGoodsNum.productStockNum
                                //建议订货量
                                suggestOrderGoodsNum =
                                    productSuggestOrderGoodsNum.productSOrderGoodsNum
                                //已提交数量
                                productAlreadyOrderNum =
                                    productSuggestOrderGoodsNum.productAlreadyOrderNum
                                //产品在途数量
                                productFutureNum =
                                    productSuggestOrderGoodsNum.productFutureNum
                                //近30天已订货数量
                                productLastMonthOrderNum =
                                    productSuggestOrderGoodsNum.productLastMonthOrderNum
                                //产品大类父类
                                productBigFatherType =
                                    productSuggestOrderGoodsNum.productBigFatherType
                                //产品大类
                                productBigType =
                                    productSuggestOrderGoodsNum.productBigType
                                //产品图片
                                productImage =
                                    productSuggestOrderGoodsNum.productImage
                                //类型（是UPDATE =0 或 INSERT =1）
                                type = 1
                                //新添加的产品原订货数量为0
                                // 订货金额
                                orderGoodsAmount = "0"
                                //订货数量
                                orderGoodsNum = 0.0
                                //处理人工号
                                userNo = userInfo.staffId
                            }

                            val fixedProduct = it[i].fixedProduct
                            if (null != fixedProduct) {
                                //类型（是UPDATE =0 或 INSERT =1）
                                type = 1
                                //产品箱装数量
                                productBoxNum = fixedProduct.productPack
                                //产品编码
                                productCode = fixedProduct.productCode
                                //产品Id
                                productId = fixedProduct.proId
                                //产品名称
                                productName = fixedProduct.productName
                                //产品价格
                                productPrice = fixedProduct.productPrice
                                //产品单位
                                productUnit = fixedProduct.productUnit
                                //产品单位Id
                                productUnitId = fixedProduct.productUnitId
                                //产品大类
                                //setProductBigType(fixedProduct.getProductBigType());
                                //产品大类父类
                                //setProductBigFatherType(fixedProduct.getProductBigFatherType());
                                //产品类别
                                productType = fixedProduct.productType
                                //产品规格
                                productPack = fixedProduct.productPack
                                //产品图片
                                productImage = fixedProduct.productImage
                                //浮点型
                                proIsDecimal = fixedProduct.proIsDecimal
                            }
                        }
                        mOrderGoodsAuditDetailDao.insertOrReplaceInTx(orderGoodsAuditDetail)
                    } else {
                        mOrderGoodsAuditDetailDao.deleteByKey(it[i].fixedProduct.proId)
                    }
                }
            }
        }

        mOrderGoodsAuditDetailList = mOrderGoodsAuditDetailDao.loadAll();
        val checkedCount = mOrderGoodsAuditDetailList.size
        ThreadManager.runOnUiThread {
            //显示选中的条目数
            mSalesCont?.text = StringUtil.formatString(
                mContext.getString(R.string.select_count),
                checkedCount - mInitCount
            )
        }
    }

    private fun setData(item: ProductParamListEntity) {
        mProductParamList.clear()
        if (item.resultList.isNotEmpty()) {
            mProductParamList.addAll(item.resultList)
        }
        for (i in mProductParamList.indices) {
            mTitles.add(mProductParamList[i].productType)
            val bundle = Bundle()
            bundle.putInt("flag", i)
            bundle.putString("productType", mProductParamList[i].productType)
            bundle.putSerializable(
                "productAndSuggestOrderGoodsList",
                mProductParamList[i].productAndSuggestOrderGoodsList as Serializable
            )
            val fragment = AddProductsTabLayoutListFragment()
            fragment.setData(bundle)
            //mFragment.setArguments(mBundle);
            mFragmentList.add(i, fragment)
        }
        configViews()
    }

    override fun onBusinessResultAtMainThread(result: ResultData?) {
        super.onBusinessResultAtMainThread(result)
        dismissDialog()
        mLoadWait.dismissAll()
        result?.let {
            if (it.taskID == BusinessID.GoodsManager.MSG_ON_FIND_PRODUCT_LIST) {
                if (!isFinishing && it.isSuccessed) {
                    val entity = Gson().fromJson(
                        it.info,
                        ProductParamListEntity::class.java
                    )
                    Log.d(
                        TAG,
                        "mProductParamListEntity=$entity"
                    )
                    if (ConstantParams.CONSTANT_PARAMS_0 == entity.retCode) {
                        //将已经在订货审核列表的产品项移除
                        if (entity.resultList.isNotNullOrSize()) {
                            for (i in entity.resultList.indices) {
                                if (entity.resultList[i].productAndSuggestOrderGoodsList.isNotNullOrSize()) {
                                    val productAndSuggestOrderGoodsList =
                                        entity.resultList[i].productAndSuggestOrderGoodsList
                                    if (mType == ORDER_GOODS_AUDIT_BATCH) {
                                        for (k in mOrderGoodsAuditBatchDetailList.indices) {
                                            var j = 0
                                            while (j < productAndSuggestOrderGoodsList.size) {
                                                if (null != productAndSuggestOrderGoodsList[j].fixedProduct && mOrderGoodsAuditBatchDetailList[k].productId == productAndSuggestOrderGoodsList[j].fixedProduct.proId) {
                                                    productAndSuggestOrderGoodsList.removeAt(j)
                                                    j--
                                                }
                                                j++
                                            }
                                        }
                                    } else {
                                        for (k in mOrderGoodsAuditDetailList.indices) {
                                            var j = 0
                                            while (j < productAndSuggestOrderGoodsList.size) {
                                                if (null != productAndSuggestOrderGoodsList[j].fixedProduct && mOrderGoodsAuditDetailList[k].productId == productAndSuggestOrderGoodsList[j].fixedProduct.proId) {
                                                    productAndSuggestOrderGoodsList.removeAt(j)
                                                    j--
                                                }
                                                j++
                                            }
                                        }
                                    }
                                }
                            }
                            //将已订产品移除后的产品列表显示在界面上
                            setData(entity)
                        }
                    } else {
                        mLoadWait.show(entity.retInfo)
                    }
                } else {
                    mLoadWait.show(LoadWaitDominator.NET_ERROR)
                }
            }
        }
    }

    override fun onClick(v: View) {
        //点击确认按钮，将添加后的产品返回给订货列表
        if (v.id == R.id.public_comfirm_btn_total_right_btn) {
            ThreadManager.runOnThread {
                mProductAndSuggestOrderGoodsList?.let {
                    if (mType == ORDER_GOODS_AUDIT_BATCH) {
                        addSelectAuditBatchDetailDataToDb(mProductAndSuggestOrderGoodsList)
                        EventBus.getDefault().post(mOrderGoodsAuditBatchDetailList)
                    } else {
                        addSelectAuditDetailDataToDb(mProductAndSuggestOrderGoodsList)
                        EventBus.getDefault().post(mOrderGoodsAuditDetailList)
                    }
                }

                ThreadManager.runOnUiThread {
                    finish()
                }
            }
        }
    }

    override fun onDestroy() {
        super.onDestroy()
        EventBus.getDefault().unregister(this)
    }
}