package com.wgmf.yxgj.module.business.manageproduct.ui

import android.content.Context
import android.support.v7.widget.RecyclerView
import android.text.TextUtils
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import android.widget.TextView
import com.wgmf.library.utils.DateUtil
import com.wgmf.library.utils.StringUtil
import com.wgmf.yxgj.dialog.AdDialog
import com.wgmf.yxgj.module.business.manageproduct.R
import com.wgmf.yxgj.module.business.manageproduct.model.ProductAndSuggestOrderGoodsList
import org.greenrobot.eventbus.EventBus
import org.jetbrains.anko.find
import java.util.*

class GoodsAuditingAddProductsAdapter(
    private val context: Context?,
    dataList: List<ProductAndSuggestOrderGoodsList>?
) :
    RecyclerView.Adapter<GoodsAuditingAddProductsAdapter.ViewHolder>() {

    private var mProductAndSuggestOrderGoodsList: MutableList<ProductAndSuggestOrderGoodsList> =
        mutableListOf()

    init {
        dataList?.let {
            mProductAndSuggestOrderGoodsList.clear()
            mProductAndSuggestOrderGoodsList.addAll(it)
        }
    }

    /**
     * 选中的产品数据
     */
    private val mCheckedOrderGoodsList: MutableList<ProductAndSuggestOrderGoodsList> =
        mutableListOf()

    override fun onCreateViewHolder(parent: ViewGroup, viewType: Int): ViewHolder {
        return ViewHolder(
            LayoutInflater.from(parent.context)
                .inflate(R.layout.list_item_add_chioce_view, parent, false)
        )
    }

    override fun onBindViewHolder(holder: ViewHolder, pos: Int) {
        val item = mProductAndSuggestOrderGoodsList[pos]
        if (null != item.fixedProduct) {
            if (item.fixedProduct.isChoice()) {
                holder.choice.setBackgroundResource(R.drawable.square_orange)
            } else {
                holder.choice.setBackgroundResource(R.drawable.square_gray)
            }
            holder.name.text = StringUtil.formatString(
                context?.getString(R.string.add_product_name_unit),
                item.fixedProduct.productName,
                item.fixedProduct.productCode
            )
            if (!TextUtils.isEmpty(item.fixedProduct.productImage)) {
                holder.img.visibility = View.VISIBLE
            } else {
                holder.img.visibility = View.GONE
            }
            holder.choice.setOnClickListener {
                checkStatus(
                    !item.fixedProduct.isChoice(),
                    holder,
                    item,
                    pos
                )
            }
            holder.img.setOnClickListener { showAdDialog(context, item.fixedProduct.productImage) }
        }
    }

    override fun getItemCount(): Int {
        return mProductAndSuggestOrderGoodsList.size
    }

    class ViewHolder(itemView: View) : RecyclerView.ViewHolder(itemView) {
        val name = itemView.find<TextView>(R.id.content_text)
        val choice = itemView.find<TextView>(R.id.content_choice)
        val img = itemView.find<TextView>(R.id.content_img)
    }

    private fun checkStatus(
        isChecked: Boolean,
        holder: ViewHolder,
        item: ProductAndSuggestOrderGoodsList,
        position: Int
    ) {
        if (isChecked) {
            holder.choice.setBackgroundResource(R.drawable.square_orange)
            item.fixedProduct.setChoice(true)
        } else {
            holder.choice.setBackgroundResource(R.drawable.square_gray)
            item.fixedProduct.setChoice(false)
        }
        item.createTime = DateUtil.getMillis(Date())
        mCheckedOrderGoodsList.add(mProductAndSuggestOrderGoodsList[position])
        EventBus.getDefault().post(mCheckedOrderGoodsList)
    }

    /**
     * 弹出图片弹窗
     *
     */
    private fun showAdDialog(context: Context?, adInfo: String) {
        val adDialog = AdDialog(context, adInfo)
        //点击空白区域能不能退出
        adDialog.setCanceledOnTouchOutside(false)
        //按返回键能能退出
        adDialog.setCancelable(true)
        adDialog.setClickLink(adInfo)
        adDialog.setLinkType("url")
        adDialog.show()
    }
}