package com.wgmf.yxgj.module.business.manageproduct.ui

import android.content.Context
import android.graphics.Typeface
import android.graphics.drawable.Drawable
import android.os.Handler
import android.support.v4.content.ContextCompat
import android.support.v7.widget.RecyclerView
import android.text.SpannableString
import android.text.Spanned
import android.text.method.LinkMovementMethod
import android.text.style.*
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import android.widget.*
import com.squareup.picasso.Callback
import com.squareup.picasso.Picasso
import com.wgmf.yxgj.dialog.AdDialog
import com.wgmf.yxgj.model.OrderGoodsAuditBatchDetail
import com.wgmf.yxgj.model.OrderGoodsAuditDetail
import com.wgmf.yxgj.model.OrderGoodsStoreWeekDayAndCycle
import com.wgmf.yxgj.module.business.manageproduct.R
import com.wgmf.yxgj.module.business.manageproduct.model.OrderGoodsAuditDetailUploadListEntity
import com.wgmf.yxgj.module.business.manageproduct.model.OrderGoodsAuditOrderReviewEntity
import com.wgmf.yxgj.utils.StringUtils
import org.jetbrains.anko.find
import java.util.*

/**
 * @author LW on 2021-9-13 0013.
 *
 */
class GoodsAuditingBatchDetailsAdapter(
    private val context: Context,
    dataList: MutableList<OrderGoodsAuditBatchDetail>? = mutableListOf(),
    private val listener: OnAdapterItemClickListener
) : RecyclerView.Adapter<GoodsAuditingBatchDetailsAdapter.GoodsAuditingBatchDetailsViewHolder>() {

    private val mAuditingList: MutableList<OrderGoodsAuditBatchDetail> =
        mutableListOf()

    private val mHandler = Handler()

    init {
        dataList?.let {
            mAuditingList.clear()
            mAuditingList.addAll(comparatorData(it))
        }
    }

    interface OnAdapterItemClickListener {
        fun onItemClick(position: Int, item: OrderGoodsAuditBatchDetail)
    }

    /**
     * 数据排序处理
     * @param list MutableList<OrderGoodsAuditDetail>
     */
    private fun comparatorData(list: MutableList<OrderGoodsAuditBatchDetail>):
            MutableList<OrderGoodsAuditBatchDetail> {
        list.sortWith(Comparator { lhs, rhs ->
            when {
                lhs.type > rhs.type -> {
                    1
                }
                lhs.type == rhs.type -> {
                    0
                }
                else -> {
                    -1
                }
            }
        })
        /*
        list.sortWith(Comparator { lhs, rhs ->
            when {
                lhs.createTime < rhs.createTime -> {
                    1
                }
                lhs.createTime == rhs.createTime -> {
                    0
                }
                else -> {
                    -1
                }
            }
        })
         */
        return list
    }

    /**
     * 刷新数据
     * @param newList  MutableList<OrderGoodsAuditDetail>
     */
    fun refreshDataList(newList: MutableList<OrderGoodsAuditBatchDetail>?) {
        if (newList != null) {
            mAuditingList.run {
                clear()
                addAll(comparatorData(newList))
                notifyDataSetChanged()
            }
        }
    }

    /**
     * 修改数据
     */
    fun updateItemData(pos: Int, item: OrderGoodsAuditBatchDetail) {
        var orderGoodsAuditNum = 0.0
        item.batchOrderAuditBillCodeList.forEach {
            orderGoodsAuditNum += it.orderGoodsAuditNum
        }
        item.orderGoodsAuditNum = orderGoodsAuditNum
        mAuditingList[pos] = item
        notifyDataSetChanged()
    }

    override fun getItemCount(): Int = mAuditingList.size

    override fun onCreateViewHolder(
        parent: ViewGroup,
        pos: Int
    ): GoodsAuditingBatchDetailsViewHolder {
        return GoodsAuditingBatchDetailsViewHolder(
            LayoutInflater.from(context)
                .inflate(R.layout.second_ordergoodsmenu_item4, parent, false)
        )
    }

    override fun onBindViewHolder(holder: GoodsAuditingBatchDetailsViewHolder, pos: Int) {
    }

    override fun onBindViewHolder(
        holder: GoodsAuditingBatchDetailsViewHolder,
        position: Int,
        payloads: List<Any?>
    ) {
        bindContentViewHolder(holder, position, payloads)
    }

    private fun bindContentViewHolder(
        holder: GoodsAuditingBatchDetailsViewHolder,
        pos: Int,
        payloads: List<Any?>
    ) {
        val data = mAuditingList[pos]
        holder.apply {
            payloads.takeIf { it.isNotEmpty() && it[0] == "refrshImage" }?.let {
                tvGoodsName.text = refreshOrderName(data)
                return
            }
            //库存在途
            tvKucun.text = data.productStockNum.toString()
            //建议订货量
            tvQuantityOrder.text = data.suggestOrderGoodsNum.toString()
            //月用量
            tvOeProDhQty.text = data.productLastMonthSaleNum.toString()
            //库存天数
            tvCyl.text = calculatorCyDay(data, data.orderGoodsNum).toInt().toString()

            //产品名
            tvGoodsName.text = refreshOrderName(data)
            tvGoodsName.movementMethod = LinkMovementMethod.getInstance()
            //单位
            tvGoodsUnit.text = String.format("%s(%s)", data.productUnit, data.productCode)
            //产品单价
            tvGoodsUnitPrice.text = String.format("单价:%s", data.productPrice)

            llGoodsCountEdit.visibility = View.GONE
            rlGoodsCountQuery.visibility = View.VISIBLE

            tvGoodsCountQuery.text = StringUtils.formatDouble(data.orderGoodsAuditNum, "0.00")

            if (data.productIsNotStock) {
                tvGoodsAlreadyMarket.setTextColor(ContextCompat.getColor(context, R.color.c_e6383a))
                tvGoodsAlreadyMarket.setText(R.string.factory_out_stock)
                tvGoodsAlreadyMarket.visibility = View.VISIBLE
            } else {
                tvGoodsAlreadyMarket.visibility = View.GONE
            }

            //通过Picasso先判断图片链接可用性，如果无效链接，则不显示“查看图片”按钮
            if (!data.isShowImageTv) {//只有在标记为false的时候，才去检查链接可用性。
                Picasso.with(context).load(mAuditingList[pos].productImage)
                    .into(tvGoodsImg, object : Callback {
                        override fun onSuccess() {
                            if (pos >= mAuditingList.size) return//防溢出
                            mAuditingList[pos].isShowImageTv = true
                            // if (this@OrderGoodsTradeAdapter.)
                            //只刷新这个组件
                            mHandler.post { notifyItemChanged(pos, "refrshImage") }
                        }

                        override fun onError() {
                            if (pos >= mAuditingList.size) return//防溢出
                            data.isShowImageTv = false
                            // notifyItemChanged(pos)
                        }
                    })
            }

            tvGoodsUpdate.setOnClickListener {
                listener.onItemClick(pos, data)
            }
        }
    }

    private fun refreshOrderName(entity: OrderGoodsAuditBatchDetail): SpannableString {
        return if (entity.isShowImageTv) {
            SpannableString(entity.productName + "img").apply {
                setSpan(
                    UnderlineSpan(),
                    0,
                    entity.productName.length,
                    Spanned.SPAN_EXCLUSIVE_EXCLUSIVE
                )

                val drawable: Drawable? =
                    ContextCompat.getDrawable(context, R.mipmap.ic_picture_order)
                drawable?.let {
                    it.setBounds(0, 0, it.intrinsicWidth, it.intrinsicHeight)
                    setSpan(
                        ImageSpan(it),
                        this.length - 3,
                        this.length,
                        Spanned.SPAN_INCLUSIVE_EXCLUSIVE
                    )
                }


                setSpan(
                    StyleSpan(Typeface.BOLD),
                    0,
                    entity.productName.length,
                    Spanned.SPAN_INCLUSIVE_EXCLUSIVE
                )

                setSpan(object : ClickableSpan() {
                    override fun onClick(v: View) {
                        showAdDialog(context, entity.productImage)
                    }
                }, 0, this.length, Spanned.SPAN_INCLUSIVE_EXCLUSIVE)

                val colorSpan =
                    ForegroundColorSpan(ContextCompat.getColor(context, R.color.normal_color))
                setSpan(colorSpan, 0, entity.productName.length, Spanned.SPAN_INCLUSIVE_EXCLUSIVE)
            }
        } else {
            SpannableString(entity.productName).apply {
                setSpan(
                    StyleSpan(Typeface.BOLD),
                    0,
                    entity.productName.length,
                    Spanned.SPAN_INCLUSIVE_EXCLUSIVE
                )
                val colorSpan =
                    ForegroundColorSpan(
                        ContextCompat.getColor(
                            context,
                            R.color.common_txt_second_color
                        )
                    )
                setSpan(colorSpan, 0, entity.productName.length, Spanned.SPAN_INCLUSIVE_EXCLUSIVE)
            }
        }
    }

    /**
     * 实时计算库存天数
     *
     * @param data   订货审核产品实体
     * @param counts 审核数量
     * @return 库存天数=（（库存数量+审核数量）/月用量）*30   结果的单位为：天 ；注：产品库存数量=（库存+在途）
     * cyd=(（ProductStockNum+OrderGoodsAuditNum）/ProductLastMonthSaleNum)*30,
     * StringUtil.formatDouble(calculatorCyDay(data, data.getOrderGoodsAuditNum()), "0")；四舍五入取整
     */
    private fun calculatorCyDay(data: OrderGoodsAuditBatchDetail, counts: Double): Double {
        val cyd: Double =
            if (data.productLastMonthSaleNum == 0.0 || counts + data.productStockNum == 0.0) {
                0.0
            } else {
                try {
                    ((data.productStockNum + data.orderGoodsNum)
                            / data.productLastMonthSaleNum) * 30
                } catch (e: Exception) {
                    0.0
                }
            }
        return cyd
    }

    /**
     *List<OrderGoodsAuditBatchDetail> 数据转换为 List<OrderGoodsAuditDetail>
     */
    fun batchListToOrderGoodsAuditDetailUploadList(auditOrderReviewEntity: OrderGoodsAuditOrderReviewEntity?):
            MutableList<OrderGoodsAuditDetailUploadListEntity> {
        val orderGoodsAuditDetailUploadList = mutableListOf<OrderGoodsAuditDetailUploadListEntity>()
        if (mAuditingList.isNullOrEmpty()) {
            return orderGoodsAuditDetailUploadList
        }
        for (element in mAuditingList) {
            val orderGoodsAuditDetailUploadListEntity =
                batchToOrderGoodsAuditDetailUploadListEntity(element, auditOrderReviewEntity)
            orderGoodsAuditDetailUploadList.add(orderGoodsAuditDetailUploadListEntity)
        }
        return orderGoodsAuditDetailUploadList
    }

    /**
     *OrderGoodsAuditBatchDetail 数据转换为 List<OrderGoodsAuditDetail>
     */
    private fun batchToOrderGoodsAuditDetailUploadListEntity(
        orderGoodsAuditBatchDetail: OrderGoodsAuditBatchDetail,
        orderGoodsAuditOrderReviewEntity: OrderGoodsAuditOrderReviewEntity?
    ): OrderGoodsAuditDetailUploadListEntity {
        val orderGoodsAuditDetailUploadListEntity = OrderGoodsAuditDetailUploadListEntity()

        val batchOrderAuditBillCodeList = orderGoodsAuditBatchDetail.batchOrderAuditBillCodeList
        if (batchOrderAuditBillCodeList.isNullOrEmpty()) {
            return orderGoodsAuditDetailUploadListEntity
        }

        val orderGoodsAuditDetailList = mutableListOf<OrderGoodsAuditDetail>()
        for (index in 0 until batchOrderAuditBillCodeList.size) {
            val orderGoodsAuditDetail = OrderGoodsAuditDetail()
            orderGoodsAuditDetailList.add(
                orderGoodsAuditDetail.apply {
                    productName = orderGoodsAuditBatchDetail.productName
                    productCode = orderGoodsAuditBatchDetail.productCode
                    userNo = orderGoodsAuditBatchDetail.userNo
                    productUnit = orderGoodsAuditBatchDetail.productUnit
                    productUnitId = orderGoodsAuditBatchDetail.productUnitId
                    productPrice = orderGoodsAuditBatchDetail.productPrice
                    productBigType = orderGoodsAuditBatchDetail.productBigType
                    productBigFatherType = orderGoodsAuditBatchDetail.productBigFatherType
                    productLastMonthSaleNum = orderGoodsAuditBatchDetail.productLastMonthSaleNum
                    productBoxNum = orderGoodsAuditBatchDetail.productBoxNum
                    productStockNum = orderGoodsAuditBatchDetail.productStockNum
                    productFutureNum = orderGoodsAuditBatchDetail.productFutureNum
                    productAlreadyOrderNum = orderGoodsAuditBatchDetail.productAlreadyOrderNum
                    productLastMonthOrderNum = orderGoodsAuditBatchDetail.productLastMonthOrderNum
                    orderGoodsAuditId = batchOrderAuditBillCodeList[index].orderGoodsAuditId
                    productId = orderGoodsAuditBatchDetail.productId
                    orderGoodsNum = batchOrderAuditBillCodeList[index].orderGoodsNum
                    orderGoodsAmount = orderGoodsAuditBatchDetail.orderGoodsAmount
                    orderGoodsAuditNum = batchOrderAuditBillCodeList[index].orderGoodsAuditNum
                    orderGoodsNumINControl = orderGoodsAuditBatchDetail.orderGoodsNumINControl
                    type = orderGoodsAuditBatchDetail.type
                    suggestOrderGoodsNum = orderGoodsAuditBatchDetail.suggestOrderGoodsNum
                    maxSuggestOrderGoodsNum = orderGoodsAuditBatchDetail.maxSuggestOrderGoodsNum
                    productIsNotStock = orderGoodsAuditBatchDetail.productIsNotStock
                    productImage = orderGoodsAuditBatchDetail.productImage
                    orderGoodsStoreWeekDayAndCycle = OrderGoodsStoreWeekDayAndCycle().apply {
                        orderGoodsCycle =
                            orderGoodsAuditOrderReviewEntity?.orderGoodsCycle.toString()
                        orderGoodsWeekDay =
                            orderGoodsAuditOrderReviewEntity?.orderGoodsWeekDay.toString()
                    }
                })
        }
        orderGoodsAuditDetailUploadListEntity.orderGoodsAuditDetailList = orderGoodsAuditDetailList
        return orderGoodsAuditDetailUploadListEntity
    }


    /**
     * 弹出图片弹窗
     */
    private fun showAdDialog(context: Context, adInfo: String) {
        val adDialog = AdDialog(context, adInfo)
        //点击空白区域能不能退出
        adDialog.setCanceledOnTouchOutside(false)
        //按返回键能能退出
        adDialog.setCancelable(true)
        adDialog.setClickLink(adInfo)
        adDialog.setLinkType("url")
        adDialog.show()
    }

    class GoodsAuditingBatchDetailsViewHolder(view: View) : RecyclerView.ViewHolder(view) {
        val tvGoodsName: TextView = view.find(R.id.tv_goods_name) as TextView
        val tvGoodsImg: ImageView = view.find(R.id.iv_goods_img) as ImageView
        val tvGoodsUnit: TextView = view.find(R.id.tv_goods_unit) as TextView
        val tvGoodsUnitPrice: TextView = view.find(R.id.tv_goods_unit_price) as TextView

        val tvKucun: TextView = view.find(R.id.tv_kucun) as TextView
        val tvQuantityOrder: TextView = view.find(R.id.tv_quantity_order) as TextView
        val tvOeProDhQty: TextView = view.find(R.id.tv_oe_pro_dh_qty) as TextView
        val tvCyl: TextView = view.find(R.id.tv_cyl) as TextView

        val tvGoodsAlreadyMarket: TextView = view.find(R.id.tv_goods_already_market) as TextView

        val llGoodsCountEdit: LinearLayout = view.find(R.id.ll_goods_count_edit) as LinearLayout

        val rlGoodsCountQuery: RelativeLayout =
            view.find(R.id.rl_goods_count_query) as RelativeLayout
        val tvGoodsCountQuery: TextView = view.find(R.id.tv_goods_count_query) as TextView
        val tvGoodsUpdate: TextView = view.find(R.id.tv_goods_update) as TextView
    }
}
