package com.wgmf.yxgj.module.business.manageproduct.ui

import android.app.Activity
import android.content.Intent
import android.os.Bundle
import android.support.v4.content.ContextCompat
import android.support.v7.widget.LinearLayoutManager
import android.view.View
import com.google.gson.Gson
import com.wgmf.library.base.BaseResponse
import com.wgmf.library.base.ResultData
import com.wgmf.library.utils.Log
import com.wgmf.library.utils.StringUtil
import com.wgmf.yxgj.base.BaseParentAct
import com.wgmf.yxgj.config.BusinessID
import com.wgmf.yxgj.db.GreenDaoManager
import com.wgmf.yxgj.db.OrderGoodsAuditBatchDetailDao
import com.wgmf.yxgj.db.OrderGoodsAuditDetailDao
import com.wgmf.yxgj.dialog.LoadWaitDominator
import com.wgmf.yxgj.dialog.PublicConformTipDialog
import com.wgmf.yxgj.global.ApprovalStatus
import com.wgmf.yxgj.global.Brand
import com.wgmf.yxgj.global.ConstantParams
import com.wgmf.yxgj.model.BatchOrderAuditBillCode
import com.wgmf.yxgj.model.OrderGoodsAuditBatchDetail
import com.wgmf.yxgj.model.OrderGoodsAuditDetail
import com.wgmf.yxgj.model.OrderGoodsStoreWeekDayAndCycle
import com.wgmf.yxgj.module.business.manageproduct.R
import com.wgmf.yxgj.module.business.manageproduct.model.*
import com.wgmf.yxgj.module.business.manageproduct.service.GoodsManagerService
import com.wgmf.yxgj.pop.PublicThreeSecondsPop
import com.wgmf.yxgj.pop.PublicThreeSecondsPop.ThreeSecondsPopListener
import com.wgmf.yxgj.utils.DensityUtil
import com.wgmf.yxgj.widgets.decoration.SpacesItemDecoration
import kotlinx.android.synthetic.main.activity_goods_auditing_detail.*
import kotlinx.android.synthetic.main.include_auditing_goods_info.*
import org.greenrobot.eventbus.EventBus
import org.greenrobot.eventbus.Subscribe
import org.jetbrains.anko.find
import java.lang.Exception
import java.lang.StringBuilder


/**
 * @author LW on 2021-9-13 0013.
 *
 */
class GoodsAuditingDetailsActivity : BaseParentAct(),
    ThreeSecondsPopListener {

    private val mBranchTitle by lazy { intent.getStringExtra("branchTitle") }

    private val mInventoryAmount by lazy { intent.getDoubleExtra("inventoryAmount", 0.00) }

    private val mInventoryDays by lazy { intent.getIntExtra("inventoryDays", 0) }

    private val mIsFzsjd by lazy { intent.getBooleanExtra("isFzsjd", false) }

    private val mOrderGoodsAuditAmount by lazy {
        intent.getDoubleExtra(
            "orderGoodsAuditAmount",
            0.00
        )
    }

    private val mSaleAmount by lazy { intent.getDoubleExtra("saleAmount", 0.00) }

    private val mStoreNo by lazy { intent.getStringExtra("storeNo") }

    private val mOrderGoodsAuditOrderReviewEntity by lazy {
        intent.getSerializableExtra("orderGoodsAuditEntity") as OrderGoodsAuditOrderReviewEntity?
    }

    private val mOrderStateType by lazy {
        intent.getIntExtra("orderStateType", JUMP_CHECK_DETAILS_TYPE)
    }

    private lateinit var mLoadWait: LoadWaitDominator

    private var mOrderGoodsAuditId: Int = -1

    private var mGoodsAuditingDetailsAdapter: GoodsAuditingDetailsAdapter? = null

    private var mGoodsAuditingBatchDetailsAdapter: GoodsAuditingBatchDetailsAdapter? = null

    private var mOrderGoodsAuditDetailList = mutableListOf<OrderGoodsAuditDetail>()

    private var mOrderGoodsAuditDetailBatchList =
        mutableListOf<OrderGoodsAuditBatchDetail>()

    private var mGoodsAuditingBatchPop: GoodsAuditingBatchPop? = null

    /**
     * OrderGoodsAuditDetailDao数据库操作对象
     */
    private val mOrderGoodsAuditDetailDao: OrderGoodsAuditDetailDao by lazy {
        GreenDaoManager.getInstance().getDaoSession(mContext).orderGoodsAuditDetailDao
    }

    /**
     * OrderGoodsAuditBatchDetailDao
     */
    private val mOrderGoodsAuditBatchDetailDao: OrderGoodsAuditBatchDetailDao by lazy {
        GreenDaoManager.getInstance().getDaoSession(mContext).orderGoodsAuditBatchDetailDao
    }

    private var mBrandId = -1

    companion object {
        /**
         * 请求码
         */
        const val GOODS_AUDITING_DETAILS_REQUEST_CODE: Int = 0X01

        //类型:去审核
        const val JUMP_TO_REVIEW_TYPE: Int = 1

        //类型:查看详情
        const val JUMP_CHECK_DETAILS_TYPE: Int = 2

        //类型:批量审批
        const val JUMP_BATCH_APPROVAL_TYPE: Int = 3
    }

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        setContentView(R.layout.activity_goods_auditing_detail)
        initTitle()
        initView()
        setListener()
    }

    override fun initTitle() {
        super.initTitle()
        homeTitleText.text = mBranchTitle
        homeTitleBackLl.visibility = View.VISIBLE
    }

    private fun initView() {
        EventBus.getDefault().register(this)
        mLoadWait = LoadWaitDominator(this, fl_auditing_detail_content_root)
        //将需要审核的信息从数据库中删除
        mOrderGoodsAuditDetailDao.deleteAll()
        mOrderGoodsAuditBatchDetailDao.deleteAll()

        when (mOrderStateType) {
            JUMP_TO_REVIEW_TYPE -> {
                rv_auditing_detail_message.setText(R.string.goods_auditing_details_message)
                rv_auditing_detail_message.setPadding(
                    DensityUtil.dip2px(mContext, 8f),
                    DensityUtil.dip2px(mContext, 8f), DensityUtil.dip2px(mContext, 8f),
                    DensityUtil.dip2px(mContext, 8f)
                )
                ll_auditing_detail_bottom_root.visibility = View.VISIBLE
                tv_auditing_form_date.visibility = View.VISIBLE
                tv_auditing_order_number.visibility = View.VISIBLE
            }
            JUMP_CHECK_DETAILS_TYPE -> {
                rv_auditing_detail_message.text = ""
                rv_auditing_detail_message.setPadding(
                    DensityUtil.dip2px(mContext, 2f),
                    DensityUtil.dip2px(mContext, 2f), DensityUtil.dip2px(mContext, 2f),
                    DensityUtil.dip2px(mContext, 2f)
                )
                ll_auditing_detail_bottom_root.visibility = View.GONE
                tv_auditing_form_date.visibility = View.VISIBLE
                tv_auditing_order_number.visibility = View.VISIBLE
            }
            JUMP_BATCH_APPROVAL_TYPE -> {
                rv_auditing_detail_message.setText(R.string.goods_auditing_details_message)
                rv_auditing_detail_message.setPadding(
                    DensityUtil.dip2px(mContext, 8f),
                    DensityUtil.dip2px(mContext, 8f), DensityUtil.dip2px(mContext, 8f),
                    DensityUtil.dip2px(mContext, 8f)
                )
                ll_auditing_detail_bottom_root.visibility = View.VISIBLE
            }
        }

        tv_auditing_inventory_amount.text = StringUtil.formatString(
            mContext.getString(R.string.goods_auditing_inventory_amount_value),
            StringUtil.formatDouble(mInventoryAmount, "0.00")
        )
        tv_auditing_inventory_day.text = StringUtil.formatString(
            mContext.getString(R.string.goods_auditing_inventory_day_value),
            mInventoryDays
        )
        tv_auditing_order_amount.text = StringUtil.formatString(
            mContext.getString(R.string.goods_auditing_audit_amount_value),
            StringUtil.formatDouble(mOrderGoodsAuditAmount, "0.00")
        )
        tv_auditing_last_sales.text = StringUtil.formatString(
            mContext.getString(R.string.goods_auditing_sale_amount_value),
            StringUtil.formatDouble(mSaleAmount, "0.00")
        )

        mOrderGoodsAuditOrderReviewEntity?.apply {
            tv_auditing_store.text = storeName
            tv_auditing_form_date.text = StringUtil.formatString(
                mContext.getString(R.string.goods_auditing_set_order_date_value),
                setOrderDate
            )
            tv_auditing_order_number.text = StringUtil.formatString(
                mContext.getString(R.string.goods_auditing_order_bill_code_value),
                orderGoodsBillCode
            )

            //订货审核单状态:1待审核 2待复核 3已作废"
            tv_auditing_status.setTextColor(ContextCompat.getColor(mContext, R.color.c_ff9a00))
            when (orderStateType) {
                ApprovalStatus.PENDING_REVIEW -> {
                    tv_auditing_status.text =
                        mContext.getString(R.string.goods_auditing_pending_review)
                }
                ApprovalStatus.REVIEWED -> {
                    tv_auditing_status.text = mContext.getString(R.string.goods_auditing_reviewed)
                }
                ApprovalStatus.OBSOLETE_REVIEW -> {
                    tv_auditing_status.text = mContext.getString(R.string.goods_auditing_abolished)
                }
            }
        }
        rv_auditing_detail_list.apply {
            layoutManager = LinearLayoutManager(mContext)

            when (mOrderStateType) {
                JUMP_TO_REVIEW_TYPE -> {
                    mGoodsAuditingDetailsAdapter = GoodsAuditingDetailsAdapter(
                        this@GoodsAuditingDetailsActivity,
                        JUMP_TO_REVIEW_TYPE,
                        mOrderGoodsAuditDetailList
                    ) { }
                    adapter = mGoodsAuditingDetailsAdapter
                }
                JUMP_CHECK_DETAILS_TYPE -> {
                    mGoodsAuditingDetailsAdapter = GoodsAuditingDetailsAdapter(
                        this@GoodsAuditingDetailsActivity,
                        JUMP_CHECK_DETAILS_TYPE,
                        mOrderGoodsAuditDetailList
                    ) { }
                    adapter = mGoodsAuditingDetailsAdapter
                }
                JUMP_BATCH_APPROVAL_TYPE -> {
                    mGoodsAuditingBatchDetailsAdapter = GoodsAuditingBatchDetailsAdapter(
                        this@GoodsAuditingDetailsActivity,
                        mOrderGoodsAuditDetailBatchList,
                        object : GoodsAuditingBatchDetailsAdapter.OnAdapterItemClickListener {
                            override fun onItemClick(
                                position: Int,
                                item: OrderGoodsAuditBatchDetail
                            ) {
                                showGoodsAuditingBatchPop(position, item)
                            }

                        }
                    )
                    adapter = mGoodsAuditingBatchDetailsAdapter
                }
            }
            addItemDecoration(SpacesItemDecoration(10, adapter!!.itemCount, true))
        }

        findOrderGoodsAuditDetails()
    }

    @Subscribe
    fun onEventOrderGoodsAuditDetail(item: List<OrderGoodsAuditDetail>?) {
        if (item != null && item.isNotEmpty()) {
            if (mOrderStateType == JUMP_CHECK_DETAILS_TYPE || mOrderStateType == JUMP_TO_REVIEW_TYPE) {
                mOrderGoodsAuditDetailList = mOrderGoodsAuditDetailDao.loadAll()
                mGoodsAuditingDetailsAdapter?.refreshDataList(mOrderGoodsAuditDetailList)
            }
        }
    }

    @Subscribe
    fun onEventOrderGoodsAuditBatchDetail(item: List<OrderGoodsAuditBatchDetail>?) {
        if (item != null && item.isNotEmpty()) {
            if (mOrderStateType == JUMP_BATCH_APPROVAL_TYPE) {
                mOrderGoodsAuditDetailBatchList = mOrderGoodsAuditBatchDetailDao.loadAll()
                try {
                    for (i in mOrderGoodsAuditDetailBatchList.indices) {
                        if (mOrderGoodsAuditDetailBatchList[i].batchOrderAuditBillCode != null && mOrderGoodsAuditDetailBatchList[i].batchOrderAuditBillCode.isNotEmpty()) {
                            mOrderGoodsAuditDetailBatchList[i].batchOrderAuditBillCodeList =
                                Gson().fromJson(
                                    mOrderGoodsAuditDetailBatchList[i].batchOrderAuditBillCode,
                                    Array<BatchOrderAuditBillCode>::class.java
                                ).asList()
                        }
                    }
                } catch (e: Exception) {
                    e.printStackTrace()
                }
                mGoodsAuditingBatchDetailsAdapter?.refreshDataList(mOrderGoodsAuditDetailBatchList)
                mBrandId = obtainBatchStoreBrandId()
            }
        }
    }

    /**
     * 显示批量审核提示框
     */
    private fun showGoodsAuditingBatchPop(
        position: Int,
        auditBatchDetail: OrderGoodsAuditBatchDetail
    ) {
        if (mGoodsAuditingBatchPop != null && mGoodsAuditingBatchPop?.isShowing() == true) {
            mGoodsAuditingBatchPop!!.dismiss()
        }
        mGoodsAuditingBatchPop =
            GoodsAuditingBatchPop(mContext,
                auditBatchDetail = auditBatchDetail,
                position = position,
                listener = object : GoodsAuditingBatchPop.OnAdapterConfirmClickListener {
                    override fun onConfirmClick(
                        position: Int,
                        auditBatchDetail: OrderGoodsAuditBatchDetail
                    ) {
                        mGoodsAuditingBatchDetailsAdapter?.updateItemData(
                            position,
                            auditBatchDetail
                        )
                    }
                })

        mGoodsAuditingBatchPop?.show(findViewById(R.id.title))
    }

    private fun setListener() {
        btn_sales_cont.setOnClickListener {
            val intent = Intent(
                this@GoodsAuditingDetailsActivity,
                GoodsAuditingAddProductsActivity::class.java
            )

            intent.putExtra("outStoreNo", mStoreNo)
            if (mOrderStateType == JUMP_BATCH_APPROVAL_TYPE) {
                //存储当前修改
                setOrderGoodsAuditDetailBatchListData(mOrderGoodsAuditDetailBatchList, false)

                val obtainBatchOrderAuditBillCode = obtainBatchOrderAuditBillCode(mBrandId)
                intent.putExtra(
                    "orderGoodsBillCode",
                    obtainBatchOrderAuditBillCode?.orderGoodsBillCode
                )
                intent.putExtra(
                    "orderGoodsAuditId",
                    obtainBatchOrderAuditBillCode?.orderGoodsAuditId
                )
                intent.putExtra("orderBrandId", obtainBatchOrderAuditBillCode?.orderGoodsBrand)
                intent.putExtra("type", GoodsAuditingAddProductsActivity.ORDER_GOODS_AUDIT_BATCH)
            } else {
                //存储当前修改
                setOrderGoodsAuditDetailListData(mOrderGoodsAuditDetailList, false)

                intent.putExtra("orderGoodsAuditId", mOrderGoodsAuditId)
                intent.putExtra("orderBrandId", mOrderGoodsAuditOrderReviewEntity?.orderBrandId)
                intent.putExtra("type", GoodsAuditingAddProductsActivity.ORDER_GOODS_AUDIT)
            }
            startActivity(intent)
        }
        btn_submit.setOnClickListener {
            //获取工厂缺货，订货数量大于0,产品编号。
            var productCodeValue = ""
            if (mOrderStateType == JUMP_BATCH_APPROVAL_TYPE) {
                productCodeValue = obtainBatchAuditProductIsNotStockCode()
                if (productCodeValue.isEmpty()) {
                    uploadCommitBatchAuditDetailData() //提交批量数据
                } else {
                    showConformTipDialog(
                        StringUtil.formatString(
                            mContext.getString(R.string.goods_auditing_details_dialog_message),
                            productCodeValue
                        )
                    )
                }
            } else {
                productCodeValue = obtainAuditProductIsNotStockCode()
                if (productCodeValue.isEmpty()) {
                    uploadCommitAuditDetailData() //提交数据
                } else {
                    showConformTipDialog(
                        StringUtil.formatString(
                            mContext.getString(R.string.goods_auditing_details_dialog_message),
                            productCodeValue
                        )
                    )
                }
            }
        }
    }

    /**
     * 获取批量审核品牌类型
     * BrandId三种类型： 8:五谷磨房  15:食补集  0 其他
     */
    private fun obtainBatchStoreBrandId(): Int {
        val brandList = mutableListOf<Int>()
        for (list in mOrderGoodsAuditDetailBatchList) {
            for (childList in list.batchOrderAuditBillCodeList) {
                val orderGoodsBrand = childList.orderGoodsBrand
                if (!brandList.contains(orderGoodsBrand)) {
                    brandList.add(orderGoodsBrand)
                }
            }
        }
        val brandSize = brandList.size
        if (brandSize >= 2) {
            return Brand.BRAND_UN_KNOWN
        } else {
            if (brandList.contains(Brand.BRAND_WUGU_MOFENG)) {
                return Brand.BRAND_WUGU_MOFENG
            } else if (brandList.contains(Brand.BRAND_FOOD_SUPPLEMENT)) {
                return Brand.BRAND_FOOD_SUPPLEMENT
            } else if (brandList.contains(Brand.BRAND_UN_KNOWN)) {
                return Brand.BRAND_UN_KNOWN
            }
        }
        return -1
    }

    /**
     * 获取批量订单信息
     */
    private fun obtainBatchOrderAuditBillCode(brandId: Int): BatchOrderAuditBillCode? {
        for (list in mOrderGoodsAuditDetailBatchList) {
            for (childList in list.batchOrderAuditBillCodeList) {
                if (brandId == childList.orderGoodsBrand) {
                    return childList
                }
            }
        }
        return null
    }

    /**
     * 获取批量审核产品缺货状态、订货数量大于零，产品编号
     */
    private fun obtainBatchAuditProductIsNotStockCode(): String {
        val orderGoodsAuditDetailUploadList =
            mGoodsAuditingBatchDetailsAdapter?.batchListToOrderGoodsAuditDetailUploadList(
                mOrderGoodsAuditOrderReviewEntity
            )
        val productCodeBuilder = StringBuilder()
        if (orderGoodsAuditDetailUploadList != null && orderGoodsAuditDetailUploadList.isNotEmpty()) {
            orderGoodsAuditDetailUploadList.forEach { upload ->
                upload.orderGoodsAuditDetailList.forEach {
                    if (it.isProductIsNotStock && it.orderGoodsAuditNum > 0.0) {
                        if (!productCodeBuilder.contains(it.productCode)) {
                            productCodeBuilder.append("${it.productCode}，")
                        }
                    }
                }
            }
        }
        return productCodeBuilder.toString()
    }

    /**
     * 获取审核产品缺货状态、订货数量大于零，产品编号
     */
    private fun obtainAuditProductIsNotStockCode(): String {
        val productCodeBuilder = StringBuilder()
        if (mOrderGoodsAuditDetailList.isNotEmpty()) {
            mOrderGoodsAuditDetailList.forEach {
                if (it.isProductIsNotStock && it.orderGoodsAuditNum > 0.0) {
                    if (!productCodeBuilder.contains(it.productCode)) {
                        productCodeBuilder.append("${it.productCode}，")
                    }
                }
            }
        }
        return productCodeBuilder.toString()
    }

    /**
     * 上传订货批量深审核数据
     */
    private fun uploadCommitBatchAuditDetailData() {
        showDialog()
        setDialogCancel(false, false)
        val orderGoodsAuditDetailUploadList =
            mGoodsAuditingBatchDetailsAdapter?.batchListToOrderGoodsAuditDetailUploadList(
                mOrderGoodsAuditOrderReviewEntity
            )

        val orderGoodsAuditBatchDetailUploadListEntity =
            OrderGoodsAuditBatchDetailUploadListEntity().apply {
                orderGoodsAuditParamList = orderGoodsAuditDetailUploadList
                alreadyorderGoodsAmount = mOrderGoodsAuditAmount
            }

        val content = Gson().toJson(orderGoodsAuditBatchDetailUploadListEntity)
        Log.d(TAG, "OrderGoodsAuditDetailUploadList=$content");

        GoodsManagerService.getInstance()
            .requestBatchSaveUpdateOrderGoodsAuditions(
                content,
                this@GoodsAuditingDetailsActivity
            )
    }

    /**
     * 上传订货审核数据
     */
    private fun uploadCommitAuditDetailData() {
        if (mOrderGoodsAuditDetailList.isNotEmpty()) {
            showDialog()
            setDialogCancel(false, false)
            for (i in mOrderGoodsAuditDetailList.indices) {
                val orderGoodsStoreWeekDayAndCycle = OrderGoodsStoreWeekDayAndCycle()
                orderGoodsStoreWeekDayAndCycle.orderGoodsCycle =
                    mOrderGoodsAuditOrderReviewEntity?.orderGoodsCycle.toString()
                orderGoodsStoreWeekDayAndCycle.orderGoodsWeekDay =
                    mOrderGoodsAuditOrderReviewEntity?.orderGoodsWeekDay.toString()
                mOrderGoodsAuditDetailList[i].orderGoodsStoreWeekDayAndCycle =
                    orderGoodsStoreWeekDayAndCycle
            }
            val orderGoodsAuditDetailUploadListEntity =
                OrderGoodsAuditDetailUploadListEntity().apply {
                    orderGoodsAuditDetailList =
                        mOrderGoodsAuditDetailList
                    isFirstOrder =
                        mOrderGoodsAuditOrderReviewEntity?.isFirstOrder ?: false
                }

            val content = Gson().toJson(orderGoodsAuditDetailUploadListEntity)
            Log.d(TAG, "OrderGoodsAuditDetailUploadListEntity=$content");

            GoodsManagerService.getInstance()
                .requestSaveUpdateOrderGoodsAuditions(content, this@GoodsAuditingDetailsActivity)
        }
    }


    /**
     * 获取订货审核明细
     */
    private fun findOrderGoodsAuditDetails() {
        mLoadWait.show(LoadWaitDominator.LOADING)
        userInfo?.let {
            mOrderGoodsAuditId = mOrderGoodsAuditOrderReviewEntity?.orderGoodsAuditId ?: -1
            if (mOrderStateType == JUMP_CHECK_DETAILS_TYPE || mOrderStateType == JUMP_TO_REVIEW_TYPE) {
                GoodsManagerService.getInstance().requestFindOrderGoodsAuditDeatil(
                    mOrderGoodsAuditId.toString(),
                    this@GoodsAuditingDetailsActivity
                )
            } else {
                GoodsManagerService.getInstance().requestBatchFindOrderGoodsDetail(
                    mStoreNo,
                    mIsFzsjd,
                    it.name,
                    it.level,
                    it.organizationId,
                    this@GoodsAuditingDetailsActivity
                )
            }
        }
    }

    /**
     * 提交加载框
     */
    private fun showPublicThreeSecondsPop() {
        val publicThreeSecondsPop = PublicThreeSecondsPop(mContext, this)
        if (!publicThreeSecondsPop.isShowing) {
            publicThreeSecondsPop.show(find(R.id.title))
        }
    }

    /**
     * 确认提示框
     */
    private fun showConformTipDialog(message: String) {
        val builder = PublicConformTipDialog.Builder(this)
        builder.setLayoutId(R.layout.view_textview_dialog2)
        builder.setTitle(R.string.audit_failure)
        builder.setMessage(message)
        builder.setNegativeButton(R.string.confirm_btn_txt) { dialog, which ->
            dialog.dismiss()
        }
        builder.create().show()
    }

    private fun setOrderGoodsAuditDetailListData(
        item: MutableList<OrderGoodsAuditDetail>,
        refresh: Boolean = true
    ) {
        if (item.isNotEmpty()) {
            //将接口返回的订货信息插入数据库
            for (i in item.indices) {
                item[i].userNo = userInfo.staffId
                mOrderGoodsAuditDetailDao.insertOrReplaceInTx(item[i])
            }
            if (refresh) {
                mOrderGoodsAuditDetailList = mOrderGoodsAuditDetailDao.loadAll()
                mGoodsAuditingDetailsAdapter?.refreshDataList(mOrderGoodsAuditDetailList)
            }
        }
    }

    private fun setOrderGoodsAuditDetailBatchListData(
        item: MutableList<OrderGoodsAuditBatchDetail>,
        refresh: Boolean = true
    ) {
        if (item.isNotEmpty()) {
            for (i in item.indices) {
                item[i].batchOrderAuditBillCode =
                    Gson().toJson(item[i].batchOrderAuditBillCodeList)
                item[i].userNo = userInfo.staffId
                if (refresh) {
                    item[i].orderGoodsAuditNum = item[i].orderGoodsNum
                }
                mOrderGoodsAuditBatchDetailDao.insertOrReplaceInTx(item[i])
            }
            if (refresh) {
                mOrderGoodsAuditDetailBatchList = item
                mGoodsAuditingBatchDetailsAdapter?.refreshDataList(mOrderGoodsAuditDetailBatchList)
                mBrandId = obtainBatchStoreBrandId()
            }
        }
    }

    override fun onBusinessResultAtMainThread(result: ResultData?) {
        super.onBusinessResultAtMainThread(result)
        dismissDialog()
        result?.let {
            val id = it.taskID
            when (id) {
                BusinessID.GoodsManager.MSG_ON_FIND_ORDERGOODS_AUDIT_DEATIL -> {
                    if (it.isSuccessed) {
                        mLoadWait.dismissAll()
                        val orderGoodsAuditDetailListEntity = Gson().fromJson(
                            it.info,
                            OrderGoodsAuditDetailListEntity::class.java
                        )
                        if (orderGoodsAuditDetailListEntity?.resultList?.isNotEmpty() == true) {
                            setOrderGoodsAuditDetailListData(orderGoodsAuditDetailListEntity.resultList)
                        } else {
                            mLoadWait.show(LoadWaitDominator.NO_DATA)
                        }
                    } else {
                        mLoadWait.show(LoadWaitDominator.NET_ERROR)
                    }
                }
                BusinessID.GoodsManager.MSG_ON_BATCH_FIND_ORDERGOODS_DEATIL -> {
                    if (it.isSuccessed) {
                        mLoadWait.dismissAll()
                        val orderGoodsAuditDetailBatchListEntity = Gson().fromJson(
                            it.info,
                            OrderGoodsAuditDetailBatchListEntity::class.java
                        )
                        if (orderGoodsAuditDetailBatchListEntity?.resultList?.isNotEmpty() == true) {
                            setOrderGoodsAuditDetailBatchListData(
                                orderGoodsAuditDetailBatchListEntity.resultList
                            )
                        } else {
                            mLoadWait.show(LoadWaitDominator.NO_DATA)
                        }

                    } else {
                        mLoadWait.show(LoadWaitDominator.NET_ERROR)
                    }
                }
                BusinessID.GoodsManager.MSG_ON_SAVE_UPDATE_ORDERGOODS_AUDITIONS -> {
                    if (it.isSuccessed) {
                        val response: BaseResponse =
                            Gson().fromJson(it.info, BaseResponse::class.java)
                        Log.d(TAG, "saveUpdateOrderGoodsAuditions=$response");
                        if (ConstantParams.CONSTANT_PARAMS_0 == response.retCode) {
                            //弹出提示进度条,等待OE返回
                            showPublicThreeSecondsPop()
                        } else {
                            showConformTipDialog(response.retInfo)
                        }
                    } else {
                        showMsg(it.resultInfo)
                    }
                }
                BusinessID.GoodsManager.MSG_ON_BATCH_SAVE_UPDATE_ORDERGOODS_AUDITIONS -> {
                    if (it.isSuccessed) {
                        val response: BaseResponse =
                            Gson().fromJson(it.info, BaseResponse::class.java)
                        Log.d(TAG, "batchSaveOrderGoodsAuditions=$response");
                        if (ConstantParams.CONSTANT_PARAMS_0 == response.retCode) {
                            //弹出提示进度条,等待OE返回
                            showPublicThreeSecondsPop()
                        } else {
                            showConformTipDialog(response.retInfo)
                        }
                    } else {
                        showMsg(it.resultInfo)
                    }
                }
            }
        }
    }

    override fun onTimingFinish() {
        setResult(Activity.RESULT_OK)
        this@GoodsAuditingDetailsActivity.finish()
    }

    override fun onDestroy() {
        super.onDestroy()
        EventBus.getDefault().unregister(this)
    }
}