package com.wgmf.yxgj.module.business.manageproduct.ui

import android.content.Context
import android.graphics.Color
import android.graphics.Typeface
import android.graphics.drawable.Drawable
import android.os.Handler
import android.support.v4.content.ContextCompat
import android.support.v7.app.AppCompatActivity
import android.support.v7.widget.RecyclerView
import android.text.SpannableString
import android.text.Spanned
import android.text.TextUtils
import android.text.method.LinkMovementMethod
import android.text.style.*
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import android.widget.*
import com.squareup.picasso.Callback
import com.squareup.picasso.Picasso
import com.wgmf.library.utils.Arith
import com.wgmf.yxgj.dialog.AdDialog
import com.wgmf.yxgj.dialog.PublicConformTipDialog
import com.wgmf.yxgj.global.PackType
import com.wgmf.yxgj.model.OrderGoodsAuditDetail
import com.wgmf.yxgj.module.business.manageproduct.R
import com.wgmf.yxgj.module.business.manageproduct.ui.GoodsAuditingDetailsActivity.Companion.JUMP_CHECK_DETAILS_TYPE
import com.wgmf.yxgj.module.business.manageproduct.ui.GoodsAuditingDetailsActivity.Companion.JUMP_TO_REVIEW_TYPE
import com.wgmf.yxgj.utils.StringUtils
import com.wgmf.yxgj.widgets.NumberKeyboard
import org.jetbrains.anko.find
import java.util.*

class GoodsAuditingDetailsAdapter(
    private val context: Context,
    private val orderStateType: Int,
    dataList: MutableList<OrderGoodsAuditDetail> = mutableListOf(),
    private val notifyPriceShow: () -> Unit
) : RecyclerView.Adapter<GoodsAuditingDetailsAdapter.GoodsAuditingDetailsViewHolder>() {

    private val mAuditingList: MutableList<OrderGoodsAuditDetail> = mutableListOf()

    private val mHandler = Handler()

    init {
        dataList.let {
            mAuditingList.clear()
            mAuditingList.addAll(comparatorData(it))
        }
    }

    private val mKeyboard: NumberKeyboard by lazy {
        NumberKeyboard.newInstance(null)
    }

    /**
     * 数据排序处理
     * @param list MutableList<OrderGoodsAuditDetail>
     */
    private fun comparatorData(list: MutableList<OrderGoodsAuditDetail>): MutableList<OrderGoodsAuditDetail> {
        list.sortWith(Comparator { lhs, rhs ->
            when {
                lhs.type > rhs.type -> {
                    1
                }
                lhs.type == rhs.type -> {
                    0
                }
                else -> {
                    -1
                }
            }
        })
        /*
        list.sortWith(Comparator { lhs, rhs ->
            when {
                lhs.createTime < rhs.createTime -> {
                    1
                }
                lhs.createTime == rhs.createTime -> {
                    0
                }
                else -> {
                    -1
                }
            }
        })
         */
        return list
    }

    /**
     * 刷新数据
     * @param newList  MutableList<OrderGoodsAuditDetail>
     */
    fun refreshDataList(newList: MutableList<OrderGoodsAuditDetail>?) {
        if (newList != null) {
            mAuditingList.run {
                clear()
                addAll(comparatorData(newList))
                notifyDataSetChanged()
            }
        }
    }

    override fun getItemCount(): Int = mAuditingList.size

    override fun onCreateViewHolder(
        parent: ViewGroup,
        pos: Int
    ): GoodsAuditingDetailsViewHolder {
        return GoodsAuditingDetailsViewHolder(
            LayoutInflater.from(context)
                .inflate(R.layout.second_ordergoodsmenu_item4, parent, false)
        )
    }

    override fun onBindViewHolder(holder: GoodsAuditingDetailsViewHolder, pos: Int) {
    }

    override fun onBindViewHolder(
        holder: GoodsAuditingDetailsViewHolder,
        position: Int,
        payloads: List<Any?>
    ) {
        bindContentViewHolder(holder, position, payloads)
    }

    private fun bindContentViewHolder(
        holder: GoodsAuditingDetailsViewHolder,
        pos: Int,
        payloads: List<Any?>
    ) {
        val data = mAuditingList[pos]
        holder.apply {
            payloads.takeIf { it.isNotEmpty() && it[0] == "refrshImage" }?.let {
                tvGoodsName.text = refreshOrderName(data)
                return
            }
            tvGoodsCountEdit.tag = pos
            //库存在途
            tvKucun.text = data.productStockNum.toString()
            //建议订货量
            tvQuantityOrder.text = data.suggestOrderGoodsNum.toString()
            //月用量
            tvOeProDhQty.text = data.productLastMonthSaleNum.toString()
            //库存天数
            if (isShowInventoryDays(data.productBigFatherType, data.productBigType)) {
                tvCyl.text = calculatorCyDay(data, data.orderGoodsAuditNum).toInt().toString()
            } else {
                tvCyl.text = "--"
            }
            //产品名
            tvGoodsName.text = refreshOrderName(data)
            tvGoodsName.movementMethod = LinkMovementMethod.getInstance()
            //单位
            tvGoodsUnit.text = String.format("%s(%s)", data.productUnit, data.productCode)
            //产品单价
            tvGoodsUnitPrice.text = String.format("单价:%s", data.productPrice)
            tvGoodsCountEdit.setTextColor(if (data.invalid) Color.RED else Color.BLACK)
            tvGoodsCountEdit.setBackgroundResource(R.drawable.shape_solid_f5f5f5_round_3)
            tvGoodsCountEdit.text = StringUtils.formatDouble(data.orderGoodsAuditNum, "0.00")
            tvGoodsCountQuery.text = StringUtils.formatDouble(data.orderGoodsAuditNum, "0.00")

            when (orderStateType) {
                JUMP_TO_REVIEW_TYPE -> {
                    llGoodsCountEdit.visibility = View.VISIBLE
                    rlGoodsCountQuery.visibility = View.GONE
                }
                JUMP_CHECK_DETAILS_TYPE -> {
                    llGoodsCountEdit.visibility = View.GONE
                    tvGoodsUpdate.visibility = View.GONE
                    rlGoodsCountQuery.visibility = View.VISIBLE
                }
            }

            if (data.isProductIsNotStock) {
                tvGoodsAlreadyMarket.setTextColor(ContextCompat.getColor(context, R.color.c_e6383a))
                tvGoodsAlreadyMarket.setText(R.string.factory_out_stock)
                tvGoodsAlreadyMarket.visibility = View.VISIBLE
            } else {
                tvGoodsAlreadyMarket.visibility = View.GONE
            }

            //减号逻辑===============
            if (data.orderGoodsAuditNum == 0.0) {
                if (data.maxSuggestOrderGoodsNum == 0.0) {//如果订货最大数量为0，那为了在点击添加时弹出提示，所以不能把按钮enable设为false
                    ibGoodsDecrease.isEnabled = true
                    ibGoodsDecrease.setImageResource(R.mipmap.icon_shop_order_subtract)//虽然是可点击的，但还是要设为灰色。
                } else {
                    ibGoodsDecrease.isEnabled = false
                    ibGoodsDecrease.setImageResource(R.mipmap.icon_shop_order_subtract)
                }
            } else {
                ibGoodsDecrease.isEnabled = true
                ibGoodsDecrease.setImageResource(R.mipmap.icon_shop_order_subtract)
            }
            //加号逻辑===============
            if (data.orderGoodsAuditNum >= data.maxSuggestOrderGoodsNum) {
                if (data.maxSuggestOrderGoodsNum == 0.0) {//如果剩余订货量为0，那为了在点击添加时弹出提示，所以不能把按钮enable设为false
                    ibGoodsPlus.isEnabled = true
                    //虽然是可点击的，但还是要设为灰色。
                    ibGoodsPlus.setImageResource(R.mipmap.icon_shop_order_add)
                } else {
                    ibGoodsPlus.isEnabled = false
                    ibGoodsPlus.setImageResource(R.mipmap.icon_shop_order_add)
                }
            } else {
                ibGoodsPlus.isEnabled = true
                ibGoodsPlus.setImageResource(R.mipmap.icon_shop_order_add)
            }

            //通过Picasso先判断图片链接可用性，如果无效链接，则不显示“查看图片”按钮
            if (!data.isShowImageTv) {//只有在标记为false的时候，才去检查链接可用性。
                Picasso.with(context).load(mAuditingList[pos].productImage)
                    .into(tvGoodsImg, object : Callback {
                        override fun onSuccess() {
                            if (pos >= mAuditingList.size) return//防溢出
                            mAuditingList[pos].isShowImageTv = true
                            // if (this@OrderGoodsTradeAdapter.)
                            //只刷新这个组件
                            mHandler.post { notifyItemChanged(pos, "refrshImage") }
                        }

                        override fun onError() {
                            if (pos >= mAuditingList.size) return//防溢出
                            data.isShowImageTv = false
                            // notifyItemChanged(pos)
                        }
                    })
            }

            //加号点击监听================================
            ibGoodsPlus.setOnClickListener {
                val cell: OrderGoodsAuditDetail = mAuditingList[pos]
                val pDHPack = cell.productBoxNum
                val d = Arith.add(cell.orderGoodsAuditNum, pDHPack)

                var temp = ""
                if (d > cell.maxSuggestOrderGoodsNum) {
                    temp = ("请检查产品：" + cell.productName
                            + ",不能超过最大订货量" + cell.maxSuggestOrderGoodsNum
                            + "! 您输入的数量为：" + d)
                }

                if (PackType.FINISHED_PRODUCT_TYPE == cell.productType && cell.productLastMonthSaleNum > 0 && d >= cell.productLastMonthSaleNum * 1.5) {
                    temp = ("请检查产品：" + cell.productName
                            + ",不能超过次大订货量" + cell.productLastMonthSaleNum * 1.5 + "! 您输入的数量为：" + d)
                    cell.secondValid = true
                }

                if (!TextUtils.isEmpty(temp)) {
                    val builder = PublicConformTipDialog.Builder(context)
                    builder.setTitle("提示")
                    builder.setMessage(temp)
                    builder.setNegativeButton(
                        "知道了并重新输入"
                    ) { dialog, which -> dialog.dismiss() }
                    builder.create().show()
                    return@setOnClickListener
                }

                cell.orderGoodsAuditNum = d
                tvGoodsCountEdit.text = StringUtils.formatDouble(d, "0.00")

                if (d < 0.0) {
                    cell.isInvalid = true
                    tvGoodsCountEdit.setTextColor(Color.RED)
                    ibGoodsDecrease.isEnabled = false
                } else {
                    if (0.0 != cell.productBoxNum && 0.0 != d && d % cell.productBoxNum != 0.0) {
                        cell.isInvalid = true
                        tvGoodsCountEdit.setTextColor(Color.RED)
                    } else {
                        cell.isInvalid = false
                        tvGoodsCountEdit.setTextColor(Color.BLACK)
                    }
                    ibGoodsDecrease.isEnabled = true
                }

                if (isShowInventoryDays(cell.productBigFatherType, cell.productBigType)) {
                    tvCyl.text =
                        calculatorCyDay(data, data.orderGoodsAuditNum).toInt().toString()
                } else {
                    tvCyl.text = "--"
                }
                notifyPriceShow.invoke()
            }

            //减号点击监听================================
            ibGoodsDecrease.setOnClickListener {
                val cell: OrderGoodsAuditDetail = mAuditingList[pos]
                val pDHPack = cell.productBoxNum
                val d = Arith.sub(cell.orderGoodsAuditNum, pDHPack)
                cell.orderGoodsAuditNum = d
                tvGoodsCountEdit.text = StringUtils.formatDouble(d, "0.00")
                if (d <= 0.0) {
                    ibGoodsDecrease.isEnabled = false
                }

                if (PackType.FINISHED_PRODUCT_TYPE == cell.productType && cell.productLastMonthSaleNum
                    > 0 && d >= cell.productLastMonthSaleNum * 1.5
                ) {
                    cell.secondValid = false
                }

                if (d < 0.0) {
                    cell.isInvalid = true
                    tvGoodsCountEdit.setTextColor(Color.RED)
                    ibGoodsPlus.isEnabled = true
                } else if (d > cell.maxSuggestOrderGoodsNum) {
                    cell.isInvalid = true
                    tvGoodsCountEdit.setTextColor(Color.RED)
                    ibGoodsPlus.isEnabled = false
                } else {
                    if (0.0 != cell.productBoxNum && 0.0 != d && d % cell.productBoxNum != 0.0) {
                        cell.isInvalid = true
                        tvGoodsCountEdit.setTextColor(Color.RED)
                    } else {
                        cell.isInvalid = false
                        tvGoodsCountEdit.setTextColor(Color.BLACK)
                    }
                    ibGoodsPlus.isEnabled = true
                }

                if (isShowInventoryDays(data.productBigFatherType, data.productBigType)) {
                    tvCyl.text = calculatorCyDay(data, data.orderGoodsAuditNum).toInt().toString()
                } else {
                    tvCyl.text = "--"
                }
                notifyPriceShow.invoke()
            }
            //数量点击监听================================
            if (!data.isProductIsNotStock) {
                tvGoodsCountEdit.setSelectAllOnFocus(true)
                tvGoodsCountEdit.setOnClickListener {
                    mKeyboard.show(
                        tvGoodsCountEdit,
                        (context as AppCompatActivity).supportFragmentManager,
                        null
                    )
                        .setDecimal(2)
                        .selectAll().setOnDismissListener {
                            if (mAuditingList.size > pos) {
                                val cell = mAuditingList[pos]
                                val input: String = tvGoodsCountEdit.text.toString()
                                var d: Double
                                val pDHPack = cell.productBoxNum
                                d = try {
                                    input.toDouble()
                                } catch (e: NumberFormatException) {
                                    0.0
                                }
                                cell.orderGoodsAuditNum = d
                                tvGoodsCountEdit.setBackgroundResource(R.drawable.shape_solid_f5f5f5_round_3)
                                tvGoodsCountEdit.text = StringUtils.formatDouble(d, "0.00")

                                var temp = ""
                                if (d <= 0.0) {
                                    temp = ("请检查产品：" + cell.productName
                                            + ",必须输入有效的数字！")
                                    ibGoodsDecrease.isEnabled = false
                                } else {
                                    ibGoodsDecrease.isEnabled = true
                                }

                                if (d > cell.maxSuggestOrderGoodsNum) {
                                    temp = ("请检查产品：" + cell.productName
                                            + ",不能超过最大订货量" + cell.maxSuggestOrderGoodsNum
                                            + "! 您输入的数量为：" + d)
                                    ibGoodsPlus.isEnabled = false
                                }
                                if (PackType.FINISHED_PRODUCT_TYPE ==
                                    cell.productType && cell.productLastMonthSaleNum > 0 && d >= cell.productLastMonthSaleNum * 1.5
                                ) {
                                    temp = ("请检查产品：" + cell.productName
                                            + ",不能超过次大订货量" + cell.productLastMonthSaleNum * 1.5 + "! 您输入的数量为：" + d)
                                    cell.secondValid = true
                                    ibGoodsPlus.isEnabled = false
                                }
                                if (0.0 != pDHPack && 0.0 != d && d % pDHPack != 0.0) {
                                    temp = ("请检查产品：" + cell.productName
                                            + ",数量必须是" + pDHPack + "倍数")
                                    data.orderGoodsAuditNum = (data.orderGoodsAuditNum.toInt()
                                            / pDHPack.toInt() * pDHPack) // 非法规格输入调整
                                    d = data.orderGoodsNum
                                    data.orderGoodsAuditNum = d
                                }

                                if (!TextUtils.isEmpty(temp)) {
                                    val builder = PublicConformTipDialog.Builder(context)
                                    builder.setTitle("提示")
                                    builder.setMessage(temp)
                                    builder.setNegativeButton(
                                        "知道了并重新输入"
                                    ) { dialog, which -> dialog.dismiss() }
                                    if (!cell.isInvalid) {
                                        builder.create().show()
                                    }
                                    cell.isInvalid = true
                                    tvGoodsCountEdit.setTextColor(Color.RED)
                                } else {
                                    cell.isInvalid = false
                                    ibGoodsPlus.isEnabled = true
                                    ibGoodsDecrease.isEnabled = true
                                    ibGoodsDecrease.setImageResource(R.mipmap.icon_shop_order_subtract)
                                    ibGoodsPlus.setImageResource(R.mipmap.icon_shop_order_add)
                                    tvGoodsCountEdit.setTextColor(Color.BLACK)
                                }

                                if (isShowInventoryDays(
                                        data.productBigFatherType,
                                        data.productBigType
                                    )
                                ) {
                                    tvCyl.text =
                                        calculatorCyDay(
                                            data,
                                            data.orderGoodsAuditNum
                                        ).toInt()
                                            .toString()
                                } else {
                                    tvCyl.text = "--"
                                }

                                notifyPriceShow.invoke()
                            }
                        }
                }
            } else {
                tvGoodsCountEdit.setSelectAllOnFocus(false)
                tvGoodsCountEdit.setOnClickListener(null)
            }
        }
    }

    private fun refreshOrderName(entity: OrderGoodsAuditDetail): SpannableString {
        return if (entity.isShowImageTv) {
            SpannableString(entity.productName + "img").apply {
                setSpan(
                    UnderlineSpan(),
                    0,
                    entity.productName.length,
                    Spanned.SPAN_EXCLUSIVE_EXCLUSIVE
                )

                val drawable: Drawable? =
                    ContextCompat.getDrawable(context, R.mipmap.ic_picture_order)
                drawable?.let {
                    it.setBounds(0, 0, it.intrinsicWidth, it.intrinsicHeight)
                    setSpan(
                        ImageSpan(it),
                        this.length - 3,
                        this.length,
                        Spanned.SPAN_INCLUSIVE_EXCLUSIVE
                    )
                }


                setSpan(
                    StyleSpan(Typeface.BOLD),
                    0,
                    entity.productName.length,
                    Spanned.SPAN_INCLUSIVE_EXCLUSIVE
                )

                setSpan(object : ClickableSpan() {
                    override fun onClick(v: View) {
                        showAdDialog(context, entity.productImage)
                    }
                }, 0, this.length, Spanned.SPAN_INCLUSIVE_EXCLUSIVE)

                val colorSpan =
                    ForegroundColorSpan(ContextCompat.getColor(context, R.color.normal_color))
                setSpan(
                    colorSpan,
                    0,
                    entity.productName.length,
                    Spanned.SPAN_INCLUSIVE_EXCLUSIVE
                )
            }
        } else {
            SpannableString(entity.productName).apply {
                setSpan(
                    StyleSpan(Typeface.BOLD),
                    0,
                    entity.productName.length,
                    Spanned.SPAN_INCLUSIVE_EXCLUSIVE
                )
                val colorSpan =
                    ForegroundColorSpan(
                        ContextCompat.getColor(
                            context,
                            R.color.common_txt_second_color
                        )
                    )
                setSpan(
                    colorSpan,
                    0,
                    entity.productName.length,
                    Spanned.SPAN_INCLUSIVE_EXCLUSIVE
                )
            }
        }
    }

    /**
     * 实时计算库存天数
     *
     * @param data   订货审核产品实体
     * @param counts 审核数量
     * @return 库存天数=（（库存数量+审核数量）/月用量）*30   结果的单位为：天 ；注：产品库存数量=（库存+在途）
     * cyd=(（ProductStockNum+OrderGoodsAuditNum）/ProductLastMonthSaleNum)*30,
     * StringUtil.formatDouble(calculatorCyDay(data, data.getOrderGoodsAuditNum()), "0")；四舍五入取整
     */
    private fun calculatorCyDay(data: OrderGoodsAuditDetail, counts: Double): Double {
        val cyd: Double =
            if (data.productLastMonthSaleNum == 0.0 || counts + data.productStockNum == 0.0) {
                0.0
            } else {
                try {
                    ((data.productStockNum + data.orderGoodsAuditNum)
                            / data.productLastMonthSaleNum) * 30
                } catch (e: Exception) {
                    0.0
                }
            }
        return cyd
    }

    /**
     * 弹出图片弹窗
     */
    private fun showAdDialog(context: Context, adInfo: String) {
        val adDialog = AdDialog(context, adInfo)
        //点击空白区域能不能退出
        adDialog.setCanceledOnTouchOutside(false)
        //按返回键能能退出
        adDialog.setCancelable(true)
        adDialog.setClickLink(adInfo)
        adDialog.setLinkType("url")
        adDialog.show()
    }

    /**
     * 判断是否特殊类型，确定是否要显示库存天数
     */
    private fun isShowInventoryDays(
        productBigFatherType: String?,
        productBigType: String?
    ): Boolean {
        if (!TextUtils.isEmpty(productBigFatherType) && !TextUtils.isEmpty(productBigType)) {
            if ((PackType.FINISHED_PRODUCT_TYPE == productBigFatherType && PackType.NO_SELL == productBigType)
                || PackType.ACCESSORIES_SUPPLIERS == productBigType
            ) {
                return false
            }
        }
        return true
    }

    class GoodsAuditingDetailsViewHolder(view: View) : RecyclerView.ViewHolder(view) {
        val tvGoodsName: TextView = view.find(R.id.tv_goods_name) as TextView
        val tvGoodsImg: ImageView = view.find(R.id.iv_goods_img) as ImageView
        val tvGoodsUnit: TextView = view.find(R.id.tv_goods_unit) as TextView
        val tvGoodsUnitPrice: TextView = view.find(R.id.tv_goods_unit_price) as TextView

        val tvKucun: TextView = view.find(R.id.tv_kucun) as TextView
        val tvQuantityOrder: TextView = view.find(R.id.tv_quantity_order) as TextView
        val tvOeProDhQty: TextView = view.find(R.id.tv_oe_pro_dh_qty) as TextView
        val tvCyl: TextView = view.find(R.id.tv_cyl) as TextView

        val tvGoodsAlreadyMarket: TextView = view.find(R.id.tv_goods_already_market) as TextView

        val llGoodsCountEdit: LinearLayout = view.find(R.id.ll_goods_count_edit) as LinearLayout
        val ibGoodsPlus: ImageButton = view.find(R.id.ib_goods_plus) as ImageButton
        val ibGoodsDecrease: ImageButton = view.find(R.id.ib_goods_decrease) as ImageButton
        val tvGoodsCountEdit: TextView = view.find(R.id.tv_goods_count_edit) as TextView

        val rlGoodsCountQuery: RelativeLayout =
            view.find(R.id.rl_goods_count_query) as RelativeLayout
        val tvGoodsCountQuery = view.find(R.id.tv_goods_count_query) as TextView
        val tvGoodsUpdate = view.find(R.id.tv_goods_update) as TextView
    }
}
