package com.wgmf.yxgj.module.business.manageproduct.ui

import android.content.Intent
import android.os.Bundle
import android.support.v4.content.ContextCompat
import android.support.v7.widget.LinearLayoutManager
import android.text.*
import android.util.Log
import android.view.Gravity
import android.view.View
import android.widget.TextView
import com.alibaba.android.arouter.facade.annotation.Route
import com.google.gson.Gson
import com.wgmf.library.base.ResultData
import com.wgmf.library.utils.TextColorDominator
import com.wgmf.yxgj.base.BaseParentAct
import com.wgmf.yxgj.config.BusinessID
import com.wgmf.yxgj.dialog.LoadWaitDominator
import com.wgmf.yxgj.global.ConstantParams
import com.wgmf.yxgj.utils.StringUtils
import com.wgmf.yxgj.module.business.manageproduct.R
import com.wgmf.yxgj.module.business.manageproduct.model.*
import com.wgmf.yxgj.module.business.manageproduct.service.GoodsManagerService
import com.wgmf.yxgj.widgets.decoration.DividerItemDecoration
import com.wgmf.yxgj.widgets.EditText.ClearEditText
import com.wgmf.yxgj.widgets.ScrollablePanel.PanelAdapter
import com.wgmf.yxgj.widgets.ScrollablePanel.ScrollablePanelManager
import com.wgmf.yxgj.widgets.ScrollablePanel.ScrollablePanelManager.PanelLineAdapter.*
import com.xp.arouter.RouterParams
import kotlinx.android.synthetic.main.activity_add_order_store.*
import kotlinx.android.synthetic.main.activity_goods_auditing_shop.*
import org.jetbrains.anko.find
import java.util.*


/**
 * @author LW on 2021-9-13 0013.
 * 订货加单 入口界面
 */
@Route(path = RouterParams.URL_GOODSAUDITINGSHOPLISTACTIVITY)
class GoodsAuditingShopListActivity : BaseParentAct(), OnContentItemClickListener {
    /**
     * 已提交门店列表
     */
    private var mOrderGoodsAuditStoreList: MutableList<OrderStoreList> = mutableListOf()

    /**
     * 未提交门店列表
     */
    private var mNotOrderGoodsAuditStoreList: MutableList<OrderStoreList> = mutableListOf()

    /**
     * 不能订货门店列表
     */
    private var mNotOrderStoreList: MutableList<NotOrderStoreList> = mutableListOf()

    private var mGoodsAuditingShopListAdapter: GoodsAuditingShopListAdapter? = null

    private var mGoodsAuditingShopTableAdapter: GoodsAuditingShopTableAdapter? = null

    private var mScrollablePanelManager: ScrollablePanelManager? = null

    private var mOrderGoodsAuditStoreGroupListEntity: OrderGoodsAuditStoreGroupListEntity? = null

    private lateinit var mLoadWait: LoadWaitDominator

    private var mCurrentStoreType: Int = STORE_SUBMITTED

    private val mBranchTitle: String by lazy {
        intent.getStringExtra("branchTitle")
    }

    private val mStoreNo by lazy {
        intent.getStringExtra("storeNo")
    }

    private var mIsAutoJump: Boolean = false

    companion object {
        //已提交
        const val STORE_SUBMITTED: Int = 1

        //未提交
        const val STORE_UN_SUBMITTED: Int = 2

        //不能订货
        const val STORE_NOT_ORDER: Int = 3
    }

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        setContentView(R.layout.activity_goods_auditing_shop)

        initTitle()
        initContent()
        setListener()
    }

    override fun onResume() {
        super.onResume()
        findOrderGoodsAuditStoreData()
    }

    private fun findOrderGoodsAuditStoreData() {
        showDialog()
        userInfo?.let {
            val staffId = userInfo.staffId
            val saleOrgId = userInfo.organizationId
            GoodsManagerService.getInstance().requestFindOrderGoodsAuditStore(
                staffId,
                saleOrgId,
                this@GoodsAuditingShopListActivity
            )
        }
    }

    override fun initTitle() {
        super.initTitle()
        homeTitleText.text = mBranchTitle
        homeTitleBackLl.visibility = View.VISIBLE
    }

    private fun initContent() {
        mLoadWait = LoadWaitDominator(this, container_root_fl)

        auditing_store_submitted_tv.isSelected = true
        auditing_store_unsubmitted_tv.isSelected = false
        auditing_store_not_order_tv.isSelected = false

        switchTabBindListData(STORE_SUBMITTED)
    }

    /**
     * 切换Tab绑定不同数据
     */
    private fun switchTabBindListData(type: Int) {
        mCurrentStoreType = type
        when (type) {
            STORE_SUBMITTED -> {
                auditing_store_submitted_tv.isSelected = true
                auditing_store_unsubmitted_tv.isSelected = false
                auditing_store_not_order_tv.isSelected = false
            }
            STORE_UN_SUBMITTED -> {
                auditing_store_submitted_tv.isSelected = false
                auditing_store_unsubmitted_tv.isSelected = true
                auditing_store_not_order_tv.isSelected = false
            }
            STORE_NOT_ORDER -> {
                auditing_store_submitted_tv.isSelected = false
                auditing_store_unsubmitted_tv.isSelected = false
                auditing_store_not_order_tv.isSelected = true
            }
        }
        //重新读取列表数据
        loadListData()
    }

    private fun setListener() {
        auditing_store_submitted_tv.setOnClickListener {
            switchTabBindListData(STORE_SUBMITTED)
        }

        auditing_store_unsubmitted_tv.setOnClickListener {
            switchTabBindListData(STORE_UN_SUBMITTED)
        }

        auditing_store_not_order_tv.setOnClickListener {
            switchTabBindListData(STORE_NOT_ORDER)
        }

        public_search_edt_view.find<ClearEditText>(R.id.store_name_et).visibility = View.VISIBLE
        public_search_edt_view.find<ClearEditText>(R.id.store_name_et)
            .addTextChangedListener(object : TextWatcher {
                override fun onTextChanged(
                    s: CharSequence, start: Int, before: Int,
                    count: Int
                ) {
                }

                override fun beforeTextChanged(
                    s: CharSequence, start: Int, count: Int,
                    after: Int
                ) {
                }

                override fun afterTextChanged(s: Editable) {
                    searchResultListData()
                }
            })
    }

    /**
     * 搜索结果列表数据
     */
    private fun searchResultListData() {
        val searchResult: String =
            public_search_edt_view.find<ClearEditText>(R.id.store_name_et).text.toString()
                .trim { it <= ' ' }
        if (searchResult.isNotEmpty()) {
            mOrderGoodsAuditStoreGroupListEntity?.result?.apply {
                when (mCurrentStoreType) {
                    STORE_SUBMITTED -> {
                        mOrderGoodsAuditStoreList.clear()
                        orderGoodsAuditStoreList?.forEach {
                            if (it.shop.shopName.contains(searchResult)) {
                                mOrderGoodsAuditStoreList.add(it)
                            }
                            if (mGoodsAuditingShopTableAdapter != null) {
                                generateTestData(mGoodsAuditingShopTableAdapter!!)
                                mScrollablePanelManager?.notifyDataSetChanged()
                            }
                        }

                    }
                    STORE_UN_SUBMITTED -> {
                        mNotOrderGoodsAuditStoreList.clear()
                        notOrderGoodsAuditStoreList?.forEach {
                            if (it.shop.shopName.contains(searchResult)) {
                                mNotOrderGoodsAuditStoreList.add(it)
                            }
                            if (mGoodsAuditingShopTableAdapter != null) {
                                generateTestData(mGoodsAuditingShopTableAdapter!!)
                                mScrollablePanelManager?.notifyDataSetChanged()
                            }
                        }
                    }
                    STORE_NOT_ORDER -> {
                        mNotOrderStoreList.clear()
                        notOrderStoreList?.forEach {
                            if (it.shopName.contains(searchResult)) {
                                mNotOrderStoreList.add(it)
                            }
                        }
                        mGoodsAuditingShopListAdapter?.apply {
                            dataList = mNotOrderStoreList
                            notifyDataSetChanged()
                        }
                    }
                }
            }
        } else {
            loadListData()
        }
    }

    private fun setData(item: OrderGoodsAuditStoreGroupListEntity?) {
        val onClickTitle = public_content_title_ll.find<TextView>(R.id.onclick_title)
        item?.let {
            it.result?.apply {
                with(onClickTitle) {
                    visibility = View.VISIBLE
                    gravity = Gravity.CENTER
                    auditing_store_submitted_tv.text = StringUtils.formatString(
                        mContext.getString(R.string.goods_auditing_item_submitted),
                        alreadyOrderStoreNum
                    )
                    auditing_store_unsubmitted_tv.text = StringUtils.formatString(
                        mContext.getString(R.string.goods_auditing_item_unsubmitted),
                        noOrderStoreNum
                    )
                    auditing_store_not_order_tv.text = StringUtils.formatString(
                        mContext.getString(R.string.goods_auditing_not_order),
                        notCanOrderStoreNum
                    )
                    val content: String = StringUtils.formatString(
                        mContext.getString(R.string.goods_auditing_stores_number_info),
                        sumStoreNum,
                        orderStoreNum,
                        alreadyOrderStoreNum
                    )

                    text = TextColorDominator.styleTextNumberColor(
                        content, ContextCompat.getColor(
                            mContext,
                            R.color.c_ff8c19
                        )
                    )
                }
            }
            if (!TextUtils.isEmpty(mStoreNo) && !mIsAutoJump) {
                mIsAutoJump = true
                run breaking@{
                    mOrderGoodsAuditStoreGroupListEntity?.result?.orderGoodsAuditStoreList?.forEach {
                        if (mStoreNo == it.shop.shopId) {
                            val intent = Intent(
                                this@GoodsAuditingShopListActivity,
                                GoodsAuditingStatusActivity::class.java
                            )
                            intent.putExtra("storeNo", it.shop.shopId)
                            intent.putExtra("branchTitle", mBranchTitle)
                            intent.putExtra("inventoryAmount", it.stockAmount)
                            intent.putExtra("inventoryDays", it.stockDayNum)
                            intent.putExtra("isFzsjd", it.isFzsjd)
                            intent.putExtra("orderGoodsAuditAmount", it.orderAmount)
                            intent.putExtra("saleAmount", it.lastTDaySaleAmount)
                            intent.putExtra("auditFlag", it.auditFlag)
                            startActivity(intent)
                            return@breaking
                        }
                    }
                }
            }
            loadListData()
        }
    }

    /**
     * 读取列表数据
     */
    private fun loadListData() {
        mOrderGoodsAuditStoreGroupListEntity?.result?.apply {
            if (null != orderGoodsAuditStoreList && orderGoodsAuditStoreList!!.isNotEmpty()) {
                mOrderGoodsAuditStoreList.clear()
                mOrderGoodsAuditStoreList.addAll(orderGoodsAuditStoreList as MutableList<OrderStoreList>)
            }
            if (null != notOrderGoodsAuditStoreList && notOrderGoodsAuditStoreList!!.isNotEmpty()) {
                mNotOrderGoodsAuditStoreList.clear()
                mNotOrderGoodsAuditStoreList.addAll(notOrderGoodsAuditStoreList as MutableList<OrderStoreList>)
            }
            if (null != notOrderStoreList && notOrderStoreList!!.isNotEmpty()) {
                mNotOrderStoreList.clear()
                mNotOrderStoreList.addAll(notOrderStoreList as MutableList<NotOrderStoreList>)
            }
            refreshListData()
        }
    }

    /**
     * 刷新列表数据
     * @param dataType 类型
     */
    private fun refreshListData() {
        if (mCurrentStoreType <= 2) {
            bindTableAdapterData()
        } else {
            bindListAdapterData()
        }
    }

    /**
     * 绑定列表数据
     */
    private fun bindListAdapterData() {
        recycler_header_root.visibility = View.GONE
        if (mNotOrderStoreList.isNullOrEmpty()) {
            mLoadWait.show(LoadWaitDominator.NO_DATA)
        } else {
            mLoadWait.dismissAll()
        }
        if (mGoodsAuditingShopListAdapter == null) {
            mGoodsAuditingShopListAdapter =
                GoodsAuditingShopListAdapter(mContext, mNotOrderStoreList)
            recycler_content_list.apply {
                layoutManager = LinearLayoutManager(mContext)
                addItemDecoration(
                    DividerItemDecoration(
                        DividerItemDecoration.HORIZONTAL_LIST,
                        1,
                        ContextCompat.getColor(mContext, R.color.c_e8e8e8)
                    )
                )
                adapter = mGoodsAuditingShopListAdapter
            }
        } else {
            recycler_content_list.apply {
                layoutManager = LinearLayoutManager(mContext)
                adapter = mGoodsAuditingShopListAdapter
            }
            mGoodsAuditingShopListAdapter?.apply {
                dataList = mNotOrderStoreList
                notifyDataSetChanged()
            }
        }
    }

    /**
     * 绑定表格数据
     */
    private fun bindTableAdapterData() {
        recycler_header_root.visibility = View.VISIBLE
        if (mGoodsAuditingShopTableAdapter == null) {
            mGoodsAuditingShopTableAdapter =
                GoodsAuditingShopTableAdapter(mContext)

            recycler_content_list.addItemDecoration(
                DividerItemDecoration(
                    DividerItemDecoration.HORIZONTAL_LIST,
                    1,
                    ContextCompat.getColor(mContext, R.color.c_e8e8e8)
                )
            )
        }
        generateTestData(mGoodsAuditingShopTableAdapter!!)
        mScrollablePanelManager = ScrollablePanelManager()
        mScrollablePanelManager?.setPanelView(
            this,
            recycler_content_list,
            recycler_header_list,
            first_item
        )
        mGoodsAuditingShopTableAdapter
        mScrollablePanelManager?.setPanelAdapter(
            mGoodsAuditingShopTableAdapter,
            this@GoodsAuditingShopListActivity
        )
    }

    /**
     * 更新数据
     */
    private fun generateTestData(
        goodsAuditingShopListAdapter: GoodsAuditingShopTableAdapter
    ) {
        if (mCurrentStoreType == STORE_SUBMITTED) {
            if (mOrderGoodsAuditStoreList.isNullOrEmpty()) {
                mLoadWait.show(LoadWaitDominator.NO_DATA)
            } else {
                mLoadWait.dismissAll()
            }
            goodsAuditingShopListAdapter.setOrderTitleList(
                mContext.resources.getStringArray(R.array.goods_auditing_submitted_list_title)
                    .asList()
                    .toMutableList()
            )
            goodsAuditingShopListAdapter.setOrderGoodsAuditStoreList(mOrderGoodsAuditStoreList)
        } else if (mCurrentStoreType == STORE_UN_SUBMITTED) {
            if (mNotOrderGoodsAuditStoreList.isNullOrEmpty()) {
                mLoadWait.show(LoadWaitDominator.NO_DATA)
            } else {
                mLoadWait.dismissAll()
            }
            goodsAuditingShopListAdapter.setOrderTitleList(
                mContext.resources.getStringArray(R.array.goods_auditing_not_submitted_list_title)
                    .asList()
                    .toMutableList()
            )
            goodsAuditingShopListAdapter.setOrderGoodsAuditStoreList(mNotOrderGoodsAuditStoreList)
        }
    }

    override fun onBusinessResultAtMainThread(result: ResultData?) {
        super.onBusinessResultAtMainThread(result)
        dismissDialog()
        result?.let {
            val id = it.taskID
            when (id) {
                BusinessID.GoodsManager.MSG_ON_FIND_ORDERGOODS_AUDIT_STORE -> {
                    val msg = it.info
                    if (it.isSuccessed) {
                        mLoadWait.dismissAll()
                        mOrderGoodsAuditStoreGroupListEntity = Gson().fromJson(
                            msg,
                            OrderGoodsAuditStoreGroupListEntity::class.java
                        )
                        Log.d(
                            TAG,
                            "mOrderGoodsAuditStoreGroupListEntity=$mOrderGoodsAuditStoreGroupListEntity"
                        )
                        if (ConstantParams.CONSTANT_PARAMS_0 == mOrderGoodsAuditStoreGroupListEntity!!.retCode) {
                            if (mOrderGoodsAuditStoreGroupListEntity!!.result != null) {
                                setData(mOrderGoodsAuditStoreGroupListEntity)
                            }
                        } else {
                            showMsg(mOrderGoodsAuditStoreGroupListEntity!!.retInfo)
                        }
                    } else {
                        mLoadWait.showNetError()
                    }
                }
                else -> {
                }
            }
        }
    }

    override fun onItemClick(position: Int, panelAdapter: PanelAdapter?) {
    }

    override fun onChildItemClick(row: Int, position: Int, panelAdapter: PanelAdapter?) {
        if (position == ConstantParams.CONSTANT_STARTS_0 && mCurrentStoreType == STORE_SUBMITTED) {
            //跳转到订货审核界面
            if (panelAdapter != null && panelAdapter is GoodsAuditingShopTableAdapter) {
                val orderGoodsAuditStoreList = panelAdapter.getOrderGoodsAuditStoreList()
                val intent = Intent(
                    this@GoodsAuditingShopListActivity,
                    GoodsAuditingStatusActivity::class.java
                )
                val orderStoreList = orderGoodsAuditStoreList[row]
                intent.putExtra("storeNo", orderStoreList.shop.shopId)
                intent.putExtra("branchTitle", mBranchTitle)
                intent.putExtra("inventoryAmount", orderStoreList.stockAmount)
                intent.putExtra("inventoryDays", orderStoreList.stockDayNum)
                intent.putExtra("orderGoodsAuditAmount", orderStoreList.orderAmount)
                intent.putExtra("saleAmount", orderStoreList.lastTDaySaleAmount)
                intent.putExtra("isFzsjd", orderStoreList.isFzsjd)
                intent.putExtra("auditFlag", orderStoreList.auditFlag)
                startActivity(intent)
            }
        }
    }
}