package com.wgmf.yxgj.module.business.manageproduct.ui

import android.content.Context
import android.support.v4.content.ContextCompat
import android.support.v7.widget.RecyclerView
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import android.widget.LinearLayout
import android.widget.RelativeLayout
import android.widget.TextView
import com.wgmf.library.utils.StringUtil
import com.wgmf.library.utils.TextColorDominator
import com.wgmf.yxgj.module.business.manageproduct.R
import com.wgmf.yxgj.module.business.manageproduct.model.OrderStoreList
import com.wgmf.yxgj.widgets.ScrollablePanel.PanelAdapter

/**
 * @author LW on 2021-9-15 0015.
 * 订货审核门店列表内容适配器
 */
class GoodsAuditingShopTableAdapter(val mContext: Context) : PanelAdapter {

    /**
     * 已提交门店列表、未提交门店列表
     */
    private var mOrderGoodsAuditStoreList: MutableList<OrderStoreList> = mutableListOf()

    /**
     * 表单每列标题
     */
    private var mOrderTitleList: MutableList<String> = mutableListOf()


    companion object {
        /**
         * 列标题类型
         */
        const val COLUMNS_TITLE_ITEM_TYPE: Int = 1

        /**
         * 行标题类型
         */
        const val ROW_TITLE_ITEM_TYPE: Int = 2

        /**
         * 内容标题类型
         */
        const val CONTENT_ITEM_TYPE: Int = 0
    }

    override fun getRowCount(): Int = mOrderGoodsAuditStoreList.size

    override fun getColumnCount(): Int = mOrderTitleList.size

    override fun getItemViewType(row: Int, column: Int): Int {
        if (row == 0) {
            return ROW_TITLE_ITEM_TYPE
        }
        if (column == 0) {
            return COLUMNS_TITLE_ITEM_TYPE
        }
        return CONTENT_ITEM_TYPE
    }

    override fun onBindViewHolder(holder: RecyclerView.ViewHolder?, row: Int, column: Int) {
        when (getItemViewType(row, column)) {
            ROW_TITLE_ITEM_TYPE -> {
                bindRowTitleItemData(holder as TitleViewHolder, column)
            }
            COLUMNS_TITLE_ITEM_TYPE -> {
                bindColumnTitleItemData(holder as TitleViewHolder, row)
            }
            else -> {
                bindContentItemData(holder as ContentViewHolder, row, column)
            }
        }
    }

    private fun bindContentItemData(
        contentViewHolder: ContentViewHolder,
        row: Int,
        column: Int
    ) {
        if (mOrderGoodsAuditStoreList.isNotEmpty()) {
            val orderStoreList = mOrderGoodsAuditStoreList[row - 1]
            orderStoreList.apply {
                if (mOrderTitleList.size == 6) {
                    contentViewHolder.tvAuditingContent.text = when (column) {
                        1 -> StringUtil.formatDouble(orderAmount, "0.00")
                        2 -> StringUtil.formatDouble(orderAddAmount, "0.00")
                        3 -> StringUtil.formatDouble(stockAmount, "0.00")
                        4 -> StringUtil.formatDouble(lastTDaySaleAmount, "0.00")
                        5 -> stockDayNum.toString()
                        else -> "--"
                    }
                } else if (mOrderTitleList.size == 5) {
                    contentViewHolder.tvAuditingContent.text = when (column) {
                        1 -> StringUtil.formatDouble(orderAmount, "0.00")
                        2 -> StringUtil.formatDouble(stockAmount, "0.00")
                        3 -> StringUtil.formatDouble(lastTDaySaleAmount, "0.00")
                        4 -> stockDayNum.toString()
                        else -> "--"
                    }
                }

                if(auditFlag=="2"){
                    contentViewHolder.tvAuditingContent.setTextColor(ContextCompat.getColor(
                        mContext,
                        R.color.c_e6383a
                    ))
                }else{
                    contentViewHolder.tvAuditingContent.setTextColor(ContextCompat.getColor(
                        mContext,
                        R.color.c_333333
                    ))
                }
                updateItemBgColor(row, contentViewHolder.llAuditingStoreItemRoot)
            }
        }
    }

    private fun bindColumnTitleItemData(
        titleViewHolder: TitleViewHolder,
        row: Int
    ) {
        if (mOrderGoodsAuditStoreList.isNotEmpty()) {
            val orderStore = mOrderGoodsAuditStoreList[row - 1]
            //1表示已审核，2表示未审核,3表示未提交
            if (orderStore.auditFlag == "2") {
                titleViewHolder.tvAuditingTitle.text = TextColorDominator.styleTextUnderlineColor(
                    orderStore.shop.shopName, ContextCompat.getColor(
                        mContext,
                        R.color.c_e6383a
                    )
                )
            } else {
                titleViewHolder.tvAuditingTitle.text = TextColorDominator.styleTextUnderlineColor(
                    orderStore.shop.shopName, ContextCompat.getColor(
                        mContext,
                        R.color.c_333333
                    )
                )
            }
            updateItemBgColor(row, titleViewHolder.rlAuditingStoreItemRoot)
        }
    }

    private fun updateItemBgColor(position: Int, item: View) {
        if (position % 2 == 0) {
            item.setBackgroundColor(
                ContextCompat.getColor(
                    mContext,
                    R.color.c_ffffff
                )
            )
        } else {
            item.setBackgroundColor(
                ContextCompat.getColor(
                    mContext,
                    R.color.c_f7f7f7
                )
            )
        }
    }

    private fun bindRowTitleItemData(
        titleViewHolder: TitleViewHolder,
        column: Int
    ) {
        if (mOrderTitleList.isNotEmpty()) {
            titleViewHolder.tvAuditingTitle.text = TextColorDominator.styleTextBoldColor(
                mOrderTitleList[column], ContextCompat.getColor(
                    mContext,
                    R.color.c_222222
                )
            )
        }
    }

    override fun onCreateViewHolder(parent: ViewGroup?, viewType: Int): RecyclerView.ViewHolder {
        when (viewType) {
            ROW_TITLE_ITEM_TYPE -> {
                return TitleViewHolder(
                    LayoutInflater.from(
                        parent?.context
                    ).inflate(R.layout.auditing_goods_shop_table_row_title_item, parent, false)
                )
            }
            COLUMNS_TITLE_ITEM_TYPE -> {
                return TitleViewHolder(
                    LayoutInflater.from(
                        parent?.context
                    ).inflate(R.layout.auditing_goods_shop_table_columns_title_item, parent, false)
                )
            }
            else -> {
                return ContentViewHolder(
                    LayoutInflater.from(
                        parent?.context
                    ).inflate(R.layout.auditing_goods_shop_table_item, parent, false)
                )
            }
        }
    }

    private class TitleViewHolder(view: View) : RecyclerView.ViewHolder(view) {
        val rlAuditingStoreItemRoot: RelativeLayout =
            view.findViewById(R.id.rl_auditing_store_item_root)
        val tvAuditingTitle: TextView = view.findViewById(R.id.tv_auditing_title)
    }

    private class ContentViewHolder(view: View) : RecyclerView.ViewHolder(view) {
        val llAuditingStoreItemRoot: LinearLayout =
            view.findViewById(R.id.ll_auditing_store_item_root)
        val tvAuditingContent: TextView = view.findViewById(R.id.tv_auditing_content)
    }


    fun setOrderTitleList(orderTitleList: MutableList<String>) {
        this.mOrderTitleList = orderTitleList
    }

    fun setOrderGoodsAuditStoreList(orderGoodsAuditStoreList: MutableList<OrderStoreList>) {
        //按订单数量倒序排序
//        Collections.sort(orderGoodsAuditStoreList,
//            Comparator<OrderStoreList> { lhs, rhs ->
//                if (lhs.auditOrderNum > rhs.auditOrderNum) {
//                    -1
//                } else if (lhs.auditOrderNum == rhs.auditOrderNum) {
//                    0
//                } else {
//                    1
//                }
//            })
        this.mOrderGoodsAuditStoreList = orderGoodsAuditStoreList
    }

    fun getOrderGoodsAuditStoreList(): MutableList<OrderStoreList> {
        return mOrderGoodsAuditStoreList
    }
}