package com.wgmf.yxgj.module.business.manageproduct.ui

import android.app.Activity
import android.content.Intent
import android.os.Bundle
import android.support.v4.content.ContextCompat
import android.support.v7.widget.LinearLayoutManager
import android.util.Log
import android.view.View
import android.widget.LinearLayout
import android.widget.TextView
import com.google.gson.Gson
import com.wgmf.library.base.ResultData
import com.wgmf.yxgj.base.BaseParentAct
import com.wgmf.yxgj.config.BusinessID
import com.wgmf.yxgj.dialog.LoadWaitDominator
import com.wgmf.yxgj.global.ConstantParams
import com.wgmf.yxgj.module.business.manageproduct.R
import com.wgmf.yxgj.module.business.manageproduct.model.OrderGoodsAuditOrderReviewEntity
import com.wgmf.yxgj.module.business.manageproduct.model.OrderGoodsAuditOrderReviewListEntity
import com.wgmf.yxgj.module.business.manageproduct.service.GoodsManagerService
import com.wgmf.yxgj.widgets.decoration.SpacesItemDecoration
import kotlinx.android.synthetic.main.activity_goods_auditing_status.*
import org.jetbrains.anko.find

/**
 * @author LW on 2021-9-23 0023.
 * 订货审核:（第二页） 选中门店后审核订单状态
 * @author LW
 */
class GoodsAuditingStatusActivity : BaseParentAct() {

    private val mBranchTitle by lazy { intent.getStringExtra("branchTitle") }

    private val mStoreNo by lazy { intent.getStringExtra("storeNo") }

    private val mInventoryAmount by lazy { intent.getDoubleExtra("inventoryAmount", 0.00) }

    private val mInventoryDays by lazy { intent.getIntExtra("inventoryDays", 0) }

    private val mIsFzsjd by lazy { intent.getBooleanExtra("isFzsjd", false) }

    private val mAuditFlag by lazy { intent.getStringExtra("auditFlag") }

    private val mOrderGoodsAuditAmount by lazy {
        intent.getDoubleExtra(
            "orderGoodsAuditAmount",
            0.00
        )
    }

    private val mSaleAmount by lazy { intent.getDoubleExtra("saleAmount", 0.00) }

    private var mReportSearchAllTxt: TextView? = null
    private var mReportSearchNoTxt: TextView? = null
    private var mReportSearchYesTxt: TextView? = null

    private lateinit var mLoadWait: LoadWaitDominator

    private var mReportSearchAll: LinearLayout? = null
    private var mReportSearchNo: LinearLayout? = null
    private var mReportSearchYes: LinearLayout? = null

    private var mOrderGoodsAuditOrderReviewEntity: MutableList<OrderGoodsAuditOrderReviewEntity> =
        mutableListOf()

    private var mGoodsAuditingStatusAdapter: GoodsAuditingStatusAdapter? = null

    private var mCurrentTabPosition = ConstantParams.CONSTANT_STARTS_0

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        setContentView(R.layout.activity_goods_auditing_status)
        initTitle()
        initView()
        setListener()
    }

    override fun initTitle() {
        super.initTitle()
        homeTitleText.text = mBranchTitle
        homeTitleBackLl.visibility = View.VISIBLE
    }

    private fun initView() {
        mLoadWait = LoadWaitDominator(this, fl_auditing_status_root)
        mReportSearchAllTxt = top_tab_ll_view.find<TextView>(R.id.tv_report_search_all_txt).apply {
            text = mContext.getString(R.string.goods_auditing_pending_review)
        }
        mReportSearchNoTxt = top_tab_ll_view.find<TextView>(R.id.tv_report_search_no_txt).apply {
            text = mContext.getString(R.string.goods_auditing_reviewed)
        }
        mReportSearchYesTxt = top_tab_ll_view.find<TextView>(R.id.tv_report_search_yes_txt).apply {
            text = mContext.getString(R.string.goods_auditing_abolished)
        }
        mReportSearchAll =
            top_tab_ll_view.find<LinearLayout>(R.id.ll_report_search_all).apply {
                setOnClickListener {
                    mCurrentTabPosition = ConstantParams.CONSTANT_STARTS_0
                    ll_auditing_batch_review.visibility = View.GONE
                    setSelectedItem()
                    queryFindOrderGoodsAuditData(ConstantParams.CONSTANT_PARAMS_1)

                }
            }
        mReportSearchNo =
            top_tab_ll_view.find<LinearLayout>(R.id.ll_report_search_no).apply {
                setOnClickListener {
                    mCurrentTabPosition = ConstantParams.CONSTANT_STARTS_1
                    ll_auditing_batch_review.visibility = View.GONE
                    setSelectedItem()
                    queryFindOrderGoodsAuditData(ConstantParams.CONSTANT_PARAMS_2)
                }
            }
        mReportSearchYes =
            top_tab_ll_view.find<LinearLayout>(R.id.ll_report_search_yes).apply {
                setOnClickListener {
                    mCurrentTabPosition = ConstantParams.CONSTANT_STARTS_2
                    ll_auditing_batch_review.visibility = View.GONE
                    setSelectedItem()
                    queryFindOrderGoodsAuditData(ConstantParams.CONSTANT_PARAMS_3)
                }
            }

        mGoodsAuditingStatusAdapter =
            GoodsAuditingStatusAdapter(mContext,
                mOrderGoodsAuditOrderReviewEntity,
                brandList,
                mInventoryAmount,
                mInventoryDays,
                object : GoodsAuditingStatusAdapter.OnAdapterItemClick {
                    override fun onItemDetailClick(
                        position: Int,
                        item: OrderGoodsAuditOrderReviewEntity?
                    ) {
                        jumpGoodsAuditingDetailsActivity(
                            GoodsAuditingDetailsActivity.JUMP_CHECK_DETAILS_TYPE,
                            item
                        )
                    }

                    override fun onItemAuditingClick(
                        position: Int,
                        item: OrderGoodsAuditOrderReviewEntity?
                    ) {
                        jumpGoodsAuditingDetailsActivity(
                            GoodsAuditingDetailsActivity.JUMP_TO_REVIEW_TYPE,
                            item
                        )
                    }
                })
        rv_auditing_status.apply {
            layoutManager = LinearLayoutManager(mContext)
            adapter = mGoodsAuditingStatusAdapter
            addItemDecoration(SpacesItemDecoration(20, adapter!!.itemCount))
        }

    }

    /**
     * 切换Tab状态
     * mAuditFlag:1表示已审核，2表示未审核,3表示未提交
     */
    private fun toggleTabStatus() {
        when (mAuditFlag) {
            ConstantParams.CONSTANT_PARAMS_1 -> {
                mReportSearchNo?.performClick()
            }
            ConstantParams.CONSTANT_PARAMS_2,
            ConstantParams.CONSTANT_PARAMS_3 -> {
                mReportSearchAll?.performClick()
            }
            else -> {
                setSelectedItem()
                mLoadWait.show(LoadWaitDominator.NO_DATA)
            }
        }
    }

    private fun setListener() {
        btn_auditing_batch_review.setOnClickListener {
            if (mOrderGoodsAuditOrderReviewEntity.size > 0) {
                jumpGoodsAuditingDetailsActivity(
                    GoodsAuditingDetailsActivity.JUMP_BATCH_APPROVAL_TYPE,
                    mOrderGoodsAuditOrderReviewEntity[0]
                )
            }
        }
    }

    override fun onResume() {
        super.onResume()
        toggleTabStatus()
    }

    /**
     * 请求获取订单审核数据
     * @param type String  类型
     */
    private fun queryFindOrderGoodsAuditData(type: String) {
        mLoadWait.show(LoadWaitDominator.LOADING)
        userInfo?.let {
            it.organization
            GoodsManagerService.getInstance()
                .requestFindOrderGoodsAudit(
                    type,
                    mStoreNo,
                    mIsFzsjd,
                    it.name,
                    it.level,
                    it.organizationId,
                    this
                )
        }
    }

    override fun onBusinessResultAtMainThread(result: ResultData?) {
        super.onBusinessResultAtMainThread(result)
        mLoadWait.dismissAll()
        result?.let {
            if (it.taskID == BusinessID.GoodsManager.MSG_ON_FIND_ORDERGOODS_AUDIT) {
                if (!isFinishing && it.isSuccessed) {
                    val entity = Gson().fromJson(
                        it.info,
                        OrderGoodsAuditOrderReviewListEntity::class.java
                    )
                    Log.d(TAG, "OrderGoodsAuditOrderReviewListEntity=$entity")
                    if (ConstantParams.CONSTANT_PARAMS_0 == entity.retCode) {
                        val list = entity.resultList
                        if (list.isNullOrEmpty()) {
                            mLoadWait.show(LoadWaitDominator.NO_DATA)
                        } else {
                            mOrderGoodsAuditOrderReviewEntity =
                                list.toMutableList().apply {
                                    mGoodsAuditingStatusAdapter?.refreshDataList(this)
                                }
                            if (mCurrentTabPosition == 0) {
                                ll_auditing_batch_review.visibility = View.VISIBLE
                            }
                        }

                    } else {
                        mLoadWait.show(entity.retInfo)
                    }
                } else {
                    mLoadWait.showNetError()
                }
            }
        }
    }

    private fun setSelectedItem() {
        mReportSearchAllTxt?.setTextColor(
            ContextCompat.getColor(
                mContext,
                R.color.tab_txt_color
            )
        )
        mReportSearchNoTxt?.setTextColor(
            ContextCompat.getColor(
                mContext,
                R.color.tab_txt_color
            )
        )
        mReportSearchYesTxt?.setTextColor(
            ContextCompat.getColor(
                mContext,
                R.color.tab_txt_color
            )
        )
        when (mCurrentTabPosition) {
            ConstantParams.CONSTANT_STARTS_0 -> {
                mReportSearchAllTxt?.setTextColor(
                    ContextCompat.getColor(
                        mContext,
                        R.color.normal_color
                    )
                )
                mReportSearchAllTxt?.paint?.isFakeBoldText = true
            }
            ConstantParams.CONSTANT_STARTS_1 -> {
                mReportSearchNoTxt?.setTextColor(
                    ContextCompat.getColor(
                        mContext,
                        R.color.normal_color
                    )
                )
                mReportSearchNoTxt?.paint?.isFakeBoldText = true
            }
            ConstantParams.CONSTANT_STARTS_2 -> {
                mReportSearchYesTxt?.setTextColor(
                    ContextCompat.getColor(
                        mContext,
                        R.color.normal_color
                    )
                )
                mReportSearchYesTxt?.paint?.isFakeBoldText = true
            }
        }
    }

    /**
     * 跳转到 GoodsAuditingDetailsActivity
     * @param type Int 类型
     * @param item OrderGoodsAuditOrderReviewEntity
     */
    private fun jumpGoodsAuditingDetailsActivity(
        type: Int,
        item: OrderGoodsAuditOrderReviewEntity?
    ) {
        val intent =
            Intent(this@GoodsAuditingStatusActivity, GoodsAuditingDetailsActivity::class.java)
        intent.putExtra("inventoryAmount", mInventoryAmount)
        intent.putExtra("inventoryDay", mInventoryDays)
        intent.putExtra("isFzsjd", mIsFzsjd)

        if (type == GoodsAuditingDetailsActivity.JUMP_BATCH_APPROVAL_TYPE) {
            intent.putExtra("orderGoodsAuditAmount", mOrderGoodsAuditAmount)
            intent.putExtra("saleAmount", mSaleAmount)
        } else {
            intent.putExtra("orderGoodsAuditAmount", item?.orderGoodsAuditAmount)
            intent.putExtra("saleAmount", item?.saleAmount)
        }
        intent.putExtra("branchTitle", mBranchTitle)
        intent.putExtra("storeNo", mStoreNo)
        intent.putExtra(
            "orderGoodsAuditEntity",
            item
        )
        intent.putExtra("orderStateType", type)
        startActivityForResult(
            intent,
            GoodsAuditingDetailsActivity.GOODS_AUDITING_DETAILS_REQUEST_CODE
        )
    }

    override fun onActivityResult(requestCode: Int, resultCode: Int, data: Intent?) {
        super.onActivityResult(requestCode, resultCode, data)
        if (resultCode == Activity.RESULT_OK) {
            if (GoodsAuditingDetailsActivity.GOODS_AUDITING_DETAILS_REQUEST_CODE == requestCode) {
                this@GoodsAuditingStatusActivity.finish()
            }
        }
    }
}