package com.wgmf.yxgj.module.business.manageproduct.ui

import android.content.Context
import android.support.v4.content.ContextCompat
import android.support.v7.widget.RecyclerView
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import android.widget.TextView
import com.google.gson.Gson
import com.wgmf.library.utils.StringUtil
import com.wgmf.yxgj.global.ApprovalStatus
import com.wgmf.yxgj.global.Brand
import com.wgmf.yxgj.model.BrandList
import com.wgmf.yxgj.module.business.manageproduct.R
import com.wgmf.yxgj.module.business.manageproduct.model.OrderGoodsAuditOrderReviewEntity
import org.jetbrains.anko.find

/**
 * @author LW on 2021-9-23 0023.
 * 订货审核适配器
 * @author LW
 */
class GoodsAuditingStatusAdapter(
    private val mContext: Context,
    private var mDataList: MutableList<OrderGoodsAuditOrderReviewEntity>? = mutableListOf(),
    private var mBrandList: List<BrandList>?,
    private var mInventoryAmount: Double,
    private var mInventoryDay: Int,
    private var mItemClick: OnAdapterItemClick?
) : RecyclerView.Adapter<GoodsAuditingStatusAdapter.GoodsAuditingStatusHolder>() {

    /**
     * 修改列表数据
     * @param newList MutableList
     */
    fun refreshDataList(newList: MutableList<OrderGoodsAuditOrderReviewEntity>?) {
        if (newList?.isNotEmpty() == true) {
            mDataList = newList
            notifyDataSetChanged()
        }
    }

    override fun onCreateViewHolder(
        parent: ViewGroup,
        viewType: Int
    ): GoodsAuditingStatusHolder {
        return GoodsAuditingStatusHolder(
            LayoutInflater.from(mContext)
                .inflate(R.layout.second_auditing_goods_item, parent, false)
        )
    }

    override fun onBindViewHolder(
        holder: GoodsAuditingStatusHolder,
        position: Int
    ) {
        val data = mDataList?.get(position)
        data?.let {
            holder.apply {
                tvAuditingStore.text = it.storeName
                tvAuditingInventoryAmount.text = StringUtil.formatString(
                    mContext.getString(R.string.goods_auditing_inventory_amount_value),
                    StringUtil.formatDouble(mInventoryAmount, "0.00")
                )
                tvAuditingInventoryDay.text = StringUtil.formatString(
                    mContext.getString(R.string.goods_auditing_inventory_day_value),
                    mInventoryDay
                )
                tvAuditingOrderAmount.text = StringUtil.formatString(
                    mContext.getString(R.string.goods_auditing_audit_amount_value),
                    StringUtil.formatDouble(it.orderGoodsAuditAmount, "0.00")
                )
                tvAuditingLastSales.text = StringUtil.formatString(
                    mContext.getString(R.string.goods_auditing_sale_amount_value),
                    StringUtil.formatDouble(it.saleAmount, "0.00")
                )
                tvAuditingFormDate.visibility = View.VISIBLE
                tvAuditingFormDate.text = StringUtil.formatString(
                    mContext.getString(R.string.goods_auditing_set_order_date_value),
                    it.setOrderDate
                )
                tvAuditingOrderNumber.visibility = View.VISIBLE
                tvAuditingOrderNumber.text = StringUtil.formatString(
                    mContext.getString(R.string.goods_auditing_order_bill_code_value),
                    it.orderGoodsBillCode
                )

                ////1正常订货  2加单
                tvAuditingAddOrderStatus.run {
                    if (it.orderstate == 2) {
                        visibility = View.VISIBLE
                        text = mContext.getString(R.string.goods_auditing_order)
                        background =
                            ContextCompat.getDrawable(
                                mContext,
                                R.drawable.shape_solid_e1eeff_round_3
                            )
                        setTextColor(ContextCompat.getColor(mContext, R.color.c_4d77ad))
                    } else {
                        visibility = View.GONE
                    }
                }

                tvAuditingStatus.visibility = View.VISIBLE
                when (it.orderBrandId) {
                    Brand.BRAND_WUGU_MOFENG -> tvAuditingStatus.text =
                        mContext.getString(R.string.goods_auditing_grind)
                    Brand.BRAND_FOOD_SUPPLEMENT -> tvAuditingStatus.text =
                        mContext.getString(R.string.goods_auditing_food_supplement)
                    else -> tvAuditingStatus.text =
                        mContext.getString(R.string.goods_auditing_unknown)
                }

                //订货审核单状态:1待审核 2待复核 3已作废"
                when (it.orderStateType) {
                    ApprovalStatus.PENDING_REVIEW -> {
                        tvAuditingJump.text = mContext.getString(R.string.goods_auditing_review)
                        tvDetailJump.text =
                            mContext.getString(R.string.goods_auditing_check_details)
                        tvAuditingCondition.text =
                            mContext.getString(R.string.goods_auditing_pending_review)

                        tvAuditingJump.visibility = if (data.submitFlag) View.VISIBLE else View.GONE
                    }
                    ApprovalStatus.REVIEWED -> {
                        tvDetailJump.text =
                            mContext.getString(R.string.goods_auditing_check_details)
                        tvAuditingCondition.text =
                            mContext.getString(R.string.goods_auditing_reviewed)
                        tvAuditingJump.visibility = View.GONE
                    }
                    ApprovalStatus.OBSOLETE_REVIEW -> {
                        tvDetailJump.text =
                            mContext.getString(R.string.goods_auditing_check_details)
                        tvAuditingCondition.text =
                            mContext.getString(R.string.goods_auditing_abolished)
                        tvAuditingJump.visibility = View.GONE
                    }
                }
                tvAuditingJump.setOnClickListener {
                    mItemClick?.onItemAuditingClick(position, data)
                }

                tvDetailJump.setOnClickListener {
                    mItemClick?.onItemDetailClick(position, data)
                }

                //判断当前用户的所属品牌，只能审核自己品牌的订货单
                if (Gson().toJson(mBrandList)?.contains(it.orderBrandId.toString()) == true) {
                    tvAuditingStatus.run {
                        background = ContextCompat.getDrawable(
                            mContext,
                            R.drawable.shape_solid_ffedd5_round_3
                        )
                        setTextColor(ContextCompat.getColor(mContext, R.color.c_d37d1a))
                    }

                } else {
                    tvAuditingStatus.background = ContextCompat.getDrawable(
                        mContext,
                        R.drawable.btn_gary_round_fill_nomal
                    )
                    if (ApprovalStatus.PENDING_REVIEW == it.orderStateType) {
                        tvAuditingJump.visibility = View.GONE
                    }
                }
            }
        }

    }

    override fun getItemCount(): Int = mDataList?.count() ?: 0

    interface OnAdapterItemClick {
        fun onItemDetailClick(position: Int, item: OrderGoodsAuditOrderReviewEntity?)

        fun onItemAuditingClick(position: Int, item: OrderGoodsAuditOrderReviewEntity?)
    }

    class GoodsAuditingStatusHolder(view: View) : RecyclerView.ViewHolder(view) {
        val tvAuditingStore: TextView = view.find(R.id.tv_auditing_store)
        val tvAuditingStatus: TextView = view.find(R.id.tv_auditing_status)
        val tvAuditingAddOrderStatus: TextView = view.find(R.id.tv_auditing_add_order_status)

        val tvAuditingInventoryAmount: TextView = view.find(R.id.tv_auditing_inventory_amount)
        val tvAuditingInventoryDay: TextView = view.find(R.id.tv_auditing_inventory_day)

        val tvAuditingOrderAmount: TextView = view.find(R.id.tv_auditing_order_amount)
        val tvAuditingLastSales: TextView = view.find(R.id.tv_auditing_last_sales)

        val tvAuditingFormDate: TextView = view.find(R.id.tv_auditing_form_date)
        val tvAuditingOrderNumber: TextView = view.find(R.id.tv_auditing_order_number)

        val tvAuditingCondition: TextView = view.find(R.id.tv_auditing_condition)
        val tvDetailJump: TextView = view.find(R.id.tv_detail_jump)
        val tvAuditingJump: TextView = view.find(R.id.tv_auditing_jump)
    }
}