package com.wgmf.yxgj.module.business.manageproduct.ui

import android.content.Intent
import android.os.Bundle
import android.support.design.widget.TabLayout
import android.support.v4.app.Fragment
import android.support.v4.content.ContextCompat
import android.support.v4.view.ViewPager
import android.text.TextUtils
import android.util.Log
import android.view.View
import android.widget.LinearLayout
import android.widget.TextView
import com.google.gson.Gson
import com.jakewharton.rxbinding.view.RxView
import com.wgmf.library.base.BaseResponse
import com.wgmf.library.base.ResultData
import com.wgmf.library.utils.AssetsUtil
import com.wgmf.library.utils.StringUtil
import com.wgmf.yxgj.base.BaseParentAct
import com.wgmf.yxgj.config.BusinessID
import com.wgmf.yxgj.dialog.LoadWaitDominator
import com.wgmf.yxgj.dialog.PublicConformTipDialog
import com.wgmf.yxgj.global.ConstantParams
import com.wgmf.yxgj.global.NetworkParams
import com.wgmf.yxgj.module.business.manageproduct.R
import com.wgmf.yxgj.module.business.manageproduct.model.StockGoodsCheckDetailsList
import com.wgmf.yxgj.module.business.manageproduct.model.StockGoodsCheckDetailsListEntity
import com.wgmf.yxgj.module.business.manageproduct.model.StockGoodsDetailsGroup
import com.wgmf.yxgj.module.business.manageproduct.service.GoodsManagerService
import com.wgmf.yxgj.module.business.manageproduct.ui.GoodsStockCheckTabLayoutListFragment.OnTestListener
import com.wgmf.yxgj.utils.isNotNullOrSize
import com.wgmf.yxgj.utils.notNullAndEmpty
import kotlinx.android.synthetic.main.activity_goods_auditing_shop.*
import kotlinx.android.synthetic.main.good_stock_check_detail_view.*
import org.jetbrains.anko.find
import java.io.Serializable
import java.util.concurrent.TimeUnit

class GoodsStockCheckDetailsActivity : BaseParentAct(), ViewPager.OnPageChangeListener,
    OnTestListener {
    private var mSubmitModifyTv: TextView? = null
    private var mSubmitConformTv: TextView? = null
    private var mPdAmountTv: TextView? = null
    private var mPdDiffNumTv: TextView? = null
    private var mSubmitLl: LinearLayout? = null

    private var mTablayout: TabLayout? = null
    private var mViewPager: ViewPager? = null

    private var mStockGoodsDetailsGroups = listOf<StockGoodsDetailsGroup>()

    /**
     * TabLayout中的tab标题
     */
    private var mTitles: MutableList<String> = mutableListOf()

    /**
     * 填充到ViewPager中的Fragment
     */
    private var mFragmentList: MutableList<Fragment> = mutableListOf()

    private lateinit var mLoadWait: LoadWaitDominator

    /**
     * 0，五谷磨房；1，食补集
     */
    private val mType = 0

    private val mPdId by lazy {
        intent.getIntExtra("pdId", 0)
    }

    /**
     * 盘点图片
     */
    private val mInventoryImages by lazy {
        intent.getStringExtra("inventoryImages")
    }

    private val mPdBillCode by lazy {
        intent.getStringExtra("pdBillCode")
    }

    /**
     * 盘点状态:OE
     */
    private val mPdState by lazy {
        intent.getStringExtra("pdState")
    }

    /**
     * 盘点状态
     */
    private val mCheckFlag by lazy {
        intent.getIntExtra("checkFlag", -1)
    }

    /**
     * 是否可以修改盘点按钮:1可修改/2不可修改
     */
    private val mIsOrNotUpdateFlag by lazy {
        intent.getStringExtra("isOrNotUpdateFlag")
    }

    /**
     * 是否可以修改盘点按钮提示
     */
    private val mIsOrNotUpdateDesc by lazy {
        intent.getStringExtra("isOrNotUpdateDesc")
    }

    /**
     * 查询的月份
     */
    private val mYearMonth by lazy {
        intent.getStringExtra("yearMonth")
    }

    /**
     * 门店名字
     */
    private val mStoreName by lazy {
        intent.getStringExtra("storeName")
    }

    /**
     * 门店编号
     */
    private val mStoreNo by lazy {
        intent.getStringExtra("storeNo")
    }

    /**
     * 选中的月份
     */
    private var mCheckoutYM: String? = null

    /**
     * 0，查询；1，可修改；2，正在编辑
     */
    private var mEditMode = 0

    private var mPdAmount: String? = null
    private var mPdDiffAmount: String? = null

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        setContentView(R.layout.good_stock_check_detail_view)
        initTitle()
        initData()
        initContent()
        findStockGoodsCheckDetail()
    }

    private fun getDataFromLocal() {
        val msg = AssetsUtil.getFromAssets(this, "GoodsCheckListVIewData.json")
        val mGoodsCheckListVIewData = Gson().fromJson(
            msg,
            StockGoodsCheckDetailsListEntity::class.java
        )
        Log.d(
            TAG,
            "GoodsCheckListVIewData=$mGoodsCheckListVIewData"
        )
        if (mGoodsCheckListVIewData.resultList?.isNotEmpty() == true) {
            setData(mGoodsCheckListVIewData)
        }
    }

    private fun findStockGoodsCheckDetail() {
        if (null != userInfo) {
            mLoadWait.show(LoadWaitDominator.LOADING)
            val url = NetworkParams.URL_FIND_STOCKGOODS_CHECK_DEATILS
            GoodsManagerService.getInstance().requestFindStockGoodsCheckDeatils(
                url,
                mPdId.toString() + "",
                this@GoodsStockCheckDetailsActivity
            )
        }
    }

    /**'
     * 反审存货盘点
     */
    private fun rejectStockGoodsCheck() {
        userInfo?.let {
            showDialog()
            val yearMonth = mYearMonth.substring(0, 4) + "-" + mYearMonth.substring(4, 6)
            GoodsManagerService.getInstance().requestRejectStockGoodsCheck(
                it.staffId, mStoreNo, yearMonth, mPdId, this@GoodsStockCheckDetailsActivity
            )
        }
    }

    override fun initTitle() {
        super.initTitle()
        homeTitleText.text = "门店盘点明细"
        homeTitleBackLl.visibility = View.VISIBLE
    }

    private fun initContent() {
        mLoadWait = LoadWaitDominator(this, ll_stock_check_root)

        find<LinearLayout>(R.id.title_more_ll).visibility = View.VISIBLE
        find<TextView>(R.id.report_detail_title).apply {
            visibility = View.VISIBLE
            val content = "$mStoreName|"
            text = content
        }
        find<TextView>(R.id.report_detail_date).apply {
            visibility = View.VISIBLE
            mCheckoutYM =
                "" + (mYearMonth!!.substring(0, 4) + "年" + mYearMonth!!.substring(4, 6)) + "月"
            text = mCheckoutYM
        }
        mSubmitLl = find(R.id.submit_ll)
        mSubmitModifyTv = find<TextView>(R.id.submit_modify_tv).apply {
            //3秒钟之内只取一个点击事件，防抖操作
            RxView.clicks(this).throttleFirst(3, TimeUnit.SECONDS).subscribe {
                if (ConstantParams.CONSTANT_STARTS_2 == mCheckFlag || ConstantParams.CONSTANT_STARTS_3 == mCheckFlag) {  //待审核、生效状态，反审处理
                    rejectStockGoodsCheck()
                } else {
                    checkMode()
                    //所有fragment刷新一遍
                    for (i in mStockGoodsDetailsGroups.indices) {
                        (mFragmentList[i] as GoodsStockCheckTabLayoutListFragment).refreash(
                            mEditMode
                        )
                    }
                }
            }
        }
        mSubmitConformTv = find<TextView>(R.id.submit_conform_tv).apply {
            text = "下一步"
            //5秒钟之内只取一个点击事件，防抖操作
            RxView.clicks(this).throttleFirst(5, TimeUnit.SECONDS)
                .subscribe { stockGoodsCheck() }

        }
        mPdAmountTv = find(R.id.pd_amount_tv)
        mPdDiffNumTv = find(R.id.pd_diff_num_tv)

        mTablayout = find(R.id.tab_layout)
        mViewPager = find(R.id.viewpager)
        mViewPager!!.offscreenPageLimit = 3
    }

    private fun initData() {
        mEditMode = checkMode(mIsOrNotUpdateFlag)
    }


    private fun setData(item: StockGoodsCheckDetailsListEntity) {
        //盘点数据
        mStockGoodsDetailsGroups = item.resultList ?: listOf()
        if (mStockGoodsDetailsGroups.isNotEmpty()) {
            //合计
            countTotal(mStockGoodsDetailsGroups)
            //初始化模式
            mEditMode = checkMode()
            if (mStockGoodsDetailsGroups.size >= 2) {
                mTablayout!!.visibility = View.VISIBLE
            }
            for (i in mStockGoodsDetailsGroups.indices) {
                if (StringUtil.isNullString(mStockGoodsDetailsGroups[i].proBrandName)) {
                    mTitles.add("其它")
                } else {
                    mTitles.add(mStockGoodsDetailsGroups[i].proBrandName)
                }

                mStockGoodsDetailsGroups[i].stockGoodsCheckDetailsList.forEach {
                    it.pdDiffAmountOld = it.pdDiffAmount
                    it.pdDiffNumOld = it.pdDiffNum
                }
                val bundle = Bundle()
                bundle.putInt("flag", i)
                bundle.putInt("editMode", mEditMode)
                bundle.putString("yearMonth", mYearMonth)
                val fragment = GoodsStockCheckTabLayoutListFragment()
                fragment.setAllData(mStockGoodsDetailsGroups)
                fragment.arguments = bundle
                mFragmentList.add(i, fragment)
            }
            // 对各种控件进行设置、适配、填充数据
            configViews()
        }
    }

    private fun configViews() {
        // 初始化ViewPager的适配器，并设置给它
        val mViewPagerAdapter = AddProductsTabLayoutViewPagerAdapter(
            supportFragmentManager,
            mTitles, mFragmentList
        )
        mViewPager?.adapter = mViewPagerAdapter
        // 设置ViewPager最大缓存的页面个数
        mViewPager?.offscreenPageLimit = 3
        // 给ViewPager添加页面动态监听器（为了让Toolbar中的Title可以变化相应的Tab的标题）
        mViewPager?.addOnPageChangeListener(this)
        mTablayout?.tabMode = TabLayout.MODE_SCROLLABLE
        // 设置TabLayout的指示器高度为0，即达到了隐藏Indicator的目的
        mTablayout?.setSelectedTabIndicatorHeight(0)
        mTablayout?.setBackgroundColor(resources.getColor(R.color.white))
        // 将TabLayout和ViewPager进行关联，让两者联动起来
        mTablayout?.setupWithViewPager(mViewPager)
        // 设置Tablayout的Tab显示ViewPager的适配器中的getPageTitle函数获取到的标题
        mTablayout?.setTabsFromPagerAdapter(mViewPagerAdapter)

    }

    override fun onPageSelected(position: Int) {
        mTablayout?.newTab()?.text = mTitles[position]
        (mFragmentList[position] as GoodsStockCheckTabLayoutListFragment).refreash(mEditMode)
    }

    override fun onPageScrolled(position: Int, positionOffset: Float, positionOffsetPixels: Int) {}

    override fun onPageScrollStateChanged(state: Int) {}

    /**
     * 选择模式转换
     */
    private fun checkMode(): Int {
        if (mEditMode == ConstantParams.CONSTANT_STARTS_0) {
            mSubmitLl?.visibility = View.VISIBLE
            mSubmitModifyTv?.visibility = View.VISIBLE
            if (ConstantParams.CONSTANT_STARTS_2 == mCheckFlag || ConstantParams.CONSTANT_STARTS_3 == mCheckFlag) {  //生效中
                mSubmitModifyTv?.text = mContext.getString(R.string.counter_examination_btn_txt)
            } else {
                mSubmitModifyTv?.setBackgroundColor(ContextCompat.getColor(this, R.color.bg_color))
                mSubmitModifyTv?.text = mContext.getString(R.string.not_modify_btn_txt)
                showTipDialog(mIsOrNotUpdateDesc)
            }
            mSubmitConformTv?.visibility = View.GONE
        } else if (mEditMode == ConstantParams.CONSTANT_STARTS_1) {
            mSubmitLl?.visibility = View.VISIBLE
            mSubmitModifyTv?.visibility = View.VISIBLE
            mSubmitModifyTv?.text = mContext.getString(R.string.modify_btn_txt)
            mEditMode = ConstantParams.CONSTANT_STARTS_2
            mSubmitConformTv!!.visibility = View.GONE
        } else if (mEditMode == ConstantParams.CONSTANT_STARTS_2) {
            mSubmitLl?.visibility = View.VISIBLE
            mSubmitModifyTv?.visibility = View.GONE
            mSubmitConformTv?.visibility = View.VISIBLE
            mEditMode = checkMode(mIsOrNotUpdateFlag)
        }

        return mEditMode
    }

    private fun showTipDialog(isOrNotUpdateDesc: String?) {
        if (isOrNotUpdateDesc.notNullAndEmpty()) {
            val builder = PublicConformTipDialog.Builder(this)
            builder.setMessage(isOrNotUpdateDesc)
            builder.setTitle("提示")
            builder.setNegativeButton(
                "知道了"
            ) { dialog, which -> dialog.dismiss() }
            builder.create().show()
        }
    }

    /**
     * 如果是已盘点状态，当月的盘点当月任意时间都可改,每月5日前可修改上月盘点，可以修改盘点数量
     *
     * @param isOrNotUpdateFlag 是否可以修改盘点按钮:1可修改/2不可修改
     * @return 返回编辑模式 0，查询；1，可修改；2，正在编辑
     */
    private fun checkMode(isOrNotUpdateFlag: String?): Int {
        if (mCheckFlag == ConstantParams.CONSTANT_STARTS_1) {  //未盘点
            return if (isOrNotUpdateFlag == ConstantParams.CONSTANT_PARAMS_1) {
                ConstantParams.CONSTANT_STARTS_1
            } else {
                ConstantParams.CONSTANT_STARTS_0
            }
        } else if (mCheckFlag == ConstantParams.CONSTANT_STARTS_2 || mCheckFlag == ConstantParams.CONSTANT_STARTS_3) {  //待审核,生效
            return ConstantParams.CONSTANT_STARTS_0
        } else {
            return ConstantParams.CONSTANT_STARTS_0
        }
    }

    /**
     * 组装盘点修改数据
     *
     * @param mStockGoodsCheckDetailsList 盘点修改数据
     */
    private fun stockGoodsCheck() {
        //数据转换
        val stockGoodsCheckDetailsList: MutableList<StockGoodsCheckDetailsList> = mutableListOf()
        if (mStockGoodsDetailsGroups.isNotEmpty()) {
            for (i in mStockGoodsDetailsGroups.indices) {
                stockGoodsCheckDetailsList.addAll(mStockGoodsDetailsGroups[i].stockGoodsCheckDetailsList)
            }
        }
        val mUpdateStockGoodsCheckDetailsList: MutableList<StockGoodsCheckDetailsList> =
            mutableListOf()
        for (i in stockGoodsCheckDetailsList.indices) {
            stockGoodsCheckDetailsList[i].yearMonth = mYearMonth
            if (!TextUtils.isEmpty(stockGoodsCheckDetailsList[i].pdAlterNum)) {
                stockGoodsCheckDetailsList[i].userNo = userInfo.staffId
                stockGoodsCheckDetailsList[i].pdStatus = mPdState
                mUpdateStockGoodsCheckDetailsList.add(stockGoodsCheckDetailsList[i])
            }
        }

        if (TextUtils.isEmpty(mStockGoodsDetailsGroups[0].pdUpdateReson)) {
            val builder = PublicConformTipDialog.Builder(this)
            builder.setLayoutId(R.layout.view_textview_dialog2)
            builder.setTitle("提示")
            builder.setMessage(R.string.stock_check_reason_tip)
            builder.setNegativeButton(
                "知道了"
            ) { dialog, _ ->
                dialog.dismiss()
            }
            builder.create().show()
            return
        }

        //将盘点数据传入下个盘点图片选择页面
        val intent = Intent(
            this@GoodsStockCheckDetailsActivity,
            GoodsStockCheckPicturesActivity::class.java
        )
        intent.putExtra("storeName", mStoreName)
        intent.putExtra("yearMonth", mCheckoutYM)
        intent.putExtra("mPdAmount", mPdAmount)
        intent.putExtra("mPdDiffAmount", mPdDiffAmount)
        intent.putExtra("pdState", mPdState)
        intent.putExtra("pdId", mPdId)
        intent.putExtra("pdBillCode", mPdBillCode)
        intent.putExtra("inventoryImages", mInventoryImages)
        intent.putExtra("stockGoodsDetailsGroups", mStockGoodsDetailsGroups as Serializable?)
        startActivity(intent)
    }

    override fun onBusinessResultAtMainThread(result: ResultData?) {
        super.onBusinessResultAtMainThread(result)
        dismissDialog()
        mLoadWait.dismissAll()
        result?.let {
            if (it.taskID == BusinessID.GoodsManager.MSG_ON_FIND_STOCKGOODS_CHECK_DEATILS) {
                if (!isFinishing && it.isSuccessed) {
                    val entity =
                        Gson().fromJson(it.info, StockGoodsCheckDetailsListEntity::class.java)
                    Log.d(TAG, "mStockGoodsCheckDetailsListEntity=$entity")
                    if (ConstantParams.CONSTANT_PARAMS_0 == entity.retCode) {
                        if (entity.resultList.isNotNullOrSize()) {
                            setData(entity)
                        } else {
                            mLoadWait.showNoData()
                        }
                    } else {
                        showMsg(entity.retInfo)
                    }
                } else {
                    mLoadWait.showNetError()
                }
            } else if (it.taskID == BusinessID.GoodsManager.MSG_ON_REJECT_STOCKGOODS_CHECK) {
                if (!isFinishing && it.isSuccessed) {
                    val entity = Gson().fromJson(it.info, BaseResponse::class.java)
                    Log.d(TAG, "BaseResponse=$entity")
                    if (ConstantParams.CONSTANT_PARAMS_0 == entity.msgCode) {
                        finish()
                    } else {
                        showMsg(entity.retInfo)
                    }
                } else {
                    showMsg(getString(R.string.request_data_fail))
                }
            }
        }
    }

    override fun showError(error: String?) {
        showMsg(error)
    }

    override fun countTotal(list: List<StockGoodsDetailsGroup>?) {
        list?.let {
            var pdAmount = 0.0
            var pdDiffAmount = 0.0
            for (i in it.indices) {
                for (j in it[i].stockGoodsCheckDetailsList.indices) {
                    pdAmount += it[i].stockGoodsCheckDetailsList[j].pdAmount
                    pdDiffAmount += it[i].stockGoodsCheckDetailsList[j].pdDiffAmount
                }
            }
            mPdAmount = "实盘金额：${StringUtil.formatDouble(pdAmount, "0.00")}"
            mPdDiffAmount = "差异金额：${StringUtil.formatDouble(pdDiffAmount, "0.00")}"
            mPdAmountTv?.text = mPdAmount
            mPdDiffNumTv?.text = mPdDiffAmount
        }
    }
}