package com.wgmf.yxgj.module.business.manageproduct.ui

import android.annotation.SuppressLint
import android.content.Context
import android.support.v7.widget.RecyclerView
import android.text.Editable
import android.text.TextWatcher
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import android.widget.EditText
import android.widget.TextView
import com.wgmf.library.utils.StringUtil
import com.wgmf.library.utils.ToastUtil
import com.wgmf.yxgj.module.business.manageproduct.R
import com.wgmf.yxgj.module.business.manageproduct.model.StockGoodsCheckDetailsList
import com.wgmf.yxgj.module.business.manageproduct.model.StockGoodsDetailsGroup
import org.jetbrains.anko.find

class GoodsStockCheckDetailsListAdapter(
    private val context: Context?,
    private var stockGoodsDetailsGroups: List<StockGoodsDetailsGroup>?,
    private val modifyNumClickListener: ModifyNumClickListener?,
    private val checkDate: String
) : RecyclerView.Adapter<RecyclerView.ViewHolder>() {
    /**
     * 0，查询；1，可修改；2，正在编辑
     */
    private var mMode = 0

    /**
     * 0:五谷磨房，1，食补集
     */
    private var mType = 0

    private var mStockGoodsCheckDetailsLists = mutableListOf<StockGoodsCheckDetailsList>()

    fun setAdapterData(list: List<StockGoodsDetailsGroup>, type: Int) {
        mType = type
        stockGoodsDetailsGroups = list
        if (list.isNotEmpty() && type < list.size) {
            mStockGoodsCheckDetailsLists = list[type].stockGoodsCheckDetailsList.toMutableList()
        }
    }

    fun setAdapterMode(mode: Int) {
        mMode = mode
    }

    interface ModifyNumClickListener {
        fun onModifyNumClickListener(list: List<StockGoodsDetailsGroup>?)

        fun onModifyNumClickListener(error: String?)
    }

    override fun getItemViewType(position: Int): Int {
        if (mStockGoodsCheckDetailsLists.size < 0) return super.getItemViewType(position)
        if (position == mStockGoodsCheckDetailsLists.size) {
            return -1
        } else {
            return super.getItemViewType(position)
        }
    }

    override fun onCreateViewHolder(
        parent: ViewGroup,
        viewType: Int
    ): RecyclerView.ViewHolder {
        if (viewType >= 0) {
            return GoodsStockCheckDetailsListHolder(
                LayoutInflater.from(context)
                    .inflate(R.layout.stock_goods_details_item2, parent, false)
            )
        } else {
            return GoodsStockCheckDetailsReasonHolder(
                LayoutInflater.from(context)
                    .inflate(R.layout.list_item_input_reason, parent, false)
            )
        }
    }

    override fun getItemCount(): Int {
        if (mStockGoodsCheckDetailsLists.size > 0) {
            return mStockGoodsCheckDetailsLists.size + 1
        }
        return mStockGoodsCheckDetailsLists.size
    }

    override fun onBindViewHolder(
        holder: RecyclerView.ViewHolder,
        @SuppressLint("RecyclerView") pos: Int
    ) {
        if (holder is GoodsStockCheckDetailsListHolder) {
            val item = mStockGoodsCheckDetailsLists[pos]
            holder.apply {
                etGoodsUpdateCount.addTextChangedListener(object : TextWatcher {
                    override fun beforeTextChanged(
                        s: CharSequence?,
                        start: Int,
                        count: Int,
                        after: Int
                    ) {
                    }

                    override fun onTextChanged(
                        s: CharSequence,
                        start: Int,
                        before: Int,
                        count: Int
                    ) {
                    }

                    override fun afterTextChanged(s: Editable?) {
                        var pdkc = 0.0
                        val stockGoodsCheckDetails =
                            mStockGoodsCheckDetailsLists[adapterPosition]

                        try {
                            if (s.toString().isNotEmpty()) {
                                pdkc = s.toString().toDouble()
                                if (pdkc >= 0.0) {
                                    //盘点数量应大于或等于零
                                    stockGoodsCheckDetails.pdAlterNum =
                                        StringUtil.formatDouble(
                                            pdkc, "0.0"
                                        )
                                    updateDiffData(pdkc, adapterPosition)
                                    modifyNumClickListener?.onModifyNumClickListener(
                                        stockGoodsDetailsGroups
                                    )
                                    return
                                }
                            }
                        } catch (e: Exception) {
                            e.printStackTrace()
                        }

                        stockGoodsCheckDetails.pdAlterNum = ""
                        rollbackDiffData(adapterPosition)
                        modifyNumClickListener?.onModifyNumClickListener(
                            stockGoodsDetailsGroups
                        )
                    }
                })
                etGoodsUpdateCount.setOnClickListener {
                    val isEditable = isEditableProduct(item.proCode)
                    if (mMode == 1&&isEditable) {
                        ToastUtil.show(context, R.string.goods_auditing_product_not_check_tip)
                    }
                }

                tvGoodsName.text = item.proName
                tvGoodsUnit.text = String.format("%s(%s)", item.proUnit, item.proCode)
                tvGoodsUnitPrice.text = String.format("单价:%s", item.proPrice)

                tvGoodsPdNum.text = item.pdNum.toString()
                tvGoodsPdAmount.text = StringUtil.formatDouble(item.pdAmount, "0.00")

                val isEditable = isEditableProduct(item.proCode)
                if (mMode == 1 && !isEditable) {
                    etGoodsUpdateCount.apply {
                        isFocusable = true
                        isFocusableInTouchMode = true
                        isCursorVisible = true
                    }
                } else {
                    etGoodsUpdateCount.apply {
                        isFocusable = false
                        isFocusableInTouchMode = false
                        isCursorVisible = false
                    }
                }

                val pdAlterNum = mStockGoodsCheckDetailsLists[pos].pdAlterNum
                val modNum: String =
                    if (pdAlterNum == null || pdAlterNum == "null" || pdAlterNum == "-1") {
                        ""
                    } else {
                        pdAlterNum + ""
                    }
                etGoodsUpdateCount.setText(modNum)
            }
        } else if (holder is GoodsStockCheckDetailsReasonHolder) {
            holder.apply {
                tvStockCheckReason.text = context?.getString(R.string.stock_check_reason)
                etStockCheckTips.setHint(R.string.stock_check_reason_tip)
                if (mMode == 1) {
                    etStockCheckTips.isFocusable = true
                    etStockCheckTips.isFocusableInTouchMode = true
                    etStockCheckTips.isCursorVisible = true
                } else {
                    etStockCheckTips.isFocusable = false
                    etStockCheckTips.isFocusableInTouchMode = false
                    etStockCheckTips.isCursorVisible = false
                }
                etStockCheckTips.setText(stockGoodsDetailsGroups?.get(mType)?.pdUpdateReson)
                etStockCheckTips.addTextChangedListener(object : TextWatcher {
                    override fun beforeTextChanged(
                        s: CharSequence?,
                        start: Int,
                        count: Int,
                        after: Int
                    ) {
                    }

                    override fun onTextChanged(
                        s: CharSequence?,
                        start: Int,
                        before: Int,
                        count: Int
                    ) {
                    }

                    override fun afterTextChanged(s: Editable?) {
                        val reson = s.toString()
                        stockGoodsDetailsGroups?.forEach {
                            it.pdUpdateReson = reson
                        }
                    }
                });
            }
        }
    }

    /**
     * 刷新修改差异数据
     * @param pdkc
     * @param position
     */
    private fun updateDiffData(
        pdkc: Double,
        position: Int
    ) {
        val stockGoodsCheckDetailsList = mStockGoodsCheckDetailsLists[position]

        stockGoodsCheckDetailsList.yearMonth = checkDate
        stockGoodsCheckDetailsList.pdDiffNum =
            pdkc - stockGoodsCheckDetailsList.stockNum
        //mStockGoodsCheckDetailsLists[position].pdAmount =
        //    pdkc * mStockGoodsCheckDetailsLists[position].proPrice
        stockGoodsCheckDetailsList.pdDiffAmount =
            (pdkc - stockGoodsCheckDetailsList.stockNum) * stockGoodsCheckDetailsList.proPrice

        //viewHolder.tvGoodsPdAmount.text = StringUtil.formatDouble(
        //    stockGoodsCheckDetailsList.pdAmount, "0.00"
        //)
    }

    /**
     * 一下产品不可编辑
     */
    private fun isEditableProduct(proCode: String): Boolean {
        return ("2.20211" == proCode || "2.20212" == proCode ||
                "2.20214" == proCode || "2.20215" == proCode || "2.20216" == proCode)
    }

    /**
     * 回滚差异数据
     * @param position
     */
    private fun rollbackDiffData(
        position: Int
    ) {
        val stockGoodsCheckDetailsList = mStockGoodsCheckDetailsLists[position]

        stockGoodsCheckDetailsList.yearMonth = checkDate
        stockGoodsCheckDetailsList.pdDiffNum = stockGoodsCheckDetailsList.pdDiffNumOld
        stockGoodsCheckDetailsList.pdDiffAmount = stockGoodsCheckDetailsList.pdDiffAmountOld
    }

    class GoodsStockCheckDetailsReasonHolder(view: View) : RecyclerView.ViewHolder(view) {
        val tvStockCheckReason =
            view.find<TextView>(R.id.tv_stock_check_reason)

        val etStockCheckTips =
            view.find<EditText>(R.id.et_stock_check_tips)
    }

    class GoodsStockCheckDetailsListHolder(view: View) : RecyclerView.ViewHolder(view) {
        //产品名字
        val tvGoodsName =
            view.find<TextView>(R.id.tv_goods_name)

        //产品编号
        val tvGoodsUnit = view.find<TextView>(R.id.tv_goods_unit)

        //产品价格
        val tvGoodsUnitPrice = view.find<TextView>(R.id.tv_goods_unit_price)

        //实盘库存
        val tvGoodsPdNum = view.find<TextView>(R.id.tv_goods_pd_num)

        //实盘金额
        val tvGoodsPdAmount = view.find<TextView>(R.id.tv_goods_pd_amount)

        //修改后数量
        val etGoodsUpdateCount = view.find<EditText>(R.id.et_goods_update_count)

    }
}
