package com.wgmf.yxgj.module.business.manageproduct.ui;

import android.content.Context;
import android.content.DialogInterface;
import android.graphics.Color;
import android.text.Editable;
import android.text.TextUtils;
import android.text.TextWatcher;
import android.view.LayoutInflater;
import android.view.View;
import android.view.View.OnClickListener;
import android.view.ViewGroup;
import android.widget.BaseAdapter;
import android.widget.ImageButton;
import android.widget.LinearLayout;
import android.widget.TextView;

import com.wgmf.library.utils.Arith;
import com.wgmf.library.utils.DateUtil;
import com.wgmf.library.utils.StringUtil;
import com.wgmf.yxgj.base.BaseActivity;
import com.wgmf.yxgj.dialog.PublicConformTipDialog;
import com.wgmf.yxgj.model.OrderGoodsAuditDetail;
import com.wgmf.yxgj.module.business.manageproduct.R;
import com.wgmf.yxgj.utils.MyToast;
import com.wgmf.yxgj.utils.helper.DialogHelper;
import com.wgmf.yxgj.widgets.EditText.EditTextDecimal;

import java.text.SimpleDateFormat;
import java.util.Collections;
import java.util.Comparator;
import java.util.Date;
import java.util.List;

import xp.timepicker.com.widget.DatePickDialog;
import xp.timepicker.com.widget.OnSureLisener;
import xp.timepicker.com.widget.bean.DateType;

/**
 * 货品调入调出添加产品
 */
@SuppressWarnings("all")
class GoodsTransferredInOrOutAdapter extends BaseAdapter {
    private List<OrderGoodsAuditDetail> mList;
    private OnListDataUpdateListener mOnListDataUpdateListener;
    private Context mContext;
    private boolean dialogIsShowing = false;
    private boolean mIsUpdate = false;


    GoodsTransferredInOrOutAdapter(List<OrderGoodsAuditDetail> list, boolean isUpdate, Context context) {
        this.mContext = context;
        this.mList = list;
        this.mIsUpdate = isUpdate;
        initList();
    }

    public void setNewData(List<OrderGoodsAuditDetail> list) {
        this.mList = list;
        initList();
        notifyDataSetChanged();
    }

    public void setOnListDataUpdateListener(OnListDataUpdateListener listener) {
        this.mOnListDataUpdateListener = listener;
    }

    interface OnListDataUpdateListener {
        void onUpdate(OrderGoodsAuditDetail update);
    }

    /**
     * 按选择后添加顺序排列
     */
    private void initList() {
        Collections.sort(mList, new Comparator<OrderGoodsAuditDetail>() {
            @Override
            public int compare(OrderGoodsAuditDetail lhs,
                               OrderGoodsAuditDetail rhs) {
                if (lhs.getCreateTime() < rhs.getCreateTime()) {
                    return 1;
                } else if (lhs.getCreateTime() == rhs.getCreateTime()) {
                    return 0;
                } else {
                    return -1;
                }
            }
        });
    }

    @Override
    public int getCount() {
        return mList == null ? 0 : mList.size();
    }

    @Override
    public Object getItem(int position) {
        return mList == null ? null : mList.get(position);
    }

    @Override
    public long getItemId(int position) {
        return position;
    }

    @Override
    public View getView(final int position, View convertView, ViewGroup parent) {
        final OrderGoodsAuditDetail data = mList.get(position);
        final ViewHolder holder;
        convertView = null;
        if (null == convertView) {
            convertView = LayoutInflater.from(mContext).inflate(R.layout.goods_transferred_in_or_out_item, null);
            holder = new ViewHolder(convertView);
            String unit = "";
            if ("".equals(data.getProductUnit()) || null == data.getProductUnit() || "null".equals(data.getProductUnit())) {
                unit = "(" + "包" + ")";
            } else {
                unit = "(" + data.getProductUnit() + " " + data.getProductCode() + ")";
            }
            holder.name.setText(data.getProductName() + unit);
            holder.price.setText("￥" + data.getProductPrice() + "");
            if ("否".equals(data.getProIsDecimal())) {
                holder.count.setDecimal(0);
            } else {
                holder.count.setDecimal(2);
            }
            holder.count.setLongClickable(false);
            String format = getFormatByDecimal(data.getProIsDecimal());
            holder.count.setText("" + StringUtil.formatDouble(data.getOrderGoodsAuditNum(), format));

            if (holder.count.getText().length() == 0) {
                holder.reduce.setEnabled(false);
            } else {
                holder.reduce.setEnabled(true);
            }
            if (data.getMaxSuggestOrderGoodsNum() > 0
                    && Double.valueOf(holder.count.getText().toString()) >= data.getMaxSuggestOrderGoodsNum()) {
                holder.add.setEnabled(false);
            } else {
                holder.add.setEnabled(true);
            }
            if (data.getProductCode().startsWith("2")) {
                holder.productionDateLl.setVisibility(View.VISIBLE);
                holder.productionDateTv.setText(data.getProduceDate());
                holder.productionDateTv.setOnClickListener(new OnClickListener() {
                    @Override
                    public void onClick(View v) {
                        DatePickDialog dialog = DialogHelper.showDatePickDialog(
                                (BaseActivity) mContext, DateType.TYPE_YMD);
                        dialog.setEndDate(new Date());
                        dialog.setOnSureLisener(new OnSureLisener() {
                            @Override
                            public void onSure(Date date) {
                                int betweenTime = DateUtil.daysBetween(date);
                                if (betweenTime < 0) {
                                    MyToast.show("日期只能选择当天或之前，请重新选择");
                                } else {
                                    refreshProductionDate(date);
                                }
                            }
                        });
                        dialog.show();
                    }

                    private void refreshProductionDate(final Date date) {
                        String messge = "";
                        try {
                            messge = DateUtil.format(date, DateType.TYPE_YMD.getFormat());
                        } catch (Exception e) {
                            e.printStackTrace();
                        }
                        data.setProduceDate(messge);
                        holder.productionDateTv.setText(messge);

                        if (mOnListDataUpdateListener != null) {
                            mOnListDataUpdateListener.onUpdate(data);
                        }
                    }
                });
            } else {
                holder.productionDateLl.setVisibility(View.GONE);
            }

            holder.add.setOnClickListener(new OnClickListener() {

                @Override
                public void onClick(View v) {
                    final OrderGoodsAuditDetail cell = mList.get(position);
                    double pDHPack = 1;
                    double d = Arith.add(cell.getOrderGoodsAuditNum(), pDHPack);
                    cell.setOrderGoodsAuditNum(d);
                    String format = getFormatByDecimal(cell.getProIsDecimal());
                    holder.count.setText(StringUtil.formatDouble(d, format));
                    if (d < 0) {
                        PublicConformTipDialog.Builder builder = new PublicConformTipDialog.Builder(mContext);
                        builder.setTitle("提示");
                        builder.setMessage("请检查产品：" + data.getProductName()
                                + ",必须输入有效的数字!");
                        builder.setNegativeButton("知道了并重新输入", new DialogInterface.OnClickListener() {
                            @Override
                            public void onClick(DialogInterface dialog, int which) {
                                dialog.dismiss();
                                dialogIsShowing = false;
                            }
                        });
                        if (!dialogIsShowing) {
                            builder.create().show();
                            dialogIsShowing = true;
                        }
                        cell.setInvalid(true);
                        holder.count.setTextColor(Color.RED);
                        holder.add.setEnabled(false);
                    } else {
                        cell.setInvalid(false);
                        holder.count.setTextColor(Color.BLACK);
                    }
                    if (d > 0) {
                        holder.reduce.setEnabled(true);
                    }

                }
            });
            holder.reduce.setOnClickListener(new OnClickListener() {

                @Override
                public void onClick(View v) {
                    OrderGoodsAuditDetail cell = mList.get(position);
                    double pDHPack = 1;
                    double d = Arith.sub(cell.getOrderGoodsAuditNum(), pDHPack);
                    cell.setOrderGoodsAuditNum(d);
                    String format = getFormatByDecimal(cell.getProIsDecimal());
                    holder.count.setText(StringUtil.formatDouble(d, format));
                    if (d <= 0) {
                        holder.reduce.setEnabled(false);
                    }
                    if (d < 0
                            || (cell.getMaxSuggestOrderGoodsNum() > 0 && d > cell
                            .getMaxSuggestOrderGoodsNum())) {

                        cell.setInvalid(true);
                        holder.count.setTextColor(Color.RED);
                    } else {
                        cell.setInvalid(false);
                        holder.add.setEnabled(true);
                        holder.count.setTextColor(Color.BLACK);
                    }
                }
            });
            holder.count.addTextChangedListener(new TextWatcher() {
                @Override
                public void beforeTextChanged(CharSequence s, int start, int count, int after) {

                }

                @Override
                public void onTextChanged(CharSequence s, int start, int before, int count) {

                }

                @Override
                public void afterTextChanged(Editable s) {
                    if (null != mList && mList.size() > position) {
                        OrderGoodsAuditDetail cell = mList.get(position);
                        String input = s.toString();
                        double d;
                        try {
                            d = Double.parseDouble(input);
                        } catch (NumberFormatException e) {
                            d = 0;
                        }
                        cell.setOrderGoodsAuditNum(d);
                        String temp = "";
                        if (d < 0) {
                            temp = "请检查产品：" + data.getProductName()
                                    + ",必须输入有效的数字！";
                            holder.reduce.setEnabled(false);
                        }
                        if (!TextUtils.isEmpty(temp)) {
                            PublicConformTipDialog.Builder builder = new PublicConformTipDialog.Builder(mContext);
                            builder.setTitle("提示");
                            builder.setMessage(temp);
                            builder.setNegativeButton("知道了并重新输入", new DialogInterface.OnClickListener() {
                                @Override
                                public void onClick(DialogInterface dialog, int which) {
                                    dialog.dismiss();
                                    dialogIsShowing = false;
                                }
                            });
                            if (!dialogIsShowing) {
                                builder.create().show();
                                dialogIsShowing = true;
                            }
                            cell.setInvalid(true);
                            holder.count.setTextColor(Color.RED);
                        } else {
                            cell.setInvalid(false);
                            holder.add.setEnabled(true);
                            holder.reduce.setEnabled(true);
                            holder.count.setTextColor(Color.BLACK);
                        }
                    }
                }
            });
            convertView.setTag(holder);
        } else {
            holder = (ViewHolder) convertView.getTag();
        }
        holder.count.setTag(position);

        return convertView;
    }

    private String getFormatByDecimal(String proIsDecimal) {
        if ("否".equals(proIsDecimal)) {
            return "0";
        } else {
            return "0.00";
        }
    }

    class ViewHolder {
        TextView name;
        TextView unit;
        TextView price;
        LinearLayout productionDateLl;
        TextView productionDateTv;
        EditTextDecimal count;
        ImageButton add;
        ImageButton reduce;
        LinearLayout llShowDetail;

        ViewHolder(View convertView) {
            name = (TextView) convertView.findViewById(R.id.goods_name);
            unit = (TextView) convertView.findViewById(R.id.goods_unit);
            price = (TextView) convertView.findViewById(R.id.goods_price);
            productionDateLl = (LinearLayout) convertView.findViewById(R.id.production_date_ll);
            productionDateTv = (TextView) convertView.findViewById(R.id.production_date_tv);
            llShowDetail = (LinearLayout) convertView.findViewById(R.id.ll_show_detail);
            count = (EditTextDecimal) convertView.findViewById(R.id.et_check_goods_count);
            add = (ImageButton) convertView.findViewById(R.id.goods_plus);
            reduce = (ImageButton) convertView.findViewById(R.id.goods_decrease);
        }
    }
}