package com.wgmf.yxgj.module.business.manageproduct.ui;

import android.content.Context;
import android.text.TextUtils;
import android.view.LayoutInflater;
import android.view.View;
import android.view.View.OnClickListener;
import android.view.ViewGroup;
import android.widget.BaseExpandableListAdapter;
import android.widget.LinearLayout;
import android.widget.TextView;

import com.wgmf.library.utils.DateUtil;
import com.wgmf.library.utils.StringUtil;
import com.wgmf.yxgj.global.ConstantParams;
import com.wgmf.yxgj.module.business.manageproduct.R;
import com.wgmf.yxgj.module.business.manageproduct.model.ProductTransferredInAndOutNumLists;
import com.wgmf.yxgj.module.business.manageproduct.model.ProductTransferredInAndOutNumListEntity;

import java.util.Date;
import java.util.List;

/**
 * 货品调入调出查询明细
 */
class GoodsTransferredInOrOutDetailsAdapter extends BaseExpandableListAdapter {
    private final Context mContext;
    private List<ProductTransferredInAndOutNumLists> mList;
    private OnStatusClickListener mStatusClickListener;

    GoodsTransferredInOrOutDetailsAdapter(Context context, List<ProductTransferredInAndOutNumLists> list) {
        this.mContext = context;
        this.mList = list;
    }

    public void setNewList(List<ProductTransferredInAndOutNumLists> list) {
        this.mList = list;
        notifyDataSetChanged();
    }

    public void setOnStatusClickListener(OnStatusClickListener statusClickListener) {
        this.mStatusClickListener = statusClickListener;
    }

    @Override
    public int getGroupCount() {
        return mList == null ? 0 : mList.size();
    }

    @Override
    public int getChildrenCount(int groupPosition) {
        return mList.get(groupPosition).getProductTransferredInAndOutNumList() == null ? 0 : mList.get(groupPosition).getProductTransferredInAndOutNumList().size();
    }

    @Override
    public Object getGroup(int groupPosition) {
        return groupPosition;
    }

    @Override
    public Object getChild(int groupPosition, int childPosition) {
        return childPosition;
    }

    @Override
    public long getGroupId(int groupPosition) {
        return groupPosition;
    }

    @Override
    public long getChildId(int groupPosition, int childPosition) {
        return childPosition;
    }

    @Override
    public boolean hasStableIds() {
        return false;
    }

    @Override
    public View getGroupView(int groupPosition, boolean isExpanded, View convertView, ViewGroup parent) {
        final GroupViewHolder groupViewHolder;
        if (convertView == null) {
            convertView = LayoutInflater.from(mContext).inflate(R.layout.list_item_goods_transferred_inorout_details_view1, null);
            groupViewHolder = new GroupViewHolder();
            groupViewHolder.transferDateTv = convertView.findViewById(R.id.transfer_date_tv);
            groupViewHolder.transfereeopleTv = convertView.findViewById(R.id.transfer_people_tv);
            groupViewHolder.storeInTv = convertView.findViewById(R.id.transfer_in_shop_name_tv);
            groupViewHolder.storeOutTv = convertView.findViewById(R.id.transfer_out_shop_name_tv);
            groupViewHolder.transferDistanceTv = convertView.findViewById(R.id.transfer_distance_tv);
            groupViewHolder.reasonTv = convertView.findViewById(R.id.transfer_reason_tv);
            convertView.setTag(groupViewHolder);
        } else {
            groupViewHolder = (GroupViewHolder) convertView.getTag();
        }
        ProductTransferredInAndOutNumLists ent = mList.get(groupPosition);
        groupViewHolder.transferDateTv.setText(ent.getTransferredInAndOutDate());
        groupViewHolder.transfereeopleTv.setText(ent.getTransferredPerson());
        groupViewHolder.storeInTv.setText(ent.getTransferredInStoreName());
        groupViewHolder.storeOutTv.setText(ent.getTransferredOutStoreName());
        if (TextUtils.isEmpty(ent.getDbReason())) {
            groupViewHolder.reasonTv.setVisibility(View.GONE);
        } else {
            groupViewHolder.reasonTv.setVisibility(View.VISIBLE);
            groupViewHolder.reasonTv.setText(StringUtil.formatString(mContext.getString(R.string.transfer_goods_cause),
                    ent.getDbReason()));
        }
        if (ent.getDistance().isEmpty()) {
            groupViewHolder.transferDistanceTv.setVisibility(View.GONE);
        } else {
            groupViewHolder.transferDistanceTv.setVisibility(View.VISIBLE);
            groupViewHolder.transferDistanceTv.setText(StringUtil.formatString(
                    parent.getContext().getString(R.string.transfer_goods_store_distance),
                    ent.getDistance()
            ));
        }
        return convertView;
    }

    @Override
    public View getChildView(int groupPosition, int childPosition, boolean isLastChild, View convertView, ViewGroup parent) {
        final ChildViewHolder childViewHolder;
        if (convertView == null) {
            convertView = LayoutInflater.from(mContext).inflate(R.layout.list_item_goods_transferred_inorout_details_view2, null);
            childViewHolder = new ChildViewHolder();
            childViewHolder.transferProTv = convertView.findViewById(R.id.transfer_pro_tv);
            childViewHolder.transferProNumTv = convertView.findViewById(R.id.transfer_pro_num_tv);
            childViewHolder.transferProductionDateLl = convertView.findViewById(R.id.transfer_production_date_ll);
            childViewHolder.transferProductionDateTv = convertView.findViewById(R.id.transfer_production_date_tv);
            childViewHolder.transferReceiverLl = convertView.findViewById(R.id.transfer_receiver_ll);
            childViewHolder.transferReceiverTv = convertView.findViewById(R.id.transfer_receiver_tv);
            childViewHolder.transferDeliveryDateTv = convertView.findViewById(R.id.transfer_delivery_date_tv);
            childViewHolder.transferStatusLl = convertView.findViewById(R.id.transfer_status_ll);
            childViewHolder.transferStatusTv = convertView.findViewById(R.id.transfer_status_tv);
            childViewHolder.transferVoidTv = convertView.findViewById(R.id.transfer_void_tv);
            childViewHolder.transferRetrieveTv = convertView.findViewById(R.id.transfer_retrieve_tv);
            childViewHolder.transferEditTv = convertView.findViewById(R.id.transfer_edit_tv);
            convertView.setTag(childViewHolder);
        } else {
            childViewHolder = (ChildViewHolder) convertView.getTag();
        }

        Context context = parent.getContext();
        final ProductTransferredInAndOutNumLists productTransferredInAndOutNum = mList.get(groupPosition);
        final ProductTransferredInAndOutNumListEntity ent = productTransferredInAndOutNum.getProductTransferredInAndOutNumList().get(childPosition);

        childViewHolder.transferProTv.setText(StringUtil.formatString(
                context.getString(R.string.transfer_goods_product_name_unit), ent.getFixedProduct().getProductName(), ent.getFixedProduct().getProductCode()));
        childViewHolder.transferProNumTv.setText(String.valueOf(ent.getTransferredInAndOutNum()));

        if (ent.getProduceDate() != null && !TextUtils.isEmpty(ent.getProduceDate())) {
            childViewHolder.transferProductionDateLl.setVisibility(View.VISIBLE);
            childViewHolder.transferProductionDateTv.setText(ent.getProduceDate());
        } else {
            childViewHolder.transferProductionDateLl.setVisibility(View.GONE);
        }

        if (isLastChild) {
            if (ent.getIsSh() == ConstantParams.CONSTANT_STARTS_0) { //未收货
                childViewHolder.transferStatusLl.setVisibility(View.VISIBLE);
                childViewHolder.transferStatusTv.setText(context.getString(R.string.transfer_goods_status_not_received));
                //超过调拨单时间+1天后，"取回"按钮呈现灰色不可点击
                childViewHolder.transferRetrieveTv.setVisibility(View.VISIBLE);
                Date sdate = DateUtil.getSpecifiedDay(DateUtil.string2Date(productTransferredInAndOutNum.getTransferredInAndOutDate(),
                        DateUtil.FORMATDEFAULT),1);
                int betweenTime = DateUtil.daysBetween(sdate);
                if (betweenTime > 0) {
                    childViewHolder.transferRetrieveTv.setEnabled(false);
                }else{
                    childViewHolder.transferRetrieveTv.setEnabled(true);
                }
                childViewHolder.transferEditTv.setVisibility(View.GONE);
            } else if (ent.getIsSh() == ConstantParams.CONSTANT_STARTS_1) {  //已收货
                childViewHolder.transferReceiverLl.setVisibility(View.VISIBLE);
                childViewHolder.transferReceiverTv.setText(StringUtil.formatString(
                        context.getString(R.string.transfer_goods_receiver), StringUtil.convertDefaultValue(ent.getShUserName())));
                childViewHolder.transferDeliveryDateTv.setText(StringUtil.formatString(
                        context.getString(R.string.transfer_goods_delivery_date), StringUtil.convertDefaultValue(ent.getShDate())));
                childViewHolder.transferStatusLl.setVisibility(View.GONE);
            } else if (ent.getIsSh() == ConstantParams.CONSTANT_STARTS_2) {  //已拒收
                childViewHolder.transferStatusLl.setVisibility(View.GONE);
            } else if (ent.getIsSh() == ConstantParams.CONSTANT_STARTS_3) {  //已取回
                childViewHolder.transferStatusLl.setVisibility(View.VISIBLE);
                childViewHolder.transferStatusTv.setText(context.getString(R.string.transrer_goods_status_retrieved));
                childViewHolder.transferRetrieveTv.setVisibility(View.GONE);
                childViewHolder.transferEditTv.setVisibility(View.VISIBLE);
            }

            //取回操作
            childViewHolder.transferRetrieveTv.setOnClickListener(new OnClickListener() {
                @Override
                public void onClick(View v) {
                    if (mStatusClickListener != null) {
                        mStatusClickListener.onStatusClick(ConstantParams.CONSTANT_STARTS_3, productTransferredInAndOutNum);
                    }
                }
            });
            //作废操作
            childViewHolder.transferVoidTv.setOnClickListener(new OnClickListener() {
                @Override
                public void onClick(View v) {
                    if (mStatusClickListener != null) {
                        mStatusClickListener.onStatusClick(ConstantParams.CONSTANT_STARTS_4, productTransferredInAndOutNum);
                    }
                }
            });
            //编辑操作
            childViewHolder.transferEditTv.setOnClickListener(new OnClickListener() {
                @Override
                public void onClick(View v) {
                    if (mStatusClickListener != null) {
                        mStatusClickListener.onStatusClick(ConstantParams.CONSTANT_STARTS_5, productTransferredInAndOutNum);
                    }
                }
            });
        } else {
            childViewHolder.transferReceiverLl.setVisibility(View.GONE);
            childViewHolder.transferStatusLl.setVisibility(View.GONE);
        }

        return convertView;
    }

    @Override
    public boolean isChildSelectable(int groupPosition, int childPosition) {
        return true;
    }

    public interface OnStatusClickListener {
        void onStatusClick(int type, ProductTransferredInAndOutNumLists groupEntity);
    }

    static class GroupViewHolder {
        TextView transferDateTv;
        TextView transfereeopleTv;
        TextView transferDistanceTv;
        TextView storeInTv;
        TextView storeOutTv;
        TextView reasonTv;
    }

    static class ChildViewHolder {
        TextView transferProTv;
        TextView transferProNumTv;
        LinearLayout transferProductionDateLl;
        TextView transferProductionDateTv;
        LinearLayout transferReceiverLl;
        TextView transferReceiverTv;
        TextView transferDeliveryDateTv;
        LinearLayout transferStatusLl;
        TextView transferStatusTv;
        TextView transferVoidTv;
        TextView transferRetrieveTv;
        TextView transferEditTv;
    }
}