package com.wgmf.yxgj.module.business.manageproduct.ui

import android.os.Bundle
import android.view.View
import android.widget.ArrayAdapter
import com.alibaba.android.arouter.facade.annotation.Route
import com.alibaba.android.arouter.launcher.ARouter
import com.google.gson.Gson
import com.wgmf.library.extfunction.afterTextChanged
import com.wgmf.yxgj.base.BaseParentAct
import com.wgmf.yxgj.module.business.manageproduct.R
import com.wgmf.yxgj.module.business.manageproduct.model.HomeBusinessFindMarkeEntity
import com.wgmf.yxgj.module.business.manageproduct.model.HomeBusinessFindProductEntity
import com.wgmf.yxgj.module.business.manageproduct.service.GoodsManagerService
import com.wgmf.yxgj.utils.CountDownDominator2
import com.xp.arouter.RouterParams
import kotlinx.android.synthetic.main.activity_home_business_stock.*

/**
 * @author Sasuke on 2020-4-29 0029.
 * 到家业务库存查询
 */
@Route(path = RouterParams.URL_HOMEBUSINESSSTOCKACT)
class HomeBusinessStockAct : BaseParentAct() {
    val branchTitle by lazy { intent.getStringExtra("branchTitle") }

    var textChangeLock = false

    //查询产品缓存
    var prodEntityCache: HomeBusinessFindProductEntity? = null

    //查询商超缓存
    var storeEntityCache: HomeBusinessFindMarkeEntity? = null
    var showStoreCache: List<HomeBusinessFindMarkeEntity.ResultList>? = null

    var intentTitleProd = ""
    var intentTitleStore = ""

    val counterProd by lazy {
        CountDownDominator2 {
            GoodsManagerService.getInstance()
                .requestHomeBusinessFindProduct(searchBarProd.text.toString()) {
                    if (!isFinishing && it.isSuccessed && searchBarProd.isFocused && searchBarProd.text.isNotBlank()) {
                        prodEntityCache =
                            Gson().fromJson(it.info, HomeBusinessFindProductEntity::class.java)
                        prodResultLv.visibility =
                            if (prodEntityCache?.resultList.isNullOrEmpty()) View.GONE else View.VISIBLE
                        prodEntityCache?.resultList?.let {
                            it.map { "${it.productName}(${it.productCode})" }.toTypedArray()
                                .takeIf { !it.isNullOrEmpty() }?.let { array ->
                                    prodResultLv.adapter = ArrayAdapter(
                                        this@HomeBusinessStockAct,
                                        R.layout.text_view_layout,
                                        array
                                    )
                                    prodResultLv.visibility = View.VISIBLE
                                }
                        }
                    }
                }
        }
    }

    val counterStore: CountDownDominator2 by lazy {
        CountDownDominator2 {
            GoodsManagerService.getInstance().requestHomeBusinessFindMarke {
                if (!isFinishing && it.isSuccessed) {
                    storeEntityCache =
                        Gson().fromJson(it.info, HomeBusinessFindMarkeEntity::class.java)?.apply {
                            resultList = resultList?.filter { !it.marketName.isNullOrBlank() }
                        }
                }
            }
        }
    }

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        setContentView(R.layout.activity_home_business_stock)
        initTitle()
        setListeners()
        /**一进来就查询商超*/
        queryMarke()
    }


    fun queryMarke() {
        counterStore.start(300)
    }

    fun setListeners() {
        //实时搜索产品编码
        searchBarProd.afterTextChanged { text ->
            if (text.isBlank()) {
                prodResultLv.visibility = View.GONE
                return@afterTextChanged
            }
            if (textChangeLock) return@afterTextChanged
            counterProd.start(300)
        }


        //本地搜索商超（一进来就已经请求完了）
        searchBarStore.afterTextChanged { text ->
            if (text.isBlank()) {
                storeResultLv.visibility = View.GONE
                return@afterTextChanged
            }
            if (textChangeLock) return@afterTextChanged
            if (storeEntityCache?.resultList.isNullOrEmpty()) {
                queryMarke()
                return@afterTextChanged
            }
            showStoreCache =
                storeEntityCache?.resultList?.filter { text in it.marketName + it.marketId }
            storeResultLv.visibility = if (storeEntityCache?.resultList.isNullOrEmpty()
                || showStoreCache.isNullOrEmpty()
            ) View.GONE else View.VISIBLE
            showStoreCache?.let {
                it.map { "${it.marketName}(${it.marketId})" }.toTypedArray()
                    .takeIf { !it.isNullOrEmpty() }?.let { array ->
                        storeResultLv.adapter =
                            ArrayAdapter(
                                this@HomeBusinessStockAct,
                                R.layout.text_view_layout,
                                array
                            )
                        storeResultLv.visibility = View.VISIBLE
                    }
            }
        }

        //产品结果列表点击
        prodResultLv.setOnItemClickListener { adapterView, view, pos, id ->
            prodEntityCache?.resultList?.let {
                textChangeLock = true//锁上
                searchBarProd.setText(it[pos].productCode)
                searchBarProd.setSelection(searchBarProd.text.toString().length)//光标移到最后一位
//                focus(searchBarProd)
                prodResultLv.visibility = View.GONE
                intentTitleProd =
                    "${it[pos].productName}，${it[pos].productCode}，单位：${it[pos].productUnamecn}"
                textChangeLock = false//解锁
            }
        }


        //商超结果列表点击
        storeResultLv.setOnItemClickListener { adapterView, view, pos, id ->
            showStoreCache?.let {
                textChangeLock = true//锁上
                searchBarStore.setText(it[pos].marketName)
                searchBarStore.setSelection(searchBarStore.text.toString().length)//光标移到最后一位
//                focus(searchBarProd)
                storeResultLv.visibility = View.GONE
                intentTitleStore = "${it[pos].marketName}系统, " + when (userInfo.level.toInt()) {
                    1, 2 -> "全国"
                    3 -> userInfo.regionName ?: ""
                    4 -> "${userInfo.regionName ?: ""}, ${userInfo.officeName ?: ""}"
                    else -> "${userInfo.regionName ?: ""}, ${userInfo.officeName ?: ""}, ${userInfo.name}"
                }
//                        if (userInfo.level.toInt() < 3) "全国" else "${userInfo.regionName ?:""} ${userInfo.officeName ?:""}, " +
//                        if (userInfo.level == "5") userInfo.name else ""
                textChangeLock = false//解锁
            }
        }

        //焦点变化隐藏列表
        arrayOf(searchBarProd, searchBarStore).forEach {
            it.setOnFocusChangeListener { view, hasFocus ->
                if (!hasFocus) {
                    prodResultLv.visibility = View.GONE
                    storeResultLv.visibility = View.GONE
                }
            }
        }

        //查询按钮点击
        queryBtn.setOnClickListener {
            if (searchBarProd.text.toString().isBlank() && prodResultLv.visibility == View.GONE) {
                showMsg("请输入产品编码")
                return@setOnClickListener
            }
            if (searchBarStore.text.toString().isBlank() && storeResultLv.visibility == View.GONE) {
                showMsg("请输入商超系统名")
                return@setOnClickListener
            }
            ARouter.getInstance().build(RouterParams.URL_HOMESTOCKDETAILACT)
                .with(Bundle().apply {
                    putString("productCode", searchBarProd.text.toString())
                    putString("markeName", searchBarStore.text.toString())
                    putString("intentTitleProd", intentTitleProd)
                    putString("intentTitleStore", intentTitleStore)
                    putInt("showLevel", userInfo.level.toInt())//1全国，3大区，4办事处，5主管
                })
                .navigation()
        }

    }


    override fun initTitle() {
        super.initTitle()
        homeTitleText.text = branchTitle
        homeTitleBackLl.visibility = View.VISIBLE

    }

}