package com.wgmf.yxgj.module.business.manageproduct.ui

import android.os.Bundle
import android.support.v7.widget.LinearLayoutManager
import com.alibaba.android.arouter.facade.annotation.Route
import com.google.gson.Gson
import com.wgmf.yxgj.base.BaseParentAct
import com.wgmf.yxgj.dialog.LoadWaitDominator
import com.wgmf.yxgj.module.business.manageproduct.R
import com.wgmf.yxgj.module.business.manageproduct.model.HomeStockDetailEntity
import com.wgmf.yxgj.module.business.manageproduct.service.GoodsManagerService
import com.xp.arouter.RouterParams
import kotlinx.android.synthetic.main.activity_home_stock_detail.*


/**
 * @author Sasuke on 2020/5/5.
 * 到家业务库存明细
 */
@Route(path = RouterParams.URL_HOMESTOCKDETAILACT)
class HomeStockDetailAct : BaseParentAct() {
    companion object {
        const val COUNTRY = 1//全国
        const val BIG_AREA = 3//大区
        const val OFFICE = 4//办事处
        const val MANAGER = 5//主管
    }

    //商超名
    val markeName by lazy { intent.getStringExtra("markeName") }
    //产品编码
    val productCode by lazy { intent.getStringExtra("productCode") }

    val intentTitleProd by lazy { intent.getStringExtra("intentTitleProd") }
    val intentTitleStore by lazy { intent.getStringExtra("intentTitleStore") }

    val code1 by lazy { intent.getStringExtra("code1") }

    //当前展示的级别
    val showLevel by lazy { intent.getIntExtra("showLevel", 5) }

    var loadWait: LoadWaitDominator? = null

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        setContentView(R.layout.activity_home_stock_detail)
        initTitle()
        init()
        query()
    }

    fun query() {
        loadWait?.show(LoadWaitDominator.LOADING)
        GoodsManagerService.getInstance().requestHomeBusinessFindStockList(
                userInfo.staffId,
                markeName,
                productCode,
                if (code1.isNullOrBlank()) userInfo.organizationCode else code1,
                showLevel) {
            loadWait?.dismissAll()
            if (!isFinishing && it.isSuccessed) {
                val stockEntity = Gson().fromJson(it.info, HomeStockDetailEntity::class.java)
                stockEntity.result?.apply {
                    proNo = productCode//传过去用于网络请求
                    proName = intentTitleProd//传过去用于拼接显示顶栏
                    marketName = markeName//传过去用于网络请求
                    orgName = intentTitleStore//传过去用于显示顶栏
                }
                dataRv.adapter = HomeStockDetailAdapter(this, stockEntity.result, showLevel)
                if (stockEntity.result == null || stockEntity?.result?.homebusinessStockList.isNullOrEmpty()) {
                    loadWait?.show(LoadWaitDominator.NO_DATA)
                }
                return@requestHomeBusinessFindStockList
            }
            loadWait?.show(LoadWaitDominator.NET_ERROR)
        }
//        dataRv.adapter = HomeStockDetailAdapter(this,)
//        Handler().postDelayed({ loadWait?.show(LoadWaitDominator.NO_DATA) }, 5000)

    }

    fun init() {
        loadWait = LoadWaitDominator(this@HomeStockDetailAct, containerLayout)
        dataRv.apply {
            layoutManager = LinearLayoutManager(this@HomeStockDetailAct)
        }
    }

    override fun initTitle() {
        super.initTitle()
        homeTitleText.text = "库存明细"
        //标题栏
        infoTitleTv.text = "${intentTitleProd}\n${intentTitleStore}"
        //表头显示字样
        listHeadLevelTv.text = when (showLevel) {
            COUNTRY -> "大区"
            BIG_AREA -> "办事处"
            OFFICE -> "主管"
            else -> "门店"
        }
    }
}