package com.wgmf.yxgj.module.business.manageproduct.ui

import android.app.Activity
import android.app.AlertDialog
import android.content.DialogInterface
import android.content.Intent
import android.os.Bundle
import android.support.v4.view.ViewPager
import android.support.v7.widget.LinearLayoutManager
import android.support.v7.widget.RecyclerView
import android.text.TextUtils.isEmpty
import android.view.LayoutInflater
import android.view.View
import android.widget.*
import com.alibaba.android.arouter.facade.annotation.Route
import com.google.gson.Gson
import com.wgmf.library.base.BaseResponse
import com.wgmf.library.utils.Arith
import com.wgmf.library.utils.Log
import com.wgmf.yxgj.base.BaseParentAct
import com.wgmf.yxgj.dialog.LoadWaitDominator
import com.wgmf.yxgj.dialog.PublicConformTipDialog
import com.wgmf.yxgj.global.PackTypeId
import com.wgmf.yxgj.module.business.manageproduct.R
import com.wgmf.yxgj.module.business.manageproduct.model.DingHuoOplQtyEntity
import com.wgmf.yxgj.module.business.manageproduct.model.OrderSubmitReqBean
import com.wgmf.yxgj.module.business.manageproduct.service.GoodsManagerService
import com.wgmf.yxgj.utils.DensityUtil
import com.wgmf.yxgj.utils.StringUtils
import com.wgmf.yxgj.utils.ViewUtils
import com.wgmf.yxgj.utils.helper.NetHelper
import com.wgmf.yxgj.widgets.AutoRadioGroup
import com.wgmf.yxgj.widgets.MyPagerAdapter
import com.wgmf.yxgj.widgets.decoration.SpacesItemDecoration
import com.xp.arouter.RouterParams
import kotlinx.android.synthetic.main.ordergoods_submit_act.*
import org.jetbrains.anko.find
import pro.xp.com.indexbar.IndexbarConfig
import java.text.MessageFormat
import java.text.SimpleDateFormat
import java.util.*
import kotlin.collections.ArrayList

/**
 * 货品管理--订货加单
 */
@Route(path = RouterParams.URL_ORDERGOODSSUBMITACT)
class OrderGoodsSubmitAct : BaseParentAct() {

    private val mShopId by lazy { intent.getStringExtra("shopId") }

    private val mShopName by lazy { intent.getStringExtra("shopName") }

    private lateinit var mLoadWait: LoadWaitDominator

    private var mTitleContainer: LinearLayout? = null

    private var mBrandRadioGroup: AutoRadioGroup? = null

    private var mColRadioGroupList: MutableList<AutoRadioGroup> = mutableListOf()

    private var mViewPagerList: MutableList<View> = mutableListOf()

    private var mResultInfoCache: DingHuoOplQtyEntity.ResultInfo? = null

    companion object {
        const val WGMF_BRAND_ID = 8
        const val XDY_BRAND_ID = 15
    }

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        setContentView(R.layout.ordergoods_submit_act)
        initTitle()
        initView()
        addOrderProductList()
    }

    override fun initTitle() {
        super.initTitle()
        homeTitleText.text = "订货加单"
        homeTitleMoreLl.visibility = View.INVISIBLE
        homeTitleBackLl.visibility = View.VISIBLE
    }

    private fun initView() {
        mLoadWait = LoadWaitDominator(this, containerLayout)

        mTitleContainer = tapLayout.find(R.id.title_container_ll)
        mBrandRadioGroup = AutoRadioGroup(mTitleContainer!!)

        tapLayout.find<ImageButton>(R.id.back_ll).setOnClickListener {
            back()
        }
        submitBtn.setOnClickListener { checkBeforeSubmit() }
    }

    private fun addOrderProductList() {
        mLoadWait.show(LoadWaitDominator.LOADING)
        if (brandList == null || brandList.isEmpty()) {
            showMsg("顾问品牌缺失，请重新登录，如仍有异常请联系相关工作人员！")
            return
        }
        var brandId = ""
        brandList?.forEachIndexed { index, it ->
            if (brandList.size > 1) {
                if (index < brandList.size) {
                    brandId = it.brandId.toString() + ","
                }
                brandId += it.brandId.toString()
            } else {
                brandId += it.brandId.toString()
            }
        }

        GoodsManagerService.getInstance()
            .requestAddOrderProductList(userInfo.staffId, mShopId, brandId) {
                if (it.isSuccessed) {
                    mLoadWait.dismissAll()
                    val dingHuoOplQtyEntity =
                        Gson().fromJson(it.info, DingHuoOplQtyEntity::class.java)
                    if (dingHuoOplQtyEntity.result != null) {
                        showOrderList(dingHuoOplQtyEntity.result)
                    } else {
                        mLoadWait.show(LoadWaitDominator.NO_DATA)
                    }
                } else {
                    mLoadWait.show(LoadWaitDominator.NET_ERROR)
                }
            }
    }

    private fun refreshUI(resultInfo: DingHuoOplQtyEntity.ResultInfo?) {
        //先存一份
        if (resultInfo?.list == null) return
        mResultInfoCache = resultInfo

        //初始化最顶栏
        resultInfo.brandPage?.let {
            if (it.size == 1) {
                //品牌大标签 只有一个品牌的情况
                titleLayout.find<TextView>(R.id.home_title_text).text = it.get(0)?.title
                titleLayout.visibility = View.VISIBLE
                tapLayout.visibility = View.GONE
            } else {
                titleLayout.visibility = View.GONE
                tapLayout.visibility = View.VISIBLE
            }
        }

        //先清一下（其实如果只走一遍好像也无所谓
        mBrandRadioGroup?.removeAllChild()
        mColRadioGroupList.forEach { it.removeAllChild() }
        viewpager.removeAllViews()
        mViewPagerList.clear()
        //初始化顶部品牌标签+内容页（循环）=========================
        resultInfo.brandPage?.forEach { brandItem ->
            //品牌大标签显示
            val radio: RadioButton = (layoutInflater.inflate(
                R.layout.tap_title_radio_btn,
                mTitleContainer,
                false
            ) as RadioButton)
            mBrandRadioGroup?.addViewWithLayoutParams(
                view = radio, text = brandItem.title, paramWith = 0,
                paramheight = RadioGroup.LayoutParams.MATCH_PARENT
            ) { pos ->
                viewpager.currentItem = pos
                refreshRvData(brandItem.type)
            }
            //数据内容页显示
            mViewPagerList.add(LayoutInflater.from(this).inflate(R.layout.ordergoods, null).apply {
                find<TextView>(R.id.tvStore).apply {
                    text = "订货门店: ${mShopName}"
                }

                // val dataList = mutableListOf<DingHuoOplQtyEntity.DinghuoDetail>().apply { addAll(resultInfo.list.filter { it.brandId == brandItem.type }) }
                //分类标签(只有 五谷磨房 才有小分类)
                val labelGroup = find<LinearLayout>(R.id.labelGroup)
                val colRadioGroup = AutoRadioGroup(labelGroup)
                if (brandItem.type == WGMF_BRAND_ID) {
                    resultInfo.col.forEach { colItem ->
                        val radioButton = layoutInflater.inflate(
                            R.layout.add_sell_radio_button,
                            null
                        ) as RadioButton
                        colRadioGroup.addView(view = radioButton, text = colItem.title) { pos ->
                            refreshItemTitle(colItem)
                            refreshRvByLabel(brandItem.type, colItem.type)//各标签的点击监听。
                        }
                    }
                    //加一个“全部”标签（无论什么品牌都要加）
                    val radioButton =
                        layoutInflater.inflate(R.layout.add_sell_radio_button, null) as RadioButton
                    colRadioGroup.addView(view = radioButton, text = "全部") {
                        refreshItemTitle(null)
                        refreshRvByLabel(brandItem.type, -1)
                    }
                } else {
                    //加一个“全部”标签（无论什么品牌都要加）
                    val radioButton =
                        layoutInflater.inflate(R.layout.add_sell_radio_button, null) as RadioButton
                    colRadioGroup.addView(view = radioButton, text = "全部") {
                        refreshItemTitle(null)
                        refreshRvByLabel(brandItem.type, 0)
                    }
                    labelGroup.visibility = View.INVISIBLE
                }
                mColRadioGroupList.add(colRadioGroup)

                if (resultInfo.col.isNotEmpty()) {
                    refreshItemTitle(resultInfo.col[0])
                } else {
                    refreshItemTitle(null)
                }

                //列表
                find<RecyclerView>(R.id.proLv).apply {
                    layoutManager = LinearLayoutManager(this@OrderGoodsSubmitAct)
                    adapter = OrderGoodsTradeAdapter(
                        this@OrderGoodsSubmitAct,
                        listOf()
                    ) { refreshPriceShow() }
                    addItemDecoration(
                        SpacesItemDecoration(
                            DensityUtil.dip2px(mContext, 10f),
                            (adapter as OrderGoodsTradeAdapter).itemCount,
                            true
                        )
                    )
                }
            })
        }

        viewpager.adapter = MyPagerAdapter(this, ArrayList(mViewPagerList))
        viewpager.currentItem = 0
        viewpager.addOnPageChangeListener(object : ViewPager.OnPageChangeListener {
            override fun onPageScrollStateChanged(p0: Int) {}
            override fun onPageScrolled(p0: Int, p1: Float, p2: Int) {}
            override fun onPageSelected(pos: Int) {
                mBrandRadioGroup?.setChildChecked(pos)
            }
        })

        mBrandRadioGroup?.setChildChecked(0)
        mColRadioGroupList.forEach { it.setChildChecked(0) }//要放在最后check，因为前面构造的时候，还没有添加到pager里面，直接check会崩。
        //每个pager都先定位到第一个分类
        //refreshRvByLabel(resultInfo.brandPage[0].type, if (brandItem.type != WGMF_BRAND_ID) -1 else resultInfo?.col[0].type)
    }


    private fun View.refreshItemTitle(label: DingHuoOplQtyEntity.Label?) {
        var titleList = Arrays.asList(*resources.getStringArray(R.array.goods_order_default_title))
        if (label?.type == PackTypeId.ACCESSORIES_SUPPLIERS) {
            titleList = Arrays.asList(*resources.getStringArray(R.array.goods_order_other_title))
        }
        find<TextView>(R.id.tvName).apply {
            text = titleList[0]
        }
        find<TextView>(R.id.tvKucun).apply {
            text = titleList[1]
        }
        find<TextView>(R.id.tvQuantity).apply {
            text = titleList[2]
        }
        find<TextView>(R.id.tvQty).apply {
            text = titleList[3]
        }
        find<TextView>(R.id.tvCyl).apply {
            text = titleList[4]
        }
    }

    /**
     * 根据上面的标签分类来过滤显示对应的列表
     */
    private fun refreshRvData(brand: Int) {
        val currentPager =
            mViewPagerList.get(mResultInfoCache?.brandPage?.indexOfFirst { it.type == brand }
                ?: 0)
        val currRv = currentPager.find<RecyclerView>(R.id.proLv)
        val adapter = currRv.adapter as OrderGoodsTradeAdapter
        adapter.notifyDataSetChanged()
    }

    /**
     * 根据上面的标签分类来过滤显示对应的列表
     */
    private fun refreshRvByLabel(brand: Int, type: Int) {
        val currentPager =
            mViewPagerList.get(mResultInfoCache?.brandPage?.indexOfFirst { it.type == brand }
                ?: 0)
        val currRv = currentPager.find<RecyclerView>(R.id.proLv)
        val adapter = currRv.adapter as OrderGoodsTradeAdapter
        adapter.notifyProByLabel(mResultInfoCache, brand, type)

        val indexbarConfig = IndexbarConfig(
            this,
            currentPager.find(R.id.product_index_bar),
            currentPager.find(R.id.tvSideBarHint),
            currRv,
            adapter.mOrderList
        ).configDefault()
        indexbarConfig.toggleShowIndexBar(type == -1)//-1表示“全部”标签
        refreshPriceShow()
    }

    /**
     * 刷新价格显示
     */
    private fun refreshPriceShow() {
        var invalidCount = 0
        var count = 0.0
        var countPrice = 0.0

        mResultInfoCache?.list?.forEach {
            if (it.isInvalid) invalidCount++
            count = Arith.add(count, it.tqty)
            countPrice = Arith.add(countPrice, it.amount)
        }
        totalCountTv.text = StringUtils.formatDouble(count, "0.00")
        totalPriceTv.text = StringUtils.formatDouble(countPrice, "0.00")
        if (invalidCount > 0) {
            submitBtn.isEnabled = false
            submitBtn.text = "您有 $invalidCount 条信息输入不合格,请重输！"
        } else {
            if (!submitBtn.isEnabled) {
                submitBtn.isEnabled = true
                submitBtn.text = "提交"
            }
        }
    }

    fun showOrderList(resultInfo: DingHuoOplQtyEntity.ResultInfo?) {
        if (isFinishing || resultInfo?.brandPage == null || resultInfo.brandPage.isEmpty()) return
        refreshUI(resultInfo.apply { list.forEach { it.isShowAlert = true } })
    }

    /**
     * 提交前的校验
     */
    private fun checkBeforeSubmit() {
        if (mResultInfoCache == null) return

        val choiceList = mResultInfoCache?.list?.filter { it.tqty > 0 } ?: listOf()
        val choiceWgmfList =
            mResultInfoCache?.list?.filter { it.tqty > 0 && it.brandId == WGMF_BRAND_ID }
                ?: listOf()
        val choiceXdyList =
            mResultInfoCache?.list?.filter { it.tqty > 0 && it.brandId == XDY_BRAND_ID }
                ?: listOf()

        if (!checkNumLimit(choiceList)) {
            AlertDialog.Builder(this)
                .setMessage("六方订货总量必须是6的整数倍，请调整数量后重新提交！")
                .setPositiveButton("我知道了", null)
                .create().show()
            return
        }
        if (choiceList.isEmpty()) {
            showMsg("您没有选择任何订货产品!")
            return
        }

        if (isEmpty(mResultInfoCache?.reason)) {
            val builder = PublicConformTipDialog.Builder(mContext)
            builder.setLayoutId(R.layout.view_textview_dialog2)
            builder.setTitle(R.string.submit_failed)
            builder.setMessage(R.string.order_goods_reason_tip)
            builder.setNegativeButton(
                R.string.confirm
            ) { dialog, which ->
                dialog.dismiss()
            }
            builder.create().show()
            return
        }

        val info = "请确认是否提交整单订货！"
        val builder = AlertDialog.Builder(this)
        builder.setTitle("重要提示").setMessage(info)
            .setNegativeButton("提交", DialogInterface.OnClickListener { dialog, which ->
                if (!NetHelper.IsHaveInternet(this@OrderGoodsSubmitAct)) {
                    showMsg("当前为离线模式，无法订货！")
                    return@OnClickListener
                }
                submitBtn.isEnabled = false
                val packedSubmitData = packedSubmitData()
                if (packedSubmitData != null) orderSubmit(packedSubmitData)
            }).setPositiveButton("取消") { dialog, which -> submitBtn.isEnabled = true }.create()
            .show()
    }

    /**上传订单*/
    private fun orderSubmit(bean: OrderSubmitReqBean) {
        ViewUtils.showProgress(this, "请稍等", "正在上传订单")
        GoodsManagerService.getInstance().requestSaveOrderGoodsAuditions(Gson().toJson(bean)) {
            ViewUtils.dismissProgress()
            if (!isFinishing && it.isSuccessed) {
                val entity = Gson().fromJson(it.info, BaseResponse::class.java)

                if (entity.retCode.equals("0") && entity.msgCode.equals("0")) {
                    showMsg("提交成功")
                    setResult(Activity.RESULT_OK)
                    finish()
                    //跳订货审核页面1
                    startActivity(Intent(this, GoodsAuditingShopListActivity::class.java).apply {
                        putExtra("storeNo", mShopId)
                        putExtra("branchTitle", "订货审核")
                    })
                    return@requestSaveOrderGoodsAuditions
                }
                showMsg(entity.retInfo)
                submitBtn.isEnabled = true
                return@requestSaveOrderGoodsAuditions
            }
            showMsg("提交失败")
        }
    }

    /**
     * 组装提交的数据
     */
    private fun packedSubmitData(): OrderSubmitReqBean? {
        if (mResultInfoCache != null) {
            var brandTemp = ""
            brandList?.forEach { brandTemp += "${it.brandId}," }
            Log.i("SasukeLog", "userInfo.brand=${brandList?.get(0)?.brandId}")
            if (brandTemp.endsWith(",")) brandTemp = brandTemp.substring(0, brandTemp.length - 1)

            val date = Date()
            //    orderSubmitReqBean.setBillCode(SystemHelper.LoginOrganId + DateUtil.format(date, "yyMMddHHmmss"));
            /*新订单号规则：门店编号+顾问ID+时间戳到秒+2位随机数，例如：0110074+75598659+170301092423+12；
    顾问ID长度最多为8位，不够的前面补0；*/
            val orderSubmitReqBean = OrderSubmitReqBean().apply {
                billCode = makeBillCode()
                brands = brandTemp
                firstOrder = mResultInfoCache!!.firstOrder
                staffNo = userInfo.staffId
                storeNo = mShopId
                dhReark = mResultInfoCache!!.reason
            }
            val detailBeans = ArrayList<OrderSubmitReqBean.DetailsBean>()
            mResultInfoCache?.list?.filter { it.tqty > 0 }?.forEach { choice ->
                detailBeans.add(
                    OrderSubmitReqBean.DetailsBean().apply {
                        brandId = choice.brandId.toString()
                        proAmount = choice.getAmount().toString()
                        proBoxQty = choice.getBox_qty().toString()
                        proCode = choice.itemid
                        proDHQty = choice.getTQTY().toString()
                        proId = choice.oe_pro_id
                        proLastMonthQty = choice.lastMonth_qty
                        proMaxQty = choice.max_opl_qty.toString()
                        proName = choice.itemName
                        proOplQty = choice.opl_qty.toString()
                        proPrice = choice.itemPrice.toString()
                        proSYQty = choice.sy_opl_qty.toString()
                        proStockQty = choice.stock_Qty.toString()
                        proUOM = choice.itemUOM
                        proUOMID = choice.itemUOM_id
                    }
                )
            }
            orderSubmitReqBean.details = detailBeans
            return orderSubmitReqBean
        }
        return null
    }

    fun showIsLoading() {
        mLoadWait.show(LoadWaitDominator.LOADING)
    }

    fun showError(errorMsg: String?) {
        mLoadWait.show(errorMsg ?: "netError")
    }

    fun showState(loadWaitState: Int) {
        mLoadWait.show(loadWaitState)
    }

    fun showDismissAll() {
        mLoadWait.dismissAll()
    }


    /*新订单号规则：门店编号+顾问ID+时间戳到秒+2位随机数，例如：0110074+75598659+170301092423+12；
    顾问ID长度最多为8位，不够的前面补0；*/
    private fun makeBillCode(): String {
        val tempId = if (userInfo.staffId.length >= 8) userInfo.staffId.substring(0, 8)
        else "00000000".substring(userInfo.staffId.length) + userInfo.staffId
        return MessageFormat.format(
            "{0}{1}{2}{3}",
            mShopId,
            tempId,
            SimpleDateFormat("yyMMddHHmmss").format(Date()),
            String.format(Locale.CHINA, "%02d", Random().nextInt(100))
        )
    }
}