package com.wgmf.yxgj.module.business.manageproduct.ui

import android.annotation.SuppressLint
import android.content.Context
import android.graphics.Color
import android.graphics.Typeface
import android.graphics.drawable.Drawable
import android.os.Handler
import android.os.Looper
import android.support.v4.content.ContextCompat
import android.support.v7.app.AppCompatActivity
import android.support.v7.widget.RecyclerView
import android.text.*
import android.text.method.LinkMovementMethod
import android.text.style.*
import android.view.*
import android.widget.*
import com.squareup.picasso.Picasso
import com.wgmf.library.utils.Arith
import com.wgmf.yxgj.global.PackTypeId
import com.wgmf.yxgj.module.business.manageproduct.R
import com.wgmf.yxgj.module.business.manageproduct.model.DingHuoOplQtyEntity
import com.wgmf.yxgj.utils.DensityUtil
import com.wgmf.yxgj.utils.MyToast
import com.wgmf.yxgj.utils.StringUtils
import com.wgmf.yxgj.utils.notNullAndEmpty
import com.wgmf.yxgj.widgets.NumberKeyboard
import org.jetbrains.anko.find

/**
 * 货品管理-订货加单适配器
 */
class OrderGoodsTradeAdapter(
    private val context: Context,
    dataList: List<DingHuoOplQtyEntity.DinghuoDetail> = mutableListOf(),
    private val notifyPriceShow: () -> Unit
) : RecyclerView.Adapter<RecyclerView.ViewHolder>() {
    /**
     * 订单列表
     */
    val mOrderList: MutableList<DingHuoOplQtyEntity.DinghuoDetail> = mutableListOf()

    private val mHandler = Handler(Looper.getMainLooper())

    /**
     * 为了用外层的最大库存天数字段，专门把整个entity传进来缓存起来。
     */
    private var mEntityCache: DingHuoOplQtyEntity.ResultInfo? = null

    /**
     * 产品类型
     */
    var mProductType: Int = PackTypeId.FINISHED_PRODUCT_TYPE

    init {
        dataList.let {
            mOrderList.clear()
            mOrderList.addAll(dataList)
        }
    }

    private val mKeyboard: NumberKeyboard by lazy {
        NumberKeyboard.newInstance(null)
    }

    override fun getItemCount(): Int {
        if (mOrderList.size > 0) {
            return mOrderList.size + 1
        }
        return mOrderList.size
    }

    override fun getItemViewType(position: Int): Int {
        if (mOrderList.size < 0) return super.getItemViewType(position)
        if (position == mOrderList.size) {
            return -1
        } else {
            return super.getItemViewType(position)
        }
    }

    override fun onCreateViewHolder(parent: ViewGroup, viewType: Int): RecyclerView.ViewHolder {
        if (viewType >= 0) {
            return OrderGoodsHolder(
                LayoutInflater.from(context)
                    .inflate(R.layout.second_ordergoodsmenu_item4, parent, false)
            )
        } else {
            return OrderGoodsReasonHolder(
                LayoutInflater.from(context)
                    .inflate(R.layout.list_item_input_reason, parent, false)
            )
        }
    }

    override fun onBindViewHolder(holder: RecyclerView.ViewHolder, position: Int) {
    }

    override fun onBindViewHolder(
        holder: RecyclerView.ViewHolder,
        @SuppressLint("RecyclerView") pos: Int,
        payloads: List<Any?>
    ) {
        if (holder is OrderGoodsHolder) {
            val data = mOrderList[pos]
            holder.apply {
                //用于局部刷新viewImageTv这一个组件
                payloads.takeIf { it.isNotEmpty() && it[0] == "refreshImage" }?.let {
                    name.text = refreshOrderName(data)
                    return
                }
                count.tag = pos
                calculatorCyl(data, data.tqty)//计算库存率
                //库存在途
                tvKucun.text = data.stock_Qty.toString()
                //建议订货量
                tvQuantityOrder.text = data.opl_qty.toString()
                //库存天数
                tvCyl.text = data.cyl.toInt().toString()

                if (mProductType == PackTypeId.ACCESSORIES_SUPPLIERS) {
                    oeProDhQty.text = data.oe_pro_dh_qty.toString()
                } else {
                    oeProDhQty.text = data.lastMonth_qty.toString()
                }

                submitCount.apply {
                    visibility = View.VISIBLE
                    setTextColor(ContextCompat.getColor(context, R.color.c_d37d1a))
                    text = String.format("已提交 : %s", data.pro_today_dhqty)
                }
                //产品名
                name.text = refreshOrderName(data)
                name.movementMethod = LinkMovementMethod.getInstance()
                //单位
                unit.text = String.format("%s(%s)", data.itemUOM, data.itemid)
                //产品单价
                unitPrice.text = String.format("单价:%s", data.itemPrice)
                count.setTextColor(if (data.isInvalid) Color.RED else Color.BLACK)

                if (data.isStockout) {
                    count.setText(R.string.factory_out_stock)
                    count.setTextColor(Color.RED)
                    count.setBackgroundResource(R.drawable.shape_transparent)
                    reduce.visibility = View.INVISIBLE
                    add.visibility = View.INVISIBLE
                } else {
                    count.setTextColor(Color.BLACK)
                    count.setBackgroundResource(R.drawable.shape_solid_f5f5f5_round_3)
                    reduce.visibility = View.VISIBLE
                    add.visibility = View.VISIBLE
                    count.text = StringUtils.formatDouble(data.tqty, "0.00")
                }

                //减号逻辑===============
                //if (data.tqty == 0.0) {
                //    if (data.sy_opl_qty == 0.0) { //如果订货最大数量为0，那为了在点击添加时弹出提示，所以不能把按钮enable设为false
                //        reduce.isEnabled = true
                //        reduce.setImageResource(R.mipmap.icon_shop_order_subtract)
                //    } else {
                //        reduce.isEnabled = false
                //        reduce.setImageResource(R.mipmap.icon_shop_order_subtract)
                //    }
                //} else {
                    reduce.isEnabled = true
                    reduce.setImageResource(R.mipmap.icon_shop_order_subtract)
                //}

                //加号逻辑===============
                //if (data.tqty >= data.sy_opl_qty) {
                //    if (data.sy_opl_qty == 0.0) { //如果剩余订货量为0，那为了在点击添加时弹出提示，所以不能把按钮enable设为false
                //        add.isEnabled = true
                //         //虽然是可点击的，但还是要设为灰色。
                //         add.setImageResource(R.mipmap.icon_shop_order_add)
                //    } else {
                //        add.isEnabled = false
                //        add.setImageResource(R.mipmap.icon_shop_order_add)
                //    }
                //} else {
                    add.isEnabled = true
                    add.setImageResource(R.mipmap.icon_shop_order_add)
                //}

                //通过Picasso先判断图片链接可用性，如果无效链接，则不显示“查看图片”按钮
                if (!data.isShowImageTv) {//只有在标记为false的时候，才去检查链接可用性。
                    Picasso.with(context).load(mOrderList[pos].picUrl)
                        .into(img, object : com.squareup.picasso.Callback {
                            override fun onSuccess() {
                                if (pos >= mOrderList.size) return//防溢出
                                mOrderList[pos].isShowImageTv = true
//                                if (this@OrderGoodsTradeAdapter.)
                                //只刷新这个组件
                                mHandler.post { notifyItemChanged(pos, "refreshImage") }
                            }

                            override fun onError() {
                                if (pos >= mOrderList.size) return//防溢出
                                mOrderList[pos].isShowImageTv = false
                                // notifyItemChanged(pos)
                            }
                        })
                }

                //加号点击监听================================
                add.setOnClickListener {
                    val cell = mOrderList[pos]
                    //if (cell.sy_opl_qty == 0.0) {//最大订货量为0时，减号是可以点击的，但只起到弹出提示的作用。
                    //    val builder = PublicConformTipDialog.Builder(context)
                    //    builder.setTitle("提示")
                    //    builder.setMessage(cell.getRemark())
                    //    builder.setNegativeButton(
                    //        "知道了"
                    //    ) { dialog, which -> dialog.dismiss() }
                    //    builder.create().show()
                    //    return@setOnClickListener
                    //}
                    //【if】getPack==0情况下默认加一；
                    //【else】getPack>0情况下以Box_qty为标准
                    cell.dhPack = if (cell.pack == 0.0) 1.0 else cell.pack
                    val d = Arith.add(cell.tqty, cell.dhPack)

                    var temp = ""
                    //如果再加就超过最大值了，那就拦截点击后面的操作
                    if (cell.officeProduct30DSaleNum.toString().notNullAndEmpty()) {
                        if (Arith.sub(
                                Arith.mul(cell.officeProduct30DSaleNum.toString(), "2").toString(),
                                d.toString()
                            ) < 0
                        ) {
                            temp = "该产品已经超过办事处销售数量的2倍，请谨慎订货！"
                        }
                    }

                    //if (d > cell.sy_opl_qty) {
                    //    temp = ("请检查产品：" + cell.itemName
                    //            + ",不能超过最大订货量" + cell.sy_opl_qty
                    //            + "! 您输入的数量为：" + d)
                    //}

                    if (!TextUtils.isEmpty(temp)) {
                        //val builder = PublicConformTipDialog.Builder(context)
                        //builder.setTitle("提示")
                        //builder.setMessage(temp)
                        //builder.setNegativeButton(
                        //    "知道了并重新输入"
                        //) { dialog, which -> dialog.dismiss() }
                        //builder.create().show()
                        //return@setOnClickListener
                        MyToast.show(temp)
                    }

                    cell.tqty = d
                    cell.amount = Arith.mul(d, cell.itemPrice)
                    count.text = StringUtils.formatDouble(d, "0.00")
                    calculatorCyl(cell, d)
                    tvCyl.text = data.cyl.toInt().toString()
                    if (d < 0.0) {
                        cell.isInvalid = true
                        count.setTextColor(Color.RED)
                        reduce.isEnabled = false
                    } else {
                        if (0.0 != cell.dhPack && 0.0 != d && d % cell.dhPack != 0.0) {
                            cell.isInvalid = true
                            count.setTextColor(Color.RED)
                        } else {
                            cell.isInvalid = false
                            count.setTextColor(Color.BLACK)
                        }
                        reduce.isEnabled = true
                    }
                    notifyPriceShow.invoke()
                }

                //减号点击监听================================
                reduce.setOnClickListener {
                    val cell = mOrderList[pos]
                    //if (cell.sy_opl_qty == 0.0) {//最大订货量为0时，减号是可以点击的，但只起到弹出提示的作用。
                    //    val builder = PublicConformTipDialog.Builder(context)
                    //    builder.setTitle("提示")
                    //    builder.setMessage(cell.getRemark())
                    //    builder.setNegativeButton(
                    //        "知道了"
                    //    ) { dialog, which -> dialog.dismiss() }
                    //    builder.create().show()
                    //    return@setOnClickListener
                    //}
                    var d = 0.0
                    //【if】getPack==0情况下默认加一；
                    //【else】getPack>0情况下以getPack为标准
                    cell.dhPack = if (cell.pack == 0.0) 1.0 else cell.pack
                    d = Arith.sub(cell.tqty, cell.dhPack)

                    var temp = ""
                    //如果再加就超过最大值了，那就拦截点击后面的操作
                    if (cell.officeProduct30DSaleNum.toString().notNullAndEmpty()) {
                        if (Arith.sub(
                                Arith.mul(cell.officeProduct30DSaleNum.toString(), "2").toString(),
                                d.toString()
                            ) < 0
                        ) {
                            temp = "该产品已经超过办事处销售数量的2倍，请谨慎订货！"
                        }
                    }

                    if (!TextUtils.isEmpty(temp)) {
                        MyToast.show(temp)
                    }

                    cell.tqty = d
                    cell.amount = Arith.mul(d, cell.itemPrice)
                    count.text = StringUtils.formatDouble(d, "0.00")
                    if (d <= 0.0) {
                        reduce.isEnabled = false
                    }
                    calculatorCyl(cell, d)
                    tvCyl.text = data.cyl.toInt().toString()
                    if (d < 0.0) {
                        cell.isInvalid = true
                        count.setTextColor(Color.RED)
                        add.isEnabled = true
                    }
                    //else if (d > cell.sy_opl_qty) {
                    //    cell.isInvalid = true
                    //    count.setTextColor(Color.RED)
                    //    add.isEnabled = false
                    //}
                    else {
                        if (0.0 != cell.dhPack && 0.0 != d && d % cell.dhPack != 0.0) {
                            cell.isInvalid = true
                            count.setTextColor(Color.RED)
                        } else {
                            cell.isInvalid = false
                            count.setTextColor(Color.BLACK)
                        }
                        add.isEnabled = true
                    }
                    notifyPriceShow.invoke()
                }
                //数量点击监听================================
                if (!data.isStockout) {
                    count.setSelectAllOnFocus(true)
                    count.setOnClickListener {

                        mKeyboard.show(
                            count,
                            (context as AppCompatActivity).supportFragmentManager,
                            null
                        )
                            .setDecimal(2)
                            .selectAll().setOnDismissListener {
                                if (mOrderList.size > pos) {
                                    val cell = mOrderList[pos]
                                    //if (cell.sy_opl_qty == 0.0) {
                                    //    val builder = PublicConformTipDialog.Builder(context)
                                    //    builder.setTitle("提示")
                                    //    builder.setMessage(cell.getRemark())
                                    //    builder.setNegativeButton(
                                    //        "知道了"
                                    //    ) { dialog, which -> dialog.dismiss() }
                                    //    builder.create().show()
                                    //    count.text = StringUtils.formatDouble(0.0, "0.00")
                                    //    return@setOnDismissListener
                                    //}

                                    cell.dhPack = cell.pack
                                    val input = count.text.toString()
                                    var d = try {
                                        input.toDouble()
                                    } catch (e: NumberFormatException) {
                                        0.0
                                    }
                                    cell.tqty = d
                                    count.setBackgroundResource(R.drawable.shape_solid_f5f5f5_round_3)
                                    count.text = StringUtils.formatDouble(d, "0.00")

                                    calculatorCyl(cell, d)
                                    tvCyl.text = data.cyl.toInt().toString()

                                    var temp = ""
                                    if (d <= 0.0) {
                                        if (d < 0.0) {
                                            temp = ("请检查产品：" + cell.itemName
                                                    + ",必须输入有效的数字！")
                                        }
                                        reduce.isEnabled = false
                                    } else {
                                        reduce.isEnabled = true
                                    }

                                    //if (d >= cell.sy_opl_qty) {
                                    //    if (d > cell.sy_opl_qty) {
                                    //        temp = ("请检查产品：" + cell.itemName
                                    //                + ",不能超过最大订货量" + cell.sy_opl_qty
                                    //                + "! 您输入的数量为：" + d)
                                    //    }
                                    //    add.isEnabled = false
                                    //}

                                    if (cell.officeProduct30DSaleNum.toString().notNullAndEmpty()) {
                                        if (Arith.sub(
                                                Arith.mul(
                                                    cell.officeProduct30DSaleNum.toString(),
                                                    "2"
                                                ).toString(), d.toString()
                                            ) < 0 && cell.isShowAlert
                                        ) {
                                            /*
                                     cell.isShowAlert = false
                                    AlertDialog.Builder(context)
                                        .setMessage("该产品已经超过办事处销售数量的2倍，请谨慎订货！")
                                        .setPositiveButton("我知道了", null)
                                        .show()
                                     */
                                            MyToast.show("该产品已经超过办事处销售数量的2倍，请谨慎订货！")
                                        }
                                    }

                                    if (0.0 != cell.dhPack && 0.0 != d) {
                                        if (d % cell.dhPack != 0.0) {
                                            temp = ("请检查产品：" + cell.itemName
                                                    + ",数量必须是" + cell.dhPack + "倍数")
                                            data.tqty = data.tqty.toInt() / cell.dhPack
                                                .toInt() * cell.dhPack// 非法规格输入调整
                                            d = data.tqty
                                        }
                                        cell.amount =
                                            Arith.mul(d, cell.itemPrice)//价格一定要放在最后来算，因为前面的校验会改数量
                                    }

                                    if (!TextUtils.isEmpty(temp)) {
                                        //val builder = PublicConformTipDialog.Builder(context)
                                        //builder.setTitle("提示")
                                        //builder.setMessage(temp)
                                        //builder.setNegativeButton(
                                        //    "知道了并重新输入"
                                        //) { dialog, _ -> dialog.dismiss() }
                                        //builder.create().show()
                                        MyToast.show(temp)
                                        cell.isInvalid = true
                                        count.setTextColor(Color.RED)
                                    } else {
                                        cell.isInvalid = false
                                        add.isEnabled = true
                                        reduce.isEnabled = true
                                        reduce.setImageResource(R.mipmap.icon_shop_order_subtract)
                                        add.setImageResource(R.mipmap.icon_shop_order_add)
                                        count.setTextColor(Color.BLACK)
                                    }
                                    notifyPriceShow.invoke()
                                }
                            }
                    }
                } else {
                    // 当商品‘缺货‘时，这个商品不能增加和输入商品数量，加号和数量显示为灰色，且不可点击
                    count.setSelectAllOnFocus(false)
                    count.setOnClickListener(null)
                }
            }

        } else if (holder is OrderGoodsReasonHolder) {
            holder.apply {
                tvStockCheckReason.text = context.getString(R.string.order_goods_reason)
                etStockCheckTips.isFocusable = true
                etStockCheckTips.setHint(R.string.order_goods_reason_tip)
                etStockCheckTips.setText(mEntityCache?.reason)
                etStockCheckTips.addTextChangedListener(object : TextWatcher {
                    override fun beforeTextChanged(
                        s: CharSequence?,
                        start: Int,
                        count: Int,
                        after: Int
                    ) {
                    }

                    override fun onTextChanged(
                        s: CharSequence?,
                        start: Int,
                        before: Int,
                        count: Int
                    ) {
                    }

                    override fun afterTextChanged(s: Editable?) {
                        mEntityCache?.reason = s.toString()
                    }
                });
            }
        }
    }

    class OrderGoodsReasonHolder(view: View) : RecyclerView.ViewHolder(view) {
        val tvStockCheckReason =
            view.find<TextView>(R.id.tv_stock_check_reason)

        val etStockCheckTips =
            view.find<EditText>(R.id.et_stock_check_tips)
    }

    class OrderGoodsHolder(view: View) : RecyclerView.ViewHolder(view) {
        var name: TextView = view.find(R.id.tv_goods_name) as TextView
        var img: ImageView = view.find(R.id.iv_goods_img) as ImageView
        var unit: TextView = view.find(R.id.tv_goods_unit) as TextView
        var unitPrice: TextView = view.find(R.id.tv_goods_unit_price) as TextView

        var tvKucun: TextView = view.find(R.id.tv_kucun) as TextView
        var tvQuantityOrder: TextView = view.find(R.id.tv_quantity_order) as TextView
        var oeProDhQty: TextView = view.find(R.id.tv_oe_pro_dh_qty) as TextView
        var tvCyl: TextView = view.find(R.id.tv_cyl) as TextView

        var count: TextView = view.find(R.id.tv_goods_count_edit) as TextView
        var submitCount: TextView = view.find(R.id.tv_goods_already_market) as TextView
        var add: ImageButton = view.find(R.id.ib_goods_plus) as ImageButton
        var reduce: ImageButton = view.find(R.id.ib_goods_decrease) as ImageButton
    }

    private fun refreshOrderName(entity: DingHuoOplQtyEntity.DinghuoDetail): SpannableString {
        return if (entity.isShowImageTv) {
            SpannableString(entity.itemName + "img").apply {
                setSpan(
                    UnderlineSpan(),
                    0,
                    entity.itemName.length,
                    Spanned.SPAN_EXCLUSIVE_EXCLUSIVE
                )

                val drawable: Drawable? =
                    ContextCompat.getDrawable(context, R.mipmap.ic_picture_order)
                drawable?.let {
                    it.setBounds(0, 0, it.intrinsicWidth, it.intrinsicHeight)
                    setSpan(
                        ImageSpan(drawable),
                        this.length - 3,
                        this.length,
                        Spanned.SPAN_INCLUSIVE_EXCLUSIVE
                    )
                }

                setSpan(
                    StyleSpan(Typeface.BOLD),
                    0,
                    entity.itemName.length,
                    Spanned.SPAN_INCLUSIVE_EXCLUSIVE
                )

                setSpan(object : ClickableSpan() {
                    override fun onClick(v: View) {
                        imageShowDetail(v, entity)
                    }
                }, 0, this.length, Spanned.SPAN_INCLUSIVE_EXCLUSIVE)

                val colorSpan =
                    ForegroundColorSpan(context.resources.getColor(R.color.c_ffa019))
                setSpan(colorSpan, 0, entity.itemName.length, Spanned.SPAN_INCLUSIVE_EXCLUSIVE)
            }
        } else {
            SpannableString(entity.itemName).apply {

                setSpan(
                    StyleSpan(Typeface.BOLD),
                    0,
                    entity.itemName.length,
                    Spanned.SPAN_INCLUSIVE_EXCLUSIVE
                );
                val colorSpan =
                    ForegroundColorSpan(context.resources.getColor(R.color.common_txt_third_color))
                setSpan(colorSpan, 0, entity.itemName.length, Spanned.SPAN_INCLUSIVE_EXCLUSIVE)
            }
        }
    }

    /**
     * 显示弹窗显示商品图片
     */
    private fun imageShowDetail(
        v: View,
        dingHuoOplQtyEntity: DingHuoOplQtyEntity.DinghuoDetail
    ) {
        val content =
            LayoutInflater.from(context).inflate(R.layout.order_trade_popup_item, null)
        val imageView = content.findViewById(R.id.popup_order_trade_iv) as ImageView
        val tempW = DensityUtil.getScreenW(context) - 20
        Picasso.with(context).load(dingHuoOplQtyEntity.picUrl)
            .placeholder(R.drawable.img_loading)
            .resize(tempW, tempW).into(imageView)
        val pw = PopupWindow(
            content,
            WindowManager.LayoutParams.MATCH_PARENT,
            WindowManager.LayoutParams.MATCH_PARENT,
            true
        )
        pw.isFocusable = true
        pw.isOutsideTouchable = true
        pw.showAtLocation(v, Gravity.CENTER, 0, 0)
        (content.findViewById(R.id.popup_order_trade_root_ll) as LinearLayout).setOnClickListener {
            if (pw.isShowing) {
                pw.dismiss()
            }
        }
        val productNameIdTv = content.findViewById(R.id.product_name_id_tv) as TextView
        productNameIdTv.text =
            dingHuoOplQtyEntity.itemName + "(" + dingHuoOplQtyEntity.itemid + ")"
    }

    /**
     * 计算库存率
     */
    private fun calculatorCyl(data: DingHuoOplQtyEntity.DinghuoDetail, counts: Double): Double {
        // 库存率=（订货数量+（库存+在途））/最近30天用量*
        var cyl: Double
        if (data.lastMonth_qty.toDouble() == 0.0 || (counts + data.stock_Qty.toDouble()) == 0.0) {
            cyl = 0.0
        } else {
            try {
                cyl =
                    (data.tqty + data.stock_Qty.toDouble()) / data.lastMonth_qty.toDouble() * 30
            } catch (e: Exception) {
                cyl = 0.0
            }

        }
        data.cyl = cyl
        return cyl
    }


    fun refreshDataList(newList: List<DingHuoOplQtyEntity.DinghuoDetail>) {
        mOrderList.run {
            clear()
            addAll(newList)
        }
    }

    /**
     * 通过标签来过滤显示的列表（后来需求要分品牌了，所以加一个品牌区分）
     */
    fun notifyProByLabel(dataEntity: DingHuoOplQtyEntity.ResultInfo?, brand: Int, type: Int) {
        mHandler.removeCallbacksAndMessages(null)
        mProductType = type
        mOrderList.run {
            val allList = dataEntity?.list
            mEntityCache = dataEntity//传进来一份缓存起来，adapter里面要用到 maxStockLimit
            clear()
            if (allList.isNullOrEmpty()) {
                addAll(listOf())
            } else {
                addAll(if (type == -1) allList.filter { it.brandId == brand } else allList.filter { it.brandId == brand && it.type == type })
            }
        }
        notifyDataSetChanged()
    }
}