package com.wgmf.yxgj.module.business.managesales.service;

import android.text.TextUtils;
import android.util.Log;

import com.google.gson.Gson;
import com.wgmf.library.base.BaseRequest;
import com.wgmf.library.base.BaseResponse;
import com.wgmf.library.base.ResultData;
import com.wgmf.library.utils.BaseSingleton;
import com.wgmf.yxgj.base.BaseService;
import com.wgmf.yxgj.config.BusinessID;
import com.wgmf.yxgj.global.NetworkParams;

import java.lang.ref.WeakReference;

/**
 * 销售管理网络请求服务
 */
public class SalesManagerService extends BaseService {
    private static BaseSingleton<SalesManagerService, Void> mMainService = new BaseSingleton<SalesManagerService, Void>() {
        @Override
        protected SalesManagerService create(Void var1) {
            return new SalesManagerService();
        }
    };

    public static SalesManagerService getInstance() {
        return mMainService.get(null);
    }

    private SalesManagerService() {
    }

    /**
     * GET /saleforecast/getSaleForecastShop 获取销售预测门店
     */
    public void requestGetSaleForecastShop(final String yearMonth, final String saleOrgId,
                                           ResultData.BusinessCallback callback) {
        BaseRequest request = new BaseRequest();
        request.taskID = BusinessID.SalesManager.MSG_ON_GET_SALEFORECAST_SHOP;
        request.callback = new WeakReference<>(callback);
        request.url = NetworkParams.URL_GET_SALEFORECAST_SHOP + "?" + "yearMonth=" + yearMonth + "&saleOrgId=" + saleOrgId;
        Log.d(TAG, "请求地址：" + request.url);
        sendGetRequest(request);
    }

    /**
     * GET /saleforecast/getSaleForecastProductInfo 填写销售预测前查询产品相关信息
     */
    public void requestGetSaleForecastProductInfo(final String yearMonth, final String shopId, final String saleForecastFlag,
                                                  ResultData.BusinessCallback callback) {
        BaseRequest request = new BaseRequest();
        request.taskID = BusinessID.SalesManager.MSG_ON_GET_SALEFORECAST_PRODUCT_INFO;
        request.callback = new WeakReference<>(callback);
        request.url = NetworkParams.URL_GET_SALEFORECAST_PRODUCT_INFO + "?" + "yearMonth=" + yearMonth + "&shopId=" + shopId + "&saleForecastFlag=" + saleForecastFlag;
        Log.d(TAG, "请求地址：" + request.url);
        sendGetRequest(request);
    }

    /**
     * POST /productManagement/saveUpdateOrderGoodsAuditions 订货审核添加或修改
     */
    public void requestSaveSaleForecast(final String json,
                                        ResultData.BusinessCallback callback) {
        BaseRequest request = new BaseRequest();
        request.taskID = BusinessID.SalesManager.MSG_ON_SAVE_SALEFORECAST;
        request.callback = new WeakReference<>(callback);
        request.url = NetworkParams.URL_SAVE_SALEFORECAST;
        request.json = json;
        Log.d(TAG, "请求地址：" + request.url);
        sendPostJsonRequest(request);
    }

    /**
     * GET /saleforecast/getShopHistorySale 获取以往销售
     */
    public void requestGetShopHistorySale(final String shopId,
                                          ResultData.BusinessCallback callback) {
        BaseRequest request = new BaseRequest();
        request.taskID = BusinessID.SalesManager.MSG_ON_GET_SHOP_HISTORY_SALE;
        request.callback = new WeakReference<>(callback);
        request.url = NetworkParams.URL_GET_SHOPHISTORY_SALE + "?" + "shopId=" + shopId;
        Log.d(TAG, "请求地址：" + request.url);
        sendGetRequest(request);
    }

    /**
     * GET /saleforecast/getShopProductHistorySale 获取以往销售-单品销售
     */
    public void requestGetShopProductHistorySale(final String shopId, final String productNo,
                                                 ResultData.BusinessCallback callback) {
        BaseRequest request = new BaseRequest();
        request.taskID = BusinessID.SalesManager.MSG_ON_GET_SHOP_PRODUCT_HISTORY_SALE;
        request.callback = new WeakReference<>(callback);
        request.url = NetworkParams.URL_GET_SHOP_PRODUCT_HISTORY_SALE + "?" + "shopId=" + shopId + "&productNo=" + productNo;
        Log.d(TAG, "请求地址：" + request.url);
        sendGetRequest(request);
    }

    @Override
    protected void onTaskDone(ResultData data) {
        if (null != data) {
            final int id = data.taskID;
            switch (id) {
                case BusinessID.SalesManager.MSG_ON_GET_SALEFORECAST_SHOP:
                case BusinessID.SalesManager.MSG_ON_GET_SALEFORECAST_PRODUCT_INFO:
                case BusinessID.SalesManager.MSG_ON_SAVE_SALEFORECAST:
                case BusinessID.SalesManager.MSG_ON_GET_SHOP_HISTORY_SALE:
                case BusinessID.SalesManager.MSG_ON_GET_SHOP_PRODUCT_HISTORY_SALE: {
                    if (data.isSuccessed()) {
                        final String json = data.getInfo();
                        if (!TextUtils.isEmpty(json)) {
                            BaseResponse mBaseResponse = new Gson().fromJson(json, BaseResponse.class);
                            Log.d(TAG, "id:" + id + ";mBaseResponse=" + mBaseResponse.toString());
                            data.setResultCode(mBaseResponse.retCode);
                            data.setResultInfo(mBaseResponse.retInfo);
                        }
                    }
                    break;
                }
                default:
                    break;
            }
        }
    }
}