package com.wgmf.yxgj.module.business.managesales.ui;

import android.content.Context;
import android.support.v4.content.ContextCompat;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.BaseAdapter;
import android.widget.TextView;

import com.wgmf.library.utils.DateUtil;
import com.wgmf.library.utils.StringUtil;

import com.wgmf.yxgj.module.business.managesales.R;
import com.wgmf.yxgj.module.business.managesales.model.ShopProductHistorySaleEntity;

import java.util.Collections;
import java.util.Comparator;
import java.util.List;

/**
 * 销售预测产品明细适配器
 * 作者：xiep on 2017/3/16 13:42
 * 邮箱：2975837870@qq.com
 */
public class SaleForecastHistoryProductsAdapter extends BaseAdapter {
    private Context context;
    private List<ShopProductHistorySaleEntity> list;

    SaleForecastHistoryProductsAdapter(List<ShopProductHistorySaleEntity> list,
                                       Context context) {
        super();
        this.list = list;
        this.context = context;
        //对年月排序
        //1，年份小的排在最前
        sortYears(list);
        //2，年份相同，月份大的排在前面
        sortMonths(list);
    }

    private void sortYears(List<ShopProductHistorySaleEntity> list) {
        Collections.sort(list, new Comparator<ShopProductHistorySaleEntity>() {
            @Override
            public int compare(ShopProductHistorySaleEntity lhs,
                               ShopProductHistorySaleEntity rhs) {
                String lhsyearsMonths = lhs.getShopProductSaleMonth();
                int lhsyears = Integer.parseInt(lhsyearsMonths.substring(0, 4));
                String rhsyearsMonths = rhs.getShopProductSaleMonth();
                int rhsyears = Integer.parseInt(rhsyearsMonths.substring(0, 4));
                if (lhsyears > rhsyears) {
                    return -1;
                } else if (lhsyears == rhsyears) {
                    return 0;
                } else {
                    return 1;
                }
            }
        });
    }

    private void sortMonths(List<ShopProductHistorySaleEntity> list) {
        Collections.sort(list, new Comparator<ShopProductHistorySaleEntity>() {
                    @Override
                    public int compare(ShopProductHistorySaleEntity lhs,
                                       ShopProductHistorySaleEntity rhs) {
                        String lhsyearsMonths = lhs.getShopProductSaleMonth();
                        int lhsmonths = Integer.parseInt(lhsyearsMonths.substring(4, 6));
                        String rhsyearsMonths = rhs.getShopProductSaleMonth();
                        int rhsmonths = Integer.parseInt(rhsyearsMonths.substring(4, 6));
                        if (lhsmonths > rhsmonths) {
                            return -1;
                        } else if (lhsmonths == rhsmonths) {
                            return 0;
                        } else {
                            return 1;
                        }
                    }
                }
        );
    }

    @Override
    public int getCount() {
        return list == null ? 0 : list.size();
    }

    @Override
    public Object getItem(int position) {
        return list == null ? null : list.get(position);
    }

    @Override
    public long getItemId(int position) {
        return position;
    }

    @Override
    public View getView(final int position, View convertView, ViewGroup parent) {
        final ViewHolder viewHolder;
        if (convertView == null) {
            convertView = LayoutInflater.from(context).inflate(
                    R.layout.saleforcast_history_products_item, null);
            viewHolder = new ViewHolder();
            viewHolder.productSaleNumTitle = (TextView) convertView.findViewById(R.id.shop_history_product_sale_num_title_tv);
            viewHolder.productSaleNumValue = (TextView) convertView.findViewById(R.id.shop_history_product_sale_num_value_tv);
            convertView.setTag(viewHolder);
        } else {
            viewHolder = (ViewHolder) convertView.getTag();
        }


        if (list != null && !list.isEmpty()) {
            String currentyMonths = DateUtil.getFormatMonth("yyyyMM", 0);
            int currentYears = Integer.parseInt(currentyMonths.substring(0, 4));
            int currentMonths = Integer.parseInt(currentyMonths.substring(4, 6));
            String yearsMonths = list.get(position).getShopProductSaleMonth();
            int years = Integer.parseInt(yearsMonths.substring(0, 4));
            int months = Integer.parseInt(yearsMonths.substring(4, 6));

            String productSaleNumTitle = years + "年" + months + "月" + "销售数量";
            if (currentYears == years && currentMonths < months) {
                //如果查询年等于当前年，查询月大于当前月为下月预计销售
                productSaleNumTitle = "下月预计销售数量";
            } else if (currentYears == years && currentMonths == months) {
                //如果查询年月与当前年月相等为当前销售
                productSaleNumTitle = "当前月销售数量";
            } else if (currentYears > years && currentMonths == months) {
                //如果查询年小于当前年且月份相同为去年同期
                productSaleNumTitle = "去年同期销售数量";
                viewHolder.productSaleNumTitle.setTextColor(ContextCompat.getColor(context, R.color.red));
                viewHolder.productSaleNumValue.setTextColor(ContextCompat.getColor(context, R.color.red));
            }
            viewHolder.productSaleNumTitle.setText(productSaleNumTitle);
            double tempValue = StringUtil.toDouble(list.get(position).getShopProductSaleNum());
            viewHolder.productSaleNumValue.setText(StringUtil.formatDouble(tempValue, "0"));
        }
        return convertView;
    }

    class ViewHolder {
        TextView productSaleNumTitle;
        TextView productSaleNumValue;
    }
}