package com.wgmf.yxgj.module.business.managesales.ui;

import android.content.Context;
import android.support.v4.content.ContextCompat;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.BaseAdapter;
import android.widget.TextView;

import com.wgmf.library.utils.DateUtil;
import com.wgmf.library.utils.StringUtil;
import com.wgmf.yxgj.module.business.managesales.R;
import com.wgmf.yxgj.module.business.managesales.model.ShopHistorySaleEntity;

import java.util.Collections;
import java.util.Comparator;
import java.util.List;

/**
 * 作者：xiep on 2017/3/16 14:34
 * 邮箱：2975837870@qq.com
 */

public class SaleForecastHistoryShopAdapter extends BaseAdapter {
    private Context context;
    private List<ShopHistorySaleEntity> list;

    SaleForecastHistoryShopAdapter(List<ShopHistorySaleEntity> list,
                                   Context context) {
        super();
        this.list = list;
        this.context = context;

        //对年月排序
        //1，年份小的排在最前
        sortYears(list);
        //2，年份相同，月份大的排在前面
        sortMonths(list);
    }

    private void sortYears(List<ShopHistorySaleEntity> list) {
        Collections.sort(list, new Comparator<ShopHistorySaleEntity>() {
            @Override
            public int compare(ShopHistorySaleEntity lhs,
                               ShopHistorySaleEntity rhs) {
                String lhsyearsMonths = lhs.getShopHistorySaleMonth();
                int lhsyears = Integer.parseInt(lhsyearsMonths.substring(0, 4));
                String rhsyearsMonths = rhs.getShopHistorySaleMonth();
                int rhsyears = Integer.parseInt(rhsyearsMonths.substring(0, 4));
                if (lhsyears > rhsyears) {
                    return -1;
                } else if (lhsyears == rhsyears) {
                    return 0;
                } else {
                    return 1;
                }
            }
        });
    }

    private void sortMonths(List<ShopHistorySaleEntity> list) {
        Collections.sort(list, new Comparator<ShopHistorySaleEntity>() {
                    @Override
                    public int compare(ShopHistorySaleEntity lhs,
                                       ShopHistorySaleEntity rhs) {
                        String lhsyearsMonths = lhs.getShopHistorySaleMonth();
                        int lhsmonths = Integer.parseInt(lhsyearsMonths.substring(4, 6));
                        String rhsyearsMonths = rhs.getShopHistorySaleMonth();
                        int rhsmonths = Integer.parseInt(rhsyearsMonths.substring(4, 6));
                        if (lhsmonths > rhsmonths) {
                            return -1;
                        } else if (lhsmonths == rhsmonths) {
                            return 0;
                        } else {
                            return 1;
                        }
                    }
                }
        );
    }


    @Override
    public int getCount() {
        return list == null ? 0 : list.size();
    }

    @Override
    public Object getItem(int position) {
        return list == null ? null : list.get(position);
    }

    @Override
    public long getItemId(int position) {
        return position;
    }

    @Override
    public View getView(final int position, View convertView, ViewGroup parent) {
        final ViewHolder viewHolder;
        if (convertView == null) {
            convertView = LayoutInflater.from(context).inflate(R.layout.saleforcast_history_shop_item, null);
            viewHolder = new ViewHolder(convertView);

            convertView.setTag(viewHolder);
        } else {
            viewHolder = (ViewHolder) convertView.getTag();
        }
        if (list != null && !list.isEmpty()) {
            String currentyMonths = DateUtil.getFormatMonth("yyyyMM", 0);
            int currentYears = Integer.parseInt(currentyMonths.substring(0, 4));
            int currentMonths = Integer.parseInt(currentyMonths.substring(4, 6));
            String yearsMonths = list.get(position).getShopHistorySaleMonth();
            int years = Integer.parseInt(yearsMonths.substring(0, 4));
            int months = Integer.parseInt(yearsMonths.substring(4, 6));

            String productSaleNumTitle = years + "年" + months + "月销售额";
            if (currentYears > years && currentMonths == months) {
                //如果查询年小于当前年且月份相等为去年同期
                productSaleNumTitle = "去年同期销售额";
                viewHolder.saleamountTitle.setTextColor(ContextCompat.getColor(context, R.color.red));
                viewHolder.saleamountValue.setTextColor(ContextCompat.getColor(context, R.color.red));
            } else if (currentYears == years && currentMonths == months) {
                //如果查询年月与当前年月相等为当前销售
                productSaleNumTitle = "当前月销售额";
            }
            viewHolder.saleamountTitle.setText(productSaleNumTitle);
            double tempValue = StringUtil.toDouble(list.get(position).getShopHistorySaleAmount());
            viewHolder.saleamountValue.setText(StringUtil.formatDouble(tempValue, "0"));
        }
        return convertView;
    }

    class ViewHolder {
        TextView saleamountTitle;
        TextView saleamountValue;

        ViewHolder(View convertView) {
            saleamountTitle = (TextView) convertView.findViewById(R.id.shop_history_saleamount_title_tv);
            saleamountValue = (TextView) convertView.findViewById(R.id.shop_history_saleamount_value_tv);
        }
    }
}