package com.wgmf.yxgj.module.business.managestaff.ui.staffdistribute

import android.os.Bundle
import android.support.v4.content.ContextCompat
import android.util.Log
import android.view.View
import android.widget.*
import com.google.gson.Gson
import com.wgmf.library.base.BaseResponse
import com.wgmf.library.base.ResultData
import com.wgmf.yxgj.base.BaseParentAct
import com.wgmf.yxgj.config.BusinessID
import com.wgmf.yxgj.global.AppConstants
import com.wgmf.yxgj.global.ConstantParams
import com.wgmf.yxgj.module.business.managestaff.R
import com.wgmf.yxgj.module.business.managestaff.model.EmployeeDissmissInfoEntity
import com.wgmf.yxgj.module.business.managestaff.model.ResignAssignmentReviewDetailsRequest
import com.wgmf.yxgj.module.business.managestaff.service.StaffManageService
import com.wgmf.yxgj.utils.MyToast
import com.wgmf.yxgj.utils.convertDefaultValue
import com.wgmf.yxgj.utils.isNullOrEmpty

/**
 * 离职审核详情
 * @author LW
 */
class ResignAssignmentReviewDetailsActivity : BaseParentAct() {

    private val mEmployeeDissmissBean: EmployeeDissmissInfoEntity.EmployeeDissmissPage.EmployeeDissmissBean? by lazy {
        intent.getSerializableExtra(AppConstants.ExtraKeys.EMPLOYEE_DISSMISS_REVIEW) as EmployeeDissmissInfoEntity.EmployeeDissmissPage.EmployeeDissmissBean?
    }

    private var mReviewDetailsTurnDownReasonEt: EditText? = null

    private var mAuditStatus: Int = ConstantParams.CONSTANT_STARTS_2

    private var mId: Int = -1

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        setContentView(R.layout.activity_resign_assignment_review_details)
        initTitle()
        initView()
    }

    override fun initTitle() {
        super.initTitle()
        homeTitleText.text = getString(R.string.employee_dissmiss_review)
        homeTitleBackLl.visibility = View.VISIBLE
    }

    private fun initView() {
        mEmployeeDissmissBean?.let {
            mId = it.id
            findViewById<TextView>(R.id.review_details_create_time_tv).text = it.createTime

            if (it.auditStatus == ConstantParams.CONSTANT_STARTS_1) {  //1-待审核,2-审核通过,3-审核驳回
                findViewById<TextView>(R.id.review_details_status_tv).apply {
                    text = getString(R.string.resign_records_treat_review)
                    setTextColor(ContextCompat.getColor(mContext, R.color.important_txt_four_color))
                }
                //审核
            } else if (it.auditStatus == ConstantParams.CONSTANT_STARTS_2) {
                findViewById<TextView>(R.id.review_details_status_tv).apply {
                    text = getString(R.string.resign_records_review_pass)
                    setTextColor(
                        ContextCompat.getColor(
                            mContext,
                            R.color.important_txt_second_color
                        )
                    )
                }
            } else if (it.auditStatus == ConstantParams.CONSTANT_STARTS_3) {
                findViewById<TextView>(R.id.review_details_status_tv).apply {
                    text = getString(R.string.resign_records_turn_down_apply)
                    setTextColor(ContextCompat.getColor(mContext, R.color.important_txt_five_color))
                }
                //重新申请
            } else {
                findViewById<TextView>(R.id.resign_records_item_status_tv).visibility = View.GONE
            }

            findViewById<TextView>(R.id.review_details_title_tv).text =
                getString(R.string.resign_records_exit_consultant)

            findViewById<TextView>(R.id.review_details_name_tv).text =
                getString(
                    R.string.resign_records_consultant_name,
                    it.staffName.convertDefaultValue()
                )
            findViewById<TextView>(R.id.review_details_store_tv).text =
                getString(
                    R.string.resign_records_store,
                    it.shopNames.convertDefaultValue()
                )

            findViewById<TextView>(R.id.review_details_client_number_tv).text =
                getString(
                    R.string.employee_dissmiss_clients_number,
                    it.customerNum.toString()
                )

            findViewById<TextView>(R.id.review_details_group_number_tv).text =
                getString(
                    R.string.employee_dissmiss_group_number,
                    it.groupNum
                )
            //1-指定分配人员, 2-自动分配 3,不分配
            if (it.allocationType == ConstantParams.CONSTANT_STARTS_1) {
                findViewById<TextView>(R.id.review_details_distribute_type_tv).text =
                    getString(R.string.resign_records_type_designated_assignee)
            } else if (it.allocationType == ConstantParams.CONSTANT_STARTS_2) {
                findViewById<TextView>(R.id.review_details_distribute_type_tv).text =
                    getString(R.string.resign_records_type_automatic_allocation)
            } else if (it.allocationType == ConstantParams.CONSTANT_STARTS_3) {
                findViewById<TextView>(R.id.review_details_distribute_type_tv).text =
                    getString(R.string.resign_records_type_not_assigned)
            } else {
                findViewById<TextView>(R.id.review_details_distribute_type_tv).visibility =
                    View.GONE
            }

            if (it.allocationType != ConstantParams.CONSTANT_STARTS_3) {
                findViewById<TextView>(R.id.review_details_distribute_target_tv).apply {
                    text = getString(
                        R.string.resign_records_distribute_target,
                        it.receiverName.convertDefaultValue()
                    )
                    visibility = View.VISIBLE
                }
            }
        }

        mReviewDetailsTurnDownReasonEt =
            findViewById(R.id.review_details_turn_down_reason_et)
        findViewById<RadioGroup>(R.id.review_details_review_status_rg).setOnCheckedChangeListener { _, checkedId ->
            if (checkedId == R.id.review_details_turn_down_rb) {  //驳回
                mReviewDetailsTurnDownReasonEt?.visibility = View.VISIBLE
                mAuditStatus = ConstantParams.CONSTANT_STARTS_3
            } else {  //通过
                mReviewDetailsTurnDownReasonEt?.visibility = View.GONE
                mAuditStatus = ConstantParams.CONSTANT_STARTS_2
            }
        }

        findViewById<Button>(R.id.review_details_confirm_btn).setOnClickListener {
            submitEmployeeDimissionAudit()
        }

    }


    /**
     * 提交员工离职审核
     */
    private fun submitEmployeeDimissionAudit() {
        userInfo?.let {
            showDialog()
            var rejectReason = ""
            if (mAuditStatus == ConstantParams.CONSTANT_STARTS_3) {
                rejectReason = mReviewDetailsTurnDownReasonEt?.text?.trim().toString()
                if (rejectReason.isNullOrEmpty()) {
                    dismissDialog()
                    MyToast.show(getString(R.string.employee_dissmiss_turn_down_reason_tip))
                    return
                }
            }

            val json =
                Gson().toJson(ResignAssignmentReviewDetailsRequest(it.staffId, mAuditStatus, mId, rejectReason))
            StaffManageService.getInstance().requestEmployeeDimissionAudit(
                json,
                this@ResignAssignmentReviewDetailsActivity
            )
        }
    }

    override fun onBusinessResultAtMainThread(result: ResultData?) {
        super.onBusinessResultAtMainThread(result)
        dismissDialog()
        result?.let {
            if (it.taskID == BusinessID.StaffManage.MSG_ON_EMPLOYEE_DIMISSION_AUDIT) {
                if (!isFinishing && it.isSuccessed) {
                    val entity =
                        Gson().fromJson(it.info, BaseResponse::class.java)
                    Log.d(TAG, "BaseResponse=$entity")
                    if (ConstantParams.CONSTANT_PARAMS_0 == entity.retCode) {
                        finish()
                    } else {
                        showMsg(entity.retInfo)
                    }
                } else {
                    showMsg(getString(R.string.request_data_fail))
                }
            }
        }
    }
}