package com.wgmf.yxgj.module.business.managestaff.ui.staffdistribute

import android.content.Intent
import android.os.Bundle
import android.support.v7.widget.LinearLayoutManager
import android.support.v7.widget.RecyclerView
import android.util.Log
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import android.widget.*
import com.google.gson.Gson
import com.scwang.smartrefresh.layout.SmartRefreshLayout
import com.wgmf.library.base.ResultData
import com.wgmf.yxgj.base.BaseParentFra
import com.wgmf.yxgj.config.BusinessID
import com.wgmf.yxgj.dialog.LoadWaitDominator
import com.wgmf.yxgj.global.AppConstants
import com.wgmf.yxgj.global.ConstantParams
import com.wgmf.yxgj.module.business.managestaff.R
import com.wgmf.yxgj.module.business.managestaff.model.QiWeiCustomersAssignmentRecordsEntity
import com.wgmf.yxgj.module.business.managestaff.model.ResignOrWorkingAssignmentReviewRequest
import com.wgmf.yxgj.module.business.managestaff.service.StaffManageService
import com.wgmf.yxgj.module.business.managestaff.ui.staffdistribute.adapter.ResignOrWorkingAssignmentReviewListAdapter
import com.wgmf.yxgj.module.business.managestaff.ui.staffdistribute.working.QiWeiCustomersAssignmentInfoActivity
import com.wgmf.yxgj.utils.DensityUtil
import com.wgmf.yxgj.utils.isNotNullOrSize
import com.wgmf.yxgj.widgets.decoration.SpacesItemDecoration

/**
 * 在职分配审核/离职分配审核页面
 * @author LW
 */
class ResignOrWorkingAssignmentReviewFragment : BaseParentFra() {

    private var mPublicListViewRv: RecyclerView? = null

    private var mPublicRefreshView: SmartRefreshLayout? = null

    private var mResignOrWorkingAssignmentReviewListAdapter: ResignOrWorkingAssignmentReviewListAdapter? =
        null

    private var mResignOrWorkingAssignmentReviewLists: MutableList<QiWeiCustomersAssignmentRecordsEntity
    .QiWeiCustomersAssignmentRecordsPage.QiWeiCustomersAssignmentRecordsBean> =
        mutableListOf()

    /**
     * 当前页码
     */
    private var mNextPage: Int = 1

    lateinit var mLoadWait: LoadWaitDominator

    private lateinit var mView: View

    private var mStaffStatus: Int = -1

    override fun onCreateView(
        inflater: LayoutInflater,
        container: ViewGroup?,
        savedInstanceState: Bundle?
    ): View {
        mView = inflater.inflate(R.layout.public_page_list_content_view, container, false).apply {
            // 防止点击穿透，底层的fragment响应上层点击触摸事件
            isClickable = true
        }
        return mView
    }

    override fun onActivityCreated(savedInstanceState: Bundle?) {
        super.onActivityCreated(savedInstanceState)
        initView()
    }


    private fun initView() {
        arguments?.let {
            mStaffStatus = it.getInt(AppConstants.ExtraKeys.RESIGN_OR_WORKING_STAFF_STATUS, -1)
        }

        mLoadWait =
            LoadWaitDominator(mContext, mView.findViewById(R.id.public_container_fl)).apply {
                setStatusImg(R.drawable.ic_msg_empty_common)
            }
        mPublicRefreshView =
            mView.findViewById<SmartRefreshLayout>(R.id.public_refresh_view).apply {
                //刷新
                setOnRefreshListener {
                    queryEmployeeCustomerAllocationAuditPageList(1)
                }
                //加载更多
                setOnLoadmoreListener {
                    queryEmployeeCustomerAllocationAuditPageList(mNextPage)
                }
            }

        mResignOrWorkingAssignmentReviewListAdapter =
            ResignOrWorkingAssignmentReviewListAdapter(mResignOrWorkingAssignmentReviewLists)
        mPublicListViewRv = mView.findViewById<RecyclerView>(R.id.public_list_view_rv).apply {
            visibility = View.VISIBLE
            layoutManager = LinearLayoutManager(mContext)
            adapter = mResignOrWorkingAssignmentReviewListAdapter
            addItemDecoration(
                SpacesItemDecoration(
                    DensityUtil.dip2px(mContext, 15f),
                    adapter!!.itemCount,
                    true
                )
            )

        }

        mResignOrWorkingAssignmentReviewListAdapter?.setOnItemChildClickListener { adapter, view, pos ->
            val bean =
                adapter?.getItem(pos) as QiWeiCustomersAssignmentRecordsEntity
                .QiWeiCustomersAssignmentRecordsPage.QiWeiCustomersAssignmentRecordsBean
            if (view.id == R.id.qiwei_customers_records_item_review_tv) {   //审核
                jumpQiWeiCustomersAssignmentInfoActivity(
                    bean,
                    QiWeiCustomersAssignmentInfoActivity.WORKING_ASSIGNMENT_REVIEW_CONFIRM
                )
            } else { //查看分配信息
                jumpQiWeiCustomersAssignmentInfoActivity(
                    bean,
                    QiWeiCustomersAssignmentInfoActivity.WORKING_ASSIGNMENT_REVIEW
                )
            }

        }
        mPublicRefreshView?.autoRefresh()
    }

    override fun onResume() {
        super.onResume()
        mPublicRefreshView?.autoRefresh()
    }

    /**
     * 跳转到 QiWeiCustomersAssignmentInfoActivity
     */
    private fun jumpQiWeiCustomersAssignmentInfoActivity(
        bean: QiWeiCustomersAssignmentRecordsEntity.QiWeiCustomersAssignmentRecordsPage.QiWeiCustomersAssignmentRecordsBean,
        type: Int
    ) {
        startActivity(Intent(mContext, QiWeiCustomersAssignmentInfoActivity::class.java).apply {
            putExtra(AppConstants.ExtraKeys.QIWEI_CUSTOMERS_ASSIGNMENT_RECORDS, bean)
            putExtra(
                AppConstants.ExtraKeys.QIWEI_CUSTOMERS_ASSIGNMENT_INFO_TYPE,
                type
            )
            putExtra(AppConstants.ExtraKeys.QIWEI_CUSTOMERS_ASSIGNMENT_ID, bean.id)
        })
    }

    /**
     * 分页查询员工客户分配审核列表
     */
    private fun queryEmployeeCustomerAllocationAuditPageList(page: Int) {
        userInfo?.let {
            val json = Gson().toJson(
                ResignOrWorkingAssignmentReviewRequest(
                    it.level,
                    it.organizationId, mStaffStatus,
                    page
                )
            )
            StaffManageService.getInstance()
                .requestEmployeeCustomerAllocationAuditPageList(
                    json,
                    this@ResignOrWorkingAssignmentReviewFragment
                )
        }
    }

    override fun onBusinessResultAtMainThread(result: ResultData?) {
        super.onBusinessResultAtMainThread(result)
        mLoadWait.dismissAll()
        mPublicRefreshView?.finishRefresh()
        mPublicRefreshView?.finishLoadmore()
        result?.let {
            if (it.taskID == BusinessID.StaffManage.MSG_ON_EMPLOYEE_CUSTOMER_ALLOCATION_AUDIT_PAGE_LIS) {
                if (it.isSuccessed) {
                    val entity =
                        Gson().fromJson(it.info, QiWeiCustomersAssignmentRecordsEntity::class.java)
                    Log.d(TAG, "QiWeiCustomersAssignmentRecordsEntity=$entity")
                    if (ConstantParams.CONSTANT_PARAMS_0 == entity.retCode) {
                        val pageData = entity.payload
                        if (pageData.pages == ConstantParams.CONSTANT_STARTS_0) {
                            mLoadWait.showNoData(R.string.no_record)
                            return
                        }
                        if (pageData.page <= pageData.pages) {
                            if (pageData.page == ConstantParams.CONSTANT_STARTS_1) {
                                refreshDataToView(pageData.data, pageData.total)
                            } else {
                                loadMoreDateToView(pageData.data)
                            }
                            this.mNextPage = pageData.page + 1
                        } else {
                            mPublicRefreshView?.resetNoMoreData()
                        }
                    } else {
                        mLoadWait.show(entity.retInfo)
                    }
                } else {
                    mLoadWait.showNetError()
                }
            }
        }
    }

    /**
     * 刷新数据更新到View
     */
    private fun refreshDataToView(
        list: List<QiWeiCustomersAssignmentRecordsEntity.QiWeiCustomersAssignmentRecordsPage.QiWeiCustomersAssignmentRecordsBean>?,
        total: Int
    ) {
        if (activity != null && activity is ResignOrWorkingAssignmentReviewActivity) {
            if (mStaffStatus == ConstantParams.CONSTANT_STARTS_0) {
                (activity as ResignOrWorkingAssignmentReviewActivity).updateTitle( ConstantParams.CONSTANT_STARTS_1, total)
            } else if (
                mStaffStatus == ConstantParams.CONSTANT_STARTS_1) {
                (activity as ResignOrWorkingAssignmentReviewActivity).updateTitle( ConstantParams.CONSTANT_STARTS_2, total)
            }

        }
        if (list.isNotNullOrSize()) {
            mResignOrWorkingAssignmentReviewLists.clear()
            mResignOrWorkingAssignmentReviewLists.addAll(list!!)
            mResignOrWorkingAssignmentReviewListAdapter?.notifyDataSetChanged()
        } else {
            mLoadWait.showNoData(R.string.no_record)
        }
    }

    /**
     * 读取更多数据更新到View
     */
    private fun loadMoreDateToView(list: List<QiWeiCustomersAssignmentRecordsEntity.QiWeiCustomersAssignmentRecordsPage.QiWeiCustomersAssignmentRecordsBean>?) {
        if (list.isNotNullOrSize()) {
            val position = mResignOrWorkingAssignmentReviewLists.size
            mResignOrWorkingAssignmentReviewLists.addAll(list!!)
            mResignOrWorkingAssignmentReviewListAdapter?.notifyItemInserted(position)
        }
    }
}