package com.wgmf.yxgj.module.business.managestaff.ui.staffdistribute

import android.content.Intent
import android.os.Bundle
import android.support.v7.widget.LinearLayoutManager
import android.support.v7.widget.RecyclerView
import android.util.Log
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import android.widget.*
import com.google.gson.Gson
import com.scwang.smartrefresh.layout.SmartRefreshLayout
import com.wgmf.library.base.ResultData
import com.wgmf.yxgj.base.BaseParentFra
import com.wgmf.yxgj.config.BusinessID
import com.wgmf.yxgj.dialog.LoadWaitDominator
import com.wgmf.yxgj.global.AppConstants
import com.wgmf.yxgj.global.ConstantParams
import com.wgmf.yxgj.module.business.managestaff.R
import com.wgmf.yxgj.module.business.managestaff.model.EmployeeDissmissInfoEntity
import com.wgmf.yxgj.module.business.managestaff.model.ResignReviewRequest
import com.wgmf.yxgj.module.business.managestaff.service.StaffManageService
import com.wgmf.yxgj.module.business.managestaff.ui.staffdistribute.adapter.ResignReviewListAdapter
import com.wgmf.yxgj.utils.DensityUtil
import com.wgmf.yxgj.utils.isNotNullOrSize
import com.wgmf.yxgj.widgets.decoration.SpacesItemDecoration

/**
 * 离职审核页面
 * @author LW
 */
class ResignReviewFragment : BaseParentFra() {

    private var mPublicListViewRv: RecyclerView? = null

    private var mPublicRefreshView: SmartRefreshLayout? = null

    private var mResignAssignmentReviewListAdapter: ResignReviewListAdapter? = null

    private var mResignReviewLists: MutableList<EmployeeDissmissInfoEntity.EmployeeDissmissPage.EmployeeDissmissBean> =
        mutableListOf()

    /**
     * 当前页码
     */
    private var mNextPage: Int = 1

    lateinit var mLoadWait: LoadWaitDominator

    private lateinit var mView: View

    override fun onCreateView(
        inflater: LayoutInflater,
        container: ViewGroup?,
        savedInstanceState: Bundle?
    ): View {
        mView = inflater.inflate(R.layout.public_page_list_content_view, container, false).apply {
            // 防止点击穿透，底层的fragment响应上层点击触摸事件
            isClickable = true
        }
        return mView
    }

    override fun onActivityCreated(savedInstanceState: Bundle?) {
        super.onActivityCreated(savedInstanceState)
        initView()
    }

    private fun initView() {
        mLoadWait =
            LoadWaitDominator(mContext, mView.findViewById(R.id.public_container_fl)).apply {
                setStatusImg(R.drawable.ic_msg_empty_common)
            }
        mPublicRefreshView =
            mView.findViewById<SmartRefreshLayout>(R.id.public_refresh_view).apply {
                //刷新
                setOnRefreshListener {
                    queryEmployeeDimissionPageList(1)
                }
                //加载更多
                setOnLoadmoreListener {
                    queryEmployeeDimissionPageList(mNextPage)
                }
            }

        mResignAssignmentReviewListAdapter =
            ResignReviewListAdapter(mResignReviewLists)
        mPublicListViewRv = mView.findViewById<RecyclerView>(R.id.public_list_view_rv).apply {
            visibility = View.VISIBLE
            layoutManager = LinearLayoutManager(mContext)
            adapter = mResignAssignmentReviewListAdapter
            addItemDecoration(
                SpacesItemDecoration(
                    DensityUtil.dip2px(mContext, 15f),
                    adapter!!.itemCount,
                    true
                )
            )

        }

        mResignAssignmentReviewListAdapter?.setOnItemChildClickListener { adapter, view, pos ->
            val bean =
                adapter?.getItem(pos) as EmployeeDissmissInfoEntity.EmployeeDissmissPage.EmployeeDissmissBean
            if (bean.auditStatus == ConstantParams.CONSTANT_STARTS_1) {
                jumpEmployeeDimissionReviewDetailsActivity(bean)
            }
        }
        mPublicRefreshView?.autoRefresh()
    }

    override fun onResume() {
        super.onResume()
        mPublicRefreshView?.autoRefresh()
    }

    /**
     * 跳转到 EmployeeDimissionReviewDetailsActivity
     */
    private fun jumpEmployeeDimissionReviewDetailsActivity(bean: EmployeeDissmissInfoEntity.EmployeeDissmissPage.EmployeeDissmissBean) {
        val intent = Intent(mContext, ResignAssignmentReviewDetailsActivity::class.java)
        intent.putExtra(AppConstants.ExtraKeys.EMPLOYEE_DISSMISS_REVIEW, bean)
        startActivity(intent)
    }

    /**
     * 分页查询员工离职记录列表
     */
    private fun queryEmployeeDimissionPageList(page: Int) {
        userInfo?.let {
            val json = Gson().toJson(
                ResignReviewRequest(
                    it.staffId,
                    it.level,
                    it.organizationId,
                    page
                )
            )
            StaffManageService.getInstance()
                .requestEmployeeDimissionAuditPageList(
                    json,
                    this@ResignReviewFragment
                )
        }
    }

    override fun onBusinessResultAtMainThread(result: ResultData?) {
        super.onBusinessResultAtMainThread(result)
        mLoadWait.dismissAll()
        mPublicRefreshView?.finishRefresh()
        mPublicRefreshView?.finishLoadmore()
        result?.let {
            if (it.taskID == BusinessID.StaffManage.MSG_ON_EMPLOYEE_DIMISSION_AUDIT_PAGE_LIST) {
                if (it.isSuccessed) {
                    val entity = Gson().fromJson(it.info, EmployeeDissmissInfoEntity::class.java)
                    Log.d(TAG, "EmployeeDissmissInfoEntity=$entity")
                    if (ConstantParams.CONSTANT_PARAMS_0 == entity.retCode) {
                        val pageData = entity.payload
                        if (pageData.pages == ConstantParams.CONSTANT_STARTS_0) {
                            mLoadWait.showNoData(R.string.no_record)
                            return
                        }
                        if (pageData.page <= pageData.pages) {
                            if (pageData.page == ConstantParams.CONSTANT_STARTS_1) {
                                refreshDataToView(pageData.data, pageData.total)
                            } else {
                                loadMoreDateToView(pageData.data)
                            }
                            this.mNextPage = pageData.page + 1
                        } else {
                            mPublicRefreshView?.resetNoMoreData()
                        }
                    } else {
                        mLoadWait.show(entity.retInfo)
                    }
                } else {
                    mLoadWait.showNetError()
                }
            }
        }
    }

    /**
     * 刷新数据更新到View
     */
    private fun refreshDataToView(
        list: List<EmployeeDissmissInfoEntity.EmployeeDissmissPage.EmployeeDissmissBean>?,
        total: Int
    ) {
        if (activity != null && activity is ResignOrWorkingAssignmentReviewActivity) {
            (activity as ResignOrWorkingAssignmentReviewActivity).updateTitle(0, total)
        }
        if (list.isNotNullOrSize()) {
            mResignReviewLists.clear()
            mResignReviewLists.addAll(list!!)
            mResignAssignmentReviewListAdapter?.notifyDataSetChanged()
        } else {
            mLoadWait.showNoData(R.string.no_record)
        }
    }

    /**
     * 读取更多数据更新到View
     */
    private fun loadMoreDateToView(list: List<EmployeeDissmissInfoEntity.EmployeeDissmissPage.EmployeeDissmissBean>?) {
        if (list.isNotNullOrSize()) {
            val position = mResignReviewLists.size
            mResignReviewLists.addAll(list!!)
            mResignAssignmentReviewListAdapter?.notifyItemInserted(position)
        }
    }
}