package com.wgmf.yxgj.module.business.managestaff.ui.staffdistribute.working

import android.graphics.Typeface
import android.os.Bundle
import android.support.v4.content.ContextCompat
import android.support.v7.widget.LinearLayoutManager
import android.support.v7.widget.RecyclerView
import android.util.Log
import android.view.View
import android.widget.*
import com.chad.library.adapter.base.BaseQuickAdapter
import com.google.gson.Gson
import com.wgmf.library.base.BaseResponse
import com.wgmf.library.base.ResultData
import com.wgmf.yxgj.base.BaseParentAct
import com.wgmf.yxgj.config.BusinessID
import com.wgmf.yxgj.dialog.LoadWaitDominator
import com.wgmf.yxgj.dialog.PublicEditChooseDialog
import com.wgmf.yxgj.global.AppConstants
import com.wgmf.yxgj.global.ConstantParams
import com.wgmf.yxgj.module.business.managestaff.R
import com.wgmf.yxgj.module.business.managestaff.model.*
import com.wgmf.yxgj.module.business.managestaff.service.StaffManageService
import com.wgmf.yxgj.module.business.managestaff.ui.staffdistribute.adapter.QiWeiCustomersAssignmentInfoListAdapter
import com.wgmf.yxgj.utils.isNotNullOrSize
import com.wgmf.yxgj.widgets.decoration.DividerItemDecoration

/**
 *  企微顾客分配信息
 * @author LW
 */
class QiWeiCustomersAssignmentInfoActivity : BaseParentAct() {

    private var mPublicListViewRv: RecyclerView? = null

    private var mContentConfirmLl: LinearLayout? = null

    private var mQiWeiCustomersAssignmentInfoListAdapter: QiWeiCustomersAssignmentInfoListAdapter? =
        null

    lateinit var mLoadWait: LoadWaitDominator

    private val mQiWeiCustomersAssignmentRecordsBean: QiWeiCustomersAssignmentRecordsEntity
    .QiWeiCustomersAssignmentRecordsPage.QiWeiCustomersAssignmentRecordsBean? by lazy {
        val bean =
            intent.getSerializableExtra(AppConstants.ExtraKeys.QIWEI_CUSTOMERS_ASSIGNMENT_RECORDS)
        if (bean != null) {
            return@lazy bean as QiWeiCustomersAssignmentRecordsEntity
            .QiWeiCustomersAssignmentRecordsPage.QiWeiCustomersAssignmentRecordsBean?
        }
        return@lazy null
    }

    private val mQiWeiCustomersAssignmentInfoType: Int by lazy {
        intent.getIntExtra(AppConstants.ExtraKeys.QIWEI_CUSTOMERS_ASSIGNMENT_INFO_TYPE, 1)
    }

    private val mId: Int by lazy {
        intent.getIntExtra(AppConstants.ExtraKeys.QIWEI_CUSTOMERS_ASSIGNMENT_ID, -1)
    }

    companion object {
        /**
         * 在职分配记录
         */
        const val WORKING_ASSIGNMENT_RECORDS: Int = 1

        /**
         * 在职分配审核
         */
        const val WORKING_ASSIGNMENT_REVIEW: Int = 2

        /**
         * 在职分配审核提交
         */
        const val WORKING_ASSIGNMENT_REVIEW_CONFIRM: Int = 3
    }


    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        setContentView(R.layout.public_list_view)
        initTitle()
        initView()
    }

    override fun initTitle() {
        super.initTitle()
        when (mQiWeiCustomersAssignmentInfoType) {
            WORKING_ASSIGNMENT_REVIEW_CONFIRM -> {
                homeTitleText.text =
                    mContext.getString(R.string.qiwei_customers_assignment_review_working_assignment_review)
            }
            else -> {
                homeTitleText.text = mContext.getString(R.string.qiwei_customers_assignment_info)
            }
        }

        homeTitleBackLl.visibility = View.VISIBLE
    }


    private fun initView() {
        mLoadWait = LoadWaitDominator(mContext, findViewById(R.id.public_container_fl)).apply {
            setStatusImg(R.drawable.ic_msg_empty_common)
        }

        findViewById<TextView>(R.id.onclick_name).apply {
            if (WORKING_ASSIGNMENT_RECORDS == mQiWeiCustomersAssignmentInfoType) {
                text = mContext.getString(
                    R.string.qiwei_customers_assignment_review_transfer_friends,
                    mQiWeiCustomersAssignmentRecordsBean?.customerNum
                )
            } else {
                text = mContext.getString(
                    R.string.qiwei_customers_assignment_info_assignment_friends,
                    mQiWeiCustomersAssignmentRecordsBean?.customerNum
                )
            }


            visibility = View.VISIBLE
            typeface = Typeface.defaultFromStyle(Typeface.BOLD)
        }
        findViewById<TextView>(R.id.onclick_title).apply {
            var inheritedNum = 0
            mQiWeiCustomersAssignmentRecordsBean?.allocationCustomerList?.forEach {
                if (it.status == ConstantParams.CONSTANT_STARTS_2) {
                    inheritedNum++
                }
            }

            typeface = Typeface.defaultFromStyle(Typeface.BOLD)
            visibility = View.VISIBLE
            if (WORKING_ASSIGNMENT_RECORDS == mQiWeiCustomersAssignmentInfoType) {
                text = mContext.getString(
                    R.string.qiwei_customers_assignment_info_assigned_num,
                    inheritedNum
                )
            } else if (WORKING_ASSIGNMENT_REVIEW == mQiWeiCustomersAssignmentInfoType) {
                text = mContext.getString(
                    R.string.qiwei_customers_assignment_review_inherited,
                    inheritedNum
                )
            } else {
                visibility = View.GONE
            }
        }

        val allocationCustomerList =
            mQiWeiCustomersAssignmentRecordsBean?.allocationCustomerList ?: mutableListOf()
        if (allocationCustomerList.isNotNullOrSize()) {
            mLoadWait.dismissAll()
            mQiWeiCustomersAssignmentInfoListAdapter =
                QiWeiCustomersAssignmentInfoListAdapter(
                    allocationCustomerList,
                    mQiWeiCustomersAssignmentInfoType
                )
            findViewById<ListView>(R.id.public_list_view_lv).visibility = View.GONE
            mPublicListViewRv = findViewById<RecyclerView>(R.id.public_list_view_rv).apply {
                visibility = View.VISIBLE
                layoutManager = LinearLayoutManager(mContext)
                adapter = mQiWeiCustomersAssignmentInfoListAdapter
                addItemDecoration(
                    DividerItemDecoration(
                        DividerItemDecoration.HORIZONTAL_LIST,
                        1,
                        ContextCompat.getColor(mContext, R.color.divider_line)
                    )
                )

            }
            BaseQuickAdapter.OnItemClickListener { adapter, view, pos -> //跳转到任务列表详情
            }.also { mQiWeiCustomersAssignmentInfoListAdapter?.onItemClickListener = it }

        } else {
            mLoadWait.showNoData()
        }

        mContentConfirmLl = findViewById(R.id.report_content_confirm_ll)
        if (mQiWeiCustomersAssignmentInfoType == WORKING_ASSIGNMENT_REVIEW_CONFIRM) {
            mContentConfirmLl?.visibility = View.VISIBLE
            findViewById<Button>(R.id.report_content_confirm_btn).setOnClickListener {
                showEmployeeCustomerAllocationAuditDialog()
            }
        } else {
            mContentConfirmLl?.visibility = View.GONE
        }
    }

    /**
     * 员工客户分配审核
     */
    private fun submitEmployeeCustomerAllocationAudit(auditStatus: Int, rejectReason: String?) {
        userInfo?.let {
            showDialog()
            val json = Gson().toJson(
                WorkingAssignmentReviewSubmitRequest(
                    mId, it.staffId,
                    auditStatus, rejectReason
                )
            )
            StaffManageService.getInstance()
                .requestEmployeeCustomerAllocationAudit(
                    json,
                    this@QiWeiCustomersAssignmentInfoActivity
                )
        }
    }


    /**
     * 显示审核对话框
     */
    private fun showEmployeeCustomerAllocationAuditDialog() {
        val builder = PublicEditChooseDialog.Builder(this)
        builder.setInputEtHintText(R.string.qiwei_customers_assignment_review_no_pass_reason)
        builder.setYesRbText(R.string.qiwei_customers_assignment_review_pass)
        builder.setNoRbText(R.string.qiwei_customers_assignment_review_reject)
        builder.setPositiveButton { dialog, _ -> dialog.dismiss() }
        builder.setNegativeButton { dialog, _ ->
            dialog.dismiss()
            if (builder.isComplete == ConstantParams.CONSTANT_STARTS_1) {
                submitEmployeeCustomerAllocationAudit(ConstantParams.CONSTANT_STARTS_2, "")
            } else if (builder.isComplete == ConstantParams.CONSTANT_STARTS_2) {
                submitEmployeeCustomerAllocationAudit(
                    ConstantParams.CONSTANT_STARTS_3,
                    builder.dialogInputValue
                )
            }
        }
        builder.create().show()
    }


    override fun onBusinessResultAtMainThread(result: ResultData?) {
        super.onBusinessResultAtMainThread(result)
        dismissDialog()
        result?.let {
            if (it.taskID == BusinessID.StaffManage.MSG_ON_EMPLOYEE_CUSTOMER_ALLOCATION_AUDIT) {
                if (!isFinishing && it.isSuccessed) {
                    val entity =
                        Gson().fromJson(it.info, BaseResponse::class.java)
                    Log.d(TAG, "BaseResponse=$entity")
                    if (ConstantParams.CONSTANT_PARAMS_0 == entity.retCode) {
                        finish()
                    } else {
                        showMsg(entity.retInfo)
                    }
                } else {
                    showMsg(getString(R.string.request_data_fail))
                }
            } else {
            }
        }
    }
}