package com.wgmf.yxgj.module.business.managestaff.ui.staffdistribute.working

import android.content.Intent
import android.os.Bundle
import android.support.v7.widget.LinearLayoutManager
import android.support.v7.widget.RecyclerView
import android.util.Log
import android.view.View
import android.widget.*
import com.chad.library.adapter.base.BaseQuickAdapter
import com.google.gson.Gson
import com.scwang.smartrefresh.layout.SmartRefreshLayout
import com.wgmf.library.base.ResultData
import com.wgmf.yxgj.base.BaseParentAct
import com.wgmf.yxgj.config.BusinessID
import com.wgmf.yxgj.dialog.LoadWaitDominator
import com.wgmf.yxgj.global.AppConstants
import com.wgmf.yxgj.global.ConstantParams
import com.wgmf.yxgj.module.business.managestaff.R
import com.wgmf.yxgj.module.business.managestaff.model.*
import com.wgmf.yxgj.module.business.managestaff.service.StaffManageService
import com.wgmf.yxgj.module.business.managestaff.ui.staffdistribute.adapter.QiWeiCustomersAssignmentRecordsListAdapter
import com.wgmf.yxgj.utils.DensityUtil
import com.wgmf.yxgj.utils.isNotNullOrSize
import com.wgmf.yxgj.widgets.decoration.SpacesItemDecoration

/**
 * 企微顾客分配记录
 * @author LW
 */
class QiWeiCustomersAssignmentRecordsActivity : BaseParentAct() {

    private var mPublicListViewRv: RecyclerView? = null

    private var mPublicRefreshView: SmartRefreshLayout? = null

    private var mQiWeiCustomersAssignmentRecordsListAdapter: QiWeiCustomersAssignmentRecordsListAdapter? =
        null

    private var mQiWeiCustomersAssignmentRecordsList: MutableList<QiWeiCustomersAssignmentRecordsEntity
    .QiWeiCustomersAssignmentRecordsPage.QiWeiCustomersAssignmentRecordsBean> =
        mutableListOf()

    /**
     * 当前页码
     */
    private var mNextPage: Int = 1

    lateinit var mLoadWait: LoadWaitDominator

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        setContentView(R.layout.public_page_list_view)
        initTitle()
        initView()
    }

    override fun initTitle() {
        super.initTitle()
        homeTitleText.text = getString(R.string.qiwei_customers_assignment_records)
        homeTitleBackLl.visibility = View.VISIBLE
    }


    private fun initView() {
        mLoadWait = LoadWaitDominator(mContext, findViewById(R.id.public_container_fl)).apply {
//            setBackgroundColor(R.color.region_two_bg)
            setStatusImg(R.drawable.ic_msg_empty_common)
        }
        mPublicRefreshView = findViewById<SmartRefreshLayout>(R.id.public_refresh_view).apply {
            //刷新
            setOnRefreshListener {
                queryEmployeeCustomerAllocationPageList(1)
            }
            //加载更多
            setOnLoadmoreListener {
                queryEmployeeCustomerAllocationPageList(mNextPage)
            }
        }

        mQiWeiCustomersAssignmentRecordsListAdapter =
            QiWeiCustomersAssignmentRecordsListAdapter(mQiWeiCustomersAssignmentRecordsList)
        mPublicListViewRv = findViewById<RecyclerView>(R.id.public_list_view_rv).apply {
            visibility = View.VISIBLE
            layoutManager = LinearLayoutManager(mContext)
            adapter = mQiWeiCustomersAssignmentRecordsListAdapter
            addItemDecoration(
                SpacesItemDecoration(
                    DensityUtil.dip2px(mContext, 15f),
                    adapter!!.itemCount,
                    true
                )
            )

        }

        BaseQuickAdapter.OnItemChildClickListener { adapter, view, pos -> //跳转到任务列表详情
            val bean =
                adapter?.getItem(pos) as QiWeiCustomersAssignmentRecordsEntity
                .QiWeiCustomersAssignmentRecordsPage.QiWeiCustomersAssignmentRecordsBean
            if (view.id == R.id.qiwei_customers_records_item_reallocate_tv) {   //重新分配
                jumpQiWeiCustomersAssignmentDetailActivity(bean)
            } else { //查看分配信息
                jumpQiWeiCustomersAssignmentInfoActivity(bean)
            }
        }.also { mQiWeiCustomersAssignmentRecordsListAdapter?.onItemChildClickListener = it }
    }

    override fun onResume() {
        super.onResume()
        mPublicRefreshView?.autoRefresh()
    }

    /**
     * 分页查询客户分配申请记录
     */
    private fun queryEmployeeCustomerAllocationPageList(page: Int) {
        userInfo?.let {
            //if (page == ConstantParams.CONSTANT_STARTS_1) {
            //mLoadWait.show(LoadWaitDominator.LOADING)
            //showDialog()
            //}
            val json = Gson().toJson(QiWeiCustomersAssignmentRecordsRequest(it.staffId, page))
            StaffManageService.getInstance()
                .requestEmployeeCustomerAllocationPageList(
                    json,
                    this@QiWeiCustomersAssignmentRecordsActivity
                )
        }
    }


    override fun onBusinessResultAtMainThread(result: ResultData?) {
        super.onBusinessResultAtMainThread(result)
        mLoadWait.dismissAll()
        mPublicRefreshView?.finishRefresh()
        mPublicRefreshView?.finishLoadmore()
        result?.let {
            if (it.taskID == BusinessID.StaffManage.MSG_ON_EMPLOYEE_CUSTOMER_ALLOCATION_PAGE_LIST) {
                if (!isFinishing && it.isSuccessed) {
                    val entity =
                        Gson().fromJson(it.info, QiWeiCustomersAssignmentRecordsEntity::class.java)
                    Log.d(TAG, "QiWeiCustomersAssignmentRecordsEntity=$entity")
                    if (ConstantParams.CONSTANT_PARAMS_0 == entity.retCode) {
                        val pageData = entity.payload
                        if (pageData.pages == ConstantParams.CONSTANT_STARTS_0) {
                            mLoadWait.showNoData(R.string.no_record)
                            return
                        }
                        if (pageData.page <= pageData.pages) {
                            if (pageData.page == ConstantParams.CONSTANT_STARTS_1) {
                                refreshDataToView(pageData.data)
                            } else {
                                loadMoreDateToView(pageData.data)
                            }
                            this.mNextPage = pageData.page + 1
                        } else {
                            mPublicRefreshView?.resetNoMoreData()
                        }
                    } else {
                        mLoadWait.show(entity.retInfo)
                    }
                } else {
                    mLoadWait.showNetError()
                }
            } else {

            }
        }
    }

    /**
     * 刷新数据更新到View
     */
    private fun refreshDataToView(
        list: List<QiWeiCustomersAssignmentRecordsEntity
        .QiWeiCustomersAssignmentRecordsPage.QiWeiCustomersAssignmentRecordsBean>?
    ) {
        if (list.isNotNullOrSize()) {
            mQiWeiCustomersAssignmentRecordsList.clear()
            mQiWeiCustomersAssignmentRecordsList.addAll(list!!)
            mQiWeiCustomersAssignmentRecordsListAdapter?.notifyDataSetChanged()
        } else {
            mLoadWait.showNoData(R.string.no_record)
        }
    }

    /**
     * 读取更多数据更新到View
     */
    private fun loadMoreDateToView(
        list: List<QiWeiCustomersAssignmentRecordsEntity
        .QiWeiCustomersAssignmentRecordsPage.QiWeiCustomersAssignmentRecordsBean>?
    ) {
        if (list.isNotNullOrSize()) {
            val position = mQiWeiCustomersAssignmentRecordsList.size
            mQiWeiCustomersAssignmentRecordsList.addAll(list!!)
            mQiWeiCustomersAssignmentRecordsListAdapter?.notifyItemInserted(position)
        }
    }

    /**
     * 跳转到 QiWeiCustomersAssignmentInfoActivity
     */
    private fun jumpQiWeiCustomersAssignmentInfoActivity(
        bean: QiWeiCustomersAssignmentRecordsEntity
        .QiWeiCustomersAssignmentRecordsPage.QiWeiCustomersAssignmentRecordsBean
    ) {
        startActivity(Intent(this, QiWeiCustomersAssignmentInfoActivity::class.java).apply {
            putExtra(AppConstants.ExtraKeys.QIWEI_CUSTOMERS_ASSIGNMENT_RECORDS, bean)
            putExtra(
                AppConstants.ExtraKeys.QIWEI_CUSTOMERS_ASSIGNMENT_INFO_TYPE,
                QiWeiCustomersAssignmentInfoActivity.WORKING_ASSIGNMENT_RECORDS
            )
        })
    }

    /**
     * 跳转到 QiWeiCustomersAssignmentDetailActivity
     */
    private fun jumpQiWeiCustomersAssignmentDetailActivity(
        bean: QiWeiCustomersAssignmentRecordsEntity
        .QiWeiCustomersAssignmentRecordsPage.QiWeiCustomersAssignmentRecordsBean
    ) {
        startActivity(
            Intent(
                mContext, QiWeiCustomersAssignmentDetailActivity::class.java
            ).apply {
                putExtra(
                    AppConstants.ExtraKeys.QIWEI_CUSTOMERS_ASSIGNMENT,
                    QiWeiCustomersAssignmentEntity.QiWeiCustomersAssignmentPage.QiWeiCustomersAssignmentBean(
                        bean.staffId,
                        bean.staffName,
                        bean.customerNum
                    )
                )
                putExtra(AppConstants.ExtraKeys.QIWEI_CUSTOMERS_ASSIGNMENT_ID, bean.id)
                putExtra(AppConstants.ExtraKeys.CONSULTANT_WORKING_STATUS, -1)
            }
        )
    }
}