package com.wgmf.yxgj.module.business.managestaff.ui.staffinfo

import android.content.Intent
import android.os.Bundle
import android.support.v4.content.ContextCompat
import android.support.v7.widget.LinearLayoutManager
import android.support.v7.widget.RecyclerView
import android.util.Log
import android.view.View
import android.widget.Button
import android.widget.LinearLayout
import android.widget.ListView
import com.chad.library.adapter.base.BaseQuickAdapter
import com.google.gson.Gson
import com.wgmf.library.base.ResultData
import com.wgmf.yxgj.base.BaseParentAct
import com.wgmf.yxgj.config.BusinessID
import com.wgmf.yxgj.global.AppConstants
import com.wgmf.yxgj.global.ConstantParams
import com.wgmf.yxgj.model.NutritionConsultant
import com.wgmf.yxgj.module.business.managestaff.R
import com.wgmf.yxgj.module.business.managestaff.model.NutritionConsultantQueryResponse
import com.wgmf.yxgj.module.business.managestaff.service.StaffManageService
import com.wgmf.yxgj.module.business.managestaff.ui.staffinfo.adapter.SelectorConsultantAdapter
import com.wgmf.yxgj.utils.isNullOrEmpty
import com.wgmf.yxgj.utils.notNullAndEmpty
import com.wgmf.yxgj.widgets.EditText.ClearEditText
import com.wgmf.yxgj.widgets.decoration.DividerItemDecoration

/**
 * 查询顾问列表
 */
class SelectorConsultantActivity : BaseParentAct() {

    private var mConsultantNameEt: ClearEditText? = null

    private var mPublicListViewRv: RecyclerView? = null

    private var mPublicListViewNewEmptyLl: LinearLayout? = null

    private var mSelectorConsultantAdapter: SelectorConsultantAdapter? = null

    private var mSelectorConsultantList = mutableListOf<NutritionConsultant>()

    private val mStaffName: String by lazy {
        intent.getStringExtra(AppConstants.ExtraKeys.STAFF_NAME)
    }

    private val mStaffId: String by lazy {
        intent.getStringExtra(AppConstants.ExtraKeys.STAFF_ID)
    }

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        setContentView(R.layout.public_list_view)
        initTitle()
        initView()
    }

    override fun initTitle() {
        super.initTitle()
        homeTitleText.text = getString(R.string.selector_consultant)
        homeTitleBackLl.visibility = View.VISIBLE

    }

    private fun initView() {
        mPublicListViewNewEmptyLl = findViewById(R.id.public_list_view_new_empty_ll)

        mConsultantNameEt = findViewById<ClearEditText>(R.id.store_name_et).apply {
            hint = getString(R.string.staff_id_or_name)
            visibility = View.VISIBLE
        }
        findViewById<Button>(R.id.store_name_query_btn).apply {
            visibility = View.VISIBLE
            setOnClickListener {
                val consultantName: String = mConsultantNameEt?.text.toString().trim { it <= ' ' }
                if (consultantName.isNullOrEmpty()) {
                    showMsg(getString(R.string.staff_id_or_name))
                } else {
                    queryNutritionConsultant(consultantName)
                }
            }
        }
        if (mStaffName.notNullAndEmpty() && mStaffId.notNullAndEmpty()) {
            val nutritionConsultant = NutritionConsultant()
            nutritionConsultant.operName = mStaffName
            nutritionConsultant.operatorId = mStaffId
            mSelectorConsultantList.add(nutritionConsultant)
        }

        mSelectorConsultantAdapter =
            SelectorConsultantAdapter(mSelectorConsultantList, userInfo?.staffId ?: "")
        findViewById<ListView>(R.id.public_list_view_lv).visibility = View.GONE
        mPublicListViewRv = findViewById<RecyclerView>(R.id.public_list_view_rv).apply {
            visibility = View.VISIBLE
            layoutManager = LinearLayoutManager(mContext)
            adapter = mSelectorConsultantAdapter
            addItemDecoration(
                DividerItemDecoration(
                    DividerItemDecoration.HORIZONTAL_LIST,
                    1,
                    ContextCompat.getColor(mContext, R.color.divider_line)
                )
            )
        }
        BaseQuickAdapter.OnItemClickListener { adapter, view, pos ->
            val bean =
                adapter?.getItem(pos) as NutritionConsultant
            jumpItemLogic(bean)
        }.also { mSelectorConsultantAdapter?.onItemClickListener = it }
    }

    /**
     * 跳转处理
     */
    private fun jumpItemLogic(bean: NutritionConsultant) {
        val intent = Intent().apply {
            putExtra(AppConstants.ExtraKeys.STAFF_NAME, bean.operName)
            putExtra(AppConstants.ExtraKeys.STAFF_ID, bean.operatorId)
        }
        setResult(ConstantParams.CONSTANT_STARTS_0, intent)
        finish()
    }

    /**
     * 查询员工列表
     */
    protected fun queryNutritionConsultant(staffIdOrName: String?) {
        //子类实现
        userInfo.let {
            showDialog()
            val organizationId = userInfo.organizationId
            StaffManageService.getInstance().requestQueryNutritionConsultant(
                staffIdOrName,
                organizationId,
                this@SelectorConsultantActivity
            )
        }
    }


    override fun onBusinessResultAtMainThread(result: ResultData?) {
        super.onBusinessResultAtMainThread(result)
        dismissDialog()
        result?.let {
            if (it.taskID == BusinessID.StaffManage.MSG_ON_QUERY_NUTRITION_CONSULTANT) {
                if (!isFinishing && it.isSuccessed) {
                    val entity =
                        Gson().fromJson(it.info, NutritionConsultantQueryResponse::class.java)
                    Log.d(TAG, "NutritionConsultantQueryResponse=$entity")
                    if (ConstantParams.CONSTANT_PARAMS_0 == entity.msgCode) {
                        mSelectorConsultantList.addAll(1, entity.result)
                        mSelectorConsultantAdapter?.notifyDataSetChanged()
                        //if (mSelectorConsultantList.isNotNullOrSize()) {
                        //    mPublicListViewNewEmptyLl?.visibility = View.GONE
                        //    mPublicListViewRv?.visibility = View.VISIBLE
                        //    mSelectorConsultantAdapter?.setNewData(list)
                        //} else {
                        //    mPublicListViewNewEmptyLl?.visibility = View.VISIBLE
                        //    mPublicListViewRv?.visibility = View.GONE
                        //}
                    } else {
                        showMsg(entity.retInfo)
                    }
                } else {
                    showMsg(it.resultInfo)
                }
            }
        }
    }
}