package com.wgmf.yxgj.module.business.managestaff.ui.staffinfo

import android.content.Intent
import android.util.Log
import android.view.View
import android.widget.LinearLayout
import android.widget.TextView
import com.google.gson.Gson
import com.wgmf.library.base.ResultData
import com.wgmf.library.utils.DateUtil
import com.wgmf.yxgj.config.BusinessID
import com.wgmf.yxgj.dialog.PublicTipDialog
import com.wgmf.yxgj.global.AppConstants
import com.wgmf.yxgj.global.ConstantParams
import com.wgmf.yxgj.global.MediaParams
import com.wgmf.yxgj.module.business.managestaff.R
import com.wgmf.yxgj.module.business.managestaff.model.EmployeeDissmissEntity
import com.wgmf.yxgj.module.business.managestaff.model.EmployeeDissmissEntityRequest
import com.wgmf.yxgj.module.business.managestaff.model.EmployeeDissmissInfoEntity
import com.wgmf.yxgj.module.business.managestaff.service.StaffManageService
import com.wgmf.yxgj.pop.PublicSelectPop
import com.wgmf.yxgj.publics.model.BaseSelectorEntity
import com.wgmf.yxgj.report.ui.ReportBaseDetailActivity
import com.wgmf.yxgj.utils.helper.DialogHelper
import com.wgmf.yxgj.utils.isNotNullOrSize
import com.wgmf.yxgj.utils.isNullOrEmpty
import com.wgmf.yxgj.utils.notNullAndEmpty
import xp.timepicker.com.widget.bean.DateType
import java.util.*

/**
 * 员工离职
 * @author LW
 */
class StaffDissimissDetailActivity : ReportBaseDetailActivity() {

    private var mStaffDimissionDateTv: TextView? = null
    private var mStaffDimissionTypeTv: TextView? = null
    private var mStaffBusinessCustomerAssignmentTv: TextView? = null

    private var mStaffDistributeTargetLl: LinearLayout? = null
    private var mStaffDistributeTargetTv: TextView? = null

    /**
     * 离职人工号
     */
    private val mOperatorId: String? by lazy {
        intent.getStringExtra(AppConstants.ExtraKeys.TURNOVER_EMPLOYEE_ID)
    }

    /**
     * 离职人姓名
     */
    private val mOperName: String? by lazy {
        intent.getStringExtra(AppConstants.ExtraKeys.TURNOVER_EMPLOYEE_NAME)
    }

    /**
     * 离职记录
     */
    private val mEmployeeDissmissBean: EmployeeDissmissInfoEntity.EmployeeDissmissPage.EmployeeDissmissBean? by lazy {
        intent.getSerializableExtra(AppConstants.ExtraKeys.EMPLOYEE_DISSMISS_RECORDS) as EmployeeDissmissInfoEntity.EmployeeDissmissPage.EmployeeDissmissBean?
    }

    /**
     * 离职类型:默认为主动离职
     */
    private var mLzType = "01"

    /**
     * 企业顾客分配
     */
    private var mCustomerAssignmentType: String = ""

    /**
     * 离职分配接收人工号
     */
    private var mReceiverStaffId: String = ""

    /**
     * 离职类型选择框
     */
    private var mDissMissTypeSelectPop: PublicSelectPop? = null

    /**
     * 企业顾客分配选择框
     */
    private var mCustomerAssignmentPop: PublicSelectPop? = null

    private var mId: Int = -1

    override fun initView() {
        super.initView()
        setContentView(R.layout.activity_staff_dissmiss)
    }

    override fun initData() {
        super.initData()
        reportType = "LZ" //离职
        pickerMode = MediaParams.PARAMS_3
        mPicSize = 5 //最多上传5张图片
        mPicDes = getString(R.string.staff_resign_upload_picture_tip)
    }

    override fun initTitle() {
        super.initTitle()
        homeTitleText.text = getString(R.string.employee_turnover)
        homeTitleBackLl.visibility = View.VISIBLE
    }

    override fun initContent() {
        super.initContent()

        findViewById<TextView>(R.id.staff_name_tv).apply {
            text = getString(R.string.staff_former_nutrition_consultant, mOperName)
        }

        mStaffDimissionDateTv = findViewById(R.id.staff_dissmiss_date_tv)
        mStaffDimissionTypeTv = findViewById<TextView>(R.id.staff_dissmiss_type_tv).apply {
            text = getString(R.string.staff_voluntary_resignation)
        }

        mStaffBusinessCustomerAssignmentTv =
            findViewById(R.id.staff_business_customer_assignment_tv)

        mStaffDistributeTargetTv = findViewById(R.id.staff_distribute_target_tv)

        mStaffDistributeTargetLl = findViewById(R.id.staff_distribute_target_ll)
        mStaffDistributeTargetLl?.setOnClickListener {
            jumpSelectorConsultantActivity()
        }

        findViewById<LinearLayout>(R.id.staff_dissmiss_date_ll).setOnClickListener {
            DialogHelper.showDatePickDialog(
                this@StaffDissimissDetailActivity,
                DateType.TYPE_YMD,
                mStaffDimissionDateTv
            )
        }
        findViewById<LinearLayout>(R.id.staff_dissmiss_type_ll).setOnClickListener {
            if (null == mDissMissTypeSelectPop) {
                mDissMissTypeSelectPop = PublicSelectPop(
                    mContext,
                    { position, reportQuerys ->
                        reportQuerys?.let {
                            val entity = it[position]
                            mStaffDimissionTypeTv?.text = entity.selectorName
                            mLzType = entity.selectorId
                        }
                    },
                    getDissMissType()
                )
            }
            if (mDissMissTypeSelectPop?.isShowing == false) {
                mDissMissTypeSelectPop?.show(findViewById(R.id.title))
            }
        }
        findViewById<LinearLayout>(R.id.staff_business_customer_assignment_ll).setOnClickListener {
            if (null == mCustomerAssignmentPop) {
                mCustomerAssignmentPop = PublicSelectPop(mContext, { position, reportQuerys ->
                    reportQuerys?.let {
                        val entity = it[position]
                        mStaffBusinessCustomerAssignmentTv?.text = entity.selectorName
                        mCustomerAssignmentType = entity.selectorId
                        if (mCustomerAssignmentType == ConstantParams.CONSTANT_PARAMS_1) {  //自定义分配
                            mStaffDistributeTargetLl?.visibility = View.VISIBLE
                        } else {
                            mStaffDistributeTargetLl?.visibility = View.GONE
                        }
                    }
                }, getCustomerAssignmentType())
            }
            if (mCustomerAssignmentPop?.isShowing == false) {
                mCustomerAssignmentPop?.show(findViewById(R.id.title))
            }
        }
    }

    override fun parseFootData() {
        super.parseFootData()
        reportContentComfirmBtn.setOnClickListener { showNoticeDialog() }

    }

    override fun setContent() {
        super.setContent()
        mEmployeeDissmissBean?.let {
            mId = it.id
            //离职日期
            mStaffDimissionDateTv?.text = it.dimissionTime
            //DateUtil.string2String(it.dimissionTime, DateUtil.FORMATDEFAULT)
            //离职类型
            mLzType = it.type ?: ""
            mStaffDimissionTypeTv?.text = if ("01" == mLzType) {
                getString(R.string.staff_voluntary_resignation)
            } else if ("02" == mLzType) {
                getString(R.string.staff_passive_resignation)
            } else {
                getString(R.string.staff_from)
            }
            //企业顾客分配
            mCustomerAssignmentType = it.allocationType.toString()
            mStaffBusinessCustomerAssignmentTv?.text =
                if (mCustomerAssignmentType == ConstantParams.CONSTANT_PARAMS_1) {  //1-指定分配人员, 2-自动分配 3,不分配
                    mStaffDistributeTargetLl?.visibility = View.VISIBLE
                    mStaffDistributeTargetTv?.text = it.receiverName
                    mReceiverStaffId = it.receiverStaffId ?: ""
                    getString(R.string.staff_designated_person)
                } else if (mCustomerAssignmentType == ConstantParams.CONSTANT_PARAMS_2) {
                    mStaffDistributeTargetLl?.visibility = View.GONE
                    getString(R.string.staff_automatic_allocation)
                } else {
                    mStaffDistributeTargetLl?.visibility = View.GONE
                    getString(R.string.staff_not_assigned)
                }
            reportEdit.setText(it.reason)
        }
    }

    /**
     * 显示离职员工提示信息对话框
     */
    private fun showNoticeDialog() {
        PublicTipDialog.Builder(this).apply {
            setMessage(getString(R.string.staff_dialog_title, mOperName))
            setTitle(R.string.staff_dialog_confrim_resignation_operation)
            setPositiveButton(
                R.string.cancel_btn_txt
            ) { dialog, which -> dialog.dismiss() }
            setNegativeButton(
                R.string.confirm_btn_txt
            ) { dialog, which ->
                setUploadData()
                dialog.dismiss()
            }
        }.create().show()
    }

    /**
     * 图片提示框
     */
    private fun showPictureTipDialog() {
        PublicTipDialog.Builder(this).apply {
            setTitle(R.string.tip)
            setMessage(R.string.staff_resign_upload_picture_two_tip)
            setNegativeButton(
                R.string.confirm_btn_txt
            ) { dialog, which -> dialog.dismiss() }

        }.create().show()
    }

    override fun setUploadData() {
        val dimissionDate = mStaffDimissionDateTv?.text.toString()
        if (dimissionDate.isNullOrEmpty()) {
            showMsg(getString(R.string.staff_input_reason_for_time))
            return
        } else {
            try {
                //当前时间的前后各2天
                if (!DateUtil.isTimeBeforeAndAfterTwoDays(dimissionDate)) {
                    showMsg(getString(R.string.staff_input_reason_time_error))
                    return
                }
            } catch (e: Exception) {
                e.printStackTrace()
            }
        }

        if (mCustomerAssignmentType.notNullAndEmpty()) {
            if ((mCustomerAssignmentType == ConstantParams.CONSTANT_PARAMS_1) && mReceiverStaffId.isNullOrEmpty()) {
                showMsg(getString(R.string.staff_input_business_customer_assignment_consultant))
                return
            }
        } else {
            showMsg(getString(R.string.staff_input_business_customer_assignment_type))
            return
        }

        val dimissionDesc = reportEdit.text.toString()
        if (dimissionDesc.isNullOrEmpty()) {
            showMsg(getString(R.string.staff_input_reason_for_leaving))
            return
        }

        if (!urlLists.isNotNullOrSize()) {
            showPictureTipDialog()
            return
        }

        super.setUploadData()
    }

    override fun uploadData() {
        super.uploadData()

        showDialog()
        val lzDate = mStaffDimissionDateTv?.text.toString()
        val lzreason = reportEdit.text.toString()
        val entity = EmployeeDissmissEntityRequest(
            mId,
            userInfo?.staffId,
            userInfo?.level,
            mCustomerAssignmentType,
            lzDate,
            urlLists,
            lzreason,
            mLzType,
            mOperName,
            mOperatorId,
            mReceiverStaffId,
            userInfo?.organizationId
        )

        val json = Gson().toJson(entity)
        Log.d(TAG, "EmployeeDissmissEntityRequest=$json")

        if (mEmployeeDissmissBean == null) {  //保存员工离职
            StaffManageService.getInstance()
                .requestEmployeeDimissionSave(json, this@StaffDissimissDetailActivity)
        } else {  //重新发起申请员工离职
            StaffManageService.getInstance()
                .requestEmployeeDimissionUpdateDimission(json, this@StaffDissimissDetailActivity)
        }
    }

    override fun onBusinessResultAtMainThread(result: ResultData?) {
        super.onBusinessResultAtMainThread(result)
        dismissDialog()
        result?.let {
            if (it.taskID == BusinessID.StaffManage.MSG_ON_EMPLOYEE_DIMISSION_SAVE ||
                it.taskID == BusinessID.StaffManage.MSG_ON_EMPLOYEE_DIMISSION_UPDATE_DIMISSION
            ) {
                if (!isFinishing && it.isSuccessed) {
                    val entity = Gson().fromJson(it.info, EmployeeDissmissEntity::class.java)
                    Log.d(TAG, "EmployeeDissmissEntity=$entity")
                    if (ConstantParams.CONSTANT_PARAMS_0 == entity.retCode) {
                        showMsg(entity.retInfo)
                        finish()
                    } else {
                        showMsg(entity.retInfo)
                    }
                } else {
                    showMsg(getString(R.string.request_data_fail))
                }
            }
        }
    }

    /**
     * 离职类型
     */
    private fun getDissMissType(): List<BaseSelectorEntity> {
        val list: MutableList<BaseSelectorEntity> = mutableListOf()
        return list.apply {
            add(BaseSelectorEntity().apply {
                selectorName = getString(R.string.staff_voluntary_resignation)
                selectorId = "01"
            })
            add(BaseSelectorEntity().apply {
                selectorName = getString(R.string.staff_passive_resignation)
                selectorId = "02"
            })
            add(BaseSelectorEntity().apply {
                selectorName = getString(R.string.staff_from)
                selectorId = "03"
            })
        }
    }

    /**
     * 顾客分配类型
     */
    private fun getCustomerAssignmentType(): List<BaseSelectorEntity> {
        val list: MutableList<BaseSelectorEntity> = mutableListOf()
        return list.apply {
            add(BaseSelectorEntity().apply {
                selectorName = getString(R.string.staff_designated_person)
                selectorId = ConstantParams.CONSTANT_PARAMS_1
            })
            add(BaseSelectorEntity().apply {
                selectorName = getString(R.string.staff_automatic_allocation)
                selectorId = ConstantParams.CONSTANT_PARAMS_2
            })
            add(BaseSelectorEntity().apply {
                selectorName = getString(R.string.staff_not_assigned)
                selectorId = ConstantParams.CONSTANT_PARAMS_3
            })
        }
    }

    override fun onActivityResult(requestCode: Int, resultCode: Int, intent: Intent?) {
        super.onActivityResult(requestCode, resultCode, intent)
        intent?.let {
            if (requestCode == ConstantParams.CONSTANT_STARTS_0 && resultCode == ConstantParams.CONSTANT_STARTS_0) {
                val operName =
                    it.getStringExtra(AppConstants.ExtraKeys.STAFF_NAME) as String
                val operatorId = it.getStringExtra(AppConstants.ExtraKeys.STAFF_ID) as String
                mStaffDistributeTargetTv?.text = operName
                mReceiverStaffId = operatorId
            }
        }
    }

    /**
     * 跳转到 SelectorConsultantActivity
     */
    private fun jumpSelectorConsultantActivity() {
        userInfo.let {
            startActivityForResult(
                Intent(this, SelectorConsultantActivity::class.java).apply {
                    putExtra(AppConstants.ExtraKeys.STAFF_NAME, it.name)
                    putExtra(AppConstants.ExtraKeys.STAFF_ID, it.staffId)
                },
                ConstantParams.CONSTANT_STARTS_0
            )
        }
    }
}