package com.wgmf.yxgj.module.business.memberday.service;

import android.text.TextUtils;
import android.util.Log;

import com.google.gson.Gson;
import com.wgmf.library.base.BaseRequest;
import com.wgmf.library.base.BaseResponse;
import com.wgmf.library.base.ResultData;
import com.wgmf.library.utils.BaseSingleton;
import com.wgmf.yxgj.base.BaseService;
import com.wgmf.yxgj.config.BusinessID;
import com.wgmf.yxgj.global.NetworkParams;

import java.lang.ref.WeakReference;

/**
 * @author XiePing
 */
public class MemberDayService extends BaseService {
    private static BaseSingleton<MemberDayService, Void> mMainService = new BaseSingleton<MemberDayService, Void>() {
        @Override
        protected MemberDayService create(Void var1) {
            return new MemberDayService();
        }
    };

    public static MemberDayService getInstance() {
        return mMainService.get(null);
    }

    private MemberDayService() {
    }

    /**
     * POST /memDaySign/checkCusDay 判断是否为会员日
     */
    public void requestCheckCusDay(final String ymd, ResultData.BusinessCallback callback) {
        BaseRequest request = new BaseRequest();
        request.taskID = BusinessID.MemberDay.MSG_ON_CHECK_CUS_DAY;
        request.callback = new WeakReference<>(callback);
        request.url = NetworkParams.URL_CHECK_CUS_DAY + "?" + "ymd=" + ymd;
        Log.d(TAG, "请求地址：" + request.url);
        sendGetRequest(request);
    }

    /**
     * POST /memDaySign/getSearchStoreByStaffId 根据工号获取该员工最近搜索的4家门店
     */
    public void requestGetSearchStoreByStaffId(final String staffId, ResultData.BusinessCallback callback) {
        BaseRequest request = new BaseRequest();
        request.taskID = BusinessID.MemberDay.MSG_ON_GET_SEARCH_STORE_BY_STAFFID;
        request.callback = new WeakReference<>(callback);
        request.url = NetworkParams.URL_GET_SEARCH_STORE_BY_STAFFID + "?" + "staffId=" + staffId;
        Log.d(TAG, "请求地址：" + request.url);
        sendGetRequest(request);
    }

    /**
     * POST /memDaySign/memDaySignShow 会员日下店签到签退(销售金额,签到状态)
     */
    public void requestGetMemDaySignShow(final String staffId, final String shopId, final String ymd, ResultData.BusinessCallback callback) {
        BaseRequest request = new BaseRequest();
        request.taskID = BusinessID.MemberDay.MSG_ON_MEM_DAY_SIGN_SHOW;
        request.callback = new WeakReference<>(callback);
        request.url = NetworkParams.URL_MEM_DAY_SIGN_SHOW + "?" + "staffId=" + staffId + "&shopId=" + shopId + "&ymd=" + ymd;
        Log.d(TAG, "请求地址：" + request.url);
        sendGetRequest(request);
    }

    /**
     * POST /memDaySign/saveSearchStore 保存门店搜索记录
     */
    public void requestSaveSearchStore(final String memDaySignSercahStore, ResultData.BusinessCallback callback) {
        BaseRequest request = new BaseRequest();
        request.taskID = BusinessID.MemberDay.MSG_ON_SAVE_SEARCH_STORE;
        request.callback = new WeakReference<>(callback);
        request.url = NetworkParams.URL_SAVE_SEARCH_STORE;
        request.json = memDaySignSercahStore;
        Log.d(TAG, "请求地址：" + request.url);
        sendPostJsonRequest(request);
    }

    /**
     * POST /memDaySign/saveSignIn 签到保存
     */
    public void requestMemDaySign(final String memDaySign, ResultData.BusinessCallback callback) {
        BaseRequest request = new BaseRequest();
        request.taskID = BusinessID.MemberDay.MSG_ON_MEM_DAY_SIGN;
        request.callback = new WeakReference<>(callback);
        request.url = NetworkParams.URL_MEM_DAY_SIGN;
        request.json = memDaySign;
        Log.d(TAG, "请求地址：" + request.url);
        sendPostJsonRequest(request);
    }

    /**
     * POST /memDaySign/saveSignOut 保存签退
     */
    public void requestSaveSignOut(final String memDaySign, ResultData.BusinessCallback callback) {
        BaseRequest request = new BaseRequest();
        request.taskID = BusinessID.MemberDay.MSG_ON_SAVE_SIGN_OUT;
        request.callback = new WeakReference<>(callback);
        request.url = NetworkParams.URL_SAVE_SIGN_OUT;
        request.json = memDaySign;
        Log.d(TAG, "请求地址：" + request.url);
        sendPostJsonRequest(request);
    }

    /**
     * POST /memDaySign/getMemDaySign 会员日下店情况报表
     */
    public void requestGetMemDaySign(final String staffId, ResultData.BusinessCallback callback) {
        BaseRequest request = new BaseRequest();
        request.taskID = BusinessID.MemberDay.MSG_ON_GET_MEM_DAY_SIGN;
        request.callback = new WeakReference<>(callback);
        request.url = NetworkParams.URL_GET_MEM_DAY_SIGN + "?" + "staffId=" + staffId;
        Log.d(TAG, "请求地址：" + request.url);
        sendGetRequest(request);
    }

    /**
     * GET /memDaySign/getMemDaySignImgAndSaleCount 门店销售金额+会员日下店签到签退图片
     */
    public void requestGetShopCusDaySaleAmount(final String signId, final String staffId, final String shopId, final String ymd, ResultData.BusinessCallback callback) {
        BaseRequest request = new BaseRequest();
        request.taskID = BusinessID.MemberDay.MSG_ON_GET_SHOP_CUS_DAY_SALE_AMOUNT;
        request.callback = new WeakReference<>(callback);
        request.url = NetworkParams.URL_GET_SHOP_CUS_DAY_SALE_AMOUNT + "?" + "staffId=" + staffId + "&shopId=" + shopId + "&signId=" + signId + "&ymd=" + ymd;
        Log.d(TAG, "请求地址：" + request.url);
        sendGetRequest(request);
    }

    @Override
    protected void onTaskDone(ResultData data) {
        if (null != data) {
            final int id = data.taskID;
            switch (id) {
                case BusinessID.MemberDay.MSG_ON_CHECK_CUS_DAY:
                case BusinessID.MemberDay.MSG_ON_GET_SEARCH_STORE_BY_STAFFID:
                case BusinessID.MemberDay.MSG_ON_MEM_DAY_SIGN_SHOW:
                case BusinessID.MemberDay.MSG_ON_SAVE_SEARCH_STORE:
                case BusinessID.MemberDay.MSG_ON_MEM_DAY_SIGN:
                case BusinessID.MemberDay.MSG_ON_SAVE_SIGN_OUT:
                case BusinessID.MemberDay.MSG_ON_GET_MEM_DAY_SIGN:
                case BusinessID.MemberDay.MSG_ON_GET_SHOP_CUS_DAY_SALE_AMOUNT: {
                    if (data.isSuccessed()) {
                        final String json = data.getInfo();
                        if (!TextUtils.isEmpty(json)) {
                            BaseResponse mBaseResponse = new Gson().fromJson(json, BaseResponse.class);
                            Log.d(TAG, "id:" + id + ";mBaseResponse=" + mBaseResponse.toString());
                            data.setResultCode(mBaseResponse.retCode);
                            data.setResultInfo(mBaseResponse.retInfo);
                        }
                    }
                    break;
                }
                default:
                    break;
            }
        }
    }
}