package com.wgmf.yxgj.base;

import android.annotation.TargetApi;
import android.content.Context;
import android.content.DialogInterface;
import android.content.res.Configuration;
import android.content.res.Resources;
import android.os.Build;
import android.os.Bundle;
import android.support.v4.content.ContextCompat;
import android.support.v7.app.AppCompatActivity;
import android.util.Log;
import android.view.View;
import android.view.Window;
import android.view.WindowManager;
import android.widget.ImageView;
import android.widget.LinearLayout;
import android.widget.TextView;
import android.widget.Toast;

import com.wgmf.library.utils.tools.DeviceHelper;
import com.wgmf.library.utils.tools.PrefTool;
import com.wgmf.library.utils.tools.SystemBarTintManager;
import com.wgmf.yxgj.db.BrandListDao;
import com.wgmf.yxgj.db.CommonResourcesBeanDao;
import com.wgmf.yxgj.db.CommonUserinfoBeanDao;
import com.wgmf.yxgj.db.NutritionConsultantDao;
import com.wgmf.yxgj.dialog.AppTipDialog;
import com.wgmf.yxgj.dialog.PublicDialogLoading;
import com.wgmf.yxgj.global.Prefs;
import com.wgmf.yxgj.model.BrandList;
import com.wgmf.yxgj.model.CommonResourcesBean;
import com.wgmf.yxgj.model.CommonUserinfoBean;
import com.wgmf.yxgj.utils.ActivityTaskManager;
import com.wgmf.yxgj.utils.helper.DialogHelper;
import com.wgmf.yxgj.widgets.TextView.MarqueeTextView;

import java.util.List;

/**
 * @author XP created at 2016/1/12 15:27
 * Activity基类
 */
public class BaseActivity extends AppCompatActivity implements DialogHelper.DialogResult {
    protected static String TAG;
    protected LinearLayout homeTitleLl, homeTitleBackLl, homeTitleCloseLl, homeTitleMoreLl;
    protected TextView homeTitleBack, homeTitleMore;
    protected MarqueeTextView homeTitleText;
    protected ImageView appTip;

    protected static CommonUserinfoBean userInfo;
    protected static List<BrandList> brandList;
    protected static List<CommonResourcesBean> resources;
    protected static BrandListDao mBrandListDao;
    protected static CommonUserinfoBeanDao mCommonUserinfoBeanDao;
    protected static CommonResourcesBeanDao mCommonResourcesBeanDao;
    protected static NutritionConsultantDao mNutritionConsultantDao;

    protected Context mContext;

    private PublicDialogLoading dialog;
    private BaseActivityPresenter baseActivityPresenter;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        mContext = this;
        //知晓当前是哪个Activity
        TAG = getClass().getSimpleName();
        ActivityTaskManager.getInstance().addActivity(this);

        initWindowView();
        init();
    }

    /**
     * 通知栏一体化
     */
    protected void initWindowView() {
        requestWindowFeature(Window.FEATURE_NO_TITLE);
        if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.KITKAT) {
            setTranslucentStatus();
        }
        SystemBarTintManager tintManager = new SystemBarTintManager(this);
        tintManager.setStatusBarTintEnabled(true);
        // 通知栏所需颜色
        tintManager.setStatusBarTintResource(R.color.normal_color);
    }

    @TargetApi(19)
    protected void setTranslucentStatus() {
        Window win = getWindow();
        WindowManager.LayoutParams winParams = win.getAttributes();
        final int bits = WindowManager.LayoutParams.FLAG_TRANSLUCENT_STATUS;
        winParams.flags |= bits;
        win.setAttributes(winParams);
    }

    private List<BrandList> getBrandList() {
        if (null == baseActivityPresenter) {
            baseActivityPresenter = new BaseActivityPresenter(this);
        }
        mBrandListDao = baseActivityPresenter.getmBrandListDao();
        brandList = baseActivityPresenter.getBrandListData();
        return brandList;
    }

    public CommonUserinfoBean getUserInfoData() {
        if (null == baseActivityPresenter) {
            baseActivityPresenter = new BaseActivityPresenter(this);
        }
        mCommonUserinfoBeanDao = baseActivityPresenter.getCommonUserinfoBeanDao();
        userInfo = baseActivityPresenter.getUserInfoData();
        return userInfo;
    }

    public List<CommonResourcesBean> getCommonResourcesData() {
        if (null == baseActivityPresenter) {
            baseActivityPresenter = new BaseActivityPresenter(this);
        }
        mCommonResourcesBeanDao = baseActivityPresenter.getmCommonResourcesBeanDao();
        resources = baseActivityPresenter.getCommonResourcesData();
        return resources;
    }

    protected void initTitle() {
        getWindow().setFeatureInt(Window.FEATURE_CUSTOM_TITLE, R.layout.public_user_title);
        homeTitleLl = findViewById(R.id.main_title_ll);
        homeTitleBackLl = findViewById(R.id.main_title_back_ll);
        homeTitleMoreLl = findViewById(R.id.home_title_more_ll);
        homeTitleCloseLl = findViewById(R.id.main_title_close_ll);
        homeTitleBack = findViewById(R.id.home_title_back);
        homeTitleText = findViewById(R.id.home_title_text);
        homeTitleMore = findViewById(R.id.home_title_more);
        appTip = findViewById(R.id.app_tip);
        int tempEnv = PrefTool.getIntPreferences(this, Prefs.PRE_ENVIRONMENT_STATUS, 0);
        if (tempEnv != 0) {
            homeTitleText.setTextColor(ContextCompat.getColor(this, R.color.important_txt_color));
            homeTitleText.setBackgroundResource(R.drawable.test_env_icon);
        } else {
            homeTitleText.setTextColor(ContextCompat.getColor(this, R.color.white));
            homeTitleText.setBackgroundResource(R.color.normal_color);
        }
        homeTitleBackLl.setVisibility(View.INVISIBLE);
        homeTitleMoreLl.setVisibility(View.INVISIBLE);
        homeTitleMoreLl.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                more();
            }
        });
        homeTitleBackLl.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                back();
            }
        });
        homeTitleCloseLl.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                close();
            }
        });
        appTip.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                showAppTipDialog();
            }
        });
    }

    /**
     * 显示版本信息
     */
    private void showAppTipDialog() {
        String tip = "版本：" + DeviceHelper.getVersion(this) + "\t\t工号：" + userInfo.getStaffId() +
                "\n设备：Android " + android.os.Build.VERSION.RELEASE + " / " + android.os.Build.MODEL;
        final AppTipDialog.Builder builder = new AppTipDialog.Builder(this);
        builder.setMessage(tip);
        builder.setPositiveButton(new DialogInterface.OnClickListener() {
            @Override
            public void onClick(DialogInterface dialog, int which) {
                dialog.dismiss();
            }
        });
        builder.create().show();
    }

    protected void back() {
        this.finish();
    }

    protected void more() {

    }

    protected void close() {

    }

    public void showMsg(String msg) {
        if (null != msg && !"".equals(msg) && !"null".equals(msg) && msg.length() != 0) {
            Toast.makeText(BaseActivity.this, msg, Toast.LENGTH_LONG).show();
        }
    }

    public void showMsg(int msg) {
        showMsg(mContext.getString(msg));
    }

    public void showDialog() {
        if (!isFinishing() && null == dialog) {
            dialog = new PublicDialogLoading(this);
        }
        if (!isFinishing() && !dialog.isShowing()) {
            dialog.show();
            setDialogCancel(false, false);
        }
    }

    public void dismissDialog() {
        try {
            if (!isFinishing() && null != dialog && dialog.isShowing()) {
                dialog.dismiss();
            }
        } catch (Exception e) {
            Log.e(TAG, "dismissDialog: error");
        }
    }

    public void setDialogCancel(boolean canceledOnTouch, boolean cancelable) {
        if (null != dialog) {
            dialog.setDialogCancel(canceledOnTouch, cancelable);
        }
    }

    @Override
    public void onDialogResult(int tag) {
    }

    protected void focus(View view) {
        view.setFocusable(true);
        view.setFocusableInTouchMode(true);
        view.requestFocus();
    }

    protected String getName() {
        return "none";
    }


    private void init() {
        if (null == dialog) {
            dialog = new PublicDialogLoading(this);
        }
        if (null == baseActivityPresenter) {
            baseActivityPresenter = new BaseActivityPresenter(this);
        }
//        ThreadManager.runOnThread(new Runnable() {
//            @Override
//            public void run() {
        getBrandList();
        getUserInfoData();
        getCommonResourcesData();
//            }
//        });
        baseActivityPresenter.getOrderGoodsAuditDetailDao();
        baseActivityPresenter.getOrderGoodsAuditBatchDetailDao();
        baseActivityPresenter.getNutritionConsultantDao();

    }

    @Override
    public Resources getResources() {
        Resources res = super.getResources();
        Configuration config = new Configuration();
        config.setToDefaults();
        res.updateConfiguration(config, res.getDisplayMetrics());
        return res;
    }

    @Override
    protected void onResume() {
        super.onResume();
        baseActivityPresenter.onResumeBase();
    }

    @Override
    public void onPause() {
        super.onPause();
        baseActivityPresenter.onPauseBase();
    }

    @Override
    protected void onStop() {
        super.onStop();
        baseActivityPresenter.onStopBase();
    }

    @Override
    protected void onDestroy() {
        dialog.dismiss();
        baseActivityPresenter.onDestroyBase();
        super.onDestroy();
        //回收当前Activity
        ActivityTaskManager.getInstance().removeActivity(this);
    }

    /**
     * 清除数据库信息
     */
    protected void clearUserData() {
        baseActivityPresenter.clearBaseUserData();
    }

    /**
     * 程序运行异常，重新登录
     */
    public void reLogin() {
        clearUserData();
    }
}