package com.wgmf.yxgj.base;

import android.app.ActivityManager;
import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.Intent;
import android.content.IntentFilter;
import android.os.CountDownTimer;
import android.text.TextUtils;
import android.util.Log;

import com.umeng.analytics.MobclickAgent;
import com.wgmf.library.utils.DataCleanManager;
import com.wgmf.library.utils.Files;
import com.wgmf.library.utils.tools.PrefTool;
import com.wgmf.yxgj.app.LibGroupContext;
import com.wgmf.yxgj.db.BrandListDao;
import com.wgmf.yxgj.db.CommonResourcesBeanDao;
import com.wgmf.yxgj.db.GreenDaoManager;
import com.wgmf.yxgj.db.NutritionConsultantDao;
import com.wgmf.yxgj.db.CommonUserinfoBeanDao;
import com.wgmf.yxgj.db.OrderGoodsAuditBatchDetailDao;
import com.wgmf.yxgj.db.OrderGoodsAuditDetailDao;
import com.wgmf.yxgj.global.Prefs;
import com.wgmf.yxgj.model.BrandList;
import com.wgmf.yxgj.model.CommonResourcesBean;
import com.wgmf.yxgj.model.CommonUserinfoBean;
import com.xp.pro.imagepickerlib.utils.PathConfig;

import java.util.List;

import cn.jpush.android.api.JPushInterface;

/**
 * @author xiep
 */
public class BaseActivityPresenter {
    private String TAG = "BaseActivityPresenter";
    static boolean isForeground = false;
    static final String KEY_TITLE = "title";
    static final String KEY_MESSAGE = "message";
    static final String KEY_EXTRAS = "extras";
    static final String MESSAGE_RECEIVED_ACTION = "com.wgmf.yxgj.MESSAGE_RECEIVED_ACTION";

    private Context context;

    private CommonUserinfoBean userInfo;
    private List<BrandList> brandList;
    private List<CommonResourcesBean> resources;
    private BrandListDao mBrandListDao;
    private CommonUserinfoBeanDao mCommonUserinfoBeanDao;
    private CommonResourcesBeanDao mCommonResourcesBeanDao;
    private OrderGoodsAuditDetailDao mOrderGoodsAuditDetailDao;
    private OrderGoodsAuditBatchDetailDao mOrderGoodsAuditBatchDetailDao;
    private NutritionConsultantDao mNutritionConsultantDao;

    BaseActivityPresenter(Context context) {
        this.context = context;
        registerMessageReceiver(); // used for receive msg
        registerHomeReceiver();
    }

    public void getData() {
        getUserInfoData();
        getCommonResourcesData();
    }

    CommonUserinfoBeanDao getCommonUserinfoBeanDao() {
        try {
            mCommonUserinfoBeanDao = GreenDaoManager.getInstance().getDaoSession(context).getCommonUserinfoBeanDao();
        } catch (Exception e) {
            Log.d(TAG, e.toString());
        }
        return mCommonUserinfoBeanDao;
    }

    BrandListDao getmBrandListDao() {
        try {
            mBrandListDao = GreenDaoManager.getInstance().getDaoSession(context).getBrandListDao();
        } catch (Exception e) {
            Log.d(TAG, e.toString());
        }
        return mBrandListDao;
    }

    CommonResourcesBeanDao getmCommonResourcesBeanDao() {
        try {
            mCommonResourcesBeanDao = GreenDaoManager.getInstance().getDaoSession(context).getCommonResourcesBeanDao();
        } catch (Exception e) {
            Log.d(TAG, e.toString());
        }
        return mCommonResourcesBeanDao;
    }

    OrderGoodsAuditDetailDao getOrderGoodsAuditDetailDao() {
        try {
            mOrderGoodsAuditDetailDao = GreenDaoManager.getInstance().getDaoSession(context).getOrderGoodsAuditDetailDao();
        } catch (Exception e) {
            Log.d(TAG, e.toString());
        }
        return mOrderGoodsAuditDetailDao;
    }

    OrderGoodsAuditBatchDetailDao getOrderGoodsAuditBatchDetailDao() {
        try {
            mOrderGoodsAuditBatchDetailDao = GreenDaoManager.getInstance().getDaoSession(context).getOrderGoodsAuditBatchDetailDao();
        } catch (Exception e) {
            Log.d(TAG, e.toString());
        }
        return mOrderGoodsAuditBatchDetailDao;
    }

    NutritionConsultantDao getNutritionConsultantDao() {
        try {
            mNutritionConsultantDao = GreenDaoManager.getInstance().getDaoSession(context).getNutritionConsultantDao();
        } catch (Exception e) {
            Log.d(TAG, e.toString());
        }
        return mNutritionConsultantDao;
    }

    List<BrandList> getBrandListData() {
        try {
            getmCommonResourcesBeanDao();
            brandList = mBrandListDao.loadAll();
        } catch (Exception e) {
            Log.d(TAG, e.toString());
        }
        return brandList;
    }

    CommonUserinfoBean getUserInfoData() {
        try {
            getCommonUserinfoBeanDao();
            userInfo = mCommonUserinfoBeanDao.loadAll().get(0);
        } catch (Exception e) {
            Log.d(TAG, e.toString());
        }
        return userInfo;
    }

    List<CommonResourcesBean> getCommonResourcesData() {
        try {
            getmCommonResourcesBeanDao();
            resources = mCommonResourcesBeanDao.loadAll();
        } catch (Exception e) {
            Log.d(TAG, e.toString());
        }
        return resources;
    }

    /**
     * for receive customer msg from jpush server
     */
    private MessageReceiver mMessageReceiver;

    /**
     * 注册JPush消息广播
     */
    private void registerMessageReceiver() {
        mMessageReceiver = new MessageReceiver();
        IntentFilter filter = new IntentFilter();
        filter.setPriority(IntentFilter.SYSTEM_HIGH_PRIORITY);
        filter.addAction(MESSAGE_RECEIVED_ACTION);
        context.registerReceiver(mMessageReceiver, filter);
    }

    /**
     * 注册Home键后台切换广播
     */
    private void registerHomeReceiver() {
        context.registerReceiver(mHomeKeyEventReceiver, new IntentFilter(
                Intent.ACTION_CLOSE_SYSTEM_DIALOGS));
    }

    void onResumeBase() {
        PrefTool.setBooleanSave(context, Prefs.PRE_NOT_TO_BACKGROUD, false);
        //创建文件夹
        Files.createFile(LibGroupContext.getApplication());
        //取消定时
        cancelTimer();
        // 统计页面(仅有Activity的应用中SDK自动调用，不需要单独写。"SplashScreen"为页面名称，可自定义)
        MobclickAgent.onPageStart(TAG);
        // 统计时长
        MobclickAgent.onResume(context);
        // 初始化 JPush。如果已经初始化，但没有登录成功，则执行重新登录。
        JPushInterface.init(context);
        isForeground = true;
    }

    void onPauseBase() {
        MobclickAgent.onPageEnd(TAG);
        MobclickAgent.onPause(context);
        isForeground = false;
    }

    void onStopBase() {
        if (!isAppOnForeground()) {
            if (PrefTool.getBooleanPreferences(context, Prefs.PRE_NOT_TO_BACKGROUD, true)) {
                // 需要进入后台时，设置关闭定时，例拍照关闭定时
                setTimer();
            } else {
                cancelTimer();
                setTimer();
            }
        }
    }

    void onDestroyBase() {
        try {
            context.unregisterReceiver(mMessageReceiver);
            context.unregisterReceiver(mHomeKeyEventReceiver);
        } catch (IllegalArgumentException e) {
            if (e.getMessage().contains("Receiver not registered")) {
                // Ignore this exception. This is exactly what is desired
            } else {
                // unexpected, re-throw
                throw e;
            }
        }
    }


    /**
     * 程序是否在前台运行
     *
     * @return 是否在前台运行
     */
    private boolean isAppOnForeground() {
        ActivityManager activityManager = (ActivityManager) context.getApplicationContext()
                .getSystemService(Context.ACTIVITY_SERVICE);
        String packageName = context.getApplicationContext().getPackageName();

        List<ActivityManager.RunningAppProcessInfo> appProcesses = activityManager.getRunningAppProcesses();
        if (appProcesses == null) {
            if (BuildConfig.DEBUG) {
                Log.d(TAG, "前台:" + null + "");
            }
            return false;
        }

        for (ActivityManager.RunningAppProcessInfo appProcess : appProcesses) {
            if (appProcess.processName.equals(packageName)
                    && appProcess.importance == ActivityManager.RunningAppProcessInfo.IMPORTANCE_FOREGROUND) {
                if (BuildConfig.DEBUG) {
                    Log.d(TAG, "后台" + appProcess.processName);
                }
                return true;
            }
        }

        return false;
    }

    private CountDownTimer countDownTimer = null;

    /**
     * 2小时退出应用程序
     */
    private void exitTimer() {
        final int closeTime = 60000 * 120;
        countDownTimer = new CountDownTimer(closeTime, 1000) {

            @Override
            public void onTick(long millisUntilFinished) {

            }

            @Override
            public void onFinish() {
                // 极端情况下，系统会直接杀死我们的app进程，
                // 并不执行activity的onDestroy()回调方法,
                // 因此我们需要使用onStop()来释放资源，从而避免内存泄漏
            }
        };
        countDownTimer.start();
    }

    /**
     * 设置定时关闭应用程序定时器
     */
    private void setTimer() {
        Log.d(TAG, "----->设置定时器");
        exitTimer();
    }

    /**
     * 取消定时关闭应用程序管理器
     */
    private void cancelTimer() {
        if (null != countDownTimer) {
            countDownTimer.cancel();
            Log.d(TAG, "----->取消定时器");
        }
    }

    /**
     * 清除用户数据
     */
    void clearBaseUserData() {
        //清除自定义文件夹下的文件
        DataCleanManager.cleanCustomCache(Files.getPhotoPath());
        DataCleanManager.cleanCustomCache(Files.getLogfile());
        DataCleanManager.cleanCustomCache(PathConfig.getImagePath());
        //删除品牌信息
        if (null == mBrandListDao) {
            mBrandListDao = getmBrandListDao();
        }
        mBrandListDao.deleteAll();
        //删除用户信息
        if (null == mCommonUserinfoBeanDao) {
            mCommonUserinfoBeanDao = getCommonUserinfoBeanDao();
        }
        mCommonUserinfoBeanDao.deleteAll();
        // 删除常用功能表
        if (null == mCommonResourcesBeanDao) {
            mCommonResourcesBeanDao = getmCommonResourcesBeanDao();
        }
        mCommonResourcesBeanDao.deleteAll();
        // 删除订货审核表
        if (null == mOrderGoodsAuditDetailDao) {
            mOrderGoodsAuditDetailDao = getOrderGoodsAuditDetailDao();
        }
        mOrderGoodsAuditDetailDao.deleteAll();

        //删除批量订货审核表
        if(null==mOrderGoodsAuditBatchDetailDao){
            mOrderGoodsAuditBatchDetailDao=getOrderGoodsAuditBatchDetailDao();
        }
        mOrderGoodsAuditBatchDetailDao.deleteAll();

        PrefTool.setStringsave(context, Prefs.PRE_USER_STAFFID, null);

        if (PrefTool.getBooleanPreferences(context, Prefs.PRE_USER_NAME_CHANGE, false)) {
            // 如果用户名改变，清除暂存数据库入职员工数据
            if (null == mNutritionConsultantDao) {
                mNutritionConsultantDao = getNutritionConsultantDao();
            }
            mNutritionConsultantDao.deleteAll();
            PrefTool.setBooleanSave(context, Prefs.PRE_USER_NAME_CHANGE, false);
        }
    }

    /**
     * 监听是否点击了home键将客户端推到后台
     */
    private BroadcastReceiver mHomeKeyEventReceiver = new BroadcastReceiver() {
        String systemReason = "reason";
        String systemHomeKey = "homekey";

        @Override
        public void onReceive(Context context, Intent intent) {
            String action = intent.getAction();
            if (Intent.ACTION_CLOSE_SYSTEM_DIALOGS.equals(action)) {
                String reason = intent.getStringExtra(systemReason);
                if (TextUtils.equals(reason, systemHomeKey)) {
                    // 表示按了home键,程序到了后台
                    exitTimer();// 定时关闭应用程序
                }
            }
        }
    };
}