package com.wgmf.yxgj.base;

import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.Intent;
import android.os.Bundle;
import android.util.Log;

import com.wgmf.library.utils.tools.PrefTool;
import com.wgmf.yxgj.global.Prefs;
import com.wgmf.yxgj.model.MessageExtraEntity;
import com.wgmf.yxgj.publics.service.ToMessageByType;
import com.wgmf.yxgj.utils.JPushUtil;
import com.xp.arouter.RouterCommonUtil;

import org.json.JSONException;
import org.json.JSONObject;

import java.util.Iterator;

import cn.jpush.android.api.JPushInterface;

/**
 * 自定义JPush推送消息接收器
 * 如果不定义这个 Receiver，则： 1) 默认用户会打开主界面 2) 接收不到自定义消息
 *
 * @author xiep
 */
@SuppressWarnings("all")
public class MessageReceiver extends BroadcastReceiver {
    private static final String TAG = "JPush";
    private static MessageExtraEntity mMessageExtraEntity = new MessageExtraEntity();

    @Override
    public void onReceive(Context context, Intent intent) {
        Bundle bundle = intent.getExtras();
        Log.d(TAG, "[MyReceiver] onReceive - " + intent.getAction() + ", extras: " + printBundle(bundle));
        if (JPushInterface.ACTION_REGISTRATION_ID.equals(intent.getAction())) {
            String regId = bundle.getString(JPushInterface.EXTRA_REGISTRATION_ID);
            Log.d(TAG, "[MyReceiver] 接收Registration Id : " + regId);
            // send the Registration Id to your server...
        } else if (JPushInterface.ACTION_MESSAGE_RECEIVED.equals(intent
                .getAction())) {
            Log.d(TAG, "[MyReceiver] 接收到推送下来的自定义消息: " + bundle.getString(JPushInterface.EXTRA_MESSAGE));
            processCustomMessage(context, bundle);
        } else if (JPushInterface.ACTION_NOTIFICATION_RECEIVED.equals(intent
                .getAction())) {
            Log.d(TAG, "[MyReceiver] 接收到推送下来的通知");
            int notifactionId = bundle.getInt(JPushInterface.EXTRA_NOTIFICATION_ID);
            Log.d(TAG, "[MyReceiver] 接收到推送下来的通知的ID: " + notifactionId);
        } else if (JPushInterface.ACTION_NOTIFICATION_OPENED.equals(intent
                .getAction())) {
            Log.d(TAG, "[MyReceiver] 用户点击打开了通知");
            // 从消息推送进入消息中心
            // 消息入口状态为真
            PrefTool.setBooleanSave(context, Prefs.PRE_MESSAGE_STATUS, true);
            // 打开自定义的Activity
            if (PrefTool.getBooleanPreferences(context, Prefs.PRE_LOGIN_STATUS, true)) {
                ToMessageByType.toClass(context, mMessageExtraEntity);
            } else {
                RouterCommonUtil.startFunctionActivity(context, -4, 0L, new Bundle());
            }
        } else if (JPushInterface.ACTION_RICHPUSH_CALLBACK.equals(intent.getAction())) {
            Log.d(TAG,
                    "[MyReceiver] 用户收到到RICH PUSH CALLBACK: "
                            + bundle.getString(JPushInterface.EXTRA_EXTRA));
            // 在这里根据 JPushInterface.EXTRA_EXTRA 的内容处理代码，比如打开新的Activity，
            // 打开一个网页等..
        } else if (JPushInterface.ACTION_CONNECTION_CHANGE.equals(intent
                .getAction())) {
            boolean connected = intent.getBooleanExtra(
                    JPushInterface.EXTRA_CONNECTION_CHANGE, false);
            Log.w(TAG, "[MyReceiver]" + intent.getAction()
                    + " connected state change to " + connected);
        } else {
            Log.d(TAG, "[MyReceiver] Unhandled intent - " + intent.getAction());
        }
    }

    /**
     * 打印所有的 intent extra 数据
     */
    private static String printBundle(Bundle bundle) {
        StringBuilder sb = new StringBuilder();
        if (bundle != null) {
            for (String key : bundle.keySet()) {
                if (key.equals(JPushInterface.EXTRA_NOTIFICATION_ID)) {
                    sb.append("\nkey:").append(key).append(", value:").append(bundle.getInt(key));
                } else if (key.equals(JPushInterface.EXTRA_CONNECTION_CHANGE)) {
                    sb.append("\nkey:").append(key).append(", value:").append(bundle.getBoolean(key));
                } else if (key.equals(JPushInterface.EXTRA_EXTRA)) {
                    if (bundle.getString(JPushInterface.EXTRA_EXTRA).isEmpty()) {
                        Log.i(TAG, "This message has no Extra data");
                        continue;
                    }
                    try {
                        JSONObject json = new JSONObject(bundle.getString(JPushInterface.EXTRA_EXTRA));
                        Iterator<String> it = json.keys();

                        while (it.hasNext()) {
                            String myKey = it.next();
                            sb.append("\nkey:").append(key).append(", value: [").append(myKey).append(" - ").append(json.optString(myKey)).append("]");
                            if ("type".equals(myKey)) {
                                mMessageExtraEntity.setType(json.optString(myKey));
                            }
                            if ("mid".equals(myKey)) {
                                mMessageExtraEntity.setMessageId(json.optString(myKey));
                            }
                            if ("operatorId".equals(myKey)) {
                                mMessageExtraEntity.setOperatorId(json.optString(myKey));
                            }
                            if ("code".equals(myKey)) {
                                mMessageExtraEntity.setCode(json.optString(myKey));
                            }
                            if ("yearMonth".equals(myKey)) {
                                mMessageExtraEntity.setYearMonth(json.optString(myKey));
                            }
                            if ("staffName".equals(myKey)) {
                                mMessageExtraEntity.setStaffName(json.optString(myKey));
                            }
                            if ("storeId".equals(myKey)) {
                                mMessageExtraEntity.setStoreId(json.optString(myKey));
                            }
                            if ("storeName".equals(myKey)) {
                                mMessageExtraEntity.setStoreName(json.optString(myKey));
                            }
                            if ("shopLevel".equals(myKey)) {
                                mMessageExtraEntity.setShopLevel(json.optString(myKey));
                            }
                            if ("storeLatitudes".equals(myKey)) {
                                mMessageExtraEntity.setStoreLatitudes(json.optString(myKey));
                            }
                            if ("storeLongitudes".equals(myKey)) {
                                mMessageExtraEntity.setStoreLongitudes(json.optString(myKey));
                            }
                        }
                    } catch (JSONException e) {
                        Log.e(TAG, "Get message extra JSON error!");
                    }
                } else {
                    sb.append("\nkey:").append(key).append(", value:").append(bundle.getString(key));
                }
            }
        }
        return sb.toString();
    }

    /**
     * send msg to MainActivity
     */
    private void processCustomMessage(Context context, Bundle bundle) {
        if (BaseActivityPresenter.isForeground) {
            String message = bundle.getString(JPushInterface.EXTRA_MESSAGE);
            String extras = bundle.getString(JPushInterface.EXTRA_EXTRA);
            Intent msgIntent = new Intent(BaseActivityPresenter.MESSAGE_RECEIVED_ACTION);
            msgIntent.putExtra(BaseActivityPresenter.KEY_MESSAGE, message);
            if (!JPushUtil.isEmpty(extras)) {
                try {
                    JSONObject extraJson = new JSONObject(extras);
                    if (extraJson.length() > 0) {
                        msgIntent.putExtra(BaseActivityPresenter.KEY_EXTRAS, extras);
                    }
                } catch (JSONException e) {
                    Log.e("MessageReceiver", "processCustomMessage: ", e);
                }

            }
            context.sendBroadcast(msgIntent);
        }
    }
}