package com.wgmf.yxgj.base;

import android.content.Context;
import android.graphics.Bitmap;
import android.graphics.drawable.Drawable;
import android.util.SparseArray;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.ImageView;
import android.widget.LinearLayout;
import android.widget.TextView;

import com.bumptech.glide.Glide;
import com.wgmf.yxgj.app.LibGroupContext;

/**
 * @author xiep on 2016/7/20 16:32
 */
public class ViewHolder {
    private final SparseArray<View> mViews;
    private int mPosition;
    private View mConvertView;

    private ViewHolder(Context context, ViewGroup parent, int layoutId,
                       int position) {
        this.mPosition = position;
        this.mViews = new SparseArray<>();
        mConvertView = LayoutInflater.from(context).inflate(layoutId, parent, false);
        // setTag
        mConvertView.setTag(this);
    }

    /**
     * 拿到一个ViewHolder对象
     */
    public static ViewHolder get(Context context, View convertView,
                                 ViewGroup parent, int layoutId, int position) {
        if (convertView == null) {
            return new ViewHolder(context, parent, layoutId, position);
        }
        return (ViewHolder) convertView.getTag();
    }

    public View getConvertView() {
        return mConvertView;
    }

    /**
     * 通过控件的Id获取对于的控件，如果没有则加入views
     */
    private <T extends View> T getView(int viewId) {
        View view = mViews.get(viewId);
        if (view == null) {
            view = mConvertView.findViewById(viewId);
            mViews.put(viewId, view);
        }
        return (T) view;
    }

    /**
     * 为TextView设置字符串
     */
    public ViewHolder setText(String text) {
        TextView view = getView(R.id.public_list_item_title);
        view.setText(text);
        return this;
    }
    /**
     * 为TextView设置字符串
     */
    public ViewHolder setTextColor(int color) {
        TextView view = getView(R.id.public_list_item_title);
        view.setTextColor(color);
        return this;
    }
    /**
     * 为TextView设置字符串
     */
    public ViewHolder setGravity(int gravity) {
        TextView view = getView(R.id.public_list_item_title);
        view.setGravity(gravity);
        return this;
    }
    /**
     * 为TextView设置字符串
     */
    public ViewHolder setBackGroud(Drawable drawable) {
        LinearLayout view = getView(R.id.public_list_item_ll);
        view.setBackground(drawable);
        return this;
    }

    /**
     * 为TextView设置字符串
     */
    public ViewHolder setPadding(int left, int top, int right, int bottom) {
        LinearLayout view = getView(R.id.public_list_item_ll);
        view.setPadding(left,top,right,bottom);
        return this;
    }
    /**
     * 为ImageView设置图片
     */
    public ViewHolder setLeftImageResource(Drawable drawableId) {
        ImageView view = getView(R.id.public_list_item_left_img);
        view.setImageDrawable(drawableId);
        return this;
    }

    /**
     * 左图标显示与隐藏
     */
    public ViewHolder setLeftImageGone(int visible) {
        TextView view = getView(R.id.public_list_item_left_img);
        view.setVisibility(visible);
        return this;
    }

    /**
     * 为ImageView设置图片
     */
    public ViewHolder setImageBitmap(int viewId, Bitmap bm) {
        ImageView view = getView(viewId);
        view.setImageBitmap(bm);
        return this;
    }

    /**
     * 为ImageView设置图片
     */
    public ViewHolder setImageByUrl(String url) {
        ImageView view = getView(R.id.public_list_item_left_img);
        Glide.with(LibGroupContext.getApplication()).load(url).into(view);
        return this;
    }

    /**
     * 右箭头显示与隐藏
     */
    public ViewHolder setRightGone(int visible) {
        TextView view = getView(R.id.public_list_item_go);
        view.setVisibility(visible);
        return this;
    }

    /**
     * 为右文字TextView设置字符串
     */
    public ViewHolder setRightText(String text) {
        TextView view = getView(R.id.public_list_item_go);
        view.setText(text);
        return this;
    }

    public int getPosition() {
        return mPosition;
    }

}