package com.wgmf.yxgj.dialog;

import android.content.Context;
import android.content.Intent;
import android.os.Bundle;
import android.text.TextUtils;
import android.view.View;
import android.widget.ImageView;
import android.widget.RelativeLayout;

import com.alibaba.android.arouter.launcher.ARouter;
import com.bumptech.glide.Glide;
import com.flyco.dialog.widget.base.BaseDialog;
import com.wgmf.yxgj.base.R;
import com.wgmf.yxgj.global.AppConstants;
import com.wgmf.yxgj.utils.MyToast;
import com.xp.arouter.RouterCommonUtil;

/**
 * @author chenji
 * @date 2018/4/28
 */
@SuppressWarnings("all")
public class AdDialog extends BaseDialog {
    private Context context;
    private ImageView ivAd;
    private ImageView back;
    private ImageView DIYImage;
    private View columnLine;//竖线
    private String imageUrl;
    private int imageRid = -1;//图片资源id
    private RelativeLayout rectangleLayout;//白色框框
    //    private NationalAdRes resultInfo;
    private String clickLink = "";
    private String linkType = "";
    private boolean isDIY = false;//是否是DIY模式（默认False）其实就是不要那个白框框
    private boolean canBackPress = true;//能否用返回键关闭弹窗（默认true）
    private DismissCallback dissmissCallback;//点击叉叉的回调

    public static abstract class DismissCallback {
        public abstract void run();
    }

    public AdDialog(Context context) {
        super(context);
        this.context = context;
    }

    public AdDialog(Context context, String imageUrl) {
        super(context);
        this.context = context;
        this.imageUrl = imageUrl;
    }

    public void setDismissCallback(DismissCallback callback){
        this.dissmissCallback = callback;
    }

    public AdDialog(Context context, int imageRid) {
        super(context);
        this.context = context;
        this.imageRid = imageRid;
    }

    public void setClickLink(String clickLink) {
        this.clickLink = clickLink;
    }

    /**
     * 图片是否是DIY模式
     */
    public void setIsDIY(boolean isDIY) {
        this.isDIY = isDIY;
    }

    public void setLinkType(String linkType) {
        this.linkType = linkType;
    }

    /**
     * 判断非空
     *
     * @param o   ...
     * @param <T> ...
     * @return ...
     */
    private <T> T requireNonNull(T o) {
        if (o == null) {
            throw new NullPointerException();
        }
        return o;
    }

    @Override
    public void onBackPressed() {
        if (canBackPress){
            super.onBackPressed();
        }
    }

    public void setCanBackPress(boolean canBack){
        this.canBackPress = canBack;
    }

    @Override
    public View onCreateView() {
//        widthScale(0.85f);
        //填充弹窗布局
        View v = View.inflate(context, R.layout.national_ad_dialog, null);
        DIYImage = (ImageView) v.findViewById(R.id.DIYImage);
        //用来放整个图片的控件
        ivAd = (ImageView) v.findViewById(R.id.iv_ad);
        //放在透明部分和错号上的隐形控件，用来点击使弹窗消失
        back = (ImageView) v.findViewById(R.id.ad_back);
        //用来加载网络图片，填充iv_ad控件，注意要添加网络权限，和Picasso的依赖和混淆
        columnLine = (View) v.findViewById(R.id.columnLine);
        rectangleLayout = (RelativeLayout) v.findViewById(R.id.rectangleLayout);
        columnLine.setVisibility(isDIY ? View.INVISIBLE : View.VISIBLE);
        rectangleLayout.setVisibility(isDIY? View.GONE : View.VISIBLE);
        if (imageRid == -1) {
            Glide.with(context)
//                .load(imageResourceId)
//                .load("https://raw.githubusercontent.com/yipianfengye/android-adDialog/master/images/testImage1.png")
                    //加载后台的图片地址
                    .load(!TextUtils.isEmpty(imageUrl) ? imageUrl : R.drawable.pop_hone_qgwsr_default)
                    .centerCrop()
                    .dontAnimate()//防止设置placeholder导致第一次不显示网络图片,只显示默认图片的问题
                    .error(R.drawable.error_404)
                    .placeholder(R.drawable.pop_hone_qgwsr_default)
                    .into(ivAd);

        } else {
            Glide.with(context)
//                .load(imageResourceId)
//                .load("https://raw.githubusercontent.com/yipianfengye/android-adDialog/master/images/testImage1.png")
                    //加载后台的图片地址
                    .load(imageRid)
//                    .fitCenter()
//                    .centerCrop()
                    .dontAnimate()//防止设置placeholder导致第一次不显示网络图片,只显示默认图片的问题
//                    .error(R.drawable.pop_hone_qgwsr_default)
//                    .placeholder(R.drawable.pop_hone_qgwsr_default)
                    .into(DIYImage);
        }

        return v;
    }

    @Override
    public void setUiBeforShow() {
        //点击弹窗相应位置，处理相关逻辑。
        ivAd.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                if (!TextUtils.isEmpty(clickLink)) {
                    jump2Page(clickLink, linkType);
                } else {
                    dismiss();
                }
            }
        });
        //点×关闭弹框的代码
        back.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                //关闭弹框的代码
                dismiss();
//                if (dissmissCallback != null){
//                    dissmissCallback.run();
//                }
            }
        });
    }

    @Override
    public void dismiss() {
        super.dismiss();
        if (dissmissCallback != null) {
            dissmissCallback.run();
        }
    }

    /**
     * 页面跳转
     */
    private void jump2Page(String clickLink, String linkType) {
        //外部跳转
        try {
            if (!TextUtils.isEmpty(linkType) && AppConstants.LinkType.URL.equals(linkType.toString().trim())) {
                if (!TextUtils.isEmpty(clickLink)) {
                    Bundle htmlBundle = new Bundle();
                    htmlBundle.putString("mainUrl", clickLink.startsWith("http")? clickLink.trim() : ("http://" + clickLink));
                    RouterCommonUtil.startFunctionActivity(context,0,null,htmlBundle);
                } else {
                    MyToast.show("当前配置有问题");
                }
            }
            //内部跳转
            else if (!TextUtils.isEmpty(linkType) && AppConstants.LinkType.NATIVE.equals(linkType.trim())) {
                //本地页面跳转
                if (!TextUtils.isEmpty(clickLink)) {
                    if (clickLink.trim().startsWith("com")) {
                        context.startActivity(new Intent(context, Class.forName(clickLink.trim())));
                    } else {
                        ARouter.getInstance().build(clickLink.trim()).navigation();
                    }
                } else {
                    MyToast.show("当前配置有问题");
                }
            }
            //不跳转 （不管是那种状态最后走到这里都需要去掉dialog）
//            else {
//            new Handler().postDelayed(new Runnable() {
//                @Override
//                public void run() {
//                    dismiss();
//                }
//            },500);

//            }
        } catch (ClassNotFoundException e) {
            e.printStackTrace();
            MyToast.show("当前配置有问题");
        }
    }
}