package com.wgmf.yxgj.dialog;

import android.app.Dialog;
import android.content.Context;
import android.content.DialogInterface;
import android.view.Gravity;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.view.ViewGroup.LayoutParams;
import android.view.Window;
import android.view.WindowManager;
import android.widget.TextView;

import com.wgmf.yxgj.base.R;

/**
 * @author xiep
 */
public class AppTipDialog extends Dialog {

    private AppTipDialog(Context context, int theme) {
        super(context, theme);
    }

    public static class Builder {
        private Context context;
        private String message;
        private OnClickListener positiveButtonClickListener;

        public Builder(Context context) {
            this.context = context;
        }

        public Builder setMessage(String message) {
            this.message = message;
            return this;
        }

        /**
         * Set the Dialog message from resource
         */
        public Builder setMessage(int message) {
            this.message = (String) context.getText(message);
            return this;
        }

        public Builder setPositiveButton(OnClickListener listener) {
            this.positiveButtonClickListener = listener;
            return this;
        }

        public AppTipDialog create() {
            // instantiate the dialog with the custom Theme
            final AppTipDialog dialog = new AppTipDialog(context, R.style.confirm_dialog);
            View layout = LayoutInflater.from(context).inflate(R.layout.view_app_tip_dialog, null);
            dialog.addContentView(layout, new LayoutParams(LayoutParams.WRAP_CONTENT, LayoutParams.WRAP_CONTENT));
            Window dialogWindow = dialog.getWindow();
            if (null != dialogWindow) {
                dialogWindow.setGravity(Gravity.BOTTOM);
            }
            if (message != null) {
                ((TextView) layout.findViewById(R.id.app_tip_content_tv)).setText(message);
            }
            // set the confirm button
            if (positiveButtonClickListener != null) {
                layout.findViewById(R.id.app_tip_cancel_btn)
                        .setOnClickListener(new View.OnClickListener() {
                            @Override
                            public void onClick(View v) {
                                positiveButtonClickListener.onClick(dialog,
                                        DialogInterface.BUTTON_POSITIVE);
                            }
                        });
            }
            dialog.setContentView(layout);
            return dialog;
        }
    }
}