package com.wgmf.yxgj.dialog;

import android.app.Dialog;
import android.content.Context;
import android.content.DialogInterface;
import android.support.v4.content.ContextCompat;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup.LayoutParams;
import android.widget.Button;
import android.widget.RelativeLayout;
import android.widget.TextView;

import com.wgmf.yxgj.base.R;
import com.wgmf.yxgj.global.ConstantParams;

/**
 * @author xiep
 */
public class MonthReportAppraiseTxtDialog extends Dialog {

    private MonthReportAppraiseTxtDialog(Context context) {
        super(context, R.style.textview_dialog);
    }

    public static class Builder {
        private Context context;
        private String title;
        private String message;
        private String positiveButtonText;
        private String negativeButtonText;
        private View contentView;
        private OnClickListener positiveButtonClickListener;
        private OnClickListener negativeButtonClickListener;
        /**
         * 提交的数据
         */
        private String appraiseMsg;
        private String setIsComplete;

        public Builder(Context context) {
            this.context = context;
        }

        /**
         * Set the Dialog message from resource
         */
        public Builder setMessage(int message) {
            this.message = (String) context.getText(message);
            return this;
        }

        /**
         * Set the Dialog title from String
         */
        public Builder setTitle(String title) {
            this.title = title;
            return this;
        }


        public void setAppraiseMsg(String appraiseMsg) {
            this.appraiseMsg = appraiseMsg;
        }

        public void setSetIsComplete(String setIsComplete) {
            this.setIsComplete = setIsComplete;
        }

        public Builder setContentView(View v) {
            this.contentView = v;
            return this;
        }

        public Builder setPositiveButton(OnClickListener listener) {
            this.positiveButtonText = "";
            this.positiveButtonClickListener = listener;
            return this;
        }

        public Builder setNegativeButton(OnClickListener listener) {
            this.negativeButtonText = "";
            this.negativeButtonClickListener = listener;
            return this;
        }

        public MonthReportAppraiseTxtDialog create() {
            // instantiate the dialog with the custom Theme
            final MonthReportAppraiseTxtDialog dialog = new MonthReportAppraiseTxtDialog(context
            );
            View layout = LayoutInflater.from(context).inflate(R.layout.appriase_monthly_report_look_dialog, null);
            dialog.addContentView(layout, new LayoutParams(
                    LayoutParams.WRAP_CONTENT, LayoutParams.WRAP_CONTENT));
            // set the dialog title
            ((TextView) layout.findViewById(R.id.appriase_title_tv))
                    .setText(title);
            TextView isCompleteNumberEt = ((TextView) layout
                    .findViewById(R.id.is_complete_et));
            Button isCompleteContentYes = ((Button) layout
                    .findViewById(R.id.is_complete_content_yes));
            Button isCompleteContentNo = ((Button) layout
                    .findViewById(R.id.is_complete_content_no));
            isCompleteNumberEt.setText(appraiseMsg);

            if (ConstantParams.CONSTANT_PARAMS_2.equals(setIsComplete)) {
                isCompleteContentYes.setTextColor(ContextCompat.getColor(context, R.color.white));
                isCompleteContentYes.setBackgroundResource(R.drawable.btn_week_check_style);
                isCompleteContentYes.setVisibility(View.VISIBLE);
                isCompleteContentYes.setText("是");
                isCompleteContentNo.setVisibility(View.INVISIBLE);
            } else {
                isCompleteContentYes.setTextColor(ContextCompat.getColor(context, R.color.white));
                isCompleteContentYes.setBackgroundResource(R.drawable.btn_week_check_style);
                isCompleteContentYes.setVisibility(View.VISIBLE);
                isCompleteContentYes.setText("否");
                isCompleteContentNo.setVisibility(View.INVISIBLE);
            }
            // set the confirm button
            if (positiveButtonText != null) {
                ((Button) layout.findViewById(R.id.appriase_cancel_btn))
                        .setText(positiveButtonText);
                if (positiveButtonClickListener != null) {
                    layout.findViewById(R.id.appriase_cancel_btn)
                            .setOnClickListener(new View.OnClickListener() {
                                @Override
                                public void onClick(View v) {
                                    positiveButtonClickListener.onClick(dialog,
                                            DialogInterface.BUTTON_POSITIVE);

                                }
                            });
                }
            } else {
                // if no confirm button just set the visibility to GONE
                layout.findViewById(R.id.appriase_cancel_btn).setVisibility(View.GONE);
            }
            // set the cancel button
            if (negativeButtonText != null) {
                ((Button) layout.findViewById(R.id.appriase_confirm_btn))
                        .setText(negativeButtonText);
                if (negativeButtonClickListener != null) {
                    layout.findViewById(R.id.appriase_confirm_btn)
                            .setOnClickListener(new View.OnClickListener() {
                                @Override
                                public void onClick(View v) {
                                    negativeButtonClickListener.onClick(dialog,
                                            DialogInterface.BUTTON_NEGATIVE);
                                }
                            });
                }
            } else {
                // if no confirm button just set the visibility to GONE
                layout.findViewById(R.id.appriase_confirm_btn).setVisibility(View.GONE);
            }
            // set the content message
            if (message != null) {
                ((TextView) layout.findViewById(R.id.is_complete_tv)).setText(message);
            } else if (contentView != null) {
                // if no message set
                // add the contentView to the dialog body
                ((RelativeLayout) layout.findViewById(R.id.appriase_content_rl))
                        .removeAllViews();
                ((RelativeLayout) layout.findViewById(R.id.appriase_content_rl))
                        .addView(contentView, new LayoutParams(
                                LayoutParams.WRAP_CONTENT,
                                LayoutParams.WRAP_CONTENT));
            }
            dialog.setContentView(layout);
            return dialog;
        }
    }
}