package com.wgmf.yxgj.dialog;

import android.app.Dialog;
import android.content.Context;
import android.content.DialogInterface;
import android.text.TextUtils;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup.LayoutParams;
import android.widget.Button;
import android.widget.RadioButton;
import android.widget.TextView;

import com.wgmf.yxgj.base.R;

/**
 * @author xiep
 */
public class PublicChooseDialog extends Dialog {

    private PublicChooseDialog(Context context) {
        super(context, R.style.textview_dialog);
    }

    public static class Builder {
        private Context context;
        private int isComplete = 1;
        private String title;
        private String positiveButtonText;
        private String negativeButtonText;
        private String yesRbText;
        private String noRbText;
        private OnClickListener positiveButtonClickListener;
        private OnClickListener negativeButtonClickListener;

        private TextView mChooseDialogTitleTv;
        private RadioButton mChooseDialogYesRb;
        private RadioButton mChooseDialogNoRb;

        public Builder(Context context) {
            this.context = context;
        }

        public int getIsComplete() {
            return isComplete;
        }

        public void setIsComplete(int isComplete) {
            this.isComplete = isComplete;
        }

        public Builder setTitle(int title) {
            this.title = (String) context.getText(title);
            return this;
        }

        public Builder setTitle(String title) {
            this.title = title;
            return this;
        }

        public Builder setYesRbText(int yesRbText) {
            this.yesRbText = (String) context.getText(yesRbText);
            return this;
        }

        public Builder setYesRbText(String yesRbText) {
            this.yesRbText = yesRbText;
            return this;
        }

        public Builder setNoRbText(int noRbText) {
            this.noRbText = (String) context.getText(noRbText);
            return this;
        }

        public Builder setNoRbText(String noRbText) {
            this.noRbText = noRbText;
            return this;
        }

        /**
         * Set the positive button resource and it's listener
         */
        public Builder setPositiveButton(int positiveButtonText,
                                         OnClickListener listener) {
            this.positiveButtonText = (String) context
                    .getText(positiveButtonText);
            this.positiveButtonClickListener = listener;
            return this;
        }

        public Builder setPositiveButton(OnClickListener listener) {
            this.positiveButtonText = "取消";
            this.positiveButtonClickListener = listener;
            return this;
        }

        public Builder setNegativeButton(int negativeButtonText,
                                         OnClickListener listener) {
            this.negativeButtonText = (String) context
                    .getText(negativeButtonText);
            this.negativeButtonClickListener = listener;
            return this;
        }

        public Builder setNegativeButton(OnClickListener listener) {
            this.negativeButtonText = "确定";
            this.negativeButtonClickListener = listener;
            return this;
        }

        public PublicChooseDialog create() {
            // instantiate the dialog with the custom Theme
            final PublicChooseDialog dialog = new PublicChooseDialog(context);
            View layout = LayoutInflater.from(context).inflate(R.layout.view_choose_dialog, null);
            dialog.addContentView(layout, new LayoutParams(
                    LayoutParams.WRAP_CONTENT, LayoutParams.WRAP_CONTENT));
            mChooseDialogTitleTv = layout.findViewById(R.id.choose_dialog_title_tv);
            if (!TextUtils.isEmpty(title)) {
                mChooseDialogTitleTv.setText(title);
                mChooseDialogTitleTv.setVisibility(View.VISIBLE);
            } else {
                mChooseDialogTitleTv.setVisibility(View.GONE);
            }
            mChooseDialogYesRb = layout
                    .findViewById(R.id.choose_dialog_yes_rb);
            if (!TextUtils.isEmpty(yesRbText)) {
                mChooseDialogYesRb.setText(yesRbText);
            }

            mChooseDialogNoRb = layout
                    .findViewById(R.id.choose_dialog_no_rb);
            if (!TextUtils.isEmpty(noRbText)) {
                mChooseDialogNoRb.setText(noRbText);
            }

            if (isComplete == 1) {
                mChooseDialogYesRb.setChecked(true);
                mChooseDialogNoRb.setChecked(false);
            } else {
                mChooseDialogNoRb.setChecked(true);
                mChooseDialogYesRb.setChecked(false);
            }

            mChooseDialogYesRb.setOnClickListener(arg0 -> {
                if (mChooseDialogYesRb.isChecked()) {
                    setIsComplete(1);
                    mChooseDialogYesRb.setChecked(true);
                } else {
                    setIsComplete(2);
                    mChooseDialogNoRb.setChecked(true);
                }
            });
            mChooseDialogNoRb.setOnClickListener(arg0 -> {
                if (mChooseDialogNoRb.isChecked()) {
                    setIsComplete(2);
                    mChooseDialogNoRb.setChecked(true);
                } else {
                    setIsComplete(1);
                    mChooseDialogYesRb.setChecked(true);
                }
            });

            // set the confirm button
            if (positiveButtonText != null) {
                ((Button) layout.findViewById(R.id.choose_dialog_cancel_btn))
                        .setText(positiveButtonText);
                if (positiveButtonClickListener != null) {
                    layout.findViewById(R.id.choose_dialog_cancel_btn)
                            .setOnClickListener(v -> positiveButtonClickListener.onClick(dialog,
                                    DialogInterface.BUTTON_POSITIVE));
                }
            } else {
                // if no confirm button just set the visibility to GONE
                layout.findViewById(R.id.choose_dialog_cancel_btn).setVisibility(View.GONE);
            }
            // set the cancel button
            if (negativeButtonText != null) {
                ((Button) layout.findViewById(R.id.choose_dialog_confirm_btn))
                        .setText(negativeButtonText);
                if (negativeButtonClickListener != null) {
                    layout.findViewById(R.id.choose_dialog_confirm_btn)
                            .setOnClickListener(v -> negativeButtonClickListener.onClick(dialog,
                                    DialogInterface.BUTTON_NEGATIVE));
                }
            } else {
                // if no confirm button just set the visibility to GONE
                layout.findViewById(R.id.choose_dialog_confirm_btn).setVisibility(View.GONE);
            }
            dialog.setContentView(layout);
            return dialog;
        }
    }
}