package com.wgmf.yxgj.dialog;

import android.app.Dialog;
import android.content.Context;
import android.content.DialogInterface;
import android.text.TextUtils;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup.LayoutParams;
import android.widget.Button;
import android.widget.EditText;
import android.widget.RadioButton;
import android.widget.RelativeLayout;
import android.widget.TextView;

import com.wgmf.yxgj.base.R;

/**
 * @author xiep
 */
public class PublicEditChooseDialog extends Dialog {

    private PublicEditChooseDialog(Context context) {
        super(context, R.style.textview_dialog);
    }

    public static class Builder {
        private Context context;
        private int isComplete = 1;
        private String title;
        private String positiveButtonText;
        private String negativeButtonText;
        private String inputEtHintText;
        private String yesRbText;
        private String noRbText;
        private OnClickListener positiveButtonClickListener;
        private OnClickListener negativeButtonClickListener;

        private TextView mEditDialogTitleTv;
        private EditText mEditDialogInputEt;
        private RadioButton mEditDialogYesRb;
        private RadioButton mEditDialogNoRb;

        public Builder(Context context) {
            this.context = context;
        }

        public int getIsComplete() {
            return isComplete;
        }

        private void setIsComplete(int isComplete) {
            this.isComplete = isComplete;
        }

        public String getDialogInputValue() {
            return mEditDialogInputEt.getText().toString();
        }

        public Builder setTitle(int title) {
            this.title = (String) context.getText(title);
            return this;
        }

        public Builder setTitle(String title) {
            this.title = title;
            return this;
        }

        public Builder setInputEtHintText(int inputEtHintText) {
            this.inputEtHintText = (String) context.getText(inputEtHintText);
            return this;
        }

        public Builder setInputEtHintText(String inputEtHintText) {
            this.inputEtHintText = inputEtHintText;
            return this;
        }

        public Builder setYesRbText(int yesRbText) {
            this.yesRbText = (String) context.getText(yesRbText);
            return this;
        }

        public Builder setYesRbText(String yesRbText) {
            this.yesRbText = yesRbText;
            return this;
        }

        public Builder setNoRbText(int noRbText) {
            this.noRbText = (String) context.getText(noRbText);
            return this;
        }

        public Builder setNoRbText(String noRbText) {
            this.noRbText = noRbText;
            return this;
        }

        /**
         * Set the positive button resource and it's listener
         */
        public Builder setPositiveButton(int positiveButtonText,
                                         OnClickListener listener) {
            this.positiveButtonText = (String) context
                    .getText(positiveButtonText);
            this.positiveButtonClickListener = listener;
            return this;
        }

        public Builder setPositiveButton(OnClickListener listener) {
            this.positiveButtonText = "取消";
            this.positiveButtonClickListener = listener;
            return this;
        }

        public Builder setNegativeButton(int negativeButtonText,
                                         OnClickListener listener) {
            this.negativeButtonText = (String) context
                    .getText(negativeButtonText);
            this.negativeButtonClickListener = listener;
            return this;
        }

        public Builder setNegativeButton(OnClickListener listener) {
            this.negativeButtonText = "确定";
            this.negativeButtonClickListener = listener;
            return this;
        }

        public PublicEditChooseDialog create() {
            // instantiate the dialog with the custom Theme
            final PublicEditChooseDialog dialog = new PublicEditChooseDialog(context);
            View layout = LayoutInflater.from(context).inflate(R.layout.view_edit_choose_dialog, null);
            dialog.addContentView(layout, new LayoutParams(
                    LayoutParams.WRAP_CONTENT, LayoutParams.WRAP_CONTENT));
            mEditDialogTitleTv = layout.findViewById(R.id.edit_dialog_title_tv);
            if (!TextUtils.isEmpty(title)) {
                mEditDialogTitleTv.setText(title);
                mEditDialogTitleTv.setVisibility(View.VISIBLE);
            } else {
                mEditDialogTitleTv.setVisibility(View.GONE);
            }
            mEditDialogInputEt = layout
                    .findViewById(R.id.edit_dialog_input_et);
            if (!TextUtils.isEmpty(inputEtHintText)) {
                mEditDialogInputEt.setHint(inputEtHintText);
            }
            mEditDialogYesRb = layout
                    .findViewById(R.id.edit_dialog_yes_rb);
            if (!TextUtils.isEmpty(yesRbText)) {
                mEditDialogYesRb.setText(yesRbText);
            }
            mEditDialogNoRb = layout
                    .findViewById(R.id.edit_dialog_no_rb);
            if (!TextUtils.isEmpty(noRbText)) {
                mEditDialogNoRb.setText(noRbText);
            }
            mEditDialogYesRb.setOnClickListener(new View.OnClickListener() {

                @Override
                public void onClick(View arg0) {
                    if (mEditDialogYesRb.isChecked()) {
                        setIsComplete(1);
                        mEditDialogInputEt.setVisibility(View.GONE);
                        mEditDialogYesRb.setChecked(true);
                    } else {
                        setIsComplete(2);
                        mEditDialogInputEt.setVisibility(View.VISIBLE);
                        mEditDialogNoRb.setChecked(true);
                    }
                }
            });
            mEditDialogNoRb.setOnClickListener(new View.OnClickListener() {

                @Override
                public void onClick(View arg0) {
                    if (mEditDialogNoRb.isChecked()) {
                        setIsComplete(2);
                        mEditDialogInputEt.setVisibility(View.VISIBLE);
                        mEditDialogNoRb.setChecked(true);
                    } else {
                        setIsComplete(1);
                        mEditDialogInputEt.setVisibility(View.GONE);
                        mEditDialogYesRb.setChecked(true);
                    }
                }
            });

            // set the confirm button
            if (positiveButtonText != null) {
                ((Button) layout.findViewById(R.id.edit_dialog_cancel_btn))
                        .setText(positiveButtonText);
                if (positiveButtonClickListener != null) {
                    layout.findViewById(R.id.edit_dialog_cancel_btn)
                            .setOnClickListener(new View.OnClickListener() {
                                @Override
                                public void onClick(View v) {
                                    positiveButtonClickListener.onClick(dialog,
                                            DialogInterface.BUTTON_POSITIVE);

                                }
                            });
                }
            } else {
                // if no confirm button just set the visibility to GONE
                layout.findViewById(R.id.edit_dialog_cancel_btn).setVisibility(View.GONE);
            }
            // set the cancel button
            if (negativeButtonText != null) {
                ((Button) layout.findViewById(R.id.edit_dialog_confirm_btn))
                        .setText(negativeButtonText);
                if (negativeButtonClickListener != null) {
                    layout.findViewById(R.id.edit_dialog_confirm_btn)
                            .setOnClickListener(new View.OnClickListener() {
                                @Override
                                public void onClick(View v) {
                                    negativeButtonClickListener.onClick(dialog,
                                            DialogInterface.BUTTON_NEGATIVE);
                                }
                            });
                }
            } else {
                // if no confirm button just set the visibility to GONE
                layout.findViewById(R.id.edit_dialog_confirm_btn).setVisibility(View.GONE);
            }
            dialog.setContentView(layout);
            return dialog;
        }
    }
}