package com.wgmf.yxgj.global

import android.annotation.SuppressLint
import android.content.Context
import android.util.Log
import com.wgmf.yxgj.db.*
import com.wgmf.yxgj.model.BrandList
import com.wgmf.yxgj.model.CommonResourcesBean
import com.wgmf.yxgj.model.CommonUserinfoBean
import java.lang.ref.SoftReference
import java.lang.ref.WeakReference

/**
 * 本地数据转换到内存中
 */
class DbToMemoryConstants private constructor(private val context: WeakReference<Context>) {

    companion object {
        private var instance: DbToMemoryConstants? = null

        fun getInstance(context: Context) =

            instance ?: synchronized(this) {
                instance ?: DbToMemoryConstants(WeakReference(context.applicationContext)).also {
                    instance = it
                }
            }

        /**
         * 用户信息
         */
        var userInfo: SoftReference<CommonUserinfoBean>? = null

        /**
         * 品牌列表数据
         */
        var brandList: SoftReference<List<BrandList>>? = null

        /**
         * 常用功能列表数据
         */
        var resources: SoftReference<List<CommonResourcesBean>>? = null

    }

    private val mBrandListDao: BrandListDao by lazy {
        GreenDaoManager.getInstance().getDaoSession(context.get()).brandListDao
    }

    private val mCommonUserinfoBeanDao: CommonUserinfoBeanDao by lazy {
        GreenDaoManager.getInstance().getDaoSession(context.get()).commonUserinfoBeanDao
    }

    private val mCommonResourcesBeanDao: CommonResourcesBeanDao by lazy {
        GreenDaoManager.getInstance().getDaoSession(context.get()).commonResourcesBeanDao
    }

    private val mOrderGoodsAuditDetailDao: OrderGoodsAuditDetailDao by lazy {
        GreenDaoManager.getInstance().getDaoSession(context.get()).orderGoodsAuditDetailDao
    }

    private val mOrderGoodsAuditBatchDetailDao: OrderGoodsAuditBatchDetailDao by lazy {
        GreenDaoManager.getInstance().getDaoSession(context.get()).orderGoodsAuditBatchDetailDao
    }

    private val mNutritionConsultantDao: NutritionConsultantDao by lazy {
        GreenDaoManager.getInstance().getDaoSession(context.get()).nutritionConsultantDao
    }

    fun init() {
        obtainBrandListData()

        obtainUserInfoData()

        obtainCommonResourcesData()
    }

    /**
     * 获取品牌列表数据
     */
    fun obtainBrandListData(): List<BrandList>? {
        try {
            brandList = SoftReference(mBrandListDao.loadAll())
        } catch (e: Exception) {
            e.printStackTrace()
        }
        return brandList?.get()
    }

    /**
     * 获取用户信息数据
     */
    fun obtainUserInfoData(): CommonUserinfoBean? {
        try {
            userInfo = SoftReference(mCommonUserinfoBeanDao.loadAll().get(0))
        } catch (e: Exception) {
            e.printStackTrace()
        }
        return userInfo?.get()
    }

    /**
     * 获取常用功能列表数据
     */
    fun obtainCommonResourcesData(): List<CommonResourcesBean>? {
        try {
            resources = SoftReference(mCommonResourcesBeanDao.loadAll())
        } catch (e: Exception) {
            e.printStackTrace()
        }
        return resources?.get()
    }
}