package com.wgmf.yxgj.pop;

import android.content.Context;
import android.graphics.drawable.BitmapDrawable;
import android.view.Gravity;
import android.view.LayoutInflater;
import android.view.View;
import android.view.WindowManager;
import android.widget.LinearLayout;
import android.widget.PopupWindow;
import com.wgmf.yxgj.base.R;
import com.wgmf.yxgj.global.MediaParams;

/**
 * 图片选择
 *
 * @author xiep on 2017/3/1 09:37
 */
@SuppressWarnings("all")
public class PhotoSelectorPop implements View.OnClickListener {

    private PopupWindow photoSelectorPw;

    private View viewParent;

    private LinearLayout takePhotoLl;

    private LinearLayout choosePhotoLl;

    private LinearLayout cancelPhotoLl;

    private LinearLayout takeAudioLl;

    private LinearLayout chooseAudioLl;

    private PhotoSelectorPopListener photoSelectorPopListener;

    public interface PhotoSelectorPopListener {
        void onTakePhoto();

        void onChoosePhoto();

        void onTakeAudio();

        void onChooseAudio();

        void onCancel();

        void onDismiss();
    }

    public PhotoSelectorPop(final Context context, PhotoSelectorPopListener listener, int mode) {
        this(context, WindowManager.LayoutParams.MATCH_PARENT, WindowManager.LayoutParams.MATCH_PARENT, listener, mode);
    }

    private PhotoSelectorPop(final Context context, final int width, final int height, PhotoSelectorPopListener listener, int pickerMode) {
        this.photoSelectorPopListener = listener;

        LayoutInflater inflater = LayoutInflater.from(context);
        viewParent = inflater.inflate(R.layout.report_picture_popupwindow, null);
        takePhotoLl = (LinearLayout) viewParent.findViewById(R.id.take_photo_ll);
        choosePhotoLl = (LinearLayout) viewParent.findViewById(R.id.choose_photo_ll);
        cancelPhotoLl = (LinearLayout) viewParent.findViewById(R.id.cancel_photo_ll);
        takeAudioLl = (LinearLayout) viewParent.findViewById(R.id.take_audio_ll);
        chooseAudioLl = (LinearLayout) viewParent.findViewById(R.id.choose_audio_ll);
        photoSelectorPw = new PopupWindow(viewParent, width, height, true);
        photoSelectorPw.setBackgroundDrawable(new BitmapDrawable());

        takePhotoLl.setOnClickListener(this);
        choosePhotoLl.setOnClickListener(this);
        cancelPhotoLl.setOnClickListener(this);
        takeAudioLl.setOnClickListener(this);
        chooseAudioLl.setOnClickListener(this);

        if (pickerMode == MediaParams.PARAMS_0) {
            //默认不可用
            takePhotoLl.setVisibility(View.GONE);
            choosePhotoLl.setVisibility(View.GONE);
            takeAudioLl.setVisibility(View.GONE);
            chooseAudioLl.setVisibility(View.GONE);
        } else if (pickerMode == MediaParams.PARAMS_1) {
            //可拍照
            takePhotoLl.setVisibility(View.VISIBLE);
            choosePhotoLl.setVisibility(View.GONE);
            takeAudioLl.setVisibility(View.GONE);
            chooseAudioLl.setVisibility(View.GONE);
        } else if (pickerMode == MediaParams.PARAMS_2) {
            //可选择图片
            takePhotoLl.setVisibility(View.GONE);
            choosePhotoLl.setVisibility(View.VISIBLE);
            takeAudioLl.setVisibility(View.GONE);
            chooseAudioLl.setVisibility(View.GONE);
        } else if (pickerMode == MediaParams.PARAMS_3) {
            //可拍照,可选择图片
            takePhotoLl.setVisibility(View.VISIBLE);
            choosePhotoLl.setVisibility(View.VISIBLE);
            takeAudioLl.setVisibility(View.GONE);
            chooseAudioLl.setVisibility(View.GONE);
        } else if (pickerMode == MediaParams.PARAMS_4) {
            //可录音
            takePhotoLl.setVisibility(View.GONE);
            choosePhotoLl.setVisibility(View.GONE);
            takeAudioLl.setVisibility(View.VISIBLE);
            chooseAudioLl.setVisibility(View.GONE);
        } else if (pickerMode == MediaParams.PARAMS_5) {
            //可选择音频
            takePhotoLl.setVisibility(View.GONE);
            choosePhotoLl.setVisibility(View.GONE);
            takeAudioLl.setVisibility(View.GONE);
            chooseAudioLl.setVisibility(View.VISIBLE);
        } else if (pickerMode == MediaParams.PARAMS_6) {
            //可录音，可选择音频
            takePhotoLl.setVisibility(View.GONE);
            choosePhotoLl.setVisibility(View.GONE);
            takeAudioLl.setVisibility(View.VISIBLE);
            chooseAudioLl.setVisibility(View.VISIBLE);
        }
    }

    public boolean isShowing() {
        return null != photoSelectorPw && photoSelectorPw.isShowing();
    }

    public void show(View parent) {
        if (null == parent) {
            throw new IllegalArgumentException("StoreDateSelectorPop.showAtLocation parent is null");
        }
        viewParent = parent;
        photoSelectorPw.showAtLocation(parent, Gravity.BOTTOM, 0, 0);
    }

    public void dismiss() {
        if (null != photoSelectorPw && photoSelectorPw.isShowing()) {
            photoSelectorPw.dismiss();
        }
    }

    @Override
    public void onClick(View view) {
        if (view == takePhotoLl) {
            dismiss();
            if (null != photoSelectorPopListener) {
                photoSelectorPopListener.onTakePhoto();
            }
        } else if (view == choosePhotoLl) {
            dismiss();
            if (null != photoSelectorPopListener) {
                photoSelectorPopListener.onChoosePhoto();
            }
        } else if (view == cancelPhotoLl) {
            dismiss();
            if (null != photoSelectorPopListener) {
                photoSelectorPopListener.onCancel();
            }
        } else if (view == chooseAudioLl) {
            dismiss();
            if (null != photoSelectorPopListener) {
                photoSelectorPopListener.onChooseAudio();
            }
        } else if (view == takeAudioLl) {
            dismiss();
            if (null != photoSelectorPopListener) {
                photoSelectorPopListener.onTakeAudio();
            }
        } else {
            dismiss();
            if (null != photoSelectorPopListener) {
                photoSelectorPopListener.onDismiss();
            }
        }
    }
}