package com.wgmf.yxgj.pop;

import android.content.Context;
import android.view.Gravity;
import android.view.LayoutInflater;
import android.view.View;
import android.view.WindowManager;
import android.widget.PopupWindow;
import android.widget.TextView;

import com.wgmf.yxgj.base.R;
import com.wgmf.yxgj.model.PickerModel;
import com.wgmf.yxgj.widgets.PickerView;

/**
 * 滚动选择器PopWindow
 *
 * @author xiep  on 2017/10/17 09:37
 */
@SuppressWarnings("all")
public class PickerPop implements View.OnClickListener {
    private PickerModel pickerModel;

    private PopupWindow pickerPw;

    private View viewParent;

    private PickerPopListener pickerPopListener;

    public interface PickerPopListener {

        void comfirmPickerPop(String value);

        void cancelPickerPop();
    }

    public PickerPop(final Context context, PickerPopListener pickerPopListener, PickerModel pickerModel) {
        this(context, WindowManager.LayoutParams.MATCH_PARENT, WindowManager.LayoutParams.MATCH_PARENT, pickerPopListener, pickerModel);
    }

    private PickerPop(final Context context, final int width, final int height, final PickerPopListener pickerPopListener, final PickerModel pickerModel) {
        this.pickerPopListener = pickerPopListener;
        this.pickerModel = pickerModel;
        LayoutInflater inflater = LayoutInflater.from(context);
        viewParent = inflater.inflate(R.layout.public_date_pickerview, null);
        PickerView minutePv = (PickerView) viewParent.findViewById(R.id.minute_pv);
        PickerView secondPv = (PickerView) viewParent.findViewById(R.id.second_pv);
        TextView cancelbtn = (TextView) viewParent.findViewById(R.id.cancel_btn);
        TextView confirmbtn = (TextView) viewParent.findViewById(R.id.confirm_btn);
        cancelbtn.setOnClickListener(this);
        confirmbtn.setOnClickListener(this);

        minutePv.setData(pickerModel.getMinutes());
        secondPv.setData(pickerModel.getSeconds());

        minutePv.setOnSelectListener(new PickerView.onSelectListener() {

            @Override
            public void onSelect(String text) {
                pickerModel.setMinute(text);
            }
        });
        secondPv.setOnSelectListener(new PickerView.onSelectListener() {

            @Override
            public void onSelect(String text) {
                pickerModel.setSecond(text);
            }
        });
        pickerPw = new PopupWindow(viewParent, width, height, true);
    }

    public boolean isShowing() {
        return null != pickerPw && pickerPw.isShowing();
    }

    public void show(View parent) {
        if (null == parent) {
            throw new IllegalArgumentException("StoreDateSelectorPop.showAtLocation parent is null");
        }
        viewParent = parent;
        pickerPw.showAtLocation(parent, Gravity.CENTER, 0, 0);
    }

    public void dismiss() {
        if (null != pickerPw && pickerPw.isShowing()) {
            pickerPw.dismiss();
        }
    }

    @Override
    public void onClick(View v) {
        if (v.getId() == R.id.cancel_btn) {
            dismiss();
            pickerPopListener.cancelPickerPop();
        } else if (v.getId() == R.id.confirm_btn) {
            dismiss();
            pickerPopListener.comfirmPickerPop(pickerModel.getMinute() + pickerModel.getSecond());
        }
    }
}