package com.wgmf.yxgj.publics.service;

import android.text.TextUtils;

import com.google.gson.Gson;
import com.wgmf.library.base.BaseRequest;
import com.wgmf.library.base.BaseResponse;
import com.wgmf.library.base.ResultData;
import com.wgmf.library.utils.BaseSingleton;

import android.util.Log;

import com.wgmf.yxgj.base.BaseService;
import com.wgmf.yxgj.config.BusinessID;
import com.wgmf.yxgj.global.NetworkParams;
import com.wgmf.yxgj.publics.service.request.SendJPushMsgRequest;
import com.wgmf.yxgj.publics.service.request.SetJPushRequest;

import java.lang.ref.WeakReference;

/**
 * @author xiep on 2016/5/31 16:29
 */
public class MainService extends BaseService {
    private static BaseSingleton<MainService, Void> mMainService = new BaseSingleton<MainService, Void>() {
        @Override
        protected MainService create(Void var1) {
            return new MainService();
        }
    };

    public static MainService getInstance() {
        return mMainService.get(null);
    }

    private MainService() {
    }

    /**
     * 版本升级
     */
    public void requestUpdate(final String staffId, final String authorityRoleIdList, final String versionNo, final String type, ResultData.BusinessCallback callback) {
        BaseRequest request = new BaseRequest();
        request.taskID = BusinessID.Update.MSG_ON_USER_UPDATE;
        request.callback = new WeakReference<>(callback);
        request.url = NetworkParams.URL_CHECK_UPDATA + "?"
                + "versionNo=" + versionNo + "&type=" + type + "&staffId=" + staffId;
        request.json = authorityRoleIdList;
        Log.d(TAG, "请求地址：" + request.url);
        sendPostJsonRequest(request);
    }

    /**
     * 上传JPush 别名
     */
    public void requestSetJPush(final String staffId, final String tag, final String alias, final String platform,
                                ResultData.BusinessCallback callback) {
        SetJPushRequest request = new SetJPushRequest(staffId, tag, alias, platform);
        request.taskID = BusinessID.JPush.MSG_ON_SET_JPUSH;
        request.callback = new WeakReference<>(callback);
        request.url = NetworkParams.URL_UPLOAD_MESSAGEUSER_INFORMATION;
        Log.d(TAG, "请求地址：" + request.url);
        sendPostRequest(request);
    }

    /**
     * 发送JPush 消息 sendStaffId, recieverStaffId, receiverType,extra,type,platformType,msgTitle,msgContent
     * platformType:默认1营销管家 2生意管家
     */
    public void requestSendMessage(final String sendStaffId, final String recieverStaffId, final String receiverType, final String extra, final String type, final String msgTitle, final String msgContent,
                                   ResultData.BusinessCallback callback) {
        SendJPushMsgRequest request = new SendJPushMsgRequest(sendStaffId, recieverStaffId, receiverType, extra, type, "1", msgTitle, msgContent);
        request.taskID = BusinessID.JPush.MSG_ON_SEND_JPUSH;
        request.callback = new WeakReference<>(callback);
        request.url = NetworkParams.URL_SENDMESSAGE;
        Log.d(TAG, "请求地址：" + request.url);
        sendPostRequest(request);
    }


    @Override
    protected void onTaskDone(ResultData data) {
        if (null != data) {
            final int id = data.taskID;
            switch (id) {
                case BusinessID.JPush.MSG_ON_SET_JPUSH: {
                    if (data.isSuccessed()) {
                        final String json = data.getInfo();
                        if (!TextUtils.isEmpty(json)) {
                            BaseResponse mBaseResponse = new Gson().fromJson(json, BaseResponse.class);
                            Log.d(TAG, "id:" + id + ";mBaseResponse=" + mBaseResponse.toString());
                            data.setResultCode(mBaseResponse.retCode);
                            data.setResultInfo(mBaseResponse.retInfo);
                        }
                    }
                    break;
                }
                default:
                    break;
            }
        }
    }
}