package com.wgmf.yxgj.publics.service;

import android.content.Context;

import com.google.gson.Gson;
import com.google.gson.reflect.TypeToken;
import com.wgmf.library.utils.AssetsUtil;
import com.wgmf.yxgj.global.ConstantParams;
import com.wgmf.yxgj.model.BrandList;
import com.wgmf.yxgj.model.NutritionConsultant;
import com.wgmf.yxgj.model.SelectImageGroupList;
import com.wgmf.yxgj.publics.model.BaseSelectorEntity;
import com.wgmf.yxgj.publics.model.Shop;

import java.lang.reflect.Type;
import java.util.ArrayList;
import java.util.Collections;
import java.util.Comparator;
import java.util.LinkedHashSet;
import java.util.List;

/**
 * 入职转换校验类
 * 作者：xiep on 2016/8/23 16:28
 * 邮箱：2975837870@qq.com
 */
@SuppressWarnings("all")
public class StaffInfoCheck {
    /**
     * @param des   字段描述
     * @param value 字段显示值
     * @return
     */
    public static String getValue(String des, String value) {
        if (null != value && "null".equals(value) && "".equals(value)) {
            return des + value + "\r\n";
        } else {
            return "";
        }

    }

    /**
     * 图片描述数据源
     */
    public static List<SelectImageGroupList> getSubjectItems(Context context) {
        String msg = AssetsUtil.getFromAssets(context, "ReportStaffData.json");
        // 是否成功
        Type listType = new TypeToken<List<SelectImageGroupList>>() {
        }.getType();
        return new Gson().fromJson(msg, listType);
    }

    /**
     * 职位转换
     *
     * @param position "工作岗位 1：驻店营养顾问 2：流动营养顾问 3：促销主管 4：机修 5：办事处文员 6：终端经理 7：区域经理")
     *                 <p>
     *                 店长的roleStatus是15
     *                 督导的roleStatus是28,29（28带流动的督导，29不带流动的督导）
     * @return
     */
    public static String getPosition(String position) {
        String staffPosition = "";
        switch (position) {
            case ConstantParams.CONSTANT_PARAMS_1:
                staffPosition = "驻店营养顾问";
                break;
            case ConstantParams.CONSTANT_PARAMS_2:
                staffPosition = "流动营养顾问";
                break;
            case ConstantParams.CONSTANT_PARAMS_3:
                staffPosition = "促销主管";
                break;
            case ConstantParams.CONSTANT_PARAMS_4:
                staffPosition = "机修";
                break;
            case ConstantParams.CONSTANT_PARAMS_5:
                staffPosition = "办事处文员";
                break;
            case ConstantParams.CONSTANT_PARAMS_6:
                staffPosition = "终端经理";
                break;
            case ConstantParams.CONSTANT_PARAMS_7:
                staffPosition = "区域经理";
                break;
            case ConstantParams.CONSTANT_PARAMS_15:
                staffPosition = "店长";
                break;
            case ConstantParams.CONSTANT_PARAMS_23:
            case ConstantParams.CONSTANT_PARAMS_28:
            case ConstantParams.CONSTANT_PARAMS_29:
                staffPosition = "督导";
                break;
        }
        return staffPosition;
    }

    /**
     * 学历转换
     *
     * @param degree "学历 01：本科 02：大专 03：中专 04：高中 05：初中 06：小学"
     * @return
     */
    public static String getDegree(String degree) {
        String staffDegree = "";
        switch (degree) {
            case "01":
                staffDegree = "本科";
                break;
            case "02":
                staffDegree = "大专";
                break;
            case "03":
                staffDegree = "中专";
                break;
            case "04":
                staffDegree = "高中";
                break;
            case "05":
                staffDegree = "初中";
                break;
            case "06":
                staffDegree = "小学";
                break;
        }
        return staffDegree;
    }

    /**
     * 性别转换
     *
     * @param sex V = "女";N= "男";
     *            }
     * @return
     */
    public static String getSex(String sex) {
        String staffSex = "";
        switch (sex) {
            case "V":
                staffSex = "女";
                break;
            case "N":
                staffSex = "男";
                break;
        }
        return staffSex;
    }

    /**
     * 离职状态
     *
     * @param status "离职状态：在职(0),离职(1)
     * @return
     */
    public static String getStatus(String status) {
        String staffStatus = "";
        switch (status) {
            case ConstantParams.CONSTANT_PARAMS_0:
                staffStatus = "在职";
                break;
            case ConstantParams.CONSTANT_PARAMS_1:
                staffStatus = "离职";
                break;
        }
        return staffStatus;
    }

    /**
     * 招聘来源
     *
     * @param recuitmentChannel ('01','58同城'),('02','赶集网'),('03','智联招聘'),('04','前程无忧'),('05','内部推荐'),('06','巡场招聘'),('07','地方论坛'),('08','熟人介绍')
     * @return
     */
    public static String getRecuitmentChannel(String recuitmentChannel) {
        String staffRecuitmentChannel = "";
        switch (recuitmentChannel) {
            case "01":
                staffRecuitmentChannel = "58同城";
                break;
            case "02":
                staffRecuitmentChannel = "赶集网";
                break;
            case "03":
                staffRecuitmentChannel = "智联招聘";
                break;
            case "04":
                staffRecuitmentChannel = "前程无忧";
                break;
            case "05":
                staffRecuitmentChannel = "内部推荐";
                break;
            case "06":
                staffRecuitmentChannel = "巡场招聘";
                break;
            case "07":
                staffRecuitmentChannel = "地方论坛";
                break;
            case "08":
                staffRecuitmentChannel = "熟人介绍";
                break;
        }
        return staffRecuitmentChannel;
    }

    /**
     * 离职状态
     *
     * @param status "离职状态：在职(0),离职(1)
     * @return
     */
    public static String gedissmissType(String type) {
        String stafftype = "";
        switch (type) {
            case "01":
                stafftype = "主动离职";
                break;
            case "02":
                stafftype = "被动离职";
                break;
            case "03":
                stafftype = "自离";
                break;
        }
        return stafftype;
    }

    /**
     * 门店名称
     */
    public static String getleavNutConWorkData(NutritionConsultant nutritionConsultant) {
        String leavNutConWorkData = "";
        if ((null != nutritionConsultant.getLeavNutConWorkDataList() && !nutritionConsultant.getLeavNutConWorkDataList().isEmpty())) {
            for (int i = 0; i < nutritionConsultant.getLeavNutConWorkDataList().size(); i++) {
                leavNutConWorkData += nutritionConsultant.getLeavNutConWorkDataList().get(i).getStartWorkDate()
                        + "至" + nutritionConsultant.getLeavNutConWorkDataList().get(i).getEndWorkDate()
                        + "\t" + nutritionConsultant.getLeavNutConWorkDataList().get(i).getBelongsOffice();
                if (i < nutritionConsultant.getLeavNutConWorkDataList().size() - 1) {
                    leavNutConWorkData = leavNutConWorkData + "\n";
                }
            }
        }
        return leavNutConWorkData;
    }

    /**
     * 门店名称
     */
    public static String getShopName(List<Shop> shopList) {
        String shopName = "";
        if (null != shopList && !shopList.isEmpty()) {
            for (int i = 0; i < shopList.size(); i++) {
                shopName += shopList.get(i).getShopName();
                if (i < shopList.size() - 1) {
                    shopName += "\n";
                }
            }
        }
        return shopName;
    }

    /**
     * 顾问品牌
     */
    public static String getBrandName(List<BrandList> brandList) {
        String brandName = "";
        if (null != brandList && !brandList.isEmpty()) {
            for (int i = 0; i < brandList.size(); i++) {
                brandName += brandList.get(i).getBrandName();
                if (i < brandList.size() - 1) {
                    brandName += "\n";
                }
            }
        }
        return brandName;
    }

    /**
     * 整理门店数据
     *
     * @return 整理后的2店3人数据
     */
    public static List<BaseSelectorEntity> initSelectorStoreData(List<BaseSelectorEntity> baseSelectorEntities) {
        //1，先按非2店3人-》2店3人排序
        Collections.sort(baseSelectorEntities, new Comparator<BaseSelectorEntity>() {
            @Override
            public int compare(BaseSelectorEntity lhs, BaseSelectorEntity rhs) {
                if (lhs.getIsLDSR() > rhs.getIsLDSR()) {
                    return -1;
                } else if (lhs.getIsLDSR().equals(rhs.getIsLDSR())) {
                    return 0;
                } else {
                    return 1;
                }
            }
        });
        //2，将2店3人数据合并在同一集合中
        List<BaseSelectorEntity> afterBaseSelectorEntities = new ArrayList<>();
        for (int i = 0; i < baseSelectorEntities.size(); i++) {
            BaseSelectorEntity baseSelectorEntity = new BaseSelectorEntity();
            List<Shop> shopList = new ArrayList<>();
            if (null != baseSelectorEntities.get(i).getIsLDSR()) {
                //同组门店，合并组装在一组数据中
                if (baseSelectorEntities.get(i).getIsLDSR() == 0) {
                    for (int j = 0; j < baseSelectorEntities.size(); j++) {
                        if (baseSelectorEntities.get(i).getlDSRCode().equals(baseSelectorEntities.get(j).getlDSRCode())) {
                            setShopData(baseSelectorEntities.get(j), baseSelectorEntity, shopList);
                            String afterBaseSelectorEntitie = new Gson().toJson(afterBaseSelectorEntities);
                            //如果整理后的集合中不包含该编号，则加入集合中
                            if (!afterBaseSelectorEntitie.contains(baseSelectorEntities.get(i).getlDSRCode())) {
                                //相同的数据只保留一个条目
                                afterBaseSelectorEntities.add(baseSelectorEntity);
                            }
                        }
                    }
                } else {
                    //非2店3人数据按单条数据格式组装
                    setShopData(baseSelectorEntities.get(i), baseSelectorEntity, shopList);
                    afterBaseSelectorEntities.add(baseSelectorEntity);
                }
            }
        }
        return removeDuplicate(afterBaseSelectorEntities);
    }

    /**
     * 设置门店数据
     *
     * @param baseSelectorEntitie
     * @param baseSelectorEntity
     * @param shopList
     */
    private static void setShopData(BaseSelectorEntity baseSelectorEntitie, BaseSelectorEntity baseSelectorEntity, List<Shop> shopList) {
        Shop shop = new Shop();
        shop.setShopId(baseSelectorEntitie.getSelectorId());
        shop.setShopName(baseSelectorEntitie.getSelectorName());
        shop.setIsLDSR(baseSelectorEntitie.getIsLDSR());
        shop.setlDSRCode(baseSelectorEntitie.getlDSRCode());
        shop.setShopCityCountryId(baseSelectorEntitie.getShopCityCountryID());
        shopList.add(shop);
        baseSelectorEntity.setShopList(shopList);
        baseSelectorEntity.setIsLDSR(baseSelectorEntitie.getIsLDSR());
        baseSelectorEntity.setlDSRCode(baseSelectorEntitie.getlDSRCode());
        baseSelectorEntity.setShopCityCountryID(baseSelectorEntitie.getShopCityCountryID());
    }

    /**
     * 利用LinkedHashSet不能添加重复数据并能保证添加顺序的特性
     *
     * @param list
     */

    private static List<BaseSelectorEntity> removeDuplicate(List<BaseSelectorEntity> list) {
        LinkedHashSet<BaseSelectorEntity> set = new LinkedHashSet<BaseSelectorEntity>(list.size());
        set.addAll(list);
        list.clear();
        list.addAll(set);
        return list;
    }
}