package com.wgmf.yxgj.publics.ui;

import android.content.Intent;
import android.os.Bundle;
import android.util.Log;
import android.view.View;
import android.view.WindowManager;
import android.widget.AdapterView;

import com.alibaba.android.arouter.facade.annotation.Route;
import com.google.gson.Gson;
import com.wgmf.library.base.ResultData;
import com.wgmf.library.global.LocationParams;
import com.wgmf.library.utils.LocationUtil;
import com.wgmf.yxgj.base.BaseCommonAdapter;
import com.wgmf.yxgj.base.ViewHolder;
import com.wgmf.yxgj.config.BusinessID;
import com.wgmf.yxgj.global.NetworkParams;
import com.wgmf.yxgj.publics.model.BaseSelectorEntity;
import com.wgmf.yxgj.publics.model.ShopDataEntity;
import com.wgmf.yxgj.publics.model.ShopDataListEntity;
import com.wgmf.yxgj.publics.service.PublicService;
import com.wgmf.yxgj.publics.service.ToFunctionByResId;
import com.xp.arouter.RouterCommonUtil;
import com.xp.arouter.RouterParams;

/**
 * 公共：根据经纬度选择门店列表
 *
 * @author xiep
 */
@SuppressWarnings("all")
@Route(path = RouterParams.URL_SELECTORSTOREGETNEARESTACTIVITY)
public class SelectorStoreGetNearestActivity extends SelectorBaseActivity {

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        getShopList();
        // 默认不弹出软键盘
        getWindow().setSoftInputMode(WindowManager.LayoutParams.SOFT_INPUT_STATE_HIDDEN);
    }

    private void getShopList() {
        if (null != userInfo) {
            showDialog();
            String url = NetworkParams.URL_SHOP_GET_NEAREST;
            String keyWords = storeNameEt.getText().toString().trim();
            String orgCode = userInfo.getOrganizationCode();
            String currentPage = "1";
            String pageSize = "10000";
            String lat = LocationParams.Latitude;
            String lng = LocationParams.Longitude;
            // 发送管理门店数据请求
            PublicService.getInstance().requestgetNearestShop(url, keyWords, orgCode, currentPage, pageSize, lng, lat, SelectorStoreGetNearestActivity.this);
        }
    }

    @Override
    public void initContent() {
        super.initContent();
        mAdapter = new BaseCommonAdapter<BaseSelectorEntity>(this, listShow) {
            @Override
            public void convert(ViewHolder helper, BaseSelectorEntity item) {
                helper.setText(item.getSelectorName() + "");
                helper.setRightText("距您" + LocationUtil.setDistanceUint(item.getDistance()));
                helper.setRightGone(View.VISIBLE);
            }
        };
        mListView.setAdapter(mAdapter);
        mListView.setOnItemClickListener(new AdapterView.OnItemClickListener() {

            @Override
            public void onItemClick(AdapterView<?> parent, View view,
                                    int position, long id) {
                mAdapter.notifyDataSetChanged();
                Long branchID = getIntent().getLongExtra("branchID", 0);
                Bundle mBundle = new Bundle();
                mBundle.putLong("branchID", branchID);
                mBundle.putString("branchTitle", branchTitle);
                mBundle.putString("shopId", listShow.get(position).getSelectorId());
                mBundle.putString("shopName", listShow.get(position).getSelectorName());
                mBundle.putString("address", listShow.get(position).getAddress() + "");
                mBundle.putString("distance", listShow.get(position).getDistance() + "");
                mBundle.putString("storeLatitudes", listShow.get(position).getLat() + "");
                mBundle.putString("storeLongitudes", listShow.get(position).getLng() + "");
                if (ToFunctionByResId.checkIsFinish(branchID)) {
                    Intent intent = new Intent();
                    intent.putExtras(mBundle);
                    setResult(RESULTCODE, intent);
                    SelectorStoreGetNearestActivity.this.finish();
                } else {
                    RouterCommonUtil.startFunctionActivity(SelectorStoreGetNearestActivity.this, 0, branchID, mBundle);
                }
            }
        });
    }

    @Override
    protected void onBusinessResultAtMainThread(ResultData result) {
        super.onBusinessResultAtMainThread(result);
        dismissDialog();
        if (null != result) {
            final int id = result.taskID;
            switch (id) {
                case BusinessID.Publics.MSG_ON_SHOP_GET_NEAREST: {
                    final String msg = result.getInfo();
                    if (result.isSuccessed()) {
                        ShopDataListEntity mGetNearestShopDataListEntity = new Gson().fromJson(msg, ShopDataListEntity.class);
                        Log.d(TAG, "mGetNearestShopDataListEntity=" + mGetNearestShopDataListEntity.toString());
                        if (!mGetNearestShopDataListEntity.getData().isEmpty()) {
                            listShow.clear();
                            for (ShopDataEntity mGetNearestShopDataEntity : mGetNearestShopDataListEntity.getData()) {
                                BaseSelectorEntity mBaseSelectorEntity = new BaseSelectorEntity();
                                mBaseSelectorEntity.setSelectorId(mGetNearestShopDataEntity.getStoreId());
                                mBaseSelectorEntity.setSelectorName(mGetNearestShopDataEntity.getStoreName());
                                mBaseSelectorEntity.setAddress(mGetNearestShopDataEntity.getAddress() + "");
                                mBaseSelectorEntity.setDistance(mGetNearestShopDataEntity.getDistance());
                                mBaseSelectorEntity.setLng(mGetNearestShopDataEntity.getLng());
                                mBaseSelectorEntity.setLat(mGetNearestShopDataEntity.getLat());
                                mBaseSelectorEntity.setSelectorCode("");
                                listShow.add(mBaseSelectorEntity);
                            }
                            mAdapter.notifyDataSetChanged();
                            search();
                        }
                    }
                }
                break;
                default:
                    break;
            }
        }
    }
}