package com.wgmf.yxgj.utils;

import android.content.Context;
import android.os.CountDownTimer;
import android.support.design.widget.Snackbar;
import android.view.View;
import android.widget.Toast;

import com.wgmf.yxgj.app.LibGroupContext;

import java.lang.ref.WeakReference;

/**
 * 自定义优化Toast，防止多个Toast连续弹出时排队。
 *
 * @author Sasuke
 * @date 2016/5/25
 */
public class MyToast {
    public static Toast toast;
    public static Snackbar sb;
    public static int MY_DURATION = Toast.LENGTH_LONG;

    public static void show(String text) {
        if (null != toast) {
            toast.cancel();
            toast = null;
        }
        toast = Toast.makeText(LibGroupContext.getApplication(), text, MY_DURATION);
        toast.show();
    }

    public static void show(Context context, String text, int length) {
        if (null != toast) {
            toast.cancel();
            toast = null;
        }
        toast = Toast.makeText(LibGroupContext.getApplication(), text, length);
        toast.show();
    }

    public static void showToast(Context context, String text, int gravity) {
        if (null != toast) {
            toast.cancel();
            toast = null;
        }
        toast = Toast.makeText(LibGroupContext.getApplication(), text, Toast.LENGTH_SHORT);
        toast.setGravity(gravity, 0, 0);
        toast.show();
    }

    public static void showSnack(View view, String text) {
        WeakReference<View> ref = new WeakReference<View>(view);
        if (null != sb) {
            sb.dismiss();
            sb = null;
        }
        if (ref.get() != null) {
            sb = Snackbar.make(ref.get(), text, Snackbar.LENGTH_LONG);
            sb.show();
        }
    }


    private TimeCounter counter;
    private Toast mToast;

    /**
     * 专门写一套可以自定义duration时长的非静态版本Toast
     * 食用方法：MyToast(msg,5000).show()
     *
     * @param showText
     * @param duration
     */
    public MyToast(String showText, long duration) {
        mToast = Toast.makeText(LibGroupContext.getApplication(), showText, MY_DURATION);
        counter = new TimeCounter(duration, 1000);
        counter.start();
    }

    public void show() {
        mToast.show();
    }

    class TimeCounter extends CountDownTimer {
        long millisInFuture;

        public TimeCounter(long millisInFuture, long countDownInterval) {
            super(millisInFuture, countDownInterval);
            this.millisInFuture = millisInFuture;
        }

        @Override
        public void onTick(long millisUntilFinished) {
            //如果已计时的等于Toast设的默认的，那就说明快消失了，那就再挣扎显示一下
            if ((millisInFuture - millisUntilFinished) % MY_DURATION == 0) {
                show();
            }
        }

        @Override
        public void onFinish() {
            mToast.cancel();
        }
    }
}
