package com.wgmf.yxgj.utils

import java.math.BigDecimal
import java.text.NumberFormat

object NumberUtils {

    private const val MILLION_UNIT = "万"
    private const val BILLION_UNIT = "亿"
    private val ONE_HUNDRED_THOUSAND = BigDecimal(10000)
    private val ONE_HUNDRED_MILLION = BigDecimal(100000000)

    /**
     * 判断是否为数值
     */
    private fun isNumber(number: String?): Boolean {
        if (number.notNullAndEmpty()) {
            number?.let {
                return it.toDoubleOrNull() != null || it.toIntOrNull() != null

            }
        }
        return false
    }

    /**
     * 金额转换为带单位
     */
    fun formatNumberWithUnit(number: String?): String {
        val sb = StringBuffer()
        if (isNumber(number)) {
            var nuit = ""
            var formatNumStr = ""

            val formatNum = BigDecimal(number)
            if (formatNum.compareTo(ONE_HUNDRED_THOUSAND) == -1) {
                formatNumStr = formatNum.toString()
            } else if ((formatNum.compareTo(ONE_HUNDRED_THOUSAND) == 0 || formatNum.compareTo(
                    ONE_HUNDRED_THOUSAND
                ) == 1) && formatNum.compareTo(
                    ONE_HUNDRED_MILLION
                ) == -1
            ) {
                formatNumStr =
                    formatNum.divide(ONE_HUNDRED_THOUSAND).setScale(2, BigDecimal.ROUND_HALF_UP)
                        .toString()
                nuit = MILLION_UNIT
            } else if (formatNum.compareTo(ONE_HUNDRED_MILLION) == 0 || formatNum.compareTo(
                    ONE_HUNDRED_MILLION
                ) == 1
            ) {
                formatNumStr =
                    formatNum.divide(ONE_HUNDRED_MILLION).setScale(2, BigDecimal.ROUND_HALF_UP)
                        .toString()
                nuit = BILLION_UNIT
            }

            formatNumStr = zeroFill(showAmountHandle(formatNumStr))
            if (formatNumStr.notNullAndEmpty()) {
                sb.append(formatNumStr).append(nuit)
            }
        }
        return sb.toString()
    }

    /**
     * 格式化
     */
    private fun showAmountHandle(formatNumber: String?): String {
        if (formatNumber.isNullOrEmpty()) {
            return ""
        }
        val nf: NumberFormat = NumberFormat.getInstance()
        nf.isGroupingUsed = false
        return nf.format(BigDecimal(formatNumber).toDouble())
    }

    /**
     * 补零
     */
    private fun zeroFill(formatNumber: String?): String {
        if (formatNumber.isNullOrEmpty()) {
            return ""
        }
        formatNumber?.let {
            if (it.indexOf(".") < 0) {
                return "$it.00"
            } else {
                val decimalValue = it.substring(it.indexOf(".") + 1)
                if (decimalValue.length < 2) {
                    return it + "0"
                }
                return it
            }
        }
        return ""
    }
}