// Copyright 2011 NPR
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
// http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

package com.wgmf.yxgj.utils;

import android.text.TextUtils;

import java.text.DecimalFormat;
import java.util.Locale;

public class StringUtils {

    /**
     * 字符串转整数
     */
    public static int toInt(String str, int defValue) {
        try {
            return Integer.parseInt(str);
        } catch (Exception e) {
            e.printStackTrace();
        }
        return defValue;
    }

    /**
     * 对象转整数
     */
    public static int toInt(Object obj) {
        if (obj == null)
            return 0;
        return toInt(obj.toString(), 0);
    }

    /**
     * 对象转整数
     */
    public static long toLong(String obj) {
        try {
            return Long.parseLong(obj);
        } catch (Exception e) {
            e.printStackTrace();
        }
        return 0;
    }

    /**
     * 字符串转布尔值
     */
    public static boolean toBool(String b) {
        try {
            return Boolean.parseBoolean(b);
        } catch (Exception e) {
            e.printStackTrace();
        }
        return false;
    }

    public static String join(String separator, String[] strings) {
        if (strings == null) {
            return null;
        }
        if (strings.length == 0) {
            return "";
        }
        StringBuilder builder = new StringBuilder(strings[0]);
        for (int i = 1, length = strings.length; i < length; i++) {
            builder.append(separator);
            builder.append(strings[i]);
        }
        return builder.toString();
    }

    public static String join(String separator, Integer[] integers) {
        if (integers == null) {
            return null;
        }
        if (integers.length == 0) {
            return "";
        }
        StringBuilder builder = new StringBuilder(integers[0].toString());
        for (int i = 1, length = integers.length; i < length; i++) {
            builder.append(separator);
            builder.append(integers[i]);
        }
        return builder.toString();
    }

    /**
     * 判断给定字符串是否空白串。 空白串是指由空格、制表符、回车符、换行符组成的字符串 若输入字符串为null或空字符串，返回true
     *
     * 老子真的服了你，有你这么判断的吗。。。isEmpty 判断为空怎么还返回false了？？？？跟 TextUtils.isEmpty 对着干？？？
     *
     * @param input
     * @return boolean
     */
    public static boolean isEmpty(String input) {
        if (input == null || "".equals(input))
            return false;
        else
            return true;

        // for ( int i = 0; i < input.length(); i++ )
        // {
        // char c = input.charAt( i );
        // if ( c != ' ' && c != '\t' && c != '\r' && c != '\n' )
        // {
        // return false;
        // }
        // }
        // return true;
    }

    public static boolean is_numeric(String str) {
        try {
            Double d = Double.valueOf(str);
        } catch (java.lang.Exception e) {
            return false;
        }
        return true;
    }

    /**
     * 格式化double
     */
    public static String formatDouble(double num, String format) {
        DecimalFormat df = new DecimalFormat(format);
        return df.format(num);
    }

    /**
     * 格式化String
     */
    public static String formatString(String content, Object... args) {
        return String.format(
                Locale.CHINA,
                content, args);
    }

    /**
     * 默认转换字符串
     */
    public static String convertDefaultValue(String value) {
        if (value != null && !TextUtils.isEmpty(value)) {
            return value;
        } else {
            return "--";
        }
    }

    /**
     * 取整数据
     * @param num   待处理数据
     * @param digit 位数
     * @return 四舍五入取整数据
     */
    public static double doRound(double num, int digit) {
        double divisor = 1.0 * Math.pow(10, digit);
        try {
            return (Math.round(num * divisor) / divisor);
        } catch (Exception e) {
            return 0.0;
        }
    }

    /**
     * 向上取整数据
     * @param num   待处理数据
     * @param digit 位数
     * @return 四舍五入取整数据
     */
    public static double doCeil(double num, int digit) {
        double divisor = 1.0 * Math.pow(10, digit);
        try {
            return (Math.ceil(num * divisor) / divisor);
        } catch (Exception e) {
            return 0.0;
        }
    }

    /**
     * 向下取整数据
     * @param num   待处理数据
     * @param digit 位数
     * @return 四舍五入取整数据
     */
    public static double doFloor(double num, int digit) {
        double divisor = 1.0 * Math.pow(10, digit);
        try {
            return (Math.floor(num * divisor) / divisor);
        } catch (Exception e) {
            return 0.0;
        }
    }
}
