package com.wgmf.yxgj.utils.helper;

import android.app.AlertDialog;
import android.app.DatePickerDialog;
import android.app.TimePickerDialog;
import android.content.Context;
import android.content.DialogInterface;
import android.view.View;
import android.widget.DatePicker;
import android.widget.TextView;
import android.widget.TimePicker;

import com.wgmf.library.utils.DateUtil;
import com.wgmf.library.utils.ToastUtil;
import com.wgmf.yxgj.base.BaseActivity;

import java.text.SimpleDateFormat;
import java.util.Calendar;
import java.util.Date;

import xp.timepicker.com.widget.DatePickDialog;
import xp.timepicker.com.widget.OnChangeLisener;
import xp.timepicker.com.widget.OnSureLisener;
import xp.timepicker.com.widget.bean.DateType;

/**
 * @author xiep
 */
@SuppressWarnings("all")
public class DialogHelper {
    /**
     * 提示框点击按钮接口
     *
     * @author Administrator
     */
    public interface DialogResult {
        /**
         * 点击按钮执行动作 tag：用来区分多个dialog的点击按钮执行动作
         */
        void onDialogResult(int tag);
    }


    public static void Alert3R(Context ctx, CharSequence title, CharSequence message, View layout, DialogInterface.OnClickListener oclt, DialogInterface.OnClickListener oclt2) {
        AlertDialog.Builder builder = createDialogDIY(ctx, title, message, layout);
        builder.setPositiveButton("取消", oclt2);
        builder.setNegativeButton("确定", oclt);
        builder.create().show();
    }

    private static AlertDialog.Builder createDialogDIY(Context ctx, CharSequence title, CharSequence message, View layout) {
        AlertDialog.Builder builder = new AlertDialog.Builder(ctx);
        builder.setMessage(message);
        builder.setTitle(title);
        builder.setView(layout);
        return builder;
    }

    public static void entrySpecialDatePicker(final Context context, final DialogResult dialog, final TextView textView) {
        Calendar c = Calendar.getInstance();
        DatePickerDialog.OnDateSetListener dateListener = new DatePickerDialog.OnDateSetListener() {

            @Override
            public void onDateSet(DatePicker view, int year, int monthOfYear,
                                  int dayOfMonth) {

                String month;
                String day;
                if (monthOfYear + 1 < 10) {
                    month = "0" + (monthOfYear + 1);
                } else {
                    month = "" + (monthOfYear + 1);
                }
                if (dayOfMonth < 10) {
                    day = "0" + dayOfMonth;
                } else {
                    day = "" + dayOfMonth;
                }

                String entryDate = year + "-" + month + "-" + day;

                if (!DateUtil.isTimeBeforeAndAfterTwoDays(entryDate)) {
                    ToastUtil.show(context, "您输入的入职日期有误，请输入当天前后两天的日期!");
                    entryDate = "";
                }
                textView.setText(entryDate);
                dialog.onDialogResult(6);
            }
        };
        DatePickerDialog datePickerDialog = new DatePickerDialog(context, android.R.style.Theme_Holo_Light_Panel,
                dateListener, c.get(Calendar.YEAR), c.get(Calendar.MONTH),
                c.get(Calendar.DAY_OF_MONTH));
        // 对话框周围不可点击
        datePickerDialog.setCanceledOnTouchOutside(false);
        datePickerDialog.show();
    }


    /**
     * 日期选择控件
     *
     * @param context
     * @param textView 回显控件
     */
    public static void AlertDatePicker(final Context context, final DialogResult dialog, final TextView textView) {
        Calendar c = Calendar.getInstance();
        DatePickerDialog.OnDateSetListener dateListener = new DatePickerDialog.OnDateSetListener() {

            @Override
            public void onDateSet(DatePicker view, int year, int monthOfYear,
                                  int dayOfMonth) {

                String month;
                String day;
                if (monthOfYear + 1 < 10) {
                    month = "0" + (monthOfYear + 1);
                } else {
                    month = "" + (monthOfYear + 1);
                }
                if (dayOfMonth < 10) {
                    day = "0" + dayOfMonth;
                } else {
                    day = "" + dayOfMonth;
                }
                textView.setText(year + "-" + month + "-" + day);
                dialog.onDialogResult(6);
            }
        };
        DatePickerDialog datePickerDialog = new DatePickerDialog(context, android.R.style.Theme_Holo_Light_Panel,
                dateListener, c.get(Calendar.YEAR), c.get(Calendar.MONTH),
                c.get(Calendar.DAY_OF_MONTH));
        // 对话框周围不可点击
        datePickerDialog.setCanceledOnTouchOutside(false);
        datePickerDialog.show();
    }

    /**
     * 时间选择控件
     *
     * @param context
     * @param textView 回显控件
     */
    public static void AlertTimePicker(final BaseActivity context,
                                       final TextView textView) {
        Calendar c = Calendar.getInstance();
        TimePickerDialog.OnTimeSetListener dateListener = new TimePickerDialog.OnTimeSetListener() {
            @Override
            public void onTimeSet(TimePicker view, int hourOfDay, int minute) {
                String hour;
                String minutes;
                if (hourOfDay < 10) {
                    hour = "0" + hourOfDay;
                } else {
                    hour = "" + hourOfDay;
                }
                if (minute < 10) {
                    minutes = "0" + minute;
                } else {
                    minutes = "" + minute;
                }
                textView.setText(hour + ":" + minutes);
            }
        };
        TimePickerDialog timePickerDialog = new TimePickerDialog(context, android.R.style.Theme_Holo_Light_Panel,
                dateListener, c.get(Calendar.HOUR), c.get(Calendar.MINUTE), true);
        // 对话框周围不可点击
        timePickerDialog.setCanceledOnTouchOutside(false);
        timePickerDialog.show();
    }

    /**
     * 日期，时间选择控件
     *
     * @param context
     * @param type     类型
     *                 TYPE_ALL("yyyy-MM-dd E hh:mm"),
     *                 TYPE_YMDHM("yyyy-MM-dd hh:mm"),
     *                 TYPE_YMDH("yyyy-MM-dd hh"),
     *                 TYPE_YMD("yyyy-MM-dd"),
     *                 TYPE_YM("yyyy-MM"),
     *                 TYPE_Y("yyyy"),
     *                 TYPE_M("MM"),
     *                 TYPE_HN("hh:mm"),
     *                 TYPE_H("hh"),
     *                 TYPE_N("mm"),
     * @param textView 回显控件
     */
    public static void showDatePickDialog(final BaseActivity context, final DateType type, final TextView textView) {
        DatePickDialog dialog = new DatePickDialog(context);
        //设置标题
        dialog.setTitle("选择时间");
        //设置类型
        dialog.setType(type);
        //设置消息体的显示格式，日期格式
        dialog.setMessageFormat(type.getFormat());
        //设置选择回调
        dialog.setOnChangeLisener(null);
        //设置点击确定按钮回调
        dialog.setOnSureLisener(new OnSureLisener() {
            @Override
            public void onSure(Date date) {
                String messge = "";
                try {
                    messge = new SimpleDateFormat(type.getFormat()).format(date);
                } catch (Exception e) {
                    e.printStackTrace();
                }
                textView.setText(messge);
            }
        });
        dialog.show();
    }


    /**
     * 日期，时间选择控件
     *
     * @param context
     * @param type     类型
     *                 TYPE_ALL("yyyy-MM-dd E hh:mm"),
     *                 TYPE_YMDHM("yyyy-MM-dd hh:mm"),
     *                 TYPE_YMDH("yyyy-MM-dd hh"),
     *                 TYPE_YMD("yyyy-MM-dd"),
     *                 TYPE_YM("yyyy-MM"),
     *                 TYPE_Y("yyyy"),
     *                 TYPE_M("MM"),
     *                 TYPE_HN("hh:mm"),
     *                 TYPE_H("hh"),
     *                 TYPE_N("mm"),
     * @param textView 回显控件
     */
    public static DatePickDialog showDatePickDialog(final BaseActivity context, final DateType type) {
        DatePickDialog dialog = new DatePickDialog(context);
        //设置标题
        dialog.setTitle("选择时间");
        //设置类型
        dialog.setType(type);
        //设置消息体的显示格式，日期格式
        dialog.setMessageFormat(type.getFormat());
        return dialog;
    }
}