package com.wgmf.yxgj.widgets.LinearLayout;

import android.content.Context;
import android.support.v4.content.ContextCompat;
import android.util.AttributeSet;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.BaseAdapter;
import android.widget.GridView;
import android.widget.LinearLayout;
import android.widget.TextView;

import com.wgmf.library.utils.DateUtil;
import com.wgmf.yxgj.base.R;

import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Calendar;
import java.util.Date;
import java.util.List;

/**
 * @author xiep
 */
@SuppressWarnings("all")
public class DayTaskCalendar extends LinearLayout {

    private Context context;
    /**
     * 选中的年月
     */
    private String choiceMonth = "";
    /**
     * 存放天
     */
    private List<CalendarBaseModelResponse> gvList = new ArrayList<>();

    private List<CalendarBaseModelResponse> daysHasThingList;
    /**
     * 选中日期
     */
    private static List<String> choiceDates = new ArrayList<>();
    /**
     * 今天及今天之后未设置
     */
    private List<String> afterTodayNo;
    /**
     * 日期格式化
     */
    private SimpleDateFormat dateFormat = new SimpleDateFormat("yyyy-MM");
    /**
     * 回调函数
     */
    private OnDaySelectListener callBack;

    public CalendarGridViewAdapter gridViewAdapter;

    public String getChoiceMonth() {
        return choiceMonth;
    }

    public void setChoiceMonth(String choiceMonth) {
        this.choiceMonth = choiceMonth;
    }

    /**
     * 构造函数
     */
    public DayTaskCalendar(Context context) {
        super(context);
        this.context = context;
        init();
    }

    /**
     * 构造函数
     */
    public DayTaskCalendar(Context context, AttributeSet attrs) {
        super(context, attrs);
        this.context = context;
        init();
    }

    /**
     * 初始化日期以及view等控件
     */
    private void init() {
        daysHasThingList = new ArrayList<>();
        // 今天及今天之后未设置
        afterTodayNo = new ArrayList<>();
        // 获取日历实例
        final Calendar ca = Calendar.getInstance();
        // 获取当前date
        Date nowDate = new Date();
        // cal设置为当天的
        ca.setTime(nowDate);
        // 结果
        Date resultDate = ca.getTime();
        choiceMonth = dateFormat.format(resultDate);
        // cal设置当前day为当前月第一天
        ca.set(Calendar.DATE, 1);
        // 获取当前月第一天为星期几
        int tempSum = countNeedHowMuchEmpety(ca);
        // 获取当前月有多少天
        int dayNumInMonth = getDayNumInMonth(ca);
        setGvListData(tempSum, dayNumInMonth);
        // 获取布局，开始初始化
        View view = LayoutInflater.from(context).inflate(R.layout.day_task_calendar, this, true);
        GridView gv = (GridView) view.findViewById(R.id.gv_calendar);
        gridViewAdapter = new CalendarGridViewAdapter();
        gv.setAdapter(gridViewAdapter);
        setGvListData(countNeedHowMuchEmpety(ca), getDayNumInMonth(ca));
        gridViewAdapter.notifyDataSetChanged();
    }

    /**
     * 为gridview中添加需要展示的数据
     */
    public void setGvListData(int tempSum, int dayNumInMonth) {
        gvList.clear();
        for (int i = 0; i < tempSum; i++) {
            CalendarBaseModelResponse mCalendarBaseModelResponse = new CalendarBaseModelResponse();
            mCalendarBaseModelResponse.setDayShowing("");
            gvList.add(mCalendarBaseModelResponse);
        }
        for (int j = 1; j <= dayNumInMonth; j++) {
            CalendarBaseModelResponse mCalendarBaseModelResponse = new CalendarBaseModelResponse();
            mCalendarBaseModelResponse.setDayShowing(String.valueOf(j));
            gvList.add(mCalendarBaseModelResponse);
        }
    }

    /**
     * 获取当前月的总共天数
     */
    public int getDayNumInMonth(Calendar cal) {
        return cal.getActualMaximum(Calendar.DATE);
    }

    /**
     * 获取当前月第一天在第一个礼拜的第几天，得出第一天是星期几
     */
    public int countNeedHowMuchEmpety(Calendar cal) {
        return cal.get(Calendar.DAY_OF_WEEK) - 1;
    }

    static class GrideViewHolder {

        TextView tvDay;
        TextView tvDaySubscript;
        SquareLayout slDay;
    }

    public class CalendarGridViewAdapter extends BaseAdapter {

        @Override
        public int getCount() {
            return gvList.size();
        }

        @Override
        public String getItem(int position) {
            return gvList.get(position).getDayShowing();
        }

        @Override
        public long getItemId(int position) {
            return position;
        }

        @Override
        public View getView(final int position, View convertView, ViewGroup parent) {
            final GrideViewHolder holder;
            if (null == convertView) {
                convertView = inflate(context, R.layout.day_task_calendar_gridview_item, null);
                holder = new GrideViewHolder();
                holder.tvDay = (TextView) convertView.findViewById(R.id.tv_calendar_day);
                holder.tvDaySubscript = (TextView) convertView.findViewById(R.id.tv_calendar_day_subscript);
                holder.slDay = (SquareLayout) convertView.findViewById(R.id.sl_calendar_day);
                convertView.setTag(holder);
            } else {
                holder = (GrideViewHolder) convertView.getTag();
            }
            final CalendarBaseModelResponse cell = new CalendarBaseModelResponse();

            String dayGrid = getItem(position);
            holder.tvDay.setText(dayGrid);

            if (!"".equals(dayGrid)) {
                final String viewDate = processDate(choiceMonth, dayGrid);
                holder.slDay.setOnClickListener(new OnClickListener() {
                    @Override
                    public void onClick(View v) {
                        if (callBack != null) {
                            // 调用回调函数回调数据
                            stateChoice(cell, viewDate);
                            callBack.onDaySelectListener(viewDate, choiceDates);
                        }
                    }
                });

                stateModified(holder, viewDate);

                if (comparingDate(viewDate) != 2) {
                    //日期为今日及今日之后，显示已设置背景
                    for (int i = 0; i < daysHasThingList.size(); i++) {
                        cell.setDayShowing(daysHasThingList.get(i).getDayShowing());
                        if (viewDate.equals(cell.getDayShowing())) {
                            // 找到对应日期，设置背景颜色
                            cell.setStateSaved(daysHasThingList.get(i).isStateSaved());
                            stateSaved(holder, cell);
                        }
                    }
                }
                stateChecked(holder, viewDate);
            }
            return convertView;
        }

        /**
         * 对日历控件日期进行格式加工
         */
        private String processDate(String choiceMonth, String dayGrid) {
            String date = choiceMonth + dayGrid;
            Date yearMonthNow = DateUtil.string2Date(date, "yyyy-MMd");
            date = DateUtil.format(yearMonthNow, "yyyy-MM-dd");
            return date;
        }

        private void stateModified(GrideViewHolder holder, String viewDate) {
            if (comparingDate(viewDate) == 1) {
                holder.tvDay.setTextColor(ContextCompat.getColor(context, R.color.state_modified_1));
            } else if (comparingDate(viewDate) == 2) {
                holder.tvDay.setTextColor(ContextCompat.getColor(context, R.color.state_modified_2));
            } else {
                holder.tvDay.setTextColor(ContextCompat.getColor(context, R.color.state_modified_0));
            }
        }

        private void stateSaved(GrideViewHolder holder, CalendarBaseModelResponse cell) {
            if (cell.isStateSaved()) {
                //已设置
                holder.tvDay.setTextColor(ContextCompat.getColor(context, R.color.state_modified_4));
                holder.tvDaySubscript.setBackgroundResource(R.drawable.mark_work);
                holder.tvDaySubscript.setVisibility(View.VISIBLE);
            } else {//未设置
                holder.tvDaySubscript.setVisibility(View.INVISIBLE);
            }
        }

        private void stateChecked(GrideViewHolder holder, String viewDate) {
            if (hasChoice(viewDate)) {
                //选中
                holder.slDay.setBackgroundResource(R.drawable.design_red_point);
                holder.tvDay.setTextColor(ContextCompat.getColor(context, R.color.state_modified_3));
            } else {
                holder.slDay.setBackgroundColor(ContextCompat.getColor(context, R.color.state_modified_5));
            }
        }

        private void stateChoice(CalendarBaseModelResponse cell, String viewDate) {

            if (comparingDate(viewDate) == 2 || cell.isStateSaved()) {
                //今天之前
                choiceDates.clear();
                afterTodayNo.clear();
                choiceDates.add(viewDate);
            } else {
                //今天及今天之后未设置
                choiceDates.clear();
                //如果集合中存在当前点击日期，说明已选中，此时移除该元素，撤销选中
                if (!removeChecked(viewDate)) {
                    afterTodayNo.add(viewDate);
                }
                choiceDates.addAll(afterTodayNo);
            }
        }

        /**
         * 如果选中数据集合中存在当前选中日期，则将其删除
         */
        private boolean removeChecked(String viewDate) {
            for (int i = 0; i < afterTodayNo.size(); i++) {
                if (viewDate.equals(afterTodayNo.get(i))) {
                    afterTodayNo.remove(i);
                    return true;
                }
            }
            return false;
        }

        private boolean hasChoice(String viewDate) {
            for (String choiceDate : choiceDates) {
                if (viewDate.equals(choiceDate)) {
                    //选中
                    return true;
                }
            }
            return false;
        }
    }


    /**
     * 选中的日期和今天比较
     */
    public int comparingDate(String date) {
        Date date1 = DateUtil.string2Date(date, "yyyy-MM-dd");
        Date date2 = DateUtil.string2Date(DateUtil.getFormatCurrentDate("yyyy-MM-dd"), "yyyy-MM-dd");
        int device = DateUtil.daysBetween(date1, date2);
        if (device == 0) {
            //今天
            return 1;
        } else if (device > 0) {
            //今天之后
            return 2;
        } else {
            //今天之前
            return 0;
        }
    }

    /**
     * 自定义监听接口
     */
    public interface OnDaySelectListener {
        void onDaySelectListener(String date, List<String> choiceDates);
    }

    /**
     * 自定义监听接口设置对象
     */
    public void setOnDaySelectListener(OnDaySelectListener listener) {
        callBack = listener;
    }

    /**
     * 设置事务
     */
    public void setDaysHasThingList(List<CalendarBaseModelResponse> daysHasThingList) {
        this.daysHasThingList = daysHasThingList;
        this.gridViewAdapter.notifyDataSetChanged();
    }
}