package com.wgmf.yxgj.widgets.ScrollablePanel;

import android.annotation.SuppressLint;
import android.content.Context;
import android.support.v7.widget.LinearLayoutManager;
import android.support.v7.widget.RecyclerView;
import android.view.LayoutInflater;
import android.view.MotionEvent;
import android.view.View;
import android.view.ViewGroup;
import android.widget.FrameLayout;

import com.wgmf.yxgj.base.R;
import com.wgmf.yxgj.widgets.ScrollablePanel.PanelAdapter;

import java.util.HashSet;

/**
 * @author LW
 * 表格管理器
 */
public class ScrollablePanelManager {
    protected RecyclerView mContentRecyclerView;
    protected RecyclerView mHeaderRecyclerView;
    protected PanelLineAdapter mPanelLineAdapter;
    protected PanelAdapter mPanelAdapter;
    protected FrameLayout mFirstItemView;

    /**
     * 绑定View
     *
     * @param context             Context
     * @param recyclerContentList RecyclerView
     * @param recyclerHeaderList  RecyclerView
     * @param firstItemView       FrameLayout
     */
    public void setPanelView(Context context, RecyclerView recyclerContentList, RecyclerView recyclerHeaderList, FrameLayout firstItemView) {
        this.mContentRecyclerView = recyclerContentList;
        mContentRecyclerView.setLayoutManager(new LinearLayoutManager(context, LinearLayoutManager.VERTICAL, false));
        this.mFirstItemView = firstItemView;
        this.mHeaderRecyclerView = recyclerHeaderList;
        mHeaderRecyclerView.setLayoutManager(new LinearLayoutManager(context, LinearLayoutManager.HORIZONTAL, false));
        mHeaderRecyclerView.setHasFixedSize(true);
    }

    /**
     * @param panelAdapter {@link PanelAdapter}
     */
    public void setPanelAdapter(PanelAdapter panelAdapter, PanelLineAdapter.OnContentItemClickListener listener) {
        if (this.mPanelLineAdapter != null) {
            mPanelLineAdapter.setPanelAdapter(panelAdapter);
            mPanelLineAdapter.notifyDataSetChanged();
        } else {
            mPanelLineAdapter = new PanelLineAdapter(panelAdapter, mContentRecyclerView, mHeaderRecyclerView);
            mPanelLineAdapter.setContentItemClickListener(listener);
            mContentRecyclerView.setAdapter(mPanelLineAdapter);
        }
        this.mPanelAdapter = panelAdapter;
        setUpFirstItemView(panelAdapter);
    }

    private void setUpFirstItemView(PanelAdapter panelAdapter) {
        RecyclerView.ViewHolder viewHolder = panelAdapter.onCreateViewHolder(mFirstItemView, panelAdapter.getItemViewType(0, 0));
        panelAdapter.onBindViewHolder(viewHolder, 0, 0);
        if (viewHolder != null) {
            mFirstItemView.addView(viewHolder.itemView);
        }
    }

    public void notifyDataSetChanged() {
        if (mPanelLineAdapter != null) {
            mPanelLineAdapter.notifyDataChanged();
        }
        setUpFirstItemView(mPanelAdapter);
    }

    public RecyclerView getContentRecyclerView(int pos) {
        if (mPanelLineAdapter != null) {
            return mPanelLineAdapter.getContentRecyclerView(pos);
        }
        return null;
    }

    public View getContentRecyclerItemView(int pos, int childPos) {
        if (mPanelLineAdapter != null) {
            return mPanelLineAdapter.getContentRecyclerItemView(pos, childPos);
        }
        return null;
    }

    /**
     * Adapter used to bind dataSet to cell View that are displayed within every row of {@link ScrollablePanelManager}.
     */
    public static class PanelLineItemAdapter extends RecyclerView.Adapter<RecyclerView.ViewHolder> {

        private final PanelAdapter panelAdapter;
        private int row;
        private OnContentChildItemClickListener onContentChildItemClickListener;

        public PanelLineItemAdapter(int row, PanelAdapter panelAdapter) {
            this.row = row;
            this.panelAdapter = panelAdapter;
        }

        public void setContentChildItemClickListener(OnContentChildItemClickListener listener) {
            this.onContentChildItemClickListener = listener;
        }

        @Override
        public RecyclerView.ViewHolder onCreateViewHolder(ViewGroup parent, int viewType) {
            return this.panelAdapter.onCreateViewHolder(parent, viewType);
        }

        @Override
        public void onBindViewHolder(RecyclerView.ViewHolder holder, int position) {
            this.panelAdapter.onBindViewHolder(holder, row, position + 1);
            holder.itemView.setOnClickListener(v -> {
                if (onContentChildItemClickListener != null) {
                    onContentChildItemClickListener.onItemClick(row-1, position + 1, panelAdapter);
                }
            });

        }

        @Override
        public int getItemViewType(int position) {
            return this.panelAdapter.getItemViewType(row, position + 1);
        }


        @Override
        public int getItemCount() {
            return panelAdapter.getColumnCount() - 1;
        }

        public void setRow(int row) {
            this.row = row;
        }

        interface OnContentChildItemClickListener {
            void onItemClick(int row, int position, PanelAdapter panelAdapter);
        }
    }


    /**
     * Adapter used to bind dataSet to views that are displayed within a{@link ScrollablePanelManager}.
     */
    public static class PanelLineAdapter extends RecyclerView.Adapter<PanelLineAdapter.ViewHolder> {

        private PanelAdapter panelAdapter;
        private final RecyclerView headerRecyclerView;
        private final RecyclerView contentRecyclerView;
        private final HashSet<RecyclerView> observerList = new HashSet<>();
        private OnContentItemClickListener onContentItemClickListener;
        private int firstPos = -1;
        private int firstOffset = -1;

        public PanelLineAdapter(PanelAdapter panelAdapter, RecyclerView contentRecyclerView, RecyclerView headerRecyclerView) {
            this.panelAdapter = panelAdapter;
            this.headerRecyclerView = headerRecyclerView;
            this.contentRecyclerView = contentRecyclerView;
            initRecyclerView(headerRecyclerView);
            setUpHeaderRecyclerView();

        }

        public void setPanelAdapter(PanelAdapter panelAdapter) {
            this.panelAdapter = panelAdapter;
            setUpHeaderRecyclerView();
        }

        @Override
        public long getItemId(int position) {
            return position;
        }

        @Override
        public int getItemCount() {
            return panelAdapter.getRowCount();
        }

        @Override
        public ViewHolder onCreateViewHolder(ViewGroup parent, int viewType) {
            ViewHolder viewHolder = new ViewHolder(LayoutInflater.from(parent.getContext())
                    .inflate(R.layout.list_item_content_row, parent, false));
            initRecyclerView(viewHolder.recyclerView);
            return viewHolder;
        }

        @Override
        public void onBindViewHolder(ViewHolder holder, @SuppressLint("RecyclerView") final int position) {
            PanelLineItemAdapter lineItemAdapter = (PanelLineItemAdapter) holder.recyclerView.getAdapter();
            if (lineItemAdapter == null) {
                lineItemAdapter = new PanelLineItemAdapter(position + 1, panelAdapter);
                holder.recyclerView.setAdapter(lineItemAdapter);
            } else {
                lineItemAdapter.setRow(position + 1);
                lineItemAdapter.notifyDataSetChanged();
            }
            holder.recyclerView.setTag(position);
            holder.itemView.setTag(position);

            if (holder.firstColumnItemVH == null) {
                RecyclerView.ViewHolder viewHolder = panelAdapter.onCreateViewHolder(holder.firstColumnItemView, panelAdapter.getItemViewType(position + 1, 0));
                holder.firstColumnItemVH = viewHolder;
                panelAdapter.onBindViewHolder(holder.firstColumnItemVH, position + 1, 0);
                if (viewHolder != null) {
                    holder.firstColumnItemView.addView(viewHolder.itemView);
                }
            } else {
                panelAdapter.onBindViewHolder(holder.firstColumnItemVH, position + 1, 0);
            }
            //ViewGroup.LayoutParams layoutParams = holder.recyclerView.getLayoutParams();
            //layoutParams.height = getViewHeight(holder.firstColumnItemView);
            //holder.recyclerView.setLayoutParams(layoutParams);

            holder.itemView.setOnClickListener(v -> {
                if (onContentItemClickListener != null) {
                    onContentItemClickListener.onItemClick(position, panelAdapter);
                }
            });
            holder.firstColumnItemView.setOnClickListener(v -> {
                if (onContentItemClickListener != null) {
                    onContentItemClickListener.onChildItemClick(position, 0, panelAdapter);
                }
            });
            lineItemAdapter.setContentChildItemClickListener((row, position1, panelAdapter) -> {
                if (onContentItemClickListener != null) {
                    onContentItemClickListener.onChildItemClick(row, position1, panelAdapter);
                }
            });
        }

        /**
         * 计算当前View高度
         *
         * @param view view
         */
        public int getViewHeight(View view) {
            int widthSpec = View.MeasureSpec.makeMeasureSpec(0, View.MeasureSpec.UNSPECIFIED);
            int heightSpec = View.MeasureSpec.makeMeasureSpec(0, View.MeasureSpec.UNSPECIFIED);
            View.MeasureSpec.makeMeasureSpec(0, View.MeasureSpec.UNSPECIFIED);
            view.measure(widthSpec, heightSpec);
            return view.getMeasuredHeight();
        }

        public interface OnContentItemClickListener {
            void onItemClick(int row, PanelAdapter panelAdapter);

            void onChildItemClick(int row, int column, PanelAdapter panelAdapter);
        }

        public void setContentItemClickListener(OnContentItemClickListener listener) {
            this.onContentItemClickListener = listener;
        }

        public void notifyDataChanged() {
            try {
                HashSet<RecyclerView> allRecycleViewSet = getRecyclerViews();
                for (RecyclerView recyclerView : allRecycleViewSet) {
                    RecyclerView.Adapter adapter = recyclerView.getAdapter();
                    if (adapter != null) {
                        adapter.notifyDataSetChanged();
                    }
                }
            } catch (Exception e) {
                e.printStackTrace();
            }
        }


        private void setUpHeaderRecyclerView() {
            if (panelAdapter != null) {
                if (headerRecyclerView.getAdapter() == null) {
                    PanelLineItemAdapter lineItemAdapter = new PanelLineItemAdapter(0, panelAdapter);
                    headerRecyclerView.setAdapter(lineItemAdapter);
                } else {
                    headerRecyclerView.getAdapter().notifyDataSetChanged();
                }
            }
        }

        @SuppressLint("ClickableViewAccessibility")
        public void initRecyclerView(RecyclerView headerRecyclerView) {
            //CoordinatorLayout事件传递问题
            headerRecyclerView.setNestedScrollingEnabled(false);
            headerRecyclerView.setHasFixedSize(true);
            LinearLayoutManager layoutManager = (LinearLayoutManager) headerRecyclerView.getLayoutManager();
            if (layoutManager != null && firstPos > 0 && firstOffset > 0) {
                layoutManager.scrollToPositionWithOffset(PanelLineAdapter.this.firstPos + 1, PanelLineAdapter.this.firstOffset);
            }
            observerList.add(headerRecyclerView);
            headerRecyclerView.setOnTouchListener((view, motionEvent) -> {
                switch (motionEvent.getAction()) {
                    case MotionEvent.ACTION_DOWN:
                    case MotionEvent.ACTION_POINTER_DOWN:
                        for (RecyclerView rv : observerList) {
                            rv.stopScroll();
                        }
                }
                return false;
            });
            headerRecyclerView.addOnScrollListener(new RecyclerView.OnScrollListener() {
                @Override
                public void onScrolled(RecyclerView recyclerView, int dx, int dy) {
                    super.onScrolled(recyclerView, dx, dy);
                    LinearLayoutManager linearLayoutManager = (LinearLayoutManager) recyclerView.getLayoutManager();
                    int firstPos = linearLayoutManager.findFirstVisibleItemPosition();
                    View firstVisibleItem = linearLayoutManager.getChildAt(0);
                    if (firstVisibleItem != null) {
                        int firstRight = linearLayoutManager.getDecoratedRight(firstVisibleItem);
                        for (RecyclerView rv : observerList) {
                            if (recyclerView != rv) {
                                LinearLayoutManager layoutManager = (LinearLayoutManager) rv.getLayoutManager();
                                if (layoutManager != null) {
                                    PanelLineAdapter.this.firstPos = firstPos;
                                    PanelLineAdapter.this.firstOffset = firstRight;
                                    layoutManager.scrollToPositionWithOffset(firstPos + 1, firstRight);
                                }
                            }
                        }
                    }
                }

                @Override
                public void onScrollStateChanged(RecyclerView recyclerView, int newState) {
                    super.onScrollStateChanged(recyclerView, newState);
                }
            });
        }

        /**
         * TODO observerList 可以获取所有的RecyclerView contentRecyclerView 只能获取界面显示的RecyclerView
         */
        private HashSet<RecyclerView> getRecyclerViews() {
            HashSet<RecyclerView> recyclerViewHashSet = new HashSet<>();
            recyclerViewHashSet.add(headerRecyclerView);
            for (int i = 0; i < contentRecyclerView.getChildCount(); i++) {
                recyclerViewHashSet.add((RecyclerView) contentRecyclerView.getChildAt(i).findViewById(R.id.recycler_line_list));
            }
            recyclerViewHashSet.add(contentRecyclerView);
            return recyclerViewHashSet;
        }

        /**
         * TODO 记住这里不可见元素是没法修改，想要修改只能对所有ViewHolder进行存储
         */
        private RecyclerView getContentRecyclerView(int pos) {
            for (int i = 0; i < contentRecyclerView.getChildCount(); i++) {
                View itemView = contentRecyclerView.getChildAt(i);
                if (itemView != null && (int) itemView.getTag() == pos) {
                    return (RecyclerView) itemView.findViewById(R.id.recycler_line_list);
                }
            }
            return null;
        }

        private View getContentRecyclerItemView(int pos, int childPos) {
            for (int i = 0; i < contentRecyclerView.getChildCount(); i++) {
                View itemView = contentRecyclerView.getChildAt(i);
                if (itemView != null && (int) itemView.getTag() == pos) {
                    RecyclerView itemRecyclerView = (RecyclerView) itemView.findViewById(R.id.recycler_line_list);
                    if (childPos >= 0 || itemRecyclerView.getChildCount() > childPos) {
                        return itemRecyclerView.getChildAt(childPos);
                    }
                }
            }
            return null;
        }

        static class ViewHolder extends RecyclerView.ViewHolder {
            public RecyclerView recyclerView;
            public FrameLayout firstColumnItemView;
            public RecyclerView.ViewHolder firstColumnItemVH;

            public ViewHolder(View view) {
                super(view);
                this.recyclerView = view.findViewById(R.id.recycler_line_list);
                this.firstColumnItemView = view.findViewById(R.id.first_column_item);
                this.recyclerView.setLayoutManager(new LinearLayoutManager(view.getContext(), LinearLayoutManager.HORIZONTAL, false));
            }
        }
    }
}
