package com.wgmf.yxgj.basewebview.ui;

import android.annotation.SuppressLint;
import android.content.Context;
import android.os.Build;
import android.os.Bundle;
import android.text.TextUtils;
import android.util.Log;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.webkit.WebChromeClient;
import android.webkit.WebSettings;
import android.webkit.WebView;
import android.widget.ImageView;
import android.widget.LinearLayout;
import android.widget.TextView;

import com.alibaba.android.arouter.facade.annotation.Route;
import com.bumptech.glide.Glide;
import com.wgmf.library.utils.NetworkUtil;
import com.wgmf.yxgj.base.BaseParentFra;
import com.wgmf.yxgj.basewebview.R;
import com.wgmf.yxgj.basewebview.graph.components.DaggerHtmlFragmentComponent;
import com.wgmf.yxgj.basewebview.graph.modules.HtmlFragmentModule;
import com.xp.arouter.RouterParams;

import org.jetbrains.annotations.NotNull;

import javax.inject.Inject;

/**
 * 网页容器
 *
 * @author xiep
 */
@SuppressWarnings("all")
@Route(path = RouterParams.URL_HTML5DETAILACTIVITY)
public class HtmlFragment extends BaseParentFra implements HtmlView {

    @Inject
    HtmlPresenter htmlPresenter;

    WebView activityDataWebview;
    LinearLayout activityDataWebviewReloadLl;
    LinearLayout activityDataWebviewLl;
    TextView activityDataWebviewPbTv;
    ImageView activityDataWebviewPbIv;
    ImageView activityDataWebviewReload;

    @Override
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        initInjector();
        setContent();
    }

    private void setContent() {
        htmlPresenter.initData();
    }

    private void setWebClient() {
        htmlPresenter.synCookies(getActivity());
        htmlPresenter.load();
    }

    private void initInjector() {
        DaggerHtmlFragmentComponent.builder()
                .htmlFragmentModule(new HtmlFragmentModule(this))
                .build().inject(this);
    }

    @Override
    public View onCreateView(@NotNull LayoutInflater inflater, ViewGroup container, Bundle savedInstanceState) {
        View view = inflater.inflate(R.layout.fragment_webview_content, container, false);
        activityDataWebview = (WebView) view.findViewById(R.id.activity_data_webview);
        activityDataWebviewReloadLl = (LinearLayout) view.findViewById(R.id.activity_data_webview_reload_ll);
        activityDataWebviewLl = (LinearLayout) view.findViewById(R.id.activity_data_webview_ll);
        activityDataWebviewPbTv = (TextView) view.findViewById(R.id.activity_data_webview_pb_tv);
        activityDataWebviewPbIv = (ImageView) view.findViewById(R.id.activity_data_webview_pb_iv);
        Glide.with(this).load(R.drawable.load).asGif().into(activityDataWebviewPbIv);
        activityDataWebviewReload = (ImageView) view.findViewById(R.id.activity_data_webview_reload);
        activityDataWebviewReload.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                refresh();
            }
        });
        activityDataWebviewReloadLl.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                refresh();
            }
        });
        initWebClient();
        setWebClient();
        return view;
    }

    public void back() {
        if (activityDataWebview.canGoBack()) {
            // 返回前一个页面
            activityDataWebview.goBack();
        } else {
            getActivity().finish();
        }
    }

    @SuppressLint({"JavascriptInterface", "AddJavascriptInterface"})
    private void initWebClient() {
        activityDataWebview.getSettings().setBuiltInZoomControls(true);
        activityDataWebview.getSettings().setJavaScriptEnabled(true);
        activityDataWebview.getSettings().setJavaScriptCanOpenWindowsAutomatically(true);
        //提高渲染的优先级
        activityDataWebview.getSettings().setRenderPriority(WebSettings.RenderPriority.HIGH);
        if (NetworkUtil.isNetworkAvailable(getActivity().getApplicationContext())) {
            //根据cache-control决定是否从网络上取数据。
//            activityDataWebview.getSettings().setCacheMode(WebSettings.LOAD_DEFAULT);
            // 不使用缓存
            activityDataWebview.getSettings().setCacheMode(WebSettings.LOAD_NO_CACHE);
        } else {
            showError("您的网络未连接，请检查！");
            //没网，则从本地获取，即离线加载
            activityDataWebview.getSettings().setCacheMode(WebSettings.LOAD_CACHE_ELSE_NETWORK);
        }
        // 开启 DOM storage API 功能
        activityDataWebview.getSettings().setDomStorageEnabled(true);
        activityDataWebview.getSettings().setDatabaseEnabled(true);

        if (Build.VERSION.SDK_INT < Build.VERSION_CODES.KITKAT) {
            activityDataWebview.getSettings().setDatabasePath(activityDataWebview.getContext().getFilesDir() + activityDataWebview.getContext().getPackageName() + "/databases/");
        }
        // WebView 默认不允许一个安全的链接混合使用HTTPS +HTTP，需要设置webview支持HTTPS +HTTP
        if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.LOLLIPOP) {
            activityDataWebview.getSettings().setMixedContentMode(WebSettings.MIXED_CONTENT_ALWAYS_ALLOW);
        }
        activityDataWebview.getSettings().setBlockNetworkImage(false);

        activityDataWebview.addJavascriptInterface(new WebViewJsBridge(), "AndroidToJsBridge");

        WebChromeClient webChromeClient = new WebChromeClient() {

            @Override
            public void onReceivedTitle(WebView view, String title) {
                super.onReceivedTitle(view, title);
                Log.d("onReceivedTitle", title);
                setTitleText(title);
            }

            @Override
            public void onProgressChanged(WebView view, int newProgress) {
                if (newProgress < 100) {
                    activityDataWebviewLl.setVisibility(View.VISIBLE);
                } else {
                    activityDataWebviewLl.setVisibility(View.GONE);
                    activityDataWebview.setVisibility(View.VISIBLE);
                }
                String progress = newProgress + "%";
                activityDataWebviewPbTv.setText("网页已加载：" + progress);
            }
        };
        // 设置setWebChromeClient对象
        activityDataWebview.setWebChromeClient(webChromeClient);
        activityDataWebview.setWebViewClient(htmlPresenter.getWebViewClient(getActivity()));
        activityDataWebview.setScrollBarStyle(WebView.SCROLLBARS_OUTSIDE_OVERLAY);
    }

    private void setTitleText(String title) {
        if (title.contains("error") || title.contains("404") || title.contains("网页无法打开")) {
            activityDataWebviewReloadLl.setVisibility(View.VISIBLE);
        } else {
            activityDataWebviewReloadLl.setVisibility(View.GONE);
        }
        if (!TextUtils.isEmpty(title) && !title.contains("index")) {
            onChangeTitleListener.changeTitle(title);
        }
    }

    /**
     * 页面Tab角标
     * @param index
     */
    public void setPageTabParams(int index) {
        htmlPresenter.setPageTabParams(index);
        //回滚到跟页面
        rollback();
    }

    @Override
    public void refresh() {
        showMsg("重新加载网页数据...");
        activityDataWebview.reload();
        // 不使用缓存
        activityDataWebview.getSettings().setCacheMode(WebSettings.LOAD_NO_CACHE);
    }

    @Override
    public void loadData(String url) {
        activityDataWebview.loadData(url, "text/html; charset=UTF-8", null);
    }

    @Override
    public void rollback() {
        while (true) {
            if (activityDataWebview.canGoBack()) {
                activityDataWebview.goBack();
            } else {
                break;
            }
        }
    }

    @Override
    public void loadUrl(String url) {
        //每次刷新网页时，重新设置cookies
        htmlPresenter.synCookies(getActivity());
        activityDataWebview.loadUrl(url);
    }

    public void test(String url) {
        activityDataWebview.loadUrl(url);
    }

    @Override
    public void showLoadingDialog() {
//        showDialog();
    }

    @Override
    public void finishLoadingDialog() {
//        dismissDialog();
    }

    @Override
    public void showError(String error) {
        showMsg(error);
    }

    @Override
    public void finishView() {
        getActivity().finish();
    }

    OnChangeTitleListener onChangeTitleListener;

    public interface OnChangeTitleListener {
        public void changeTitle(String title);
    }

    @Override
    public void onAttach(Context activity) {
        super.onAttach(activity);
        try {
            onChangeTitleListener = (OnChangeTitleListener) getActivity();
        } catch (ClassCastException e) {
            throw new ClassCastException(activity.toString() + " must implement OnHeadlineSelectedListener");
        }
    }
}