package com.wgmf.yxgj.businessmodule.ui.base;

import android.os.Bundle;
import android.support.annotation.NonNull;

import com.wgmf.yxgj.base.BaseActivity;
import com.wgmf.yxgj.base.BaseCommonAdapter;
import com.wgmf.yxgj.base.BaseParentFra;
import com.wgmf.yxgj.base.ViewHolder;
import com.wgmf.yxgj.model.CommonResourcesBean;
import com.wgmf.yxgj.model.CommonResourcesListBean;
import com.wgmf.yxgj.publics.service.ToFunctionByResId;
import com.xp.arouter.RouterCommonUtil;

import java.util.ArrayList;
import java.util.List;

/**
 * IBasePresenter:
 * Author: xp
 * Date: 17/8/24 15:18
 * Email: xiexiepro@gmail.com
 * Blog: http://XieXiePro.github.io
 */
public class IBasePresenter {

    private IBaseView iBaseView;
    private List<CommonResourcesBean> mCommonResourcesBean;
    private List<CommonResourcesBean> fonctionList;
    private List<CommonResourcesBean> branchList;

    public IBasePresenter(@NonNull IBaseView iBaseView) {
        this.iBaseView = iBaseView;
    }

    /**
     * 根据父ID添加列表数据
     *
     * @param parentId 父ID
     */
    public List<CommonResourcesBean> getDataByID(int parentId) {
        fonctionList = new ArrayList<>();
        branchList = new ArrayList<>();
        try {
            mCommonResourcesBean = ((BaseActivity) ((BaseParentFra) iBaseView).getActivity()).getCommonResourcesData();
            for (int i = 0; i < mCommonResourcesBean.size(); i++) {
                if (mCommonResourcesBean.get(i).getParentId() == parentId) {
                    fonctionList.add(mCommonResourcesBean.get(i));
                }
            }
        } catch (Exception e) {
            mCommonResourcesBean = new ArrayList<>();
        }
        return fonctionList;
    }

    /**
     * 列表条目点击事件
     *
     * @param position 列表位置
     */
    public void onItemClickListener(int position) {
        if (null != fonctionList && position < fonctionList.size()) {
            Long resId = fonctionList.get(position).getResourceId();
            int type = fonctionList.get(position).getType();
            branchList.clear();
            //首先判断当前为第二级菜单，然后判断是否有子节点，若有子节点，先跳入子列表界面，再根据资源ID跳转到对应功能
            for (int i = 0; i < mCommonResourcesBean.size(); i++) {
                if (type == 2 && mCommonResourcesBean.get(i).getParentId().equals(resId)) {
                    branchList.add(mCommonResourcesBean.get(i));
                }
            }
            int flag = 0;
            String orientation = "PORTRAIT";
            Long branchID = fonctionList.get(position).getResourceId();

            if (!branchList.isEmpty()) {
                flag = -1;
            } else if (ToFunctionByResId.checkChoiceShop(branchID)) {
                flag = -2;
            } else if (fonctionList.get(position).getParentId() == 118) {
                // 118是运营绩效类
                orientation = "LANDSCAPE";
            }
            Bundle mBundle = new Bundle();
            mBundle.putLong("branchID", branchID);
            mBundle.putString("branchTitle", fonctionList.get(position).getName());
            mBundle.putString("branchUrl", fonctionList.get(position).getResUrl());
            mBundle.putString("orientation", orientation);
            RouterCommonUtil.startFunctionActivity(((BaseParentFra) iBaseView).getActivity(), flag, branchID, mBundle);
        }
    }

    /**
     * 获取适配器
     *
     * @return BaseCommonAdapter
     */
    BaseCommonAdapter<CommonResourcesBean> getAdapter() {
        return new BaseCommonAdapter<CommonResourcesBean>(
                ((BaseParentFra) iBaseView).getActivity(), fonctionList) {
            @Override
            public void convert(ViewHolder helper, CommonResourcesBean item) {
                helper.setText(item.getName());
            }
        };
    }

    /**
     * 设置功能权限嵌套关系图
     *
     * @param parentId 父ID
     * @return 功能权限
     */
    public List<CommonResourcesListBean> getAllData(int parentId) {
        try {
            mCommonResourcesBean = ((BaseActivity) ((BaseParentFra) iBaseView).getActivity()).getCommonResourcesData();
        } catch (Exception e) {
            mCommonResourcesBean = new ArrayList<>();
        }
        List<CommonResourcesListBean> listBeans = new ArrayList<>();
        List<CommonResourcesBean> resourcesBeans = new ArrayList<>();
        for (CommonResourcesBean res : mCommonResourcesBean) {
            if (res.getParentId() == parentId) {
                CommonResourcesListBean listInfo = new CommonResourcesListBean();
                listInfo.setResourceId(res.getResourceId());
                listInfo.setParentId(res.getParentId());
                listInfo.setName(res.getName());
                listInfo.setType(res.getType());
                listInfo.setDescription(res.getDescription());
                listInfo.setResUrl(res.getResUrl());
                listBeans.add(listInfo);
            } else {
                CommonResourcesBean gridInfo = new CommonResourcesBean();
                gridInfo.setResourceId(res.getResourceId());
                gridInfo.setParentId(res.getParentId());
                gridInfo.setName(res.getName());
                gridInfo.setType(res.getType());
                gridInfo.setDescription(res.getDescription());
                gridInfo.setResUrl(res.getResUrl());
                resourcesBeans.add(gridInfo);
            }
        }
        for (int i = 0; i < listBeans.size(); i++) {
            List<CommonResourcesBean> beans = new ArrayList<>();
            for (CommonResourcesBean gridDataInfo : resourcesBeans) {
                Long listId = listBeans.get(i).getResourceId();
                Long gridId = gridDataInfo.getParentId();
                if (listId.equals(gridId)) {
                    beans.add(gridDataInfo);
                }
            }
            listBeans.get(i).setResourcesList(beans);
        }
        return listBeans;
    }

    /**
     * Gird列表条目点击事件
     *
     * @param position 列表位置
     */

    public void onGirdClickListener(List<CommonResourcesBean> fonctionList, int position) {
        String title = fonctionList.get(position).getName();
        Long resId = fonctionList.get(position).getResourceId();
        int type = fonctionList.get(position).getType();
        branchList.clear();
        //首先判断当前为第二级菜单，然后判断是否有子节点，若有子节点，先跳入子列表界面，再根据资源ID跳转到对应功能
        for (int i = 0; i < mCommonResourcesBean.size(); i++) {
            if (type == 2 && mCommonResourcesBean.get(i).getParentId().equals(resId)) {
                branchList.add(mCommonResourcesBean.get(i));
            }
        }
        int flag = 0;
        Long branchID = fonctionList.get(position).getResourceId();

        if (!branchList.isEmpty()) {
            flag = -1;
        } else if (ToFunctionByResId.checkChoiceShop(branchID)) {
            flag = -2;
        }
        Bundle mBundle = new Bundle();
        mBundle.putLong("branchID", branchID);
        mBundle.putString("branchTitle", title);
        mBundle.putString("branchUrl", fonctionList.get(position).getResUrl());
        RouterCommonUtil.startFunctionActivity(((BaseParentFra) iBaseView).getActivity(), flag, branchID, mBundle);
    }
}