package com.wgmf.yxgj.loginmodule.ui;


import android.app.Activity;
import android.content.Context;
import android.os.Bundle;
import android.os.Handler;
import android.os.Message;
import android.support.annotation.NonNull;
import android.text.TextUtils;
import android.util.Log;

import com.google.gson.Gson;
import com.wgmf.library.app.WGMFLibApplication;
import com.wgmf.library.base.ResultData;
import com.wgmf.library.global.LocationParams;
import com.wgmf.library.utils.LocationUtil;
import com.wgmf.library.utils.StringUtil;
import com.wgmf.library.utils.ToastUtil;
import com.wgmf.library.utils.tools.DeviceHelper;
import com.wgmf.library.utils.tools.PrefTool;
import com.wgmf.yxgj.app.LibGroupContext;
import com.wgmf.yxgj.base.BaseParentAct;
import com.wgmf.yxgj.config.BusinessID;
import com.wgmf.yxgj.db.BrandListDao;
import com.wgmf.yxgj.db.CommonResourcesBeanDao;
import com.wgmf.yxgj.db.CommonUserinfoBeanDao;
import com.wgmf.yxgj.global.ConstantParams;
import com.wgmf.yxgj.global.OeRoleParams;
import com.wgmf.yxgj.global.Prefs;
import com.wgmf.yxgj.loginmodule.R;
import com.wgmf.yxgj.loginmodule.model.LoginImgResultEntity;
import com.wgmf.yxgj.loginmodule.model.UserOrgInfoData;
import com.wgmf.yxgj.loginmodule.service.LoginService;
import com.wgmf.yxgj.model.BrandList;
import com.wgmf.yxgj.model.CommonDataBean;
import com.wgmf.yxgj.model.CommonResourcesBean;
import com.wgmf.yxgj.model.CommonUserinfoBean;
import com.wgmf.yxgj.publics.service.MainService;
import com.wgmf.yxgj.publics.service.TotalPerfomanceManager;
import com.wgmf.yxgj.utils.JPushUtil;
import com.xp.arouter.RouterCommonUtil;

import java.net.URLEncoder;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.Set;

import cn.jpush.android.api.JPushInterface;
import cn.jpush.android.api.TagAliasCallback;

/**
 * @author XP on 2016/7/19 16:27
 */
public class LoginPresenter {
    private static final String TAG = "LoginPresenter";
    private static final int MSG_SET_ALIAS = 1001;
    private int mCount;
    private long mPreClickTime;
    private LoginView userLoginView;

    public LoginPresenter(@NonNull LoginView userLoginView) {
        this.userLoginView = userLoginView;
    }

    void initContent() {
        // 登录状态为假
        PrefTool.getBooleanPreferences((Activity) userLoginView, Prefs.PRE_LOGIN_STATUS, false);
        // 消息入口状态为假
        PrefTool.setBooleanSave((Activity) userLoginView, Prefs.PRE_MESSAGE_STATUS, false);

        String version = DeviceHelper.getVersion((Activity) userLoginView);
        int tempEnv = PrefTool.getIntPreferences((Activity) userLoginView, Prefs.PRE_ENVIRONMENT_STATUS, 0);

        String des = "当前版本 v." + version;
        if (tempEnv != 0) {
            des = "测试环境 v." + version;
            userLoginView.setVersion(des, R.color.red);
        } else {
            userLoginView.setVersion(des, R.color.common_txt_color);
        }
    }

    /**
     * 获取登录背景图片
     */
    void getLoginImage() {
        LoginService.getInstance().requestLoginImage(ConstantParams.CONSTANT_PARAMS_1, (BaseParentAct) userLoginView);
    }

    /**
     * 获取登录后相关信息
     */
    void getLoginInfo(String staffId, String orgId) {
        LoginService.getInstance().requestLoginInfo(staffId, orgId, (BaseParentAct) userLoginView);
    }

    /**
     * 用户登录
     *
     * @param username 用户名
     * @param password 密码
     */
    public void login(String username, String password) {
        if (!StringUtil.isNotNullAndNotEmpty(username)) {
            userLoginView.showTip("请输入账号");
            return;
        }
        if (!StringUtil.isNotNullAndNotEmpty(password)) {
            userLoginView.showTip("请输入密码");
            return;
        }
        try {
            userLoginView.showLoginDialog();
            //处理密码特殊参数
            LoginService.getInstance().requestLogin(username, URLEncoder.encode(password, "utf-8"), (BaseParentAct) userLoginView);
        } catch (Exception e) {
            Log.e(TAG, "login");
        }

    }

    /**
     * 登录信息验证
     *
     * @param context         LoginActivity
     * @param userOrgInfoData 用户信息
     */
    void checkAccount(Context context, UserOrgInfoData userOrgInfoData) {
        if (!ConstantParams.CONSTANT_PARAMS_0.equals(userOrgInfoData.retCode)) {
            //登录失败，打印接口提示
            userLoginView.showTip(userOrgInfoData.retInfo);
        } else {
            if (userOrgInfoData.getData() == null) {
                userLoginView.showTip("未获取到员工工号");
                return;
            }
            if (userOrgInfoData.getData().getUserOrgList() == null) {
                userLoginView.showTip("未获取到员工组织");
                return;
            }
            //将员工工号保存到缓存中
            PrefTool.setStringsave((Activity) userLoginView, Prefs.PRE_USER_STAFFID, userOrgInfoData.getData().getStaffId());
            if (userOrgInfoData.getData().getUserOrgList().size() > 1) {
                //如果有多个组织（userOrgList.size>1），进入组织选择界面；
                userLoginView.loginOrgSelect(userOrgInfoData.getData().getStaffId());
                return;
            }
            if (!userOrgInfoData.getData().getUserOrgList().isEmpty()) {
                //通过获取到的工号和组织，请求用户信息
                userLoginView.loginSuccess(userOrgInfoData.getData().getStaffId(), userOrgInfoData.getData().getUserOrgList().get(0).getOrganizationId());
            }
        }
    }

    /**
     * 清除用户数据
     *
     * @param context LoginActivity
     * @param account 用户名
     */
    void cleanAccout(Context context, String account) {
        String userName = PrefTool.getStringPerferences(context, Prefs.PRE_USER_NAME);
        if (!account.equals(userName)) {
            PrefTool.setBooleanSave(context, Prefs.PRE_USER_NAME_CHANGE, true);
        } else {
            PrefTool.setBooleanSave(context, Prefs.PRE_USER_NAME_CHANGE, false);
        }
    }

    /**
     * 是否记住密码
     *
     * @param context   LoginActivity
     * @param isChecked 是否选中记住密码选项
     */
    void checkPwdStatus(Context context, boolean isChecked) {
        PrefTool.setBooleanSave(context, Prefs.PRE_REMENBER_PASS, isChecked);
    }

    /**
     * 将用户登录账号写入文件
     *
     * @param username 用户名
     */
    void writeAccout(Context context, String username, String password) {
        PrefTool.setStringsave(context, Prefs.PRE_USER_NAME, username);
        PrefTool.setStringsave(context, Prefs.PRE_USER_PASS, password);
    }

    /**
     * 从SharePerferences中读取用户账号
     *
     * @param context LoginActivity
     */
    void readAccount(Context context) {
        String userName = PrefTool.getStringPerferences(context, Prefs.PRE_USER_NAME);
        String userPassword = PrefTool.getStringPerferences(context, Prefs.PRE_USER_PASS);
        if (PrefTool.getBooleanPreferences(context, Prefs.PRE_REMENBER_PASS, true)) {
            userLoginView.rememberLoginPassword(true, userName, userPassword);
        } else {
            userLoginView.rememberLoginPassword(false, userName, "");
        }
    }

    /**
     * 获取位置信息
     *
     * @param context LoginActivity
     */
    void getLocationInfo(Context context) {
        new LocationUtil(context, new LocationUtil.OnCallback() {

            @Override
            public void onFinish(String longitude, String latitude,
                                 String address, String city, int code, String error) {

                if (!TextUtils.isEmpty(address)) {
                    //将获取到的位置信息存储到本地
                    Map<String, String> params = new HashMap<>();
                    params.put("lat", LocationParams.Latitude);
                    params.put("lng", LocationParams.Longitude);
                    params.put("address", LocationParams.Address);
                    params.put("city", LocationParams.city);
                    Log.i("当前位置：", params + " Address:" + LocationParams.Address);
                }
            }
        });
    }


    /**
     * 设置JPush别名，用于识别用户
     *
     * @param context LoginActivity
     */
    void setAlias(Context context) {
        String alias = PrefTool.getStringPerferences(context, Prefs.PRE_USER_STAFFID);

        if (TextUtils.isEmpty(alias)) {
            Log.d(TAG, "alias不能为空");
            return;
        }
        if (!JPushUtil.isValidTagAndAlias(alias)) {
            Log.d(TAG, "格式不对");
            return;
        }

        // 调用JPush API设置Alias
        mHandler.sendMessage(mHandler.obtainMessage(MSG_SET_ALIAS, alias));
    }

    /**
     * 上报员工相关的jpush的信息
     *
     * @param context LoginActivity
     */
    void sendJPush(Context context) {
        String staffId = PrefTool.getStringPerferences(context, Prefs.PRE_USER_STAFFID);
        String tag = PrefTool.getStringPerferences(context, Prefs.PRE_USER_STAFF_POSITION);
        String alias = PrefTool.getStringPerferences(context, Prefs.PRE_USER_STAFFID);
        String platform = "android";
        MainService.getInstance().requestSetJPush(staffId, tag, alias, platform, (BaseParentAct) context);
    }

    private static final Handler mHandler = new Handler() {
        @Override
        public void handleMessage(Message msg) {
            super.handleMessage(msg);
            switch (msg.what) {
                case MSG_SET_ALIAS:
                    Log.d(TAG, "Set alias in handler.");
                    JPushInterface.setAliasAndTags(LibGroupContext.getApplication(), (String) msg.obj, null, mAliasCallback);
                    break;
                default:
                    Log.i(TAG, "Unhandled msg - " + msg.what);
                    break;
            }
        }
    };

    private static final TagAliasCallback mAliasCallback = new TagAliasCallback() {

        @Override
        public void gotResult(int code, String alias, Set<String> tags) {
            String logs;
            switch (code) {
                case 0:
                    logs = "Set tag and alias success";
                    Log.i(TAG, logs);
                    break;

                case 6002:
                    logs = "Failed to set alias and tags due to timeout. Try again after 60s.";
                    Log.i(TAG, logs);
                    if (JPushUtil.isConnected(LibGroupContext.getApplication())) {
                        mHandler.sendMessageDelayed(
                                mHandler.obtainMessage(MSG_SET_ALIAS, alias),
                                1000L * 60);
                    } else {
                        Log.i(TAG, "No network");
                    }
                    break;

                default:
                    logs = "Failed with errorCode = " + code;
                    Log.e(TAG, logs);
            }
        }

    };

    /**
     * 将用户数据存入数据库
     *
     * @param commonData              用户功能数据
     * @param mCommonUserinfoBeanDao  用户数据
     * @param mCommonResourcesBeanDao 用户功能
     */
    void saveUserData(CommonDataBean commonData, CommonUserinfoBeanDao mCommonUserinfoBeanDao, CommonResourcesBeanDao mCommonResourcesBeanDao, BrandListDao mBrandListDao) {
        // 存入数据库
        CommonUserinfoBean commonUserinfoEntity = commonData.getUserinfo();
        //OE角色21为KA主管,23为督导,24为片区经理，25为片区主管，实为3主管的功能
        commonUserinfoEntity.setOeRole(TotalPerfomanceManager.setOeRole(commonUserinfoEntity.getOeRole()));
        //自定义白名单升级->用户菜单权限角色，List转化为String存入数据库中
        if (null != commonUserinfoEntity.getAuthorityRoleIdBeanList() && !commonUserinfoEntity.getAuthorityRoleIdBeanList().isEmpty()) {
            String authorityRoleIdBeanList = new Gson().toJson(commonUserinfoEntity.getAuthorityRoleIdBeanList());
            authorityRoleIdBeanList = "{\"authorityRoleIdBeanList\":" + authorityRoleIdBeanList + "}";
            commonUserinfoEntity.setAuthorityRoleIdBean(authorityRoleIdBeanList);
        }
        //存储品牌信息
        if (null != commonUserinfoEntity.getBrandList() && !commonUserinfoEntity.getBrandList().isEmpty()) {
            List<BrandList> brandList = commonData.getUserinfo().getBrandList();
            mBrandListDao.insertOrReplaceInTx(brandList);
            String brandListString = new Gson().toJson(commonUserinfoEntity.getBrandList());
            commonUserinfoEntity.setBrandListBean(brandListString);
        }

        // 当前用户ID
        PrefTool.setStringsave((BaseParentAct) userLoginView, Prefs.PRE_USER_STAFFID, commonUserinfoEntity.getStaffId());
        // 当前用户职位
        PrefTool.setStringsave((BaseParentAct) userLoginView, Prefs.PRE_USER_STAFF_POSITION, commonUserinfoEntity.getOrganization());
        // 上级工号
        PrefTool.setStringsave((BaseParentAct) userLoginView, Prefs.PRE_USER_STAFF_LEADERID, commonUserinfoEntity.getWorkCode());
        // 登录状态为真
        PrefTool.setBooleanSave((BaseParentAct) userLoginView, Prefs.PRE_LOGIN_STATUS, true);
        //创建并更新用户信息表
        mCommonUserinfoBeanDao.insertOrReplaceInTx(commonUserinfoEntity);
        List<CommonResourcesBean> commonResourceEntity = commonData.getResources();

        if (null != commonResourceEntity) {
            for (int i = 0; i < commonResourceEntity.size(); i++) {
                // 去除根目录,parentID=10008时为根目录.过滤掉10008根记录
                if (commonResourceEntity.get(i).getParentId() != 10008) {
                    try {
                        mCommonResourcesBeanDao.insert(commonResourceEntity.get(i));
                    } catch (Exception e) {
                        //更新数据，常用功能列表被重置
                        Log.d(TAG, commonResourceEntity.get(i).getName() + ":此条数据已存在。");
                    }
                }
            }
        }
    }

    /**
     * 进入下一个页面
     *
     * @param context LoginActivity
     */
    void toNextActivity(Context context, CommonDataBean commonData) {
        userLoginView.dismissLoginDialog();
        if (PrefTool.getBooleanPreferences(context, Prefs.PRE_MESSAGE_STATUS, true)) {
            Bundle mBundle = new Bundle();
            mBundle.putLong("branchID", 0L);
            mBundle.putString("branchTitle", "消息");
            RouterCommonUtil.startFunctionActivity(context, -5, 0L, mBundle);
        } else {
            if (null != commonData && null != commonData.getUserinfo()) {
                PrefTool.setStringsave(context, Prefs.PRE_USER_PART_TIME_NAME, commonData.getUserinfo().getName());
                //兼职督查
                if (null != commonData.getUserinfo().getOeRole() && OeRoleParams.OE_ROLE_PARAMS_26.equals(commonData.getUserinfo().getOeRole())) {
                    PrefTool.setStringsave(context, Prefs.PRE_USER_PART_TIME_NAME, null);
                    userLoginView.loginPartTime();
                } else {
                    userLoginView.loginHome();
                }
            } else {
                userLoginView.loginHome();
            }
        }
        // 消息入口状态为假
        PrefTool.setBooleanSave(context, Prefs.PRE_MESSAGE_STATUS, false);
    }

    /**
     * 进入开发者模式
     *
     * @param context LoginActivity
     */
    void changeEnv(final Context context) {
        long now = System.currentTimeMillis();
        if (now - mPreClickTime < 300) {
            mCount++;
        } else {
            mCount = 1;
        }
        mPreClickTime = now;
        if (mCount >= 7) {
            //设置环境标志
            int which = PrefTool.getIntPreferences(context, Prefs.PRE_ENVIRONMENT_STATUS, 0);
            if (which == 0) {
                PrefTool.setIntSave(context, Prefs.PRE_ENVIRONMENT_STATUS, 1);
                ToastUtil.show(context, "成功切换到测试环境，请重新启动营销管家！");
            } else {
                PrefTool.setIntSave(context, Prefs.PRE_ENVIRONMENT_STATUS, 0);
                ToastUtil.show(context, "成功切换到正式环境，请重新启动营销管家！");
            }
            try {
                Thread.sleep(1000);
            } catch (InterruptedException e) {
                e.printStackTrace();
            }
            WGMFLibApplication.getInstance().exit();
        }
    }

    /**
     * 根据接口返回数据进行服务切换
     *
     * @param result 服务器返回数据
     */
    void switchService(ResultData result) {
        if (null != result) {
            final int id = result.taskID;
            switch (id) {
                case BusinessID.Login.MSG_ON_USER_LOGIN:
                    checkUserLogin(result);
                    break;
                case BusinessID.Login.MSG_ON_USER_LOGIN_INFO:
                    checkUserLoginInfo(result);
                    break;
                case BusinessID.Login.MSG_ON_FRONT_DISPLAY:
                    getDisplayImage(result);
                    break;
                default:
                    break;
            }
        }
    }

    private void checkUserLoginInfo(ResultData result) {
        final String msg = result.getInfo();
        if (result.isSuccessed() && ConstantParams.CONSTANT_PARAMS_0.equals(result.getResultCode())) {
            try {
                CommonDataBean commonData = new Gson().fromJson(msg, CommonDataBean.class);
                Log.d(TAG, "commonData=" + commonData.toString());
                if (null == commonData.getUserinfo()) {
                    userLoginView.showTip(((BaseParentAct) userLoginView).getString(R.string.login_limit_userinfo_fail));
                } else {
                    userLoginView.loginSuccessInfo(commonData);
                }
            } catch (Exception e) {
                userLoginView.showTip(result.getResultInfo());
            }
        } else {
            userLoginView.showTip(result.getResultInfo());
        }
    }

    private void checkUserLogin(ResultData result) {
        final String msg = result.getInfo();
        if (result.isSuccessed() && ConstantParams.CONSTANT_PARAMS_0.equals(result.getResultCode())) {
            try {
                UserOrgInfoData userOrgInfoData = new Gson().fromJson(msg, UserOrgInfoData.class);
                Log.d(TAG, "userOrgInfoData=" + userOrgInfoData.toString());
                // 登录允许判断
                userLoginView.loginAllow(userOrgInfoData);
            } catch (Exception e) {
                userLoginView.showTip(result.getResultInfo());
            }
        } else {
            userLoginView.showTip(result.getResultInfo());
        }
    }

    private void getDisplayImage(ResultData result) {
        final String msg = result.getInfo();
        if (result.isSuccessed()) {
            LoginImgResultEntity mLoginImgResultEntity = new Gson().fromJson(msg, LoginImgResultEntity.class);
            Log.d(TAG, "mLoginImgResultEntity=" + mLoginImgResultEntity.toString());
            if (ConstantParams.CONSTANT_PARAMS_0.equals(mLoginImgResultEntity.msgCode)) {
                String url = mLoginImgResultEntity.getResultInfo().getIMAGE2();
                if (null != url) {
                    // 登录背景图片配置
                    userLoginView.loginBgImg(url);
                }
            }
        }
    }
}