package com.wgmf.yxgj.loginmodule.ui;

import android.os.Bundle;
import android.util.Log;
import android.view.View;
import android.widget.ImageView;
import android.widget.ListView;

import com.alibaba.android.arouter.facade.annotation.Route;
import com.google.gson.Gson;
import com.wgmf.library.base.ResultData;
import com.wgmf.library.utils.tools.PrefTool;
import com.wgmf.yxgj.base.BaseParentAct;
import com.wgmf.yxgj.config.BusinessID;
import com.wgmf.yxgj.global.ConstantParams;
import com.wgmf.yxgj.global.OeRoleParams;
import com.wgmf.yxgj.global.Prefs;
import com.wgmf.yxgj.loginmodule.R;
import com.wgmf.yxgj.loginmodule.graph.components.DaggerOrgSelectorActivityComponent;
import com.wgmf.yxgj.loginmodule.graph.modules.OrgSelectorActivityModule;
import com.wgmf.yxgj.loginmodule.model.UserOrgInfoData;
import com.wgmf.yxgj.loginmodule.model.UserOrgList;
import com.wgmf.yxgj.loginmodule.service.LoginService;
import com.wgmf.yxgj.model.CommonDataBean;
import com.xp.arouter.RouterCommonUtil;
import com.xp.arouter.RouterParams;

import java.util.List;

import javax.inject.Inject;

/**
 * 组织选择页
 */
@Route(path = RouterParams.URL_ORGSELECTORACTIVITY)
public class OrgSelectorActivity extends BaseParentAct implements OrgSelectorAdapter.SelectListener, LoginView {

    ListView orgLv;
    String staffId;

    @Inject
    OrgSelectorPresenter orgSelectorPresenter;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_org_selector);
        initView();
        initInjector();
        getData();
    }

    private void initInjector() {
        DaggerOrgSelectorActivityComponent.builder()
                .orgSelectorActivityModule(new OrgSelectorActivityModule(this))
                .build()
                .inject(this);
    }

    private void getData() {
        staffId = PrefTool.getStringPerferences(this, Prefs.PRE_USER_STAFFID);
        LoginService.getInstance().requestGetSaleOrgInfo(staffId, this);
    }

    private void initView() {
        orgLv = (ListView) findViewById(R.id.org_lv);
        ImageView backBtn = (ImageView) findViewById(R.id.back_btn);
        backBtn.setVisibility(View.GONE);
        backBtn.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                OrgSelectorActivity.this.finish();
            }
        });
    }

    @Override
    protected void onBusinessResultAtMainThread(ResultData result) {
        super.onBusinessResultAtMainThread(result);
        dismissDialog();
        if (null != result) {
            final int id = result.taskID;
            if (id == BusinessID.Login.MSG_ON_GET_SALE_ORG_INFO) {
                final String msg = result.getInfo();
                if (result.isSuccessed()) {
                    UserOrgInfoData userOrgInfoData = new Gson().fromJson(msg, UserOrgInfoData.class);
                    Log.d(TAG, "userOrgInfoData=" + userOrgInfoData.toString());
                    if (ConstantParams.CONSTANT_PARAMS_0.equals(userOrgInfoData.retCode)) {
                        if (userOrgInfoData.getData() != null && userOrgInfoData.getData().getUserOrgList() != null) {
                            List<UserOrgList> userOrgList = userOrgInfoData.getData().getUserOrgList();
                            orgLv.setAdapter(new OrgSelectorAdapter(userOrgList, OrgSelectorActivity.this, OrgSelectorActivity.this));
                        }
                    } else {
                        showMsg(userOrgInfoData.retInfo);
                    }
                } else {
                    showMsg(result.getResultInfo());
                }
            } else if (id == BusinessID.Login.MSG_ON_USER_LOGIN_INFO) {
                final String msg = result.getInfo();
                if (result.isSuccessed() && ConstantParams.CONSTANT_PARAMS_0.equals(result.getResultCode())) {
                    try {
                        CommonDataBean commonData = new Gson().fromJson(msg, CommonDataBean.class);
                        Log.d(TAG, "commonData=" + commonData.toString());
                        if (null == commonData.getUserinfo()) {
                            showMsg(getString(R.string.login_limit_userinfo_fail));
                        } else {
                            loginSuccessInfo(commonData);
                        }
                    } catch (Exception e) {
                        showMsg(result.getResultInfo());
                    }
                } else {
                    showMsg(result.getResultInfo());
                }
            }
        }
    }

    @Override
    public void showTip(String msg) {

    }

    @Override
    public void rememberLoginPassword(boolean isRemember, String userName, String userPassword) {

    }

    @Override
    public void setVersion(String version, int color) {

    }

    @Override
    public void loginAllow(UserOrgInfoData userOrgInfoData) {

    }

    @Override
    public void loginSuccess(String staffId, String orgId) {

    }

    @Override
    public void loginBgImg(String url) {

    }

    @Override
    public void loginHome() {
        Bundle mBundle = new Bundle();
        mBundle.putLong("branchID", 0L);
        mBundle.putString("branchTitle", "营销管家");
        RouterCommonUtil.startFunctionActivity(this, -3, 0L, mBundle);
        OrgSelectorActivity.this.finish();
    }

    @Override
    public void loginPartTime() {

    }

    @Override
    public void loginOrgSelect(String staffId) {

    }

    @Override
    public void showLoginDialog() {

    }

    @Override
    public void dismissLoginDialog() {

    }

    @Override
    public void loginSuccessInfo(CommonDataBean commonData) {
        orgSelectorPresenter.saveUserData(commonData, mCommonUserinfoBeanDao, mCommonResourcesBeanDao, mBrandListDao);
        orgSelectorPresenter.setAlias(this);
        orgSelectorPresenter.sendJPush(this);
        orgSelectorPresenter.getLocationInfo(this);

        if (null != commonData.getUserinfo()) {
            PrefTool.setStringsave(mContext, Prefs.PRE_USER_PART_TIME_NAME, commonData.getUserinfo().getName());
            //兼职督查
            if (null != commonData.getUserinfo().getOeRole() && OeRoleParams.OE_ROLE_PARAMS_26.equals(commonData.getUserinfo().getOeRole())) {
                PrefTool.setStringsave(mContext, Prefs.PRE_USER_PART_TIME_NAME, null);
            }
        }
        loginHome();
    }

    @Override
    public void onSelect(String orgId) {
        showDialog();
        //删除原有的用户信息
        clearUserData();
        //根据选择的组织信息获取用户信息和权限
        LoginService.getInstance().requestLoginInfo(staffId, orgId, this);
    }
}