package com.wgmf.yxgj.loginmodule.ui;

import android.content.Context;
import android.support.v4.content.ContextCompat;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.BaseAdapter;
import android.widget.ImageView;
import android.widget.TextView;

import com.wgmf.yxgj.loginmodule.R;
import com.wgmf.yxgj.loginmodule.model.UserOrgList;

import java.util.List;

/**
 * @author xiep
 */
public class OrgSelectorAdapter extends BaseAdapter {
    private Context context;
    private List<UserOrgList> reportTypeList;
    private SelectListener selectListener;

    public interface SelectListener {
        void onSelect(String orgId);
    }

    OrgSelectorAdapter(List<UserOrgList> reportTypeList, Context context, SelectListener selectListener) {
        this.reportTypeList = reportTypeList;
        this.context = context;
        this.selectListener = selectListener;
    }

    @Override
    public int getCount() {
        return reportTypeList == null ? 0 : reportTypeList.size();
    }

    @Override
    public Object getItem(int position) {
        return reportTypeList == null ? null : reportTypeList.get(position);
    }

    @Override
    public long getItemId(int position) {
        return position;
    }

    @SuppressWarnings("all")
    @Override
    public View getView(final int position, View convertView, ViewGroup parent) {
        final ViewHolder viewHolder;
        if (convertView == null) {
            convertView = LayoutInflater.from(context).inflate(R.layout.item_org_selector, null);
            viewHolder = new ViewHolder();
            viewHolder.orgTv = (TextView) convertView.findViewById(R.id.org_tv);
            viewHolder.orgBtn = (ImageView) convertView.findViewById(R.id.org_btn);
            convertView.setTag(viewHolder);
        } else {
            viewHolder = (ViewHolder) convertView.getTag();
        }
        final UserOrgList item = reportTypeList.get(position);
        viewHolder.orgTv.setText(item.getOrganizationName());

        setSelect(item, viewHolder);
        convertView.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                // 默认所有项目为未选中状态
                for (UserOrgList it : reportTypeList) {
                    it.setSelect(false);
                }
                selectListener.onSelect(item.getOrganizationId());
                item.setSelect(!item.isSelect());
                setSelect(item, viewHolder);
                notifyDataSetChanged();
            }
        });
        return convertView;
    }

    private void setSelect(UserOrgList item, ViewHolder viewHolder) {
        if (item.isSelect()) {
            viewHolder.orgBtn.setImageDrawable(ContextCompat.getDrawable(context, R.mipmap.btn_coupons_choose_2));
        } else {
            viewHolder.orgBtn.setImageDrawable(ContextCompat.getDrawable(context, R.mipmap.btn_coupons_choose_1));
        }
    }

    class ViewHolder {
        TextView orgTv;
        ImageView orgBtn;
    }
}