package com.wgmf.yxgj.modulemain.dialog

import android.app.Dialog
import android.content.Context
import android.view.Gravity
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import android.widget.Button
import android.widget.LinearLayout
import android.widget.TextView
import com.wgmf.yxgj.global.ConstantParams
import com.wgmf.yxgj.modulemain.R
import com.wgmf.yxgj.modulemain.model.PopWindowShowEntity
import com.wgmf.yxgj.utils.DensityUtil

/**
 * @author LW
 * 首页消息弹窗
 */
class HomeDataAnalyzeDialog(context: Context, theme: Int) : Dialog(context, theme) {

    init {
        //这句代码设置这个对话框是否能被用户触摸取消掉
        setCanceledOnTouchOutside(false)
        //这句代码设置这个对话框是否能被用户按[返回键]而取消掉
        setCancelable(true)
    }

    companion object {

        class Builder(private val context: Context) {
            private var bean: PopWindowShowEntity.PopWindowShowBean? = null
            private var level: String? = null
            private var clickDialogListener: OnClickDialogListener? = null

            fun setPopWindowShowBean(bean: PopWindowShowEntity.PopWindowShowBean?): Builder {
                this.bean = bean
                return this
            }

            fun setLevel(level: String): Builder {
                this.level = level
                return this
            }


            fun setClickButton(listener: OnClickDialogListener?): Builder {
                clickDialogListener = listener
                return this
            }

            fun create(): HomeDataAnalyzeDialog {
                val dialog = HomeDataAnalyzeDialog(context, R.style.confirm_dialog)
                val layout: View =
                    LayoutInflater.from(context).inflate(R.layout.view_data_analyze_dialog, null)

                dialog.window?.apply {
                    setGravity(Gravity.CENTER)
                }

                layout.findViewById<LinearLayout>(R.id.fl_container_root).layoutParams =
                    LinearLayout.LayoutParams(
                        DensityUtil.getScreenW(context) - DensityUtil.sp2px(context, 40f),
                        LinearLayout.LayoutParams.WRAP_CONTENT
                    )

                if (bean != null) {
                    layout.findViewById<TextView>(R.id.data_analyze_title_tv).text =
                        bean?.popContentNor
                    layout.findViewById<TextView>(R.id.data_analyze_message_tv).text =
                        bean?.popContentRed
                }

                layout.findViewById<TextView>(R.id.data_analyze_tip_tv).apply {
                    if (level == "1") {
                        visibility = View.GONE
                    } else {
                        visibility = View.VISIBLE
                    }
                }

                if (clickDialogListener != null) {
                    layout.findViewById<Button>(R.id.data_analyze_pond_entry_rate_btn)
                        .setOnClickListener {
                            clickDialogListener!!.onClick(
                                dialog,
                                ConstantParams.CONSTANT_STARTS_1
                            )
                        }

                    layout.findViewById<Button>(R.id.data_analyze_benefit_card_btn)
                        .setOnClickListener {
                            clickDialogListener!!.onClick(
                                dialog,
                                ConstantParams.CONSTANT_STARTS_2
                            )
                        }

                    layout.findViewById<Button>(R.id.data_analyze_thousands_people_btn)
                        .setOnClickListener {
                            clickDialogListener!!.onClick(
                                dialog,
                                ConstantParams.CONSTANT_STARTS_3
                            )
                        }

                    layout.findViewById<Button>(R.id.data_analyze_cancel_btn).setOnClickListener {
                        dialog.dismiss()
                    }
                }
                dialog.addContentView(
                    layout,
                    ViewGroup.LayoutParams(
                        ViewGroup.LayoutParams.MATCH_PARENT,
                        ViewGroup.LayoutParams.WRAP_CONTENT
                    )
                )
                return dialog
            }
        }
    }


    interface OnClickDialogListener {
        fun onClick(dialog: Dialog, index: Int)
    }

}