package com.wgmf.yxgj.modulemain.service;

import android.text.TextUtils;
import android.util.Log;

import com.google.gson.Gson;
import com.wgmf.library.base.BaseRequest;
import com.wgmf.library.base.BaseResponse;
import com.wgmf.library.base.ResultData;
import com.wgmf.library.utils.BaseSingleton;
import com.wgmf.yxgj.base.BaseService;
import com.wgmf.yxgj.config.BusinessID;
import com.wgmf.yxgj.global.NetworkParams;

import java.lang.ref.WeakReference;

/**
 * @author LW on 2022/10/11 15:19
 */
public class HomeService extends BaseService {
    private static BaseSingleton<HomeService, Void> mHomeService = new BaseSingleton<HomeService, Void>() {
        @Override
        protected HomeService create(Void var1) {
            return new HomeService();
        }
    };

    public static HomeService getInstance() {
        return mHomeService.get(null);
    }

    private HomeService() {
    }

    /**
     * get /frontDisplay/adPage 前端显示首页弹出广告列表
     */
    public void requestAdPage(final String staffId, final String orgId, ResultData.BusinessCallback callback) {
        BaseRequest request = new BaseRequest();
        request.taskID = BusinessID.HomePage.MSG_ON_GET_AD_PAGE;
        request.callback = new WeakReference<>(callback);
        request.url = NetworkParams.URL_AD_PAGE + "?" + "staffId=" + staffId + "&systemType=2" + "&orgId=" + orgId;
        Log.d(TAG, "请求地址：" + request.url);
        sendGetRequest(request);
    }

    /**
     * get /homePage/popWindowShow 首页弹窗查询
     */
    public void requestPopWindowShow(final String staffId, final String orgId, final String userPostLevel, ResultData.BusinessCallback callback) {
        BaseRequest request = new BaseRequest();
        request.taskID = BusinessID.HomePage.MSG_ON_POP_WINDOW_SHOW;
        request.callback = new WeakReference<>(callback);
        request.url = NetworkParams.URL_POP_WINDOW_SHOW + "?" + "staffId=" + staffId + "&orgId=" + orgId + "&userPostLevel=" + userPostLevel;
        Log.d(TAG, "请求地址：" + request.url);
        sendGetRequest(request);
    }

    @Override
    protected void onTaskDone(ResultData data) {
        if (null != data) {
            final int id = data.taskID;
            switch (id) {
                case BusinessID.HomePage.MSG_ON_GET_AD_PAGE:
                case BusinessID.HomePage.MSG_ON_POP_WINDOW_SHOW: {
                    if (data.isSuccessed()) {
                        final String json = data.getInfo();
                        if (!TextUtils.isEmpty(json)) {
                            BaseResponse mBaseResponse = new Gson().fromJson(json, BaseResponse.class);
                            Log.d(TAG, "id:" + id + ";mBaseResponse=" + mBaseResponse.toString());
                            data.setResultCode(mBaseResponse.retCode);
                            data.setResultInfo(mBaseResponse.retInfo);
                        }
                    }
                    break;
                }
                default:
                    break;
            }
        }
    }
}