package com.wgmf.yxgj.modulemain.ui;

import android.Manifest;
import android.content.pm.PackageManager;
import android.graphics.Bitmap;
import android.graphics.BitmapFactory;
import android.os.Build;
import android.os.Bundle;
import android.support.annotation.NonNull;
import android.support.v4.app.ActivityCompat;
import android.support.v4.content.ContextCompat;
import android.util.Log;
import android.view.View;
import android.widget.RelativeLayout;
import android.widget.TextView;

import com.google.zxing.Result;
import com.wgmf.library.utils.tools.PrefTool;
import com.wgmf.library.wx_share.WechatShareManager;
import com.wgmf.yxgj.base.BaseActivity;
import com.wgmf.yxgj.base.BaseParentAct;
import com.wgmf.yxgj.global.Prefs;
import com.wgmf.yxgj.modulemain.R;
import com.wgmf.yxgj.other.UpdateManager;
import com.wgmf.yxgj.utils.PhotoUtils;
import com.wgmf.library.utils.tools.DeviceHelper;

/**
 * 设置/二维码分享界面
 *
 * @author XP created at 2016/1/18 10:07
 */
public class SettingActivity extends BaseParentAct implements View.OnClickListener, View.OnLongClickListener {

    private String options;
    private Result qrRetsult;

    private static final int REQUEST_EXTERNAL_STORAGE_PERMISSION = 0;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_erweima);
        initTitle();
        initUI();
    }

    @Override
    public void initTitle() {
        super.initTitle();
        options = getIntent().getStringExtra("options");
        homeTitleMoreLl.setVisibility(View.INVISIBLE);
        homeTitleBackLl.setVisibility(View.VISIBLE);

        if ("qr_share".equals(options)) {
            homeTitleText.setText("二维码分享");
            qrRetsult = shareApkURL();
        } else {
            homeTitleText.setText("版本更新");
        }
    }

    private void initUI() {
        TextView erweimaTv = (TextView) findViewById(R.id.erweima_tv);
        TextView versionTv = (TextView) findViewById(R.id.version_tv);
        TextView updateTv = (TextView) findViewById(R.id.update_tv);
        TextView shareTv = (TextView) findViewById(R.id.share_tv);
        TextView yxgjShareLl = (TextView) findViewById(R.id.yxgj_share_tencent_ll);
        TextView sygjShareLl = (TextView) findViewById(R.id.sygj_share_tencent_ll);
        RelativeLayout yxgjQrRl = (RelativeLayout) findViewById(R.id.yxgj_qr_rl);
        RelativeLayout sygjQrRl = (RelativeLayout) findViewById(R.id.sygj_qr_rl);
        RelativeLayout updateRl = (RelativeLayout) findViewById(R.id.update_rl);

        if ("qr_share".equals(options)) {
            yxgjShareLl.setOnClickListener(this);
            sygjShareLl.setOnClickListener(this);
            updateTv.setVisibility(View.GONE);
            erweimaTv.setVisibility(View.GONE);
            updateRl.setVisibility(View.GONE);
        } else {
            shareTv.setVisibility(View.GONE);
            yxgjQrRl.setVisibility(View.GONE);
            sygjQrRl.setVisibility(View.GONE);
            erweimaTv.setVisibility(View.VISIBLE);
            erweimaTv.setBackgroundResource(R.drawable.app_icon);
            String ver = "当前版本号：" + DeviceHelper.getVersion(this) + "";
            versionTv.setText(ver);
            updateTv.setText("检查新版本");
            updateTv.setOnClickListener(this);
            versionTv.setOnClickListener(this);
            erweimaTv.setOnLongClickListener(this);
        }
    }

    /**
     * 获取二维码解析结果
     *
     * @return Result
     */
    private Result shareApkURL() {
        Result ret;
        try {
            Bitmap bitmap = BitmapFactory.decodeResource(getResources(), R.drawable.share_qr_yxgj);
            ret = PhotoUtils.parseQRcodeBitmap(bitmap);
            return ret;
        } catch (Exception e) {
            return null;
        }

    }

    @Override
    public void onClick(View v) {
        WechatShareManager mWechatShareManager = WechatShareManager.getInstance();
        mWechatShareManager.initWechatShareManager(this);
        if (v.getId() == R.id.yxgj_share_tencent_ll) {
            // 营销管家微信分享
            WechatShareManager.ShareContentWebpage sessionShareContent1 = mWechatShareManager.new ShareContentWebpage(
                    "营销管家", "营销管家安装包下载地址", qrRetsult.toString(), R.drawable.share_qr_yxgj);
            // 分享给微信会话列表
            mWechatShareManager.shareByWeixin(sessionShareContent1,
                    WechatShareManager.WEIXIN_SHARE_TYPE_TALK);
            PrefTool.setBooleanSave(this, Prefs.PRE_NOT_TO_BACKGROUD, true);
        } else if (v.getId() == R.id.sygj_share_tencent_ll) {
            // 生意管家微信分享
            WechatShareManager.ShareContentWebpage sessionShareContent2 = mWechatShareManager.new ShareContentWebpage(
                    "生意管家", "生意管家安装包下载地址", qrRetsult.toString(), R.drawable.share_qr_sygj);
            // 分享给微信会话列表
            mWechatShareManager.shareByWeixin(sessionShareContent2,
                    WechatShareManager.WEIXIN_SHARE_TYPE_TALK);
            PrefTool.setBooleanSave(this, Prefs.PRE_NOT_TO_BACKGROUD, true);
        } else if (v.getId() == R.id.update_tv) {
            // 版本升级
            UpdateManager updateManager = new UpdateManager(this);
            updateManager.checkUpdate();
        }
    }

    /**
     * 如果本地补丁放在了外部存储卡中, 6.0以上需要申请读外部存储卡权限才能够使用. 应用内部存储则不受影响
     */

    private void requestExternalStoragePermission() {
        // 缺少权限时, 进入权限配置页面
        if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.M && ContextCompat.checkSelfPermission(this, Manifest.permission.READ_EXTERNAL_STORAGE)
                != PackageManager.PERMISSION_GRANTED) {
            ActivityCompat.requestPermissions(this, new String[]{Manifest.permission.READ_EXTERNAL_STORAGE},
                    REQUEST_EXTERNAL_STORAGE_PERMISSION);
        }
    }

    @Override
    public void onRequestPermissionsResult(int requestCode, @NonNull String[] permissions, @NonNull int[] grantResults) {
        if (requestCode == REQUEST_EXTERNAL_STORAGE_PERMISSION && grantResults.length <= 0 || grantResults[0] != PackageManager.PERMISSION_GRANTED) {
            Log.d(BaseActivity.TAG, "onRequestPermissionsResult: local external storage patch is invalid as not read external storage permission");
        }
    }

    @Override
    protected void onResume() {
        super.onResume();
        PrefTool.setBooleanSave(SettingActivity.this,
                Prefs.PRE_LOGINACT_STATUS, true);
    }

    @Override
    protected void onStop() {
        super.onStop();
        PrefTool.setBooleanSave(SettingActivity.this,
                Prefs.PRE_LOGINACT_STATUS, false);
    }

    @Override
    public boolean onLongClick(View v) {
        // 安装补丁包
//        if (v.getId() == R.id.erweima_tv && Build.VERSION.SDK_INT >= 23) {
//            requestExternalStoragePermission();
//        }
//        SophixManager.getInstance().queryAndLoadNewPatch();
//        android.os.Process.killProcess(android.os.Process.myPid());
        return false;
    }
}