package com.wgmf.yxgj.modulemessage;

import android.os.Bundle;
import android.util.Log;
import android.view.View;
import android.view.ViewGroup;
import android.widget.AdapterView;
import android.widget.AdapterView.OnItemClickListener;
import android.widget.BaseAdapter;
import android.widget.ImageView;
import android.widget.ListView;
import android.widget.TextView;

import com.alibaba.android.arouter.facade.annotation.Route;
import com.bumptech.glide.Glide;
import com.google.gson.Gson;
import com.wgmf.library.base.ResultData;
import com.wgmf.yxgj.base.BaseParentAct;
import com.wgmf.yxgj.config.BusinessID;
import com.wgmf.yxgj.global.ConstantParams;
import com.wgmf.yxgj.model.JpushMassegeBean;
import com.wgmf.yxgj.model.MessageExtraEntity;
import com.wgmf.yxgj.model.MessageResponse;
import com.wgmf.yxgj.modulemessage.service.MessageService;
import com.wgmf.yxgj.publics.service.ToMessageByType;
import com.xp.arouter.RouterParams;

import java.util.ArrayList;
import java.util.List;

/**
 * @author xiep
 */
@Route(path = RouterParams.URL_MESSAGEACTIVITY)
public class MessageActivity extends BaseParentAct {
    private MssageAdapter mAdapter;

    private List<JpushMassegeBean> data = new ArrayList<>();

    @Override
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.public_list_view);
        initTitle();
        initContent();
    }

    private void initContent() {
        ListView mListView = (ListView) findViewById(R.id.public_list_view_lv);
        //为列表添加空布局
        View emptyView = findViewById(R.id.public_list_view_empty_ll);
        ImageView publicListViewEmptyIv = (ImageView) findViewById(R.id.public_list_view_empty_iv);
        Glide.with(this).load(R.drawable.img_load_fail).asGif().into(publicListViewEmptyIv);
        mListView.setEmptyView(emptyView);
        mAdapter = new MssageAdapter();
        mListView.setAdapter(mAdapter);
        mListView.setOnItemClickListener(mItemClick);
    }

    @Override
    protected void onResume() {
        initData();
        super.onResume();
    }

    private void initData() {
        if (null != userInfo) {
            showDialog();
            MessageService.getInstance().requestMsgList(userInfo.getStaffId(), "", MessageActivity.this);
        }
    }

    @Override
    protected void onBusinessResultAtMainThread(ResultData result) {
        super.onBusinessResultAtMainThread(result);
        dismissDialog();
        if (null != result) {
            final int id = result.taskID;
            if (id == BusinessID.Message.MSG_ON_MSG_LIST) {
                final String msg = result.getInfo();
                if (result.isSuccessed()) {
                    MessageResponse mMessageResponse = new Gson().fromJson(msg, MessageResponse.class);
                    Log.d(TAG, "mMessageResponse" + mMessageResponse);
                    if (null != mMessageResponse && null != mMessageResponse.getData() && ConstantParams.CONSTANT_PARAMS_0.equals(mMessageResponse.retCode)) {
                        data = mMessageResponse.getData();
                        mAdapter.notifyDataSetChanged();
                    }
                }
            }
        }
    }

    @Override
    public void initTitle() {
        super.initTitle();
        homeTitleText.setText("消息");
        homeTitleMoreLl.setVisibility(View.INVISIBLE);
        homeTitleBackLl.setVisibility(View.VISIBLE);
    }

    private OnItemClickListener mItemClick = new OnItemClickListener() {
        @Override
        public void onItemClick(AdapterView<?> parent, View view, int position,
                                long id) {
            // 若消息为未读，点击相应条目变为已读状态
            if (data.get(position).getReadStatus() != 1) {
                MessageService.getInstance().requestMsgUpdate(data.get(position).getId(), MessageActivity.this);
            }
            String extra = data.get(position).getExtra();
            MessageExtraEntity mMessageExtraEntity = new Gson().fromJson(extra, MessageExtraEntity.class);
            if (null != mMessageExtraEntity && extra.contains("type")) {
                ToMessageByType.toClass(MessageActivity.this, mMessageExtraEntity);
            } else {
                showMsg("别点了，这个消息没有更多内容了！");
            }
        }
    };

    private class MssageAdapter extends BaseAdapter {

        @Override
        public int getCount() {
            return data.size();
        }

        @Override
        public View getView(int position, View convertView, ViewGroup parent) {
            View view;
            if (convertView == null) {
                view = View.inflate(MessageActivity.this,
                        R.layout.list_item_message, null);
            } else {
                view = convertView;
            }
            TextView listItemMessageTitle = (TextView) view
                    .findViewById(R.id.list_item_message_title);
            TextView listItemMessageDate = (TextView) view
                    .findViewById(R.id.list_item_message_date);
            TextView listItemMessageContent = (TextView) view
                    .findViewById(R.id.list_item_message_content);
            ImageView listItemMessageImg = (ImageView) view
                    .findViewById(R.id.list_item_message_img);

            listItemMessageTitle.setText(data.get(position).getMsgTitle());
            listItemMessageContent.setText(data.get(position).getMsgContent());
            listItemMessageDate.setText(data.get(position).getCreateDate());

            if (data.get(position).getReadStatus() == 0) {
                listItemMessageImg.setVisibility(View.VISIBLE);
            } else {
                listItemMessageImg.setVisibility(View.INVISIBLE);
            }
            return view;
        }

        @Override
        public Object getItem(int position) {
            return null;
        }

        @Override
        public long getItemId(int position) {
            return 0;
        }
    }
}