package com.wgmf.yxgj.modulemessage.service;

import android.text.TextUtils;
import android.util.Log;

import com.google.gson.Gson;
import com.wgmf.library.base.BaseRequest;
import com.wgmf.library.base.BaseResponse;
import com.wgmf.library.base.ResultData;
import com.wgmf.library.utils.BaseSingleton;
import com.wgmf.yxgj.base.BaseService;
import com.wgmf.yxgj.config.BusinessID;
import com.wgmf.yxgj.global.NetworkParams;

import java.lang.ref.WeakReference;

public class MessageService extends BaseService {
    private static BaseSingleton<MessageService, Void> mMainService = new BaseSingleton<MessageService, Void>() {
        @Override
        protected MessageService create(Void var1) {
            return new MessageService();
        }
    };

    public static MessageService getInstance() {
        return mMainService.get(null);
    }

    private MessageService() {
    }

    /**
     * 查询消息列表
     */
    public void requestMsgList(final String user, final String type,
                               ResultData.BusinessCallback callback) {
        BaseRequest request = new BaseRequest();
        request.taskID = BusinessID.Message.MSG_ON_MSG_LIST;
        request.callback = new WeakReference<>(callback);
        request.url = NetworkParams.URL_GETMESSAGE + "?"
                + "user=" + user + "&type=" + type;
        Log.d(TAG, "请求地址：" + request.url);
        sendGetRequest(request);
    }

    /**
     * 消息已读未读状态
     */
    public void requestMsgUpdate(final String id, ResultData.BusinessCallback callback) {
        BaseRequest request = new BaseRequest();
        request.taskID = BusinessID.Message.MSG_ON_MSG_UPDATE;
        request.callback = new WeakReference<>(callback);
        request.url = NetworkParams.URL_UPDATE_MESSAGE + "?"
                + "id=" + id;
        Log.d(TAG, "请求地址：" + request.url);
        sendGetRequest(request);
    }

    @Override
    protected void onTaskDone(ResultData data) {
        if (null != data) {
            final int id = data.taskID;
            switch (id) {
                case BusinessID.Message.MSG_ON_MSG_LIST:
                case BusinessID.Message.MSG_ON_MSG_UPDATE: {
                    if (data.isSuccessed()) {
                        final String json = data.getInfo();
                        if (!TextUtils.isEmpty(json)) {
                            BaseResponse mBaseResponse = new Gson().fromJson(json, BaseResponse.class);
                            Log.d(TAG, "id:" + id + ";mBaseResponse=" + mBaseResponse.toString());
                            data.setResultCode(mBaseResponse.retCode);
                            data.setResultInfo(mBaseResponse.retInfo);
                        }
                    }
                    break;
                }
                default:
                    break;
            }
        }
    }
}