package com.wgmf.yxgj.module.business.parttime.service;

import android.text.TextUtils;
import android.util.Log;

import com.google.gson.Gson;
import com.wgmf.library.base.BaseRequest;
import com.wgmf.library.base.BaseResponse;
import com.wgmf.library.base.ResultData;
import com.wgmf.library.utils.BaseSingleton;
import com.wgmf.yxgj.base.BaseService;
import com.wgmf.yxgj.config.BusinessID;
import com.wgmf.yxgj.global.NetworkParams;

import java.lang.ref.WeakReference;

public class PartTimeService extends BaseService {
    private static BaseSingleton<PartTimeService, Void> mMainService = new BaseSingleton<PartTimeService, Void>() {
        @Override
        protected PartTimeService create(Void var1) {
            return new PartTimeService();
        }
    };

    public static PartTimeService getInstance() {
        return mMainService.get(null);
    }

    private PartTimeService() {
    }

    /**
     * get /protocol/getProtocol 获取协议
     */
    public void requestGetProtocol(final String type, ResultData.BusinessCallback callback) {
        BaseRequest request = new BaseRequest();
        request.taskID = BusinessID.PartTime.MSG_ON_GET_PROTOCOL;
        request.callback = new WeakReference<>(callback);
        request.url = NetworkParams.URL_GET_PROTOCOL + "?"
                + "type=" + type;
        Log.d(TAG, "请求地址：" + request.url);
        sendGetRequest(request);
    }

    /**
     * post /protocol/saveProtocolRecord 保存用户协议记录
     */
    public void requestSaveProtocolRecord(final String json, ResultData.BusinessCallback callback) {
        BaseRequest request = new BaseRequest();
        request.taskID = BusinessID.PartTime.MSG_ON_SAVE_PROTOCOL_RECORD;
        request.callback = new WeakReference<>(callback);
        request.url = NetworkParams.URL_SAVE_PROTOCOL_RECORD;
        request.json = json;
        Log.d(TAG, "请求地址：" + request.url);
        sendPostJsonRequest(request);
    }

    /**
     * GET /partTimeTourShop/getPartTimeTourShopCheck 判读该店是否检查过
     */
    public void requestGetPartTimeTourShopCheck(final String checkDate, final String shopId, final String partTimeStaffId, final String partTimeStaffName,
                                                ResultData.BusinessCallback callback) {
        BaseRequest request = new BaseRequest();
        request.taskID = BusinessID.PartTime.MSG_ON_GET_PARTTIME_TOURSHOP_CHECK;
        request.callback = new WeakReference<>(callback);
        request.url = NetworkParams.URL_GET_PARTTIME_TOURSHOP_CHECK + "?" + "checkDate=" + checkDate + "&shopId=" + shopId + "&partTimeStaffId=" + partTimeStaffId + "&partTimeStaffName=" + partTimeStaffName;
        Log.d(TAG, "请求地址：" + request.url);
        sendGetRequest(request);
    }

    /**
     * GET /partTimeTourShop/getPartTimeTourShopModel 获取检查项的模型
     * type:类型 0;员工形象检查 1:专柜卫生及内部陈列检查 2:专柜外部陈列检查 3:专柜服务检查
     */
    public void requestGetPartTimeTourShopModel(final String type, final String shopId,
                                                ResultData.BusinessCallback callback) {
        BaseRequest request = new BaseRequest();
        request.taskID = BusinessID.PartTime.MSG_ON_GET_PARTTIME_TOURSHOP_MODEL;
        request.callback = new WeakReference<>(callback);
        request.url = NetworkParams.URL_GET_PARTTIME_TOURSHOP_MODEL + "?" + "type=" + type + "&shopId=" + shopId;
        Log.d(TAG, "请求地址：" + request.url);
        sendGetRequest(request);
    }

    /**
     * GET /partTimeTourShop/getShopInfo 巡店门店搜索
     */
    public void requestGetShopInfo(final String url, final String staffId, final String keyWords, final String city, final String lng,
                                   final String lat, final String pageSize, final String pageNo, final String partTimeStaffName,
                                   ResultData.BusinessCallback callback) {
        BaseRequest request = new BaseRequest();
        request.taskID = BusinessID.PartTime.MSG_ON_GET_SHOP_INFO;
        request.callback = new WeakReference<>(callback);
        request.url = url + "?" + "keyWords=" + keyWords + "&staffId=" + staffId + "&city=" + city
                + "&lng=" + lng + "&lat=" + lat + "&pageSize=" + pageSize + "&pageNo=" + pageNo + "&partTimeStaffName=" + partTimeStaffName;
        Log.d(TAG, "请求地址：" + request.url);
        sendGetRequest(request);
    }

    /**
     * GET /partTimeTakeStock/takeStockGetShopInfo  巡店门店搜索(带临期货数)
     */
    public void requestTakeStockGetShopInfo(final String staffId, final String keyWords, final String city, final String lng,
                                            final String lat, final String pageSize, final String pageNo, final String partTimeStaffName,
                                            final String brandId,
                                            ResultData.BusinessCallback callback) {
        BaseRequest request = new BaseRequest();
        request.taskID = BusinessID.PartTime.MSG_ON_TAKE_STOCK_GET_SHOP_INFO;
        request.callback = new WeakReference<>(callback);
        request.url = NetworkParams.URL_TAKE_STOCK_GET_SHOP_INFO + "?" + "keyWords=" + keyWords + "&staffId=" + staffId + "&city=" + city
                + "&lng=" + lng + "&lat=" + lat + "&pageSize=" + pageSize + "&pageNo=" + pageNo + "&partTimeStaffName=" + partTimeStaffName
                + "&brandId=" + brandId;
        Log.d(TAG, "请求地址：" + request.url);
        sendGetRequest(request);
    }

    /**
     * GET /partTimeTakeStock/getShopCheckList  查询门店的盘点记录
     */
    public void requestGetShopCheckList(final String shopId,
                                        ResultData.BusinessCallback callback) {
        BaseRequest request = new BaseRequest();
        request.taskID = BusinessID.PartTime.MSG_ON_GET_SHOP_CHECK_LIST;
        request.callback = new WeakReference<>(callback);
        request.url = NetworkParams.URL_GET_SHOP_CHECK_LIST + "?" + "shopId=" + shopId;
        Log.d(TAG, "请求地址：" + request.url);
        sendGetRequest(request);
    }

    /**
     * POST /partTimeTourShop/savePartTimeTourShop 保存兼职督查巡店检查
     */
    public void requestSavePartTimeTourShop(final String json,
                                            ResultData.BusinessCallback callback) {
        BaseRequest request = new BaseRequest();
        request.taskID = BusinessID.PartTime.MSG_ON_SAVE_PARTTIME_TOURSHOP;
        request.callback = new WeakReference<>(callback);
        request.url = NetworkParams.URL_SAVE_PARTTIME_TOURSHOP;
        request.json = json;
        Log.d(TAG, "请求地址：" + request.url);
        sendPostJsonRequest(request);
    }

    /**
     * POST /partTimeTourShop/savePartTimeTourShopDetail 提交检查
     */
    public void requestSavePartTimeTourShopDetail(final String json, ResultData.BusinessCallback callback) {
        BaseRequest request = new BaseRequest();
        request.taskID = BusinessID.PartTime.MSG_ON_SAVE_PARTTIME_TOURSHOP_DETAIL;
        request.callback = new WeakReference<>(callback);
        request.url = NetworkParams.URL_SAVE_PARTTIME_TOURSHOP_DETAIL;
        request.json = json;
        Log.d(TAG, "请求地址：" + request.url);
        sendPostJsonRequest(request);
    }

    /**
     * GET /shopSchedule/getFetureShopSchedule 获取门店近七天排班
     */
    public void requestGetFetureShopSchedule(final String storeId, final int brandId,
                                             ResultData.BusinessCallback callback) {
        BaseRequest request = new BaseRequest();
        request.taskID = BusinessID.PartTime.MSG_ON_GET_FETURE_SHOP_SCHEDULE;
        request.callback = new WeakReference<>(callback);
        request.url = NetworkParams.URL_GET_FETURE_SHOP_SCHEDULE + "?" + "storeId=" + storeId + "&brandId=" + brandId;
        Log.d(TAG, "请求地址：" + request.url);
        sendGetRequest(request);
    }

    /**
     * GET /partTimeTakeStock/getPartTimeTakeStock 当天是否锁定库存盘点
     */
    public void requestGetPartTimeTakeStock(final String shopId, final String partTimeStaffName, final String staffId, final int brandId,
                                            ResultData.BusinessCallback callback) {
        BaseRequest request = new BaseRequest();
        request.taskID = BusinessID.PartTime.MSG_ON_GET_PARTTIME_TAKESTOCK;
        request.callback = new WeakReference<>(callback);
        request.url = NetworkParams.URL_GET_PARTTIME_TAKESTOCK + "?" + "shopId=" + shopId + "&staffId=" + staffId + "&partTimeStaffName=" + partTimeStaffName + "&brandId=" + brandId;
        Log.d(TAG, "请求地址：" + request.url);
        sendGetRequest(request);
    }

    /**
     * POST /partTimeTakeStock/savePartTimeTakeStock 锁定库存
     */
    public void requestSavePartTimeTakeStock(final String json, ResultData.BusinessCallback callback) {
        BaseRequest request = new BaseRequest();
        request.taskID = BusinessID.PartTime.MSG_ON_SAVE_PARTTIME_TAKESTOCK;
        request.callback = new WeakReference<>(callback);
        request.url = NetworkParams.URL_SAVE_PARTTIME_TAKESTOCK;
        request.json = json;
        Log.d(TAG, "请求地址：" + request.url);
        sendPostJsonRequest(request);
    }

    /**
     * GET /partTimeTakeStock/removePartTimeTakeStock 解除库存
     */
    public void requestRemovePartTimeTakeStock(final String shopId, final String partTimeStaffName, final String staffId, final int brandId,
                                               ResultData.BusinessCallback callback) {
        BaseRequest request = new BaseRequest();
        request.taskID = BusinessID.PartTime.MSG_ON_REMOVE_PARTTIME_TAKESTOCK;
        request.callback = new WeakReference<>(callback);
        request.url = NetworkParams.URL_REMOVE_PARTTIME_TAKESTOCK + "?" + "shopId=" + shopId + "&staffId=" + staffId + "&partTimeStaffName=" + partTimeStaffName + "&brandId=" + brandId;
        Log.d(TAG, "请求地址：" + request.url);
        sendGetRequest(request);
    }

    /**
     * GET /partTimeTakeStock/getTakeStockByShopId 获取门店盘点信息
     */
    public void requestGetTakeStockByShopId(final String shopId, final String partTimeStaffName, final String staffId,
                                            final int brandId, ResultData.BusinessCallback callback) {
        BaseRequest request = new BaseRequest();
        request.taskID = BusinessID.PartTime.MSG_ON_GET_TAKESTOCK_BY_SHOPID;
        request.callback = new WeakReference<>(callback);
        request.url = NetworkParams.URL_GET_TAKESTOCK_BY_SHOPID + "?" + "shopId=" + shopId + "&partTimeStaffName=" + partTimeStaffName + "&brandId=" + brandId + "&staffId=" + staffId;
        Log.d(TAG, "请求地址：" + request.url);
        sendGetRequest(request);
    }

    /**
     * GET /partTimeTakeStock/getPartTimeTakeStockDetail 盘点信息详情
     */
    public void requestGetPartTimeTakeStockDetail(final String takeStockId, ResultData.BusinessCallback callback) {
        BaseRequest request = new BaseRequest();
        request.taskID = BusinessID.PartTime.MSG_ON_GET_PARTTIME_TAKESTOCK_DETAIL;
        request.callback = new WeakReference<>(callback);
        request.url = NetworkParams.URL_GET_PARTTIME_TAKESTOCK_DETAIL + "?" + "takeStockId=" + takeStockId;
        Log.d(TAG, "请求地址：" + request.url);
        sendGetRequest(request);
    }

    /**
     * GET /partTimeTakeStock/getShopBrandList  添加门店查询品牌
     */
    public void requestGetShopBrandList(final String shopId, ResultData.BusinessCallback callback) {
        BaseRequest request = new BaseRequest();
        request.taskID = BusinessID.PartTime.MSG_ON_GET_SHOP_BRAND_LIST;
        request.callback = new WeakReference<>(callback);
        request.url = NetworkParams.URL_GET_SHOP_BRAND_LIST + "?" + "shopId=" + shopId;
        Log.d(TAG, "请求地址：" + request.url);
        sendGetRequest(request);
    }

    /**
     * POST /partTimeTakeStock/batchSavePartTimeTakeStockDetail 批量盘点提交
     */
    public void requestBatchSavePartTimeTakeStockDetail(final String json, ResultData.BusinessCallback callback) {
        BaseRequest request = new BaseRequest();
        request.taskID = BusinessID.PartTime.MSG_ON_BATCH_SAVE_PARTTIME_TAKESTOCK_DETAIL;
        request.callback = new WeakReference<>(callback);
        request.url = NetworkParams.URL_GET_BATCH_SAVE_PARTTIME_TAKESTOCK_DETAIL;
        request.json = json;
        Log.d(TAG, "请求地址：" + request.url);
        sendPostJsonRequest(request);
    }

    /**
     * get /partTimeTourShop/cancelTourShop 兼职督察自己作废
     */
    public void requestcancelTourShop(final String tourId, ResultData.BusinessCallback callback) {
        BaseRequest request = new BaseRequest();
        request.taskID = BusinessID.PartTime.MSG_ON_CANCEL_TOUR_SHOP;
        request.callback = new WeakReference<>(callback);
        request.url = NetworkParams.URL_GET_CANCEL_TOUR_SHOP + "?" + "tourId=" + tourId;
        Log.d(TAG, "请求地址：" + request.url);
        sendGetRequest(request);
    }

    @Override
    protected void onTaskDone(ResultData data) {
        if (null != data) {
            final int id = data.taskID;
            switch (id) {
                case BusinessID.PartTime.MSG_ON_GET_PROTOCOL:
                case BusinessID.PartTime.MSG_ON_SAVE_PROTOCOL_RECORD:
                case BusinessID.PartTime.MSG_ON_GET_PARTTIME_TOURSHOP_CHECK:
                case BusinessID.PartTime.MSG_ON_GET_PARTTIME_TOURSHOP_MODEL:
                case BusinessID.PartTime.MSG_ON_GET_SHOP_INFO:
                case BusinessID.PartTime.MSG_ON_SAVE_PARTTIME_TOURSHOP:
                case BusinessID.PartTime.MSG_ON_SAVE_PARTTIME_TOURSHOP_DETAIL:
                case BusinessID.PartTime.MSG_ON_GET_FETURE_SHOP_SCHEDULE:
                case BusinessID.PartTime.MSG_ON_GET_PARTTIME_TAKESTOCK:
                case BusinessID.PartTime.MSG_ON_SAVE_PARTTIME_TAKESTOCK:
                case BusinessID.PartTime.MSG_ON_REMOVE_PARTTIME_TAKESTOCK:
                case BusinessID.PartTime.MSG_ON_GET_PARTTIME_TAKESTOCK_DETAIL:
                case BusinessID.PartTime.MSG_ON_BATCH_SAVE_PARTTIME_TAKESTOCK_DETAIL:
                case BusinessID.PartTime.MSG_ON_GET_TAKESTOCK_BY_SHOPID:
                case BusinessID.PartTime.MSG_ON_GET_SHOP_BRAND_LIST:
                case BusinessID.PartTime.MSG_ON_CANCEL_TOUR_SHOP: {
                    if (data.isSuccessed()) {
                        final String json = data.getInfo();
                        if (!TextUtils.isEmpty(json)) {
                            BaseResponse mBaseResponse = new Gson().fromJson(json, BaseResponse.class);
                            Log.d(TAG, "id:" + id + ";mBaseResponse=" + mBaseResponse.toString());
                            data.setResultCode(mBaseResponse.retCode);
                            data.setResultInfo(mBaseResponse.retInfo);
                        }
                    }
                }
                break;
                default:
                    break;
            }
        }
    }
}