package com.wgmf.yxgj.module.business.parttime.ui

import android.os.Bundle
import android.support.v4.content.ContextCompat
import android.support.v7.widget.LinearLayoutManager
import android.support.v7.widget.RecyclerView
import android.util.Log
import android.view.View
import android.widget.TextView
import com.chad.library.adapter.base.BaseQuickAdapter
import com.google.gson.Gson
import com.scwang.smartrefresh.layout.SmartRefreshLayout
import com.wgmf.library.base.ResultData
import com.wgmf.yxgj.base.BaseParentAct
import com.wgmf.yxgj.config.BusinessID
import com.wgmf.yxgj.dialog.LoadWaitDominator
import com.wgmf.yxgj.global.AppConstants
import com.wgmf.yxgj.global.ConstantParams
import com.wgmf.yxgj.module.business.parttime.R
import com.wgmf.yxgj.module.business.parttime.model.PartTimeCheckRecordsEntity
import com.wgmf.yxgj.module.business.parttime.service.PartTimeService
import com.wgmf.yxgj.module.business.parttime.ui.adapter.PartTimeCheckRecordsListAdapter
import com.wgmf.yxgj.utils.isNotNullOrSize
import com.wgmf.yxgj.widgets.decoration.DividerItemDecoration

/**
 *  @author LW on 2023-7-14 0014.
 * 兼职督察门店盘点记录
 */
class PartTimeCheckRecordsActivity : BaseParentAct() {

    private var mPublicListViewRv: RecyclerView? = null

    private var mPublicRefreshView: SmartRefreshLayout? = null

    private var mPartTimeCheckRecordListAdapter: PartTimeCheckRecordsListAdapter? =
        null

    private lateinit var mLoadWait: LoadWaitDominator

    private val mBranchTitle: String? by lazy {
        intent.getStringExtra(AppConstants.ExtraKeys.BRANCH_TITLE)
    }

    private val mStoreId: String? by lazy {
        intent.getStringExtra(AppConstants.ExtraKeys.STORE_ID)
    }

    private val mStoreName: String? by lazy {
        intent.getStringExtra(AppConstants.ExtraKeys.STORE_NAME)
    }

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        setContentView(R.layout.activity_part_time_check_records)
        initTitle()
        initView()
    }

    override fun initTitle() {
        super.initTitle()
        homeTitleText.text = mBranchTitle
        homeTitleBackLl.visibility = View.VISIBLE
    }


    private fun initView() {
        findViewById<TextView>(R.id.part_time_check_records_shop_tv).text = mStoreName
        mLoadWait = LoadWaitDominator(mContext, findViewById(R.id.public_container_fl)).apply {
//            setBackgroundColor(R.color.region_two_bg)
            setStatusImg(R.drawable.ic_msg_empty_common)
        }

        mPublicRefreshView = findViewById<SmartRefreshLayout>(R.id.public_refresh_view).apply {
            isEnableLoadmore = false
            //刷新
            setOnRefreshListener {
                getShopCheckList()
            }
        }

        mPartTimeCheckRecordListAdapter =
            PartTimeCheckRecordsListAdapter(mutableListOf())
        mPublicListViewRv = findViewById<RecyclerView>(R.id.public_list_view_rv).apply {
            layoutManager = LinearLayoutManager(mContext)
            adapter = mPartTimeCheckRecordListAdapter
            addItemDecoration(
                DividerItemDecoration(
                    DividerItemDecoration.HORIZONTAL_LIST,
                    1,
                    ContextCompat.getColor(mContext, R.color.divider_line_deep_two)
                )
            )
        }

        BaseQuickAdapter.OnItemChildClickListener { adapter, view, pos -> //跳转到任务列表详情
            val bean =
                adapter?.getItem(pos) as PartTimeCheckRecordsEntity.CheckRecordsBean
        }.also { mPartTimeCheckRecordListAdapter?.onItemChildClickListener = it }
    }

    override fun onResume() {
        super.onResume()
        mPublicRefreshView?.autoRefresh()
    }

    /**
     * 查询门店的盘点记录
     */
    private fun getShopCheckList() {
        PartTimeService.getInstance()
            .requestGetShopCheckList(
                mStoreId,
                this@PartTimeCheckRecordsActivity
            )
    }

    override fun onBusinessResultAtMainThread(result: ResultData?) {
        super.onBusinessResultAtMainThread(result)
        mLoadWait.dismissAll()
        mPublicRefreshView?.finishRefresh()
        result?.let {
            if (it.taskID == BusinessID.PartTime.MSG_ON_GET_SHOP_CHECK_LIST) {
                if (!isFinishing && it.isSuccessed) {
                    val entity =
                        Gson().fromJson(it.info, PartTimeCheckRecordsEntity::class.java)
                    Log.d(TAG, "PartTimeCheckRecordsEntity=$entity")
                    if (ConstantParams.CONSTANT_PARAMS_0 == entity.msgCode) {
                        val list = entity.result
                        refreshDataToView(list)
                    } else {
                        mLoadWait.show(entity.retInfo)
                    }
                } else {
                    mLoadWait.showNetError()
                }
            }
        }
    }

    /**
     * 刷新数据更新到View
     */
    private fun refreshDataToView(
        list: List<PartTimeCheckRecordsEntity.CheckRecordsBean>?
    ) {
        if (list.isNotNullOrSize()) {
            mPartTimeCheckRecordListAdapter?.setNewData(list)
        } else {
            mLoadWait.showNoData(R.string.no_record)
        }
    }
}