package com.wgmf.yxgj.module.business.parttime.ui

import android.content.Intent
import android.os.Bundle
import android.support.v4.content.ContextCompat
import android.support.v7.widget.RecyclerView
import android.util.Log
import android.view.View
import android.view.inputmethod.EditorInfo
import android.widget.FrameLayout
import android.widget.ImageView
import android.widget.TextView
import com.alibaba.android.arouter.facade.annotation.Route
import com.google.gson.Gson
import com.wgmf.library.base.ResultData
import com.wgmf.library.extfunction.setOnEditorActionListener
import com.wgmf.library.global.LocationParams
import com.wgmf.library.utils.ThreadManager
import com.wgmf.library.utils.tools.PrefTool
import com.wgmf.yxgj.base.BaseParentAct
import com.wgmf.yxgj.config.BusinessID
import com.wgmf.yxgj.dialog.LoadWaitDominator
import com.wgmf.yxgj.global.AppConstants
import com.wgmf.yxgj.global.ConstantParams
import com.wgmf.yxgj.global.Prefs
import com.wgmf.yxgj.module.business.parttime.R
import com.wgmf.yxgj.module.business.parttime.model.PartTimeShopInfoListEntity
import com.wgmf.yxgj.module.business.parttime.service.PartTimeService
import com.wgmf.yxgj.module.business.parttime.ui.adapter.PartTimeInventoryShopInfoTableAdapter
import com.wgmf.yxgj.module.business.parttime.ui.takestock.PartTimeTakeStockLockActivity
import com.wgmf.yxgj.utils.notNullAndEmpty
import com.wgmf.yxgj.widgets.EditText.ClearEditText
import com.wgmf.yxgj.widgets.ScrollablePanel.PanelAdapter
import com.wgmf.yxgj.widgets.ScrollablePanel.ScrollablePanelManager
import com.wgmf.yxgj.widgets.ScrollablePanel.ScrollablePanelManager.PanelLineAdapter.*
import com.wgmf.yxgj.widgets.decoration.DividerItemDecoration
import com.xp.arouter.RouterParams

/**
 * @author LW on 2023-7-13 0013.
 * 兼职督察盘点信息录入选择门店
 */
@Route(path = RouterParams.URL_PART_TIME_INVENTORY_SHOP_INFO_ACTIVITY)
class PartTimeInventoryShopInfoActivity : BaseParentAct(), OnContentItemClickListener {

    private var mPartTimeInventoryShopInfoTableAdapter: PartTimeInventoryShopInfoTableAdapter? =
        null

    private var mScrollablePanelManager: ScrollablePanelManager? = null

    private var mShopInfoList: MutableList<PartTimeShopInfoListEntity.ShopInfoBean> =
        mutableListOf()

    private lateinit var mLoadWait: LoadWaitDominator

    private var mInventoryShopInfoSearchEt: ClearEditText? = null
    private var mInventoryShopInfoWgmfTv: TextView? = null
    private var mInventoryShopInfoBulkTv: TextView? = null

    private var mTableFirstItem: FrameLayout? = null
    private var mTableRecyclerHeaderList: RecyclerView? = null
    private var mTableRecyclerContentList: RecyclerView? = null

    private var mCurrentBrandId: Int = BRAND_WGMF

    private val mBranchTitle: String? by lazy {
        intent.getStringExtra(AppConstants.ExtraKeys.BRANCH_TITLE)
    }

    private var mIsFirstLoad: Boolean = true

    private var mKeyWords: String = ""

    companion object {
        //五谷磨房
        const val BRAND_WGMF: Int = 8

        //食补集
        const val BRAND_BULK: Int = 15
    }

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        setContentView(R.layout.activity_part_time_inventory_shop_info)
        initTitle()
        initView()
    }

    override fun initTitle() {
        super.initTitle()
        homeTitleText.text = mBranchTitle
        homeTitleBackLl.visibility = View.VISIBLE
    }

    private fun initView() {
        mLoadWait = LoadWaitDominator(mContext, findViewById(R.id.fl_container_root))

        mInventoryShopInfoSearchEt =
            findViewById<ClearEditText>(R.id.inventory_shop_info_search_et).apply {
                setOnEditorActionListener { actionId, _ ->
                    if (actionId == EditorInfo.IME_ACTION_SEARCH) {
                        mKeyWords =
                            mInventoryShopInfoSearchEt?.text.toString().trim { it <= ' ' }
                        loadListData()
                        return@setOnEditorActionListener true
                    }
                    return@setOnEditorActionListener false
                }

                setOnClearClickListener {
                    mKeyWords = ""
                    loadListData()
                }
            }

        mInventoryShopInfoWgmfTv = findViewById<TextView>(R.id.inventory_shop_info_wgmf_tv).apply {
            setOnClickListener {
                switchTabBindListData(BRAND_WGMF)
            }
        }
        mInventoryShopInfoBulkTv = findViewById<TextView>(R.id.inventory_shop_info_bulk_tv).apply {
            setOnClickListener {
                switchTabBindListData(BRAND_BULK)
            }
        }

        mTableFirstItem = findViewById(R.id.first_item)
        mTableRecyclerHeaderList = findViewById(R.id.recycler_header_list)
        mTableRecyclerContentList = findViewById(R.id.recycler_content_list)

        switchTabBindListData(BRAND_WGMF)
    }


    override fun onResume() {
        super.onResume()
        if (!mIsFirstLoad) {
            loadListData()
        }
    }

    /**
     * 切换Tab绑定不同数据
     */
    private fun switchTabBindListData(type: Int) {
        mCurrentBrandId = type
        when (type) {
            BRAND_WGMF -> {
                mInventoryShopInfoWgmfTv?.isSelected = true
                mInventoryShopInfoBulkTv?.isSelected = false
            }
            BRAND_BULK -> {
                mInventoryShopInfoWgmfTv?.isSelected = false
                mInventoryShopInfoBulkTv?.isSelected = true
            }
        }

        loadListData()
    }

    private fun loadListData() {
        if (mKeyWords.notNullAndEmpty()) {
            searchTakeStockGetShopInfo()
        } else {
            takeStockGetShopInfo()
        }
    }

    /**
     * 查询巡店门店搜索(全国数据)
     */
    private fun searchTakeStockGetShopInfo() {
        showDialog()
        userInfo?.let {
            val staffId = it.staffId
            val pageNo = ConstantParams.CONSTANT_PARAMS_1
            val pageSize = ConstantParams.CONSTANT_PARAMS_50
            val lat = LocationParams.Latitude
            val lng = LocationParams.Longitude
            val partTimeStaffName =
                PrefTool.getStringPerferences(mContext, Prefs.PRE_USER_PART_TIME_NAME)
            val brandId = mCurrentBrandId.toString()

            PartTimeService.getInstance().requestTakeStockGetShopInfo(
                staffId,
                mKeyWords, "",
                lng,
                lat,
                pageSize,
                pageNo,
                partTimeStaffName,
                brandId,
                this@PartTimeInventoryShopInfoActivity
            )
        }

    }

    /**
     * 查询巡店门店搜索
     */
    private fun takeStockGetShopInfo() {
        showDialog()
        userInfo?.let {
            val staffId = it.staffId
            val pageNo = ConstantParams.CONSTANT_PARAMS_1
            val pageSize = ConstantParams.CONSTANT_PARAMS_50
            val city = LocationParams.city
            val lat = LocationParams.Latitude
            val lng = LocationParams.Longitude
            val partTimeStaffName =
                PrefTool.getStringPerferences(mContext, Prefs.PRE_USER_PART_TIME_NAME)
            val brandId = mCurrentBrandId.toString()
            PartTimeService.getInstance().requestTakeStockGetShopInfo(
                staffId,
                "", city,
                lng,
                lat,
                pageSize,
                pageNo,
                partTimeStaffName,
                brandId,
                this@PartTimeInventoryShopInfoActivity
            )
        }
    }

    /**
     * 刷新列表数据
     * @param dataType 类型
     */
    private fun refreshListData() {
        if (mShopInfoList.isNullOrEmpty()) {
            mLoadWait.show(LoadWaitDominator.NO_DATA)
        } else {
            bindTableAdapterData()
            if (mIsFirstLoad) {
                findViewById<ImageView>(R.id.inventory_shop_more_data_iv).apply {
                    visibility = View.VISIBLE
                    ThreadManager.postDelayedOnUiThread({
                        visibility = View.GONE
                    }, 5000)
                }
                mIsFirstLoad = false
            }
        }
    }

    /**
     * 修改列表数据
     * @param dataType 类型
     */
    private fun updateListData() {
        if (mShopInfoList.isNullOrEmpty()) {
            mLoadWait.show(LoadWaitDominator.NO_DATA)
        } else {
            mLoadWait.dismissAll()
            generateTestData()
            mScrollablePanelManager?.notifyDataSetChanged()
        }
    }

    /**
     * 初始化表格数据
     */
    private fun bindTableAdapterData() {
        if (mPartTimeInventoryShopInfoTableAdapter == null) {
            mPartTimeInventoryShopInfoTableAdapter =
                PartTimeInventoryShopInfoTableAdapter(mContext,
                    object : PartTimeInventoryShopInfoTableAdapter.OnChildItemClickListener {
                        override fun onItemClick(
                            position: Int,
                            shopinfo: PartTimeShopInfoListEntity.ShopInfoBean
                        ) {
                            jumpPartTimeCheckRecordsActivity(shopinfo)
                        }
                    })

            mTableRecyclerContentList?.addItemDecoration(
                DividerItemDecoration(
                    DividerItemDecoration.HORIZONTAL_LIST,
                    1,
                    ContextCompat.getColor(mContext, R.color.c_e8e8e8)
                )
            )
        }
        generateTestData()

        mScrollablePanelManager = ScrollablePanelManager()
        mScrollablePanelManager?.setPanelView(
            mContext,
            mTableRecyclerContentList,
            mTableRecyclerHeaderList,
            mTableFirstItem
        )

        mScrollablePanelManager?.setPanelAdapter(
            mPartTimeInventoryShopInfoTableAdapter, this@PartTimeInventoryShopInfoActivity
        )
    }

    /**
     * 更新数据
     */
    private fun generateTestData() {
        mPartTimeInventoryShopInfoTableAdapter?.setTableTitleList(
            mContext.resources.getStringArray(R.array.part_time_shop_info_list_title)
                .asList()
                .toMutableList()
        )
        mPartTimeInventoryShopInfoTableAdapter?.setShopInfoList(mShopInfoList)
    }

    override fun onBusinessResultAtMainThread(result: ResultData?) {
        super.onBusinessResultAtMainThread(result)
        dismissDialog()
        mLoadWait.dismissAll()
        result?.let {
            if (it.taskID == BusinessID.PartTime.MSG_ON_TAKE_STOCK_GET_SHOP_INFO) {
                if (!isFinishing && it.isSuccessed) {
                    val entity =
                        Gson().fromJson(it.info, PartTimeShopInfoListEntity::class.java)
                    Log.d(TAG, "PartTimeShopInfoListEntity=$entity")
                    if (ConstantParams.CONSTANT_PARAMS_0 == entity.retCode) {
                        val list = entity.result
                        mShopInfoList =
                            list as MutableList<PartTimeShopInfoListEntity.ShopInfoBean>
                        refreshListData()
                    } else {
                        mLoadWait.show(entity.retInfo)
                    }
                } else {
                    mLoadWait.showNetError()
                }
            }
        }
    }

    override fun onItemClick(row: Int, panelAdapter: PanelAdapter?) {
        val bean = mShopInfoList[row]
        jumpPartTimeTakeStockLockActivity(bean)
    }

    override fun onChildItemClick(row: Int, position: Int, panelAdapter: PanelAdapter?) {
        val bean = mShopInfoList[row]
        jumpPartTimeTakeStockLockActivity(bean)
    }

    /**
     * 跳转到 PartTimeCheckRecordsActivity
     */
    private fun jumpPartTimeCheckRecordsActivity(bean: PartTimeShopInfoListEntity.ShopInfoBean) {
        startActivity(Intent(mContext, PartTimeCheckRecordsActivity::class.java).apply {
            putExtra(AppConstants.ExtraKeys.STORE_ID, bean.storeId)
            putExtra(AppConstants.ExtraKeys.STORE_NAME, bean.storeName)
            putExtra(AppConstants.ExtraKeys.BRANCH_TITLE, mBranchTitle)
        })
    }

    /**
     * 跳转到  PartTimeTakeStockLockActivity
     */
    private fun jumpPartTimeTakeStockLockActivity(bean: PartTimeShopInfoListEntity.ShopInfoBean) {
        startActivity(
            Intent(mContext, PartTimeTakeStockLockActivity::class.java).apply {
                putExtra(AppConstants.ExtraKeys.PART_TIME_SHOP_INFO, bean)
            }
        )
    }
}
