package com.wgmf.yxgj.module.business.parttime.ui

import android.graphics.Typeface
import android.os.Bundle
import android.support.v4.content.ContextCompat
import android.support.v7.widget.LinearLayoutManager
import android.support.v7.widget.RecyclerView
import android.util.Log
import android.util.TypedValue
import android.view.Gravity
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import android.widget.LinearLayout
import android.widget.TextView
import com.google.gson.Gson
import com.wgmf.library.base.ResultData
import com.wgmf.library.global.LocationParams
import com.wgmf.library.utils.LocationUtil
import com.wgmf.library.utils.TextColorDominator
import com.wgmf.yxgj.base.BaseParentFra
import com.wgmf.yxgj.config.BusinessID
import com.wgmf.yxgj.dialog.LoadWaitDominator
import com.wgmf.yxgj.global.AppConstants
import com.wgmf.yxgj.global.ConstantParams
import com.wgmf.yxgj.module.business.parttime.R
import com.wgmf.yxgj.module.business.parttime.model.*
import com.wgmf.yxgj.module.business.parttime.service.PartTimeService
import com.wgmf.yxgj.module.business.parttime.ui.adapter.PartTimeScheduleInfoAdapter
import com.wgmf.yxgj.module.business.parttime.ui.adapter.PartTimeSignInfoRecordsListAdapter
import com.wgmf.yxgj.module.business.parttime.ui.takestock.PartTimeTakeStockLockActivity
import com.wgmf.yxgj.utils.*
import com.wgmf.yxgj.widgets.ListView.ListViewForScrollView
import com.wgmf.yxgj.widgets.TextView.MarqueeTextView
import com.xp.arouter.RouterCommonUtil
import kotlinx.android.synthetic.main.part_time_take_stock_choose_item.*

/**
 * @author LW on 2023-7-14 0014.
 * 门店打卡记录
 */
class PartTimeShopScheduleFragment : BaseParentFra(), WeekTaskCalendar.OnDaySelectListener {

    private var mPartTimeScheduleInfoLv: ListViewForScrollView? = null
    private var mWeekTaskCalendar: WeekTaskCalendar? = null
    private var mPartTimeScheduleInfoDateTv: TextView? = null

    private var mPartTimeSignInfoRecordsListAdapter:
            PartTimeSignInfoRecordsListAdapter? = PartTimeSignInfoRecordsListAdapter(listOf())

    private val mShopInfoBean: PartTimeShopInfoListEntity.ShopInfoBean? by lazy {
        arguments?.getSerializable(AppConstants.ExtraKeys.PART_TIME_SHOP_INFO) as PartTimeShopInfoListEntity.ShopInfoBean
    }

    private val mPartTimeShopBrandList: List<PartTimeShopBrandEntity.PartTimeShopBrandBean>? by lazy {
        arguments?.getParcelableArrayList<PartTimeShopBrandEntity.PartTimeShopBrandBean>(
            AppConstants.ExtraKeys.PART_TIME_SHOP_BRAND
        )
    }

    private val mBrandId: Int by lazy {
        arguments?.getInt(AppConstants.ExtraKeys.BRAND_ID, -1) ?: -1
    }

    private lateinit var mLoadWait: LoadWaitDominator

    override fun onCreateView(
        inflater: LayoutInflater,
        container: ViewGroup?,
        savedInstanceState: Bundle?
    ): View {
        val view: View =
            inflater.inflate(R.layout.part_time_shop_schedule_fragment, container, false)
        view.findViewById<LinearLayout>(R.id.part_time_store_info_ll).setOnClickListener {
            //进入地图导航
            jumpMapActivity()
        }

        view.findViewById<MarqueeTextView>(R.id.part_time_store_info_name_tv).text =
            mShopInfoBean?.storeName.convertDefaultValue()

        val address = mShopInfoBean?.address
        if (address.notNullAndEmpty()) {
            view.findViewById<MarqueeTextView>(R.id.part_time_store_info_address_tv).text = address
        }

        val distance = mShopInfoBean?.distance ?: 0.0
        if (distance > 0.0) {
            view.findViewById<TextView>(R.id.part_time_store_info_distance_tv).text =
                StringUtils.formatString(
                    mContext.getString(R.string.part_time_shop_info_store_distance_size),
                    LocationUtil.setDistanceUint(distance)
                )
        }
        val lastMonthSaleCount = mShopInfoBean?.lastMonthSaleCount
        if (lastMonthSaleCount.notNullAndEmpty()) {
            view.findViewById<TextView>(R.id.part_time_store_info_last_sales_tv).apply {
                visibility = View.VISIBLE

                val content = StringUtils.formatString(
                    mContext.getString(R.string.part_time_shop_info_sales_last_month),
                    NumberUtils.formatNumberWithUnit(lastMonthSaleCount)
                )
                text = TextColorDominator.styleTextColor(
                    content,
                    ContextCompat.getColor(mContext, R.color.important_txt_four_color),
                    content.lastIndexOf("："),
                    content.length - 1
                )
            }
        }

        mLoadWait =
            LoadWaitDominator(mContext, view.findViewById(R.id.part_time_sign_info_container_fl))
        view.findViewById<LinearLayout>(R.id.part_time_sign_info_brand_info_ll).let {
            if (mPartTimeShopBrandList.isNotNullOrSize()) {
                initBrandView(it, mPartTimeShopBrandList!!)
                it.visibility = View.VISIBLE
            } else {
                it.visibility = View.GONE
            }
        }
        view.findViewById<RecyclerView>(R.id.part_time_sign_info_records_rv).apply {
            layoutManager = LinearLayoutManager(mContext)
            adapter = mPartTimeSignInfoRecordsListAdapter
        }

        mWeekTaskCalendar =
            view.findViewById<WeekTaskCalendar>(R.id.part_time_schedule_info_weektaskcalendar)
                .apply {
                    setOnDaySelectListener(this@PartTimeShopScheduleFragment)
                }

        mPartTimeScheduleInfoDateTv = view.findViewById(R.id.part_time_schedule_info_date_tv)
        mPartTimeScheduleInfoLv = view.findViewById(R.id.part_time_schedule_info_lv)
        return view
    }

    override fun onViewCreated(view: View, savedInstanceState: Bundle?) {
        super.onViewCreated(view, savedInstanceState)
        if (mBrandId > 0) {
            getFetureShopSchedule(mBrandId)
        }
    }

    /**
     * 初始化品牌View
     */
    private fun initBrandView(
        rootView: LinearLayout,
        partTimeShopBrandBean: List<PartTimeShopBrandEntity.PartTimeShopBrandBean>
    ) {
        rootView.removeAllViews()

        val params = LinearLayout.LayoutParams(
            LinearLayout.LayoutParams.WRAP_CONTENT,
            LinearLayout.LayoutParams.WRAP_CONTENT
        )
        params.setMargins(
            DensityUtil.dip2px(mContext, 5f), 0,
            DensityUtil.dip2px(mContext, 5f),
            0
        )
        partTimeShopBrandBean.forEachIndexed { index, bean ->
            rootView.addView(
                TextView(mContext).apply {
                    text = bean.brandName
                    tag = bean.brandId
                    gravity = Gravity.CENTER

                    setTypeface(Typeface.DEFAULT_BOLD);
                    setBackgroundResource(R.drawable.selector_one_tab_btn)
                    setTextSize(TypedValue.COMPLEX_UNIT_SP, 14f)
                    setTextColor(
                        ContextCompat.getColor(
                            mContext,
                            R.color.important_txt_seven_color
                        )
                    )
                    setPadding(
                        DensityUtil.dip2px(mContext, 40f),
                        DensityUtil.dip2px(mContext, 10f),
                        DensityUtil.dip2px(mContext, 40f),
                        DensityUtil.dip2px(mContext, 10f)
                    )
                    isClickable = true
                    setOnClickListener { view ->
                        for (count in 0 until rootView.childCount) {
                            rootView.getChildAt(count).let {
                                if (it is TextView) {
                                    it.isSelected = false
                                    it.setTextColor(
                                        ContextCompat.getColor(
                                            mContext,
                                            R.color.important_txt_seven_color
                                        )
                                    )
                                }
                            }
                        }
                        view.isSelected = true
                        (view as (TextView)).setTextColor(
                            ContextCompat.getColor(
                                mContext,
                                R.color.important_txt_third_color
                            )
                        )
                        val brandId = view.tag as Int
                        setBrandIdToActivity(brandId)
                        //获取门店近七天排班
                        getFetureShopSchedule(brandId)
                    }
                    if (index == ConstantParams.CONSTANT_STARTS_0) {
                        performClick()
                    }
                },
                params
            )
        }
    }

    private fun setBrandIdToActivity(brandId: Int) {
        if (activity is PartTimeTakeStockLockActivity) {
            (activity as (PartTimeTakeStockLockActivity)).setSelectBranchId(brandId)
        }
    }

    /**
     * 获取门店近七天排班
     */
    private fun getFetureShopSchedule(brandId: Int) {
        mShopInfoBean?.let {
            mLoadWait.show(LoadWaitDominator.LOADING)
            PartTimeService.getInstance().requestGetFetureShopSchedule(
                it.storeId,
                brandId,
                this@PartTimeShopScheduleFragment
            )
        }
    }

    override fun onBusinessResultAtMainThread(result: ResultData?) {
        super.onBusinessResultAtMainThread(result)
        mLoadWait.dismissAll()
        result?.let {
            if (it.taskID == BusinessID.PartTime.MSG_ON_GET_FETURE_SHOP_SCHEDULE) {
                if (it.isSuccessed) {
                    val entity =
                        Gson().fromJson(it.info, PartTimeShopScheduleEntity::class.java)
                    Log.d(
                        TAG,
                        "PartTimeShopScheduleEntity=$entity"
                    )
                    if (ConstantParams.CONSTANT_PARAMS_0 == entity.retCode) {
                        val partTimeShopScheduleBean = entity.result
                        fetureShopScheduleData(partTimeShopScheduleBean)
                    } else {
                        mLoadWait.show(entity.retInfo)
                    }
                } else {
                    mLoadWait.showNetError()
                }
            }
        }
    }

    /**
     * 门店近七天排班
     */
    private fun fetureShopScheduleData(partTimeShopScheduleBean: PartTimeShopScheduleEntity.PartTimeShopScheduleBean?) {
        partTimeShopScheduleBean?.let {
            if (it.shopScheduleVoList.isNotNullOrSize()) {
                mWeekTaskCalendar?.apply {
                    setDaysHasThingList(it.shopScheduleVoList)
                    setGvListData()
                    gridViewAdapter.initData()
                    gridViewAdapter.notifyDataSetChanged()
                }
            }
            //打卡数据处理
            if (it.signTimeBeanList.isNotNullOrSize()) {
                mLoadWait.dismissAll()
                mPartTimeSignInfoRecordsListAdapter?.setNewData(it.signTimeBeanList)
            } else {
                mLoadWait.showNoData()
            }
        }
    }

    /**
     * 打开地图
     */
    private fun jumpMapActivity() {
        mShopInfoBean?.let {
            var mainUrl = "http://m.amap.com/navi/?"
            mainUrl = mainUrl + "start=" + LocationParams.Longitude + "," + LocationParams.Latitude
            mainUrl = "$mainUrl&dest=$it.lng,$it.lat"
            mainUrl = "$mainUrl&destName=$it.address"
            mainUrl = "$mainUrl&key=9721b93d58c40c76b182cd3ed1196e96"
            val mBundle = Bundle()
            mBundle.putString("mainUrl", mainUrl)
            RouterCommonUtil.startFunctionActivity(activity, 0, 0L, mBundle)
        }
    }

    override fun onDaySelectListener(shopScheduleVoBean: PartTimeShopScheduleEntity.PartTimeShopScheduleBean.ShopScheduleVoBean?) {
        shopScheduleVoBean?.let {
            val week = """
            周${it.getDecodeWeek(it.week)}
            ${it.schedulingDay}
            """.trimIndent()
            mPartTimeScheduleInfoDateTv?.text = week
            if (it.shopScheduleList.isNotNullOrSize()) {
                val partTimeScheduleInfoAdapter =
                    PartTimeScheduleInfoAdapter(
                        it.shopScheduleList,
                        activity
                    )
                mPartTimeScheduleInfoLv?.adapter = partTimeScheduleInfoAdapter
            }
        }
    }
}