package com.wgmf.yxgj.module.business.parttime.ui;

import android.content.Context;
import android.support.v4.content.ContextCompat;
import android.util.AttributeSet;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.BaseAdapter;
import android.widget.GridView;
import android.widget.LinearLayout;
import android.widget.TextView;

import com.wgmf.yxgj.module.business.parttime.R;
import com.wgmf.yxgj.module.business.parttime.model.PartTimeShopScheduleEntity;
import com.wgmf.yxgj.widgets.LinearLayout.SquareLayout;

import java.util.ArrayList;
import java.util.Calendar;
import java.util.Date;
import java.util.List;

/**
 * 周日历控件
 *
 * @author xiep
 */
@SuppressWarnings("all")
public class WeekTaskCalendar extends LinearLayout {

    private Context context;
    /**
     * 存放天
     */
    private List<PartTimeShopScheduleEntity.PartTimeShopScheduleBean.ShopScheduleVoBean> gvList = new ArrayList<>();
    /**
     * 回调函数
     */
    private OnDaySelectListener callBack;

    public WeekTaskCalendarAdapter gridViewAdapter;

    /**
     * 构造函数
     */
    public WeekTaskCalendar(Context context) {
        super(context);
        this.context = context;
        init();
    }

    /**
     * 构造函数
     */
    public WeekTaskCalendar(Context context, AttributeSet attrs) {
        super(context, attrs);
        this.context = context;
        init();
    }

    /**
     * 初始化日期以及view等控件
     */
    private void init() {
        daysHasThingList = new ArrayList<>();
        // 获取日历实例
        final Calendar ca = Calendar.getInstance();
        // 获取当前date
        Date nowDate = new Date();
        // cal设置为当天的
        ca.setTime(nowDate);
        setGvListData();
        // 获取布局，开始初始化
        View view = LayoutInflater.from(context).inflate(R.layout.week_task_calendar, this, true);
        GridView gv = (GridView) view.findViewById(R.id.gv_calendar);
        gridViewAdapter = new WeekTaskCalendarAdapter();
        gv.setAdapter(gridViewAdapter);
        gridViewAdapter.notifyDataSetChanged();
    }

    /**
     * 为gridview中添加需要展示的数据
     */
    public void setGvListData() {
        gvList.clear();
        gvList.addAll(daysHasThingList);
    }

    /**
     * 自定义监听接口设置对象
     */
    public void setOnDaySelectListener(OnDaySelectListener listener) {
        callBack = listener;
    }

    /**
     * 自定义监听接口
     */
    public interface OnDaySelectListener {
        void onDaySelectListener(PartTimeShopScheduleEntity.PartTimeShopScheduleBean.ShopScheduleVoBean partTimeShopScheduleEntity);

    }

    class WeekTaskCalendarAdapter extends BaseAdapter {

        private int selected = 0;

        public void initData() {
            if (!gvList.isEmpty())
                callBack.onDaySelectListener(gvList.get(0));
        }


        public int getSelected() {
            return selected;
        }

        private void setSelected(int selected) {
            this.selected = selected;
        }

        @Override
        public int getCount() {
            return gvList.size();
        }

        @Override
        public String getItem(int position) {
            return gvList.get(position).getSchedulingDay();
        }

        @Override
        public long getItemId(int position) {
            return position;
        }

        @Override
        public View getView(final int position, View convertView, ViewGroup parent) {
            final PartTimeShopScheduleEntity.PartTimeShopScheduleBean.ShopScheduleVoBean shopScheduleVoListEntity = gvList.get(position);
            final GrideViewHolder holder;
            if (null == convertView) {
                convertView = inflate(context, R.layout.day_task_calendar_gridview_item, null);
                holder = new GrideViewHolder(convertView);

                holder.slDay.setOnClickListener(new OnClickListener() {
                    @Override
                    public void onClick(View v) {
                        setSelected(position);
                        callBack.onDaySelectListener(shopScheduleVoListEntity);
                        notifyDataSetChanged();
                    }
                });
                convertView.setTag(holder);
            } else {
                holder = (GrideViewHolder) convertView.getTag();
            }
            holder.slDay.setTag(shopScheduleVoListEntity);

            holder.tvDay.setText(shopScheduleVoListEntity.getDecodeWeek(shopScheduleVoListEntity.getWeek()));

            if (selected == position) {
                // 设置为选中
                holder.tvDay.setTextColor(ContextCompat.getColor(context, R.color.white));
                holder.slDay.setBackgroundResource(R.drawable.week_fill_circlelayout_orange_dark);
            } else {
                // 设置为未选中
                holder.tvDay.setTextColor(ContextCompat.getColor(context, R.color.white));
                holder.slDay.setBackgroundResource(R.drawable.week_fill_circlelayout_orange);

            }
            return convertView;
        }
    }

    private static class GrideViewHolder {
        TextView tvDay;
        TextView tvDaySubscript;
        SquareLayout slDay;

        GrideViewHolder(View convertView) {
            tvDay = (TextView) convertView.findViewById(R.id.tv_calendar_day);
            tvDaySubscript = (TextView) convertView.findViewById(R.id.tv_calendar_day_subscript);
            slDay = (SquareLayout) convertView.findViewById(R.id.sl_calendar_day);
        }
    }

    private List<PartTimeShopScheduleEntity.PartTimeShopScheduleBean.ShopScheduleVoBean> daysHasThingList;

    /**
     * 设置事务
     */
    public void setDaysHasThingList(List<PartTimeShopScheduleEntity.PartTimeShopScheduleBean.ShopScheduleVoBean> daysHasThingList) {
        this.daysHasThingList = daysHasThingList;
        this.gridViewAdapter.notifyDataSetChanged();
    }
}