package com.wgmf.yxgj.module.business.parttime.ui.adapter

import android.content.Context
import android.support.v4.content.ContextCompat
import android.support.v7.widget.RecyclerView
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import android.widget.LinearLayout
import android.widget.RelativeLayout
import android.widget.TextView
import com.wgmf.yxgj.global.ConstantParams
import com.wgmf.yxgj.module.business.parttime.R
import com.wgmf.yxgj.module.business.parttime.model.PartTimeShopInfoListEntity
import com.wgmf.yxgj.utils.NumberUtils
import com.wgmf.yxgj.utils.StringUtils
import com.wgmf.yxgj.utils.convertDefaultValue
import com.wgmf.yxgj.utils.isNotNullOrSize
import com.wgmf.yxgj.widgets.ScrollablePanel.PanelAdapter

/**
 * @author LW on 2023-7-12 0015.
 * 盘点信息录入列表内容适配器
 */
class PartTimeInventoryShopInfoTableAdapter(
    val mContext: Context,
    val mChildItemClickListener: OnChildItemClickListener? = null
) : PanelAdapter {

    /**
     * 门店排班详情
     */
    private var mShopInfoList: MutableList<PartTimeShopInfoListEntity.ShopInfoBean> =
        mutableListOf()

    /**
     * 表单每列标题
     */
    private var mTableTitleList: MutableList<String> = mutableListOf()

    companion object {
        /**
         * 列标题类型
         */
        const val COLUMNS_TITLE_ITEM_TYPE: Int = 1

        /**
         * 行标题类型
         */
        const val ROW_TITLE_ITEM_TYPE: Int = 2

        /**
         * 内容标题类型
         */
        const val CONTENT_ITEM_TYPE: Int = 0
    }

    override fun getRowCount(): Int = mShopInfoList.size

    override fun getColumnCount(): Int = mTableTitleList.size

    override fun getItemViewType(row: Int, column: Int): Int {
        if (row == 0) {
            return ROW_TITLE_ITEM_TYPE
        }
        if (column == 0) {
            return COLUMNS_TITLE_ITEM_TYPE
        }
        return CONTENT_ITEM_TYPE
    }

    override fun onBindViewHolder(holder: RecyclerView.ViewHolder?, row: Int, column: Int) {
        when (getItemViewType(row, column)) {
            ROW_TITLE_ITEM_TYPE -> {
                bindRowTitleItemData(holder as RowTitleViewHolder, column)
            }
            COLUMNS_TITLE_ITEM_TYPE -> {
                bindColumnTitleItemData(holder as ColumnsTitleViewHolder, row)
            }
            else -> {
                bindContentItemData(holder as ContentViewHolder, row, column)
            }
        }
    }

    private fun bindContentItemData(
        contentViewHolder: ContentViewHolder,
        row: Int,
        column: Int
    ) {
        if (mShopInfoList.isNotNullOrSize()) {
            val shopinfo = mShopInfoList[row - 1]
            shopinfo.apply {
                contentViewHolder.valueTv.text = when (column) {
                    1 -> submitTime.convertDefaultValue()
                    2 -> {
                        val columnValue =
                            if (checkType == ConstantParams.CONSTANT_STARTS_1) {   //1全盘2抽盘3临期
                                mContext.getString(R.string.part_time_shop_info_wholesale)
                            } else if (checkType == ConstantParams.CONSTANT_STARTS_2) {
                                mContext.getString(R.string.part_time_shop_info_draw)
                            } else if (checkType == ConstantParams.CONSTANT_STARTS_3) {
                                mContext.getString(R.string.part_time_shop_info_advent)
                            } else {
                                "".convertDefaultValue()
                            }
                        columnValue
                    }
                    3 -> NumberUtils.formatNumberWithUnit(stockAmount).convertDefaultValue()
                    4 -> NumberUtils.formatNumberWithUnit(lastMonthSaleCount).convertDefaultValue()
                    5 -> NumberUtils.formatNumberWithUnit(adventAmount).convertDefaultValue()
                    6 -> NumberUtils.formatNumberWithUnit(currentMonthSaleCount)
                        .convertDefaultValue()
                    else -> "".convertDefaultValue()
                }
                updateItemBgColor(row, contentViewHolder.itemRootLl)
            }
            if (column == 2) {
                contentViewHolder.tipTv.visibility = View.VISIBLE
                contentViewHolder.tipTv.text =
                    mContext.getString(R.string.part_time_shop_info_look_detail)
                contentViewHolder.tipTv.setOnClickListener {
                    mChildItemClickListener?.onItemClick(row, shopinfo)
                }
            } else {
                contentViewHolder.tipTv.visibility = View.GONE
            }
        }
    }

    private fun bindColumnTitleItemData(
        titleViewHolder: ColumnsTitleViewHolder,
        row: Int
    ) {
        if (mShopInfoList.isNotNullOrSize()) {
            val shopInfo = mShopInfoList[row - 1]
            titleViewHolder.columnsTitleTv.text = shopInfo.storeName.convertDefaultValue()
            titleViewHolder.columnsInfoTv.text = StringUtils
                .formatString(
                    mContext.getString(R.string.part_time_shop_info_code),
                    shopInfo.storeId.convertDefaultValue()
                )
            updateItemBgColor(row, titleViewHolder.itemRootLl)
        }
    }

    private fun updateItemBgColor(position: Int, item: View) {
        if (position % 2 == 0) {
            item.setBackgroundColor(
                ContextCompat.getColor(
                    mContext,
                    R.color.c_ffffff
                )
            )
        } else {
            item.setBackgroundColor(
                ContextCompat.getColor(
                    mContext,
                    R.color.c_f7f7f7
                )
            )
        }
    }

    private fun bindRowTitleItemData(
        titleViewHolder: RowTitleViewHolder,
        column: Int
    ) {
        if (mTableTitleList.isNotNullOrSize()) {
            titleViewHolder.rowTitleTv.text = mTableTitleList[column]
        }
    }

    override fun onCreateViewHolder(parent: ViewGroup?, viewType: Int): RecyclerView.ViewHolder {
        when (viewType) {
            ROW_TITLE_ITEM_TYPE -> {
                return RowTitleViewHolder(
                    LayoutInflater.from(
                        parent?.context
                    ).inflate(R.layout.item_part_time_shop_info_table_row_title, parent, false)
                )
            }
            COLUMNS_TITLE_ITEM_TYPE -> {
                return ColumnsTitleViewHolder(
                    LayoutInflater.from(
                        parent?.context
                    ).inflate(R.layout.item_part_time_shop_info_table_columns_title, parent, false)
                )
            }
            else -> {
                return ContentViewHolder(
                    LayoutInflater.from(
                        parent?.context
                    ).inflate(R.layout.item_part_time_shop_info_table_item, parent, false)
                )
            }
        }
    }

    private class RowTitleViewHolder(view: View) : RecyclerView.ViewHolder(view) {
        val itemRootRl: RelativeLayout =
            view.findViewById(R.id.part_time_table_item_root_rl)
        val rowTitleTv: TextView = view.findViewById(R.id.part_time_table_row_title_tv)
    }

    private class ColumnsTitleViewHolder(view: View) : RecyclerView.ViewHolder(view) {
        val itemRootLl: LinearLayout =
            view.findViewById(R.id.part_time_table_item_root_ll)
        val columnsTitleTv: TextView = view.findViewById(R.id.part_time_table_columns_title_tv)
        val columnsInfoTv: TextView = view.findViewById(R.id.part_time_table_columns_info_tv)
    }

    private class ContentViewHolder(view: View) : RecyclerView.ViewHolder(view) {
        val itemRootLl: LinearLayout =
            view.findViewById(R.id.part_time_table_item_root_ll)
        val valueTv: TextView = view.findViewById(R.id.part_time_table_value_tv)
        val tipTv: TextView =
            view.findViewById(R.id.part_time_table_tip_tv)
    }

    fun setTableTitleList(tableTitleList: MutableList<String>) {
        this.mTableTitleList = tableTitleList
    }

    fun setShopInfoList(shopInfoList: MutableList<PartTimeShopInfoListEntity.ShopInfoBean>) {
        this.mShopInfoList = shopInfoList
    }

    fun getShopInfoList(): MutableList<PartTimeShopInfoListEntity.ShopInfoBean> {
        return mShopInfoList
    }

    interface OnChildItemClickListener {
        fun onItemClick(position: Int, shopinfo: PartTimeShopInfoListEntity.ShopInfoBean)
    }
}