package com.wgmf.yxgj.module.business.parttime.ui.adapter

import android.annotation.SuppressLint
import android.util.TypedValue
import android.view.Gravity
import android.view.View
import android.widget.LinearLayout
import android.widget.TextView
import com.chad.library.adapter.base.BaseQuickAdapter
import com.chad.library.adapter.base.BaseViewHolder
import com.wgmf.library.utils.TextColorDominator
import com.wgmf.yxgj.module.business.parttime.R
import com.wgmf.yxgj.module.business.parttime.model.PartTimeShopScheduleEntity
import com.wgmf.yxgj.utils.DensityUtil
import com.wgmf.yxgj.utils.StringUtils
import com.wgmf.yxgj.utils.isNotNullOrSize
import com.wgmf.yxgj.utils.notNullAndEmpty

/**
 * @author LW on 2023-7-12 0015.
 * 门店详情打卡适配器
 */
class PartTimeSignInfoRecordsListAdapter(
    entity: List<PartTimeShopScheduleEntity.PartTimeShopScheduleBean.SignTimeBeanBean>
) : BaseQuickAdapter<PartTimeShopScheduleEntity.PartTimeShopScheduleBean.SignTimeBeanBean, BaseViewHolder>(
    R.layout.item_part_time_sign_info_records,
    entity
) {

    override fun convert(
        helper: BaseViewHolder?,
        item: PartTimeShopScheduleEntity.PartTimeShopScheduleBean.SignTimeBeanBean?
    ) {
        helper?.apply {
            item?.let {
                setText(
                    R.id.part_time_sign_info_records_title_tv, it.signDayDesc
                )

                val partTimeSignInfoRecordsListLl =
                    getView<LinearLayout>(R.id.part_time_sign_info_records_list_ll).apply {
                        removeAllViews()
                    }
                if (it.todaySignVoList.isNotNullOrSize()) {
                    childContentView(partTimeSignInfoRecordsListLl, it.todaySignVoList!!)
                } else {
                    partTimeSignInfoRecordsListLl.addView(
                        View.inflate(
                            mContext,
                            R.layout.item_part_time_sign_info_records_empty,
                            null
                        )
                    )
                }
            }
        }
    }

    private fun childContentView(
        rootView: LinearLayout,
        todaySignVoList: List<PartTimeShopScheduleEntity.PartTimeShopScheduleBean.SignTimeBeanBean.ToDaySignVoBean>

    ) {
        todaySignVoList.forEach {
            val params = LinearLayout.LayoutParams(
                LinearLayout.LayoutParams.MATCH_PARENT,
                LinearLayout.LayoutParams.WRAP_CONTENT
            ).apply {
                setMargins(
                    0, 0, 0,
                    DensityUtil.dip2px(
                        mContext, 4f
                    )
                )
            }
            val childView = View.inflate(
                mContext,
                R.layout.item_part_time_sign_info_records_item,
                null
            ).apply {
                findViewById<TextView>(R.id.part_time_sign_info_sign_name_tv).text = it.staffName
                val partTimeSignInfoSignInLl =
                    findViewById<LinearLayout>(R.id.part_time_sign_info_sign_in_ll).apply {
                        removeAllViews()
                    }
                val partTimeSignInfoSignOutLl =
                    findViewById<LinearLayout>(R.id.part_time_sign_info_sign_out_ll).apply {
                        removeAllViews()
                    }
                it.toDaySignList?.forEachIndexed { index, bean ->
                    if (bean.signInTime.notNullAndEmpty()) {
                        childContentItemView(
                            partTimeSignInfoSignInLl,
                            StringUtils.formatString(
                                mContext.getString(R.string.part_time_shop_info_check_in),
                                index + 1,
                                bean.signInTime
                            )
                        )
                    }
                    if (bean.signOutTime.notNullAndEmpty()) {
                        childContentItemView(
                            partTimeSignInfoSignOutLl,
                            StringUtils.formatString(
                                mContext.getString(R.string.part_time_shop_info_sign_out),
                                index + 1,
                                bean.signOutTime
                            )
                        )
                    }
                }
            }
            rootView.addView(childView, params)
        }
    }

    @SuppressLint("ResourceAsColor")
    private fun childContentItemView(
        rootView: LinearLayout,
        content: String?
    ) {
        content?.let {
            rootView.addView(
                TextView(mContext).apply {
                    val start = it.length - 5
                    val end = it.length
                    text = TextColorDominator.styleTextBoldColor(
                        it, resources.getColor(R.color.important_txt_second_color), start, end
                    )
                    gravity = Gravity.CENTER
                    setTextSize(TypedValue.COMPLEX_UNIT_SP, 14f)
                    setPadding(
                        0,
                        DensityUtil.dip2px(mContext, 15f),
                        0,
                        DensityUtil.dip2px(mContext, 15f)
                    )
                },
                LinearLayout.LayoutParams(
                    LinearLayout.LayoutParams.WRAP_CONTENT,
                    LinearLayout.LayoutParams.WRAP_CONTENT
                )
            )
        }
    }
}



