package com.wgmf.yxgj.module.business.parttime.ui.takestock

import android.content.Intent
import android.support.v4.content.ContextCompat
import android.support.v7.widget.LinearLayoutManager
import android.support.v7.widget.RecyclerView
import android.view.View
import android.widget.*
import com.chad.library.adapter.base.BaseQuickAdapter
import com.google.gson.Gson
import com.jakewharton.rxbinding.view.RxView
import com.scwang.smartrefresh.layout.SmartRefreshLayout
import com.wgmf.library.base.BaseResponse
import com.wgmf.library.base.ResultData
import com.wgmf.library.utils.Log
import com.wgmf.library.utils.ToastUtil
import com.wgmf.library.utils.tools.PrefTool
import com.wgmf.yxgj.config.BusinessID
import com.wgmf.yxgj.dialog.LoadWaitDominator
import com.wgmf.yxgj.dialog.PublicTipDialog
import com.wgmf.yxgj.global.AppConstants
import com.wgmf.yxgj.global.ConstantParams
import com.wgmf.yxgj.global.Prefs
import com.wgmf.yxgj.module.business.parttime.R
import com.wgmf.yxgj.module.business.parttime.model.PartTimeTakeStockDetailBatchSaveEntity
import com.wgmf.yxgj.module.business.parttime.model.PartTimeTakeStockDetailEntity
import com.wgmf.yxgj.module.business.parttime.service.PartTimeService
import com.wgmf.yxgj.module.business.parttime.ui.PartTimeInventoryShopInfoActivity
import com.wgmf.yxgj.module.business.parttime.ui.takestock.adapter.PartTimeTakeStockDetailAdapter
import com.wgmf.yxgj.report.ui.ReportWithPhotoBaseActivity
import com.wgmf.yxgj.utils.isNotNullOrSize
import com.wgmf.yxgj.utils.isNullOrEmpty
import com.wgmf.yxgj.widgets.decoration.DividerItemDecoration
import com.xp.pro.imagepickerlib.TakePictureActivity
import com.xp.pro.imagepickerlib.bean.ImageItem
import com.xp.pro.imagepickerlib.global.Params
import com.xp.pro.imagepickerlib.widgets.ImagePickerLayout
import com.xp.pro.imagepickerlib.widgets.ImagePickerLayout.ImagePicker
import java.util.*
import java.util.concurrent.TimeUnit

/**
 *  @author LW on 2023-7-20 0020.
 * 专柜货品检查
 */
class PartTimeTakeStockDetailActivity : ReportWithPhotoBaseActivity(), ImagePicker {

    private val mTakeStockId: String? by lazy {
        intent?.getStringExtra(AppConstants.ExtraKeys.PART_TIME_TAKE_STOCK_ID)
    }

    private val mSelectBrandId: Int by lazy {
        intent.getIntExtra(AppConstants.ExtraKeys.BRAND_ID, -1)
    }

    private var mPartTimeTakeStockDetailBean: PartTimeTakeStockDetailEntity.PartTimeTakeStockDetailBean? =
        null

    private lateinit var mLoadWait: LoadWaitDominator

    private var mPartTimeTakeStockDetailAdapter: PartTimeTakeStockDetailAdapter? = null

    private var mUserPartTimeName: String? = null

    private var mPublicRefreshView: SmartRefreshLayout? = null

    private var mPartTimeTakeStockRemarkEt: EditText? = null

    private var mPartTimeTakeStockDetailTitleTv: TextView? = null

    private var mRecyclerFootView: View? = null

    /**
     * 门店是否有纸质盘点报表
     */
    private var mPaperReport: Int = -1

    /**
     * 兼职是否检查门店货品
     */
    private var mCheckStoreGoods: Int = -1

    override fun initData() {
        super.initData()
        //兼职盘点
        reportType = "PTPD"
        //兼职督察盘点默认使用200K
        PrefTool.setIntSave(mContext, Prefs.PRE_IMAGE_SIZE, 200)

        mUserPartTimeName = PrefTool.getStringPerferences(mContext, Prefs.PRE_USER_PART_TIME_NAME)
    }

    override fun initView() {
        setContentView(R.layout.activity_part_time_take_stock_detail)
        mPublicListViewRv = findViewById(R.id.public_list_view_rv)

        mPartTimeTakeStockDetailTitleTv = findViewById(R.id.part_time_take_stock_detail_title_tv)

        findViewById<Button>(R.id.part_time_take_stock_submit_btn).let {
            //3秒钟之内只取一个点击事件，防抖操作
            RxView.clicks(it).throttleFirst(3, TimeUnit.SECONDS)
                .subscribe { setUploadData() }
        }
    }

    override fun initTitle() {
        super.initTitle()
        homeTitleText.text = mContext.getString(R.string.part_time_take_stock_goods_check)
        homeTitleBackLl.visibility = View.VISIBLE
    }

    override fun setListAdapter() {
        super.setListAdapter()
        initRecyclerView()
    }

    private fun initRecyclerView() {
        mLoadWait =
            LoadWaitDominator(mContext, findViewById(R.id.public_container_fl))

        mPublicRefreshView = findViewById<SmartRefreshLayout>(R.id.public_refresh_view).apply {
            isEnableLoadmore = false
            isEnableRefresh = false
            //刷新
            setOnRefreshListener {
                getPartTimeTakeStockDetail()
            }
        }

        mPartTimeTakeStockDetailAdapter = PartTimeTakeStockDetailAdapter(mutableListOf())
        mPublicListViewRv = findViewById<RecyclerView>(R.id.public_list_view_rv).apply {
            layoutManager = LinearLayoutManager(mContext)
            adapter = mPartTimeTakeStockDetailAdapter
            addItemDecoration(
                DividerItemDecoration(
                    DividerItemDecoration.HORIZONTAL_LIST,
                    1,
                    ContextCompat.getColor(mContext, R.color.divider_line_deep_two)
                )
            )
        }

        BaseQuickAdapter.OnItemChildClickListener { adapter, view, pos -> //跳转到任务列表详情
            val bean =
                adapter?.getItem(pos) as PartTimeTakeStockDetailEntity.PartTimeTakeStockDetailBean.TakeStockDetailBeam
        }.also { mPartTimeTakeStockDetailAdapter?.onItemChildClickListener = it }

        if (mRecyclerFootView != null) {
            mPartTimeTakeStockDetailAdapter?.setFooterView(mRecyclerFootView)
        }
        //mPublicRefreshView?.autoRefresh()
        getPartTimeTakeStockDetail()
    }

    override fun setListHeadAndFootView() {
        mRecyclerFootView =
            layoutInflater.inflate(R.layout.include_part_time_take_stock_detail_footer, null)
    }

    override fun parseFootData() {
        mRecyclerFootView?.let {
            publicTakePhotoRootLl = it.findViewById(R.id.public_take_photo_root_ll)
            publicTakePhotoLl = it.findViewById(R.id.public_take_photo_ll)
            publicTakePhotoRootLl.visibility = View.VISIBLE
            publicTakePhotoLl.visibility = View.GONE

            initPictureDisplayView()

            mPartTimeTakeStockRemarkEt = it.findViewById(R.id.part_time_take_stock_remark_et)
            it.findViewById<TextView>(R.id.part_time_take_stock_supervisor_name_tv).apply {
                text = mUserPartTimeName
            }

            it.findViewById<RadioGroup>(R.id.part_time_take_stock_paper_report_rg)
                .setOnCheckedChangeListener { group, checkedId ->
                    if (checkedId == R.id.part_time_take_stock_paper_report_yes_rb) {
                        mPaperReport = 1
                    } else {
                        mPaperReport = 0
                    }
                }

            it.findViewById<RadioGroup>(R.id.part_time_take_stock_check_store_goods_rg)
                .setOnCheckedChangeListener { group, checkedId ->
                    if (checkedId == R.id.part_time_take_stock_check_store_goods_yes_rb) {
                        mCheckStoreGoods = 1
                    } else {
                        mCheckStoreGoods = 0
                    }
                }
        }
    }

    private fun initPictureDisplayView() {
        idImagePickerContainer =
            mRecyclerFootView?.findViewById(R.id.id_image_picker_container)
        idImagePickerContainer.visibility = View.VISIBLE
        idImagePickerContainer.title = "上传与货品检查相关的图片【选填】"
        idImagePickerContainer.tip = "(最多可上传15张图片)"
        idImagePickerContainer.imagePicker = this
        idImagePickerContainer.sizePhotoNum = 3
        idImagePickerContainer.maxPhotoNum = 15
        idImagePickerContainer.setmImageselectList(mImageselectList)
        idImagePickerContainer.imagePickerView = idImagePickerContainer
        idImagePickerContainer.isOlnyViewMode = false
    }

    /**
     * 添加门店查询品牌
     */
    private fun getPartTimeTakeStockDetail() {
        showDialog()
        PartTimeService.getInstance()
            .requestGetPartTimeTakeStockDetail(mTakeStockId, this@PartTimeTakeStockDetailActivity)
    }

    override fun setUploadData() {
        val takeStockDetailList: List<PartTimeTakeStockDetailEntity.PartTimeTakeStockDetailBean.TakeStockDetailBeam>? =
            mPartTimeTakeStockDetailBean?.takeStockDetailList
        if (takeStockDetailList.isNotNullOrSize()) {
            takeStockDetailList?.forEach {
                if (it.stockCount == null) {
                    ToastUtil.show(mContext, R.string.part_time_take_stock_not_check_tip)
                    dismissDialog()
                    return
                }
            }
            //takeStockDetailList?.forEach {
            //    if (it.stockDifferenceCount != 0.0 && it.differenceDesc.isNullOrEmpty()) {
            //        ToastUtil.show(
            //            mContext,
            //            StringUtils.formatString(
            //                mContext.getString(R.string.part_time_take_stock_difference_desc_tip),
            //                it.productName
            //            )
            //        )
            //        dismissDialog()
            //        return
            //    }
            //}
        }
        if (mPaperReport < 0) {
            ToastUtil.show(mContext, R.string.part_time_take_stock_paper_report_tip)
            dismissDialog()
            return
        }
        if (mCheckStoreGoods < 0) {
            ToastUtil.show(mContext, R.string.part_time_take_stock_check_store_goods_tip)
            dismissDialog()
            return
        }

        super.setUploadData()
    }

    override fun uploadData() {
        super.uploadData()
        showDialog()

        //设置图片
        val partTimeTakeStockImgList: MutableList<PartTimeTakeStockDetailBatchSaveEntity.PartTimeTakeStockImgBean> =
            mutableListOf()
        if (mImageselectList.isNotNullOrSize()) {
            for (index in urlLists.indices) {
                val partTimeTakeStockImgBean =
                    PartTimeTakeStockDetailBatchSaveEntity.PartTimeTakeStockImgBean(
                        mTakeStockId,
                        urlLists[index]
                    )
                partTimeTakeStockImgList.add(partTimeTakeStockImgBean)
            }
        }

        val partTimeRemark = mPartTimeTakeStockRemarkEt?.getText().toString()

        val takeStockDetailList = mPartTimeTakeStockDetailBean?.takeStockDetailList

        val partTimeTakeStockDetailEntity = PartTimeTakeStockDetailBatchSaveEntity(
            imgStatus,
            mUserPartTimeName,
            partTimeRemark,
            mPaperReport,
            mSelectBrandId,
            mCheckStoreGoods,
            mTakeStockId,
            takeStockDetailList,
            partTimeTakeStockImgList
        )

        val content = Gson().toJson(partTimeTakeStockDetailEntity)
        android.util.Log.d(TAG, content)
        PartTimeService.getInstance()
            .requestBatchSavePartTimeTakeStockDetail(content, this@PartTimeTakeStockDetailActivity)
    }

    override fun onBusinessResultAtMainThread(result: ResultData?) {
        super.onBusinessResultAtMainThread(result)
        dismissDialog()
        mLoadWait.dismissAll()
        mPublicRefreshView?.finishRefresh()
        result?.let {
            if (it.taskID == BusinessID.PartTime.MSG_ON_BATCH_SAVE_PARTTIME_TAKESTOCK_DETAIL) {
                if (!isFinishing && it.isSuccessed) {
                    val entity =
                        Gson().fromJson(it.info, BaseResponse::class.java)
                    Log.d(TAG, "BaseResponse=$entity")
                    if (ConstantParams.CONSTANT_PARAMS_0 == entity.retCode) {
                        if (imgStatus.contains("失败")) {
                            showTipDialog("提示", entity.retInfo + ",图片上传" + imgStatus)
                            return
                        }
                        //盘点成功，退出到门店列表页
                        val intent = Intent(
                            this@PartTimeTakeStockDetailActivity,
                            PartTimeInventoryShopInfoActivity::class.java
                        )
                        intent.flags = Intent.FLAG_ACTIVITY_NEW_TASK
                        startActivity(intent)
                    }
                    ToastUtil.show(mContext, entity.retInfo)
                } else {
                    ToastUtil.show(mContext, R.string.request_data_fail)
                }
            } else if (it.taskID == BusinessID.PartTime.MSG_ON_GET_PARTTIME_TAKESTOCK_DETAIL) {
                if (!isFinishing && it.isSuccessed) {
                    val entity =
                        Gson().fromJson(it.info, PartTimeTakeStockDetailEntity::class.java)
                    Log.d(TAG, "PartTimeTakeStockDetailEntity=$entity")
                    if (ConstantParams.CONSTANT_PARAMS_0 == entity.retCode) {
                        this.mPartTimeTakeStockDetailBean = entity.result
                        refreshListData()
                    } else {
                        mLoadWait.show(entity.retInfo)
                    }
                } else {
                    mLoadWait.showNetError()
                }
            }
        }
    }

    private fun refreshListData() {
        mPartTimeTakeStockDetailBean?.let {
            val takeStockDetailList = it.takeStockDetailList

            //if (it.checkListStatus == ConstantParams.CONSTANT_STARTS_1) {
                mPartTimeTakeStockDetailTitleTv?.text =
                    mContext.getString(R.string.part_time_take_stock_real_time_inventory)
            //} else {
            //    mPartTimeTakeStockDetailTitleTv?.text =
            //        mContext.getString(R.string.part_time_take_stock_last_month_number)
            //}

            if (takeStockDetailList.isNullOrEmpty()) {
                mLoadWait.show(LoadWaitDominator.NO_DATA)
            } else {
                mLoadWait.dismissAll()
                mPartTimeTakeStockDetailAdapter?.setCheckListStatus(it.checkListStatus)
                mPartTimeTakeStockDetailAdapter?.setNewData(takeStockDetailList)
            }
        }

    }

    override fun showTipDialog(title: String?, msg: String) {
        if (!PrefTool.getBooleanPreferences(
                mContext,
                Prefs.PRE_DIALOG_SHOWING,
                false
            )
        ) {
            val builder = PublicTipDialog.Builder(mContext)
            builder.setMessage("$msg\n点击重报将尝试减小图片质量重新上报，点击确定完成本次上报。")
            builder.setTitle(title)
            builder.setPositiveButton(
                "重报"
            ) { dialog, which ->
                dialog.dismiss()
                //图片上传不成功，减小大小使用100k
                PrefTool.setIntSave(mContext, Prefs.PRE_IMAGE_SIZE, 100)
                PrefTool.setBooleanSave(
                    mContext,
                    Prefs.PRE_DIALOG_SHOWING,
                    false
                )
            }
            builder.setNegativeButton(
                "确定"
            ) { dialog, which ->
                dialog.dismiss()
                //图片默认大小使用200k
                PrefTool.setIntSave(mContext, Prefs.PRE_IMAGE_SIZE, 200)
                PrefTool.setBooleanSave(
                    mContext,
                    Prefs.PRE_DIALOG_SHOWING,
                    false
                )
                //盘点成功，退出到门店列表页
                val intent = Intent(
                    this@PartTimeTakeStockDetailActivity,
                    PartTimeInventoryShopInfoActivity::class.java
                )
                intent.flags = Intent.FLAG_ACTIVITY_NEW_TASK
                startActivity(intent)
            }
            builder.create().show()
            PrefTool.setBooleanSave(mContext, Prefs.PRE_DIALOG_SHOWING, true)
        }
    }

    override fun setSelectDialog(selectType: Int, view: View?) {
        idImagePickerContainer = view as ImagePickerLayout
        setSelectDialogListeners(View.OnClickListener { //拍照处理
            takePhoto(idImagePickerContainer)
            hideSelectDialog()
        }, View.OnClickListener { //相片处理
            getPictrue(idImagePickerContainer)
            hideSelectDialog()
        }, View.OnClickListener { hideSelectDialog() })
        showSelectDialog("选择图片", null, "相机拍照", "本地相册", "取消")
    }

    /**
     * 调用系统拍照
     */
    protected fun takePhoto(idImagePickerContainer: ImagePickerLayout?) {
        val intent = Intent(mContext, TakePictureActivity::class.java)
        intent.putExtra("authority", "com.wgmf.yxgj")
        startActivityForResultByAnimation(intent, Params.TAKE_PICTURE)
    }

    override fun toPhotoPreview(index: Int, imageselectList: ArrayList<ImageItem>?) {
        toPhotoPreviewFragment(index, imageselectList) //大图显示
    }
}