package com.wgmf.yxgj.module.business.parttime.ui.takestock.adapter

import android.support.v4.content.ContextCompat
import android.widget.EditText
import android.widget.TextView
import com.chad.library.adapter.base.BaseQuickAdapter
import com.chad.library.adapter.base.BaseViewHolder
import com.wgmf.library.extfunction.afterTextChanged
import com.wgmf.yxgj.dialog.PublicChooseDialog
import com.wgmf.yxgj.global.ConstantParams
import com.wgmf.yxgj.module.business.parttime.R
import com.wgmf.yxgj.module.business.parttime.model.PartTimeTakeStockDetailEntity
import com.wgmf.yxgj.utils.StringUtils
import com.wgmf.yxgj.utils.notNullAndEmpty
import com.wgmf.yxgj.widgets.EditText.LimitEditText

/**
 * 专柜货品检查 适配器
 * @author LW
 */
class PartTimeTakeStockDetailAdapter(
    val entity: List<PartTimeTakeStockDetailEntity.PartTimeTakeStockDetailBean.TakeStockDetailBeam>
) : BaseQuickAdapter<PartTimeTakeStockDetailEntity.PartTimeTakeStockDetailBean.TakeStockDetailBeam, BaseViewHolder>(
    R.layout.item_part_time_take_stock_detail_item,
    entity
) {
    /**
     * 是否审核(0未审核1已审核)
     */
    private var mCheckListStatus: Int = 0

    fun setCheckListStatus(checkListStatus: Int) {
        this.mCheckListStatus = checkListStatus
    }

    override fun convert(
        helper: BaseViewHolder?,
        item: PartTimeTakeStockDetailEntity.PartTimeTakeStockDetailBean.TakeStockDetailBeam?
    ) {
        helper?.apply {
            item?.let {
                getView<LimitEditText>(R.id.part_time_take_stock_actual_number_et).apply {
                    if (it.stockCount != null) {
                        setText(it.stockCount.toString())
                    } else {
                        setText("")
                    }
                    afterTextChanged { text ->
                        if (adapterPosition >= 0 && adapterPosition < data.size) {
                            val bean = data[adapterPosition]
                            if (text.notNullAndEmpty()) {
                                bean.stockCount = text.toDouble()
                            } else {
                                bean.stockCount = null
                            }
                            if (it.stockCount != null) {
                                bean.stockDifferenceCount =
                                    (bean.stockCount
                                        ?: 0.0) - bean.stockQty
                            } else {
                                bean.stockDifferenceCount = 0.0;
                            }

                            refreshStockDifferenceCount(helper, bean)
                        }
                    }
                }
                //差异说明
                getView<EditText>(R.id.part_time_take_stock_difference_desc_et).apply {
                    setText(it.differenceDesc)
                    afterTextChanged { text ->
                        if (adapterPosition >= 0 && adapterPosition < data.size) {
                            val bean = data[adapterPosition]
                            bean.differenceDesc = text
                        }
                    }
                }

                //临期
                getView<LimitEditText>(R.id.part_time_take_stock_date_num_et).apply {
                    setText(it.partTimeAdventQty)
                    afterTextChanged { text ->
                        if (adapterPosition >= 0 && adapterPosition < data.size) {
                            val bean = data[adapterPosition]
                            bean.partTimeAdventQty = text
                        }
                    }
                }
                getView<EditText>(R.id.part_time_take_stock_date_remark_et).apply {
                    setText(it.remark)
                    afterTextChanged { text ->
                        if (adapterPosition >= 0 && adapterPosition < data.size) {
                            val bean = data[adapterPosition]
                            bean.remark = text
                        }
                    }
                }
                //过期
                getView<LimitEditText>(R.id.part_time_take_stock_date_over_et).apply {
                    setText(it.overTimeNumber)
                    afterTextChanged { text ->
                        if (adapterPosition >= 0 && adapterPosition < data.size) {
                            val bean = data[adapterPosition]
                            bean.overTimeNumber = text
                        }
                    }
                }
                getView<EditText>(R.id.part_time_take_stock_date_over_remark_et).apply {
                    setText(it.overTimeRemark)
                    afterTextChanged { text ->
                        if (adapterPosition >= 0 && adapterPosition < data.size) {
                            val bean = data[adapterPosition]
                            bean.overTimeRemark = text
                        }
                    }
                }

                setText(
                    R.id.part_time_take_stock_product_name_tv,
                    it.productName
                )

                setText(
                    R.id.part_time_take_stock_product_code_tv,
                    StringUtils.formatString(
                        mContext.getString(R.string.part_time_shop_info_code_two),
                        it.productNo
                    )
                )
                //提示临期
                setText(
                    R.id.part_time_take_stock_tip_advent_tv,
                    it.adventQty.toString()
                )

                //if (mCheckListStatus == ConstantParams.CONSTANT_STARTS_1) {
                //实时库存
                setText(
                    R.id.part_time_take_stock_real_time_inventory_tv,
                    it.stockQty.toString()
                )
                //} else {
                //上月盘点数量
                //    setText(
                //        R.id.part_time_take_stock_real_time_inventory_tv,
                //        it.invQty.toString()
                //    )
                //}

                //差异
                refreshStockDifferenceCount(this, it)

                //是/否有临期
                refreshAdvent(this, it)

                getView<TextView>(R.id.part_time_take_stock_is_advent_tv).setOnClickListener {
                    showIsAdventDialog(adapterPosition)
                }
            }
        }
    }

    private fun refreshAdvent(
        helper: BaseViewHolder,
        it: PartTimeTakeStockDetailEntity.PartTimeTakeStockDetailBean.TakeStockDetailBeam
    ) {
        helper.apply {
            if (it.adventStatus == ConstantParams.CONSTANT_STARTS_1) {
                setText(
                    R.id.part_time_take_stock_is_advent_tv,
                    mContext.getString(R.string.part_time_take_stock_yes)
                )
                setGone(R.id.part_time_take_stock_date_ll, true)
                setGone(R.id.part_time_take_stock_date_over_ll, true)
            } else {
                setText(
                    R.id.part_time_take_stock_is_advent_tv,
                    mContext.getString(R.string.part_time_take_stock_no)
                )
                setGone(R.id.part_time_take_stock_date_ll, false)
                setGone(R.id.part_time_take_stock_date_over_ll, false)
            }
            if (it.adventStatus == ConstantParams.CONSTANT_STARTS_1 || it.stockDifferenceCount != 0.0) {
                setGone(R.id.part_time_take_stock_detail_content_ll, true)
            } else {
                setGone(R.id.part_time_take_stock_detail_content_ll, false)
            }
        }
    }

    /**
     * 显示是否临期
     */
    private fun showIsAdventDialog(adapterPosition: Int) {
        if (adapterPosition >= 0 && adapterPosition < data.size) {
            val bean = data[adapterPosition]
            val builder = PublicChooseDialog.Builder(mContext)
            builder.setYesRbText(R.string.part_time_take_stock_advent)
            builder.setNoRbText(R.string.part_time_take_stock_not_advent)
            builder.isComplete = bean.adventStatus
            builder.setPositiveButton { dialog, _ -> dialog.dismiss() }
            builder.setNegativeButton { dialog, _ ->
                dialog.dismiss()
                bean.adventStatus = builder.isComplete
                notifyItemChanged(adapterPosition)
            }
            builder.create().show()
        }
    }

    private fun refreshStockDifferenceCount(
        helper: BaseViewHolder,
        it: PartTimeTakeStockDetailEntity.PartTimeTakeStockDetailBean.TakeStockDetailBeam
    ) {
        helper.apply {
            if (it.stockDifferenceCount == 0.0) {
                setTextColor(
                    R.id.part_time_take_stock_difference_tv,
                    ContextCompat.getColor(mContext, R.color.important_txt_second_color)
                )
                setGone(R.id.part_time_take_stock_difference_desc_ll, false)
            } else {
                setTextColor(
                    R.id.part_time_take_stock_difference_tv,
                    ContextCompat.getColor(mContext, R.color.common_txt_tag_color)
                )
                setGone(R.id.part_time_take_stock_difference_desc_ll, true)
            }

            setText(
                R.id.part_time_take_stock_difference_tv,
                it.stockDifferenceCount.toString()
            )

            if (it.adventStatus == ConstantParams.CONSTANT_STARTS_1 || it.stockDifferenceCount != 0.0) {
                setGone(R.id.part_time_take_stock_detail_content_ll, true)
            } else {
                setGone(R.id.part_time_take_stock_detail_content_ll, false)
            }
        }
    }
}