package com.wgmf.yxgj.module.business.reportbigdata.service;

import android.text.TextUtils;
import android.util.Log;

import com.google.gson.Gson;
import com.wgmf.library.base.BaseRequest;
import com.wgmf.library.base.BaseResponse;
import com.wgmf.library.base.ResultData;
import com.wgmf.library.utils.BaseSingleton;
import com.wgmf.yxgj.base.BaseService;
import com.wgmf.yxgj.config.BusinessID;
import com.wgmf.yxgj.global.NetworkParams;

import java.lang.ref.WeakReference;

/**
 * 商超大数据网络请求服务
 */
public class BigDataManagerService extends BaseService {
    private static BaseSingleton<BigDataManagerService, Void> mMainService = new BaseSingleton<BigDataManagerService, Void>() {
        @Override
        protected BigDataManagerService create(Void var1) {
            return new BigDataManagerService();
        }
    };

    public static BigDataManagerService getInstance() {
        return mMainService.get(null);
    }

    private BigDataManagerService() {
    }

    /**
     * GET /supermarketData/getSupermarketBigDataShop 查询门店是否填写商超大数据
     * staffId(required)商超大数据填写人id query	string
     * orgId(required)填写人的销售组织id query	long
     */
    public void requestGetSupermarketBigDataShop(final String staffId, final String orgId, ResultData.BusinessCallback callback) {
        BaseRequest request = new BaseRequest();
        request.taskID = BusinessID.BigDataReport.MSG_ON_GET_SUPERMARKET_BIGDATA_SHOP;
        request.callback = new WeakReference<>(callback);
        request.url = NetworkParams.URL_GET_SUPERMARKET_BIGDATA_SHOP + "?" + "staffId=" + staffId + "&orgId=" + orgId;
        Log.d(TAG, "请求地址：" + request.url);
        sendGetRequest(request);
    }

    /**
     * GET /supermarketData/findStoreSupermarketBigData 查询门店商超大数据
     * shopId 0110297 门店shopId query	string
     */
    public void requestFindStoreSupermarketBigData(final String shopId, ResultData.BusinessCallback callback) {
        BaseRequest request = new BaseRequest();
        request.taskID = BusinessID.BigDataReport.MSG_ON_FIND_STORE_SUPERMARKET_BIGDATA;
        request.callback = new WeakReference<>(callback);
        request.url = NetworkParams.URL_FIND_STORE_SUPERMARKET_BIGDATA + "?" + "shopId=" + shopId;
        Log.d(TAG, "请求地址：" + request.url);
        sendGetRequest(request);
    }

    /**
     * GET /supermarketData/getSupermarketBigDataReport 查询门店商超大数据
     * dataRangeId 1 数据范围Id query	string
     * orgId 1546 填写人的销售组织id query	long
     */
    public void requestGetSupermarketBigDataReport(final String dataRangeId, final String orgId,
                                                   ResultData.BusinessCallback callback) {
        BaseRequest request = new BaseRequest();
        request.taskID = BusinessID.BigDataReport.MSG_ON_GET_SUPERMARKET_BIGDATA_REPORT;
        request.callback = new WeakReference<>(callback);
        request.url = NetworkParams.URL_GET_SUPERMARKET_BIGDATA_REPORT + "?" + "orgId=" + orgId + "&dataRangeId=" + dataRangeId;
        Log.d(TAG, "请求地址：" + request.url);
        sendGetRequest(request);
    }

    /**
     * POST /supermarketData/saveSupermarketBigData 新增商超大数据
     */
    public void requestSaveSupermarketBigData(final String json,
                                              ResultData.BusinessCallback callback) {
        BaseRequest request = new BaseRequest();
        request.taskID = BusinessID.BigDataReport.MSG_ON_SAVE_SUPERMARKET_BIGDATA;
        request.callback = new WeakReference<>(callback);
        request.url = NetworkParams.URL_SAVE_SUPERMARKET_BIGDATA;
        request.json = json;
        Log.d(TAG, "请求地址：" + request.url);
        sendPostJsonRequest(request);
    }

    @Override
    protected void onTaskDone(ResultData data) {
        if (null != data) {
            final int id = data.taskID;
            switch (id) {
                case BusinessID.BigDataReport.MSG_ON_GET_SUPERMARKET_BIGDATA_SHOP:
                case BusinessID.BigDataReport.MSG_ON_GET_SUPERMARKET_BIGDATA_REPORT:
                case BusinessID.BigDataReport.MSG_ON_FIND_STORE_SUPERMARKET_BIGDATA:
                case BusinessID.BigDataReport.MSG_ON_SAVE_SUPERMARKET_BIGDATA:{
                    if (data.isSuccessed()) {
                        final String json = data.getInfo();
                        if (!TextUtils.isEmpty(json)) {
                            BaseResponse mBaseResponse = new Gson().fromJson(json, BaseResponse.class);
                            Log.d(TAG, "mBaseResponse=" + mBaseResponse.toString());

                            data.setResultCode(mBaseResponse.retCode);
                            data.setResultInfo(mBaseResponse.retInfo);
                        }
                    }
                    break;
                }
                default:
                    break;
            }
        }
    }
}