package com.wgmf.yxgj.module.business.reportbigdata.ui.bigData;

import android.support.annotation.NonNull;
import android.util.Log;

import com.google.gson.Gson;
import com.wgmf.library.base.BaseResponse;
import com.wgmf.library.base.ResultData;
import com.wgmf.yxgj.base.BaseParentAct;
import com.wgmf.yxgj.config.BusinessID;
import com.wgmf.yxgj.module.business.reportbigdata.model.SupermarketBigData;
import com.wgmf.yxgj.module.business.reportbigdata.model.SupermarketBigDataList;
import com.wgmf.yxgj.module.business.reportbigdata.service.BigDataManagerService;
import com.wgmf.yxgj.publics.model.BaseSelectorEntity;

import java.util.ArrayList;
import java.util.List;

/**
 * 作者：xiep on 2017/9/4 17:13
 * 邮箱：2975837870@qq.com
 */

public class BigDataPresenter {
    private static final String TAG = "BigDataPresenter";

    private List<BaseSelectorEntity> dataTypes = new ArrayList<>();
    private List<BaseSelectorEntity> dataRanges = new ArrayList<>();

    private BigDataView customerVisitView;

    /**
     * dataTypeId (string, optional): 数据类型Id : 年度数据/'1'；半年度数据/'2'；季度数据/'3'；月度数据/'4' ,
     */
    private String[] dataType = new String[]{"年度数据", "半年度数据", "季度数据", "月度数据"};
    /**
     * dataRangeId (string, optional): 数据范围id:生鲜区/'1'；果蔬区/'2';生鲜+果蔬/'3'；熟食区/'4'；整个门店/'5' ,
     */
    private String[] dataRange = new String[]{"生鲜区", "果蔬区", "生鲜区+果蔬区", "熟食区", "整个门店"};

    public BigDataPresenter(@NonNull BigDataView customerVisitView) {
        this.customerVisitView = customerVisitView;
    }

    List<BaseSelectorEntity> getDataType() {
        for (int i = 0; i < dataType.length; i++) {
            BaseSelectorEntity mBaseSelectorEntity = new BaseSelectorEntity();
            mBaseSelectorEntity.setSelectorName(dataType[i]);
            mBaseSelectorEntity.setSelectorId(i + 1 + "");
            dataTypes.add(mBaseSelectorEntity);
        }
        return dataTypes;
    }

    List<BaseSelectorEntity> getDataRange() {
        for (int i = 0; i < dataRange.length; i++) {
            BaseSelectorEntity mBaseSelectorEntity = new BaseSelectorEntity();
            mBaseSelectorEntity.setSelectorName(dataRange[i]);
            mBaseSelectorEntity.setSelectorId(i + 1 + "");
            dataRanges.add(mBaseSelectorEntity);
        }
        return dataRanges;
    }

    /**
     * 商超大数据提交
     *
     * @param mSupermarketBigData 商超大数据
     */
    void uploadData(SupermarketBigData mSupermarketBigData) {
        String content = new Gson().toJson(mSupermarketBigData);
        Log.d(TAG, content);
        BigDataManagerService.getInstance().requestSaveSupermarketBigData(content, (BaseParentAct) customerVisitView);
    }

    /**
     * 根据接口返回数据进行服务切换
     *
     * @param result 服务器返回数据
     */
    void switchService(ResultData result) {
        if (null != result) {
            final int id = result.taskID;
            switch (id) {
                case BusinessID.BigDataReport.MSG_ON_SAVE_SUPERMARKET_BIGDATA:
                    getSaveData(result);
                    break;
                case BusinessID.BigDataReport.MSG_ON_FIND_STORE_SUPERMARKET_BIGDATA:
                    getFindData(result);
                    break;
                default:
                    break;
            }
        }
    }

    private void getFindData(ResultData result) {
        final String msg = result.getInfo();
        if (result.isSuccessed()) {
            SupermarketBigDataList mSupermarketBigDataList = new Gson().fromJson(msg, SupermarketBigDataList.class);
            Log.d(TAG, "mSupermarketBigDataList=" + mSupermarketBigDataList.toString());
            customerVisitView.findStore(mSupermarketBigDataList.getResultList());
        }
    }

    private void getSaveData(ResultData result) {
        final String msg = result.getInfo();
        if (result.isSuccessed()) {
            BaseResponse mBaseResponse = new Gson().fromJson(msg, BaseResponse.class);
            Log.d(TAG, "mBaseResponse=" + mBaseResponse.toString());
            customerVisitView.saveSuccessed(result.getResultInfo());
        }
    }
}