package com.wgmf.yxgj.module.bussiness.reporthome.service

import android.util.Log
import com.google.gson.Gson
import com.wgmf.library.base.BaseRequest
import com.wgmf.library.base.BaseResponse
import com.wgmf.library.base.ResultData
import com.wgmf.yxgj.base.BaseService
import com.wgmf.yxgj.config.BusinessID
import com.wgmf.yxgj.global.NetworkParams
import com.wgmf.yxgj.utils.notNullAndEmpty
import java.lang.ref.WeakReference

/**
 * 到家业务接口 Service
 */
class ReportHomeService private constructor() : BaseService() {

    companion object {
        @JvmStatic
        val instance: ReportHomeService by lazy(mode = LazyThreadSafetyMode.PUBLICATION) {
            ReportHomeService()
        }
    }

    /**
     * get  /gohome/queryTaskList 到家业务任务查询
     * @param orgId 组织Id
     * @param orgLevel 1/全国，3/大区，4/办事处，5/主管
     */
    fun requestQueryTaskList(
        orgId: String?,
        orgLevel: String?,
        callback: ResultData.BusinessCallback
    ) {
        val request = BaseRequest().apply {
            this.taskID = BusinessID.HomeReport.MSG_ON_QUERY_TASK_LIST
            this.callback = WeakReference(callback)
            this.url =
                NetworkParams.URL_QUERY_TASK_LIST + "?orgId=" + orgId + "&orgLevel=" + orgLevel
        }
        Log.d(TAG, "请求地址：" + request.url)
        sendGetRequest(request)
    }

    /**
     * get  /gohome/queryTaskDetail 到家业务任务详情查询
     * @param taskId 任务id
     * @param shopId 门店id
     */
    fun requestQueryTaskDetail(
        taskId: String?,
        shopId: String?,
        callback: ResultData.BusinessCallback
    ) {
        val request = BaseRequest().apply {
            this.taskID = BusinessID.HomeReport.MSG_ON_QUERY_TASK_DETAIL
            this.callback = WeakReference(callback)
            this.url =
                NetworkParams.URL_QUERY_TASK_DETAIL + "?taskId=" + taskId + "&shopId=" + shopId
        }
        Log.d(TAG, "请求地址：" + request.url)
        sendGetRequest(request)
    }

    /**
     * post /gohome/submit 提交任务
     * @param shopId 门店id
     */
    fun requestSubmit(
        json:String,
        callback: ResultData.BusinessCallback
    ) {
        val request = BaseRequest().apply {
            this.taskID = BusinessID.HomeReport.MSG_ON_SUBMIT
            this.callback=WeakReference(callback)
            this.url = NetworkParams.URL_SUBMIT
            this.json=json
        }
        Log.d(TAG, "请求地址：" + request.url)
        sendPostJsonRequest(request)
    }

    override fun onTaskDone(data: ResultData?) {
        data?.let {
            when (it.taskID) {
                BusinessID.HomeReport.MSG_ON_QUERY_TASK_LIST,
                BusinessID.HomeReport.MSG_ON_QUERY_TASK_DETAIL,
                BusinessID.HomeReport.MSG_ON_SUBMIT -> {
                    if (it.isSuccessed) {
                        val json = it.info
                        if (json.notNullAndEmpty()) {
                            val response = Gson().fromJson(
                                json,
                                BaseResponse::class.java
                            )
                            Log.d(TAG, "id:${it.taskID};mBaseResponse=$response")
                            it.resultCode = response.retCode
                            it.resultInfo = response.retInfo
                        }
                    }
                }
                else -> {
                }
            }
        }
    }
}