package com.wgmf.yxgj.module.bussiness.reporthome.ui

import android.content.Intent
import android.os.Bundle
import android.support.v4.content.ContextCompat
import android.support.v7.widget.LinearLayoutManager
import android.support.v7.widget.RecyclerView
import android.util.Log
import android.view.View
import android.widget.ListView
import com.alibaba.android.arouter.facade.annotation.Route
import com.chad.library.adapter.base.entity.MultiItemEntity
import com.google.gson.Gson
import com.wgmf.library.base.ResultData
import com.wgmf.yxgj.base.BaseParentAct
import com.wgmf.yxgj.config.BusinessID
import com.wgmf.yxgj.dialog.LoadWaitDominator
import com.wgmf.yxgj.global.ConstantParams
import com.wgmf.yxgj.module.bussiness.reporthome.R
import com.wgmf.yxgj.module.bussiness.reporthome.model.HomeBusinessEntity
import com.wgmf.yxgj.module.bussiness.reporthome.model.HomeTasksChild
import com.wgmf.yxgj.module.bussiness.reporthome.model.HomeTasksGroup
import com.wgmf.yxgj.module.bussiness.reporthome.service.ReportHomeService
import com.wgmf.yxgj.module.bussiness.reporthome.ui.adapter.HomeBusinessAdapter
import com.wgmf.yxgj.utils.isNotNullOrSize
import com.wgmf.yxgj.widgets.decoration.DividerItemDecoration
import com.xp.arouter.RouterParams

/**
 *  到家业务:（第一页） 到家业务门店列表
 * @author LW
 */
@Route(path = RouterParams.URL_HOME_BUSINESS_ACTIVITY)
class HomeBusinessActivity : BaseParentAct(), HomeBusinessAdapter.OnClickListener {

    private var mPublicListViewRv: RecyclerView? = null

    private var mHomeBusinessAdapter: HomeBusinessAdapter? = null

    private val mHomeBusinessList = mutableListOf<HomeTasksGroup>()

    private val mBranchTitle: String? by lazy {
        intent.getStringExtra("branchTitle")
    }

    lateinit var mLoadWait: LoadWaitDominator

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        setContentView(R.layout.public_list_view)
        initTitle()
        initView()
    }

    override fun initTitle() {
        super.initTitle()
        homeTitleText.text = mBranchTitle
        homeTitleBackLl.visibility = View.VISIBLE
    }

    private fun queryTaskList() {
        userInfo?.let {
            showDialog()
            mLoadWait.show(LoadWaitDominator.LOADING)
            ReportHomeService.instance.requestQueryTaskList(
                it.organizationId,
                it.level,
                this@HomeBusinessActivity
            )
        }
    }

    override fun onResume() {
        super.onResume()
        queryTaskList()
    }

    private fun initView() {
        mLoadWait = LoadWaitDominator(this, findViewById(R.id.public_container_fl))

        mHomeBusinessAdapter = HomeBusinessAdapter(arrayListOf(), this, this)
        findViewById<ListView>(R.id.public_list_view_lv).visibility = View.GONE
        mPublicListViewRv = findViewById<RecyclerView>(R.id.public_list_view_rv).apply {
            visibility = View.VISIBLE
            layoutManager = LinearLayoutManager(mContext, RecyclerView.VERTICAL, false)
            addItemDecoration(
                DividerItemDecoration(
                    DividerItemDecoration.HORIZONTAL_LIST,
                    1,
                    ContextCompat.getColor(mContext, R.color.divider_line_deep)
                )
            )
            adapter = mHomeBusinessAdapter
        }
        mHomeBusinessAdapter?.expandAll()

    }

    override fun onBusinessResultAtMainThread(result: ResultData?) {
        super.onBusinessResultAtMainThread(result)
        dismissDialog()
        mLoadWait.show(LoadWaitDominator.DISMISS)
        result?.let {
            if (it.taskID == BusinessID.HomeReport.MSG_ON_QUERY_TASK_LIST) {
                if (!isFinishing && it.isSuccessed) {
                    val entity = Gson().fromJson(it.info, HomeBusinessEntity::class.java)
                    Log.d(TAG, "HomeBusinessEntity=$entity")
                    if (ConstantParams.CONSTANT_PARAMS_0 == entity.retCode) {
                        val list = entity.resultList
                        if (list.isNotNullOrSize()) {
                            mLoadWait.show(LoadWaitDominator.DISMISS)
                            refreshDataToView(list!!)
                        } else {
                            mLoadWait.show(LoadWaitDominator.NO_DATA)
                        }
                    } else {
                        mLoadWait.show(entity.retInfo)
                    }
                } else {
                    mLoadWait.show(LoadWaitDominator.NET_ERROR)
                }
            }
        }
    }

    private fun refreshDataToView(data: List<HomeBusinessEntity.HomeBusinessList>) {
        mHomeBusinessList.clear()
        data.forEach {
            val group = HomeTasksGroup(it.shopId, it.shopName)
            it.list?.forEach {
                group.addSubItem(
                    HomeTasksChild(
                        group.shopId,
                        group.shopName,
                        it.reportStatus,
                        it.auditStatus,
                        it.taskId,
                        it.taskName
                    )
                )
            }
            mHomeBusinessList.add(group)
        }
        mHomeBusinessAdapter?.setNewData(mHomeBusinessList as List<MultiItemEntity?>?)
    }

    override fun onGroupClick(view: View?, pos: Int, bean: HomeTasksGroup?, expanded: Boolean) {
        if (!expanded) {
            try {
                mPublicListViewRv?.smoothScrollToPosition(pos + 1)
            } catch (e: Exception) {
                e.printStackTrace()
            }
        }
    }

    override fun onChildClick(view: View?, pos: Int, bean: HomeTasksChild?) {
        bean?.let {
            jumpDisplayReportEditActivity(it)
        }
    }

    /**
     * 跳转到 HomeBusinessEditActivity
     */
    private fun jumpDisplayReportEditActivity(tasksChild: HomeTasksChild) {
        val intent = Intent(this, HomeBusinessEditActivity::class.java)
        intent.putExtra("tasksChild", tasksChild)
        intent.putExtra("branchTitle",mBranchTitle)
        startActivity(intent)
    }

}