package com.wgmf.yxgj.module.bussiness.reporthome.ui.adapter

import android.content.Context
import android.view.View
import com.chad.library.adapter.base.BaseMultiItemQuickAdapter
import com.chad.library.adapter.base.BaseViewHolder
import com.chad.library.adapter.base.entity.MultiItemEntity
import com.wgmf.yxgj.module.bussiness.reporthome.R
import com.wgmf.yxgj.module.bussiness.reporthome.model.HomeTasksChild
import com.wgmf.yxgj.module.bussiness.reporthome.model.HomeTasksGroup

/**
 * 到家业务任务列表适配器
 * @author LW
 */
class HomeBusinessAdapter(
    entity: List<MultiItemEntity>,
    private val context: Context,
    private val onClickListener: OnClickListener?
) :
    BaseMultiItemQuickAdapter<MultiItemEntity?, BaseViewHolder?>(entity) {

    companion object {
        const val TYPE_LEVEL_0 = 0
        const val TYPE_LEVEL_1 = 1
    }

    init {
        addItemType(TYPE_LEVEL_0, R.layout.item_report_exlist_group)
        addItemType(TYPE_LEVEL_1, R.layout.item_report_exlist_child)
    }

    override fun convert(holder: BaseViewHolder?, item: MultiItemEntity?) {
        holder?.apply {
            item?.let {
                when (itemViewType) {
                    TYPE_LEVEL_0 -> {
                        val homeTasksGroup: HomeTasksGroup = it as HomeTasksGroup
                        setText(R.id.report_group_type_tv, homeTasksGroup.shopName)
                        setImageResource(
                            R.id.report_group_arrow_iv,
                            if (homeTasksGroup.isExpanded) R.drawable.list_group_open else R.drawable.list_group_close
                        )
                        itemView.setOnClickListener {
                            val pos = adapterPosition
                            val expanded = homeTasksGroup.isExpanded
                            if (homeTasksGroup.isExpanded) {
                                collapse(pos)
                            } else {
                                expand(pos)
                            }
                            onClickListener?.onGroupClick(
                                itemView,
                                pos,
                                homeTasksGroup,
                                expanded
                            )
                        }
                    }
                    TYPE_LEVEL_1 -> {
                        val tasksChild: HomeTasksChild = it as HomeTasksChild
                        val taskStausRemark = taskStatus(context, tasksChild)
                        setText(
                            R.id.report_child_title_tv, tasksChild.taskName
                        ).setText(R.id.report_child_subtitle_tv, taskStausRemark)
                        itemView.setOnClickListener {
                            val pos = adapterPosition
                            onClickListener?.onChildClick(itemView, pos, tasksChild)
                        }
                    }
                    else -> {
                    }
                }
            }
        }
    }

    /**
     * 任务状态
     * auditStatus 审核状态（0：未审核，1：合格，2：不合格）
     * reportStatus  提交状态（0：未提交，1：已提交）
     */
    private fun taskStatus(context: Context, tasksChild: HomeTasksChild): String {
        val resId = if (tasksChild.reportStatus == "1") {  //已提交
            if (tasksChild.auditStatus == "1") {  //合格
                R.string.display_report_qualified
            } else if (tasksChild.auditStatus == "2") { //不合格
                R.string.display_report_failed
            } else {  //待审核
                R.string.display_report_pending_review
            }
        } else { //已提交
            R.string.display_report_unsubmitted
        }
        return context.getString(resId)
    }

    interface OnClickListener {

        fun onGroupClick(view: View?, pos: Int, bean: HomeTasksGroup?, expanded: Boolean)

        fun onChildClick(view: View?, pos: Int, bean: HomeTasksChild?)
    }
}