package com.wgmf.yxgj.module.business.reportibeacon.service;

import android.text.TextUtils;
import android.util.Log;

import com.google.gson.Gson;
import com.wgmf.library.base.BaseRequest;
import com.wgmf.library.base.BaseResponse;
import com.wgmf.library.base.ResultData;
import com.wgmf.library.utils.BaseSingleton;
import com.wgmf.yxgj.base.BaseService;
import com.wgmf.yxgj.config.BusinessID;
import com.wgmf.yxgj.global.NetworkParams;

import java.lang.ref.WeakReference;

/**
 * 作者：XiePing on 2016/5/31 16:27
 * 邮箱：2975837870@qq.com
 */
public class IbeaconService extends BaseService {
    private static BaseSingleton<IbeaconService, Void> mMainService = new BaseSingleton<IbeaconService, Void>() {
        @Override
        protected IbeaconService create(Void var1) {
            return new IbeaconService();
        }
    };

    public static IbeaconService getInstance() {
        return mMainService.get(null);
    }

    private IbeaconService() {
    }

    /**
     * GET /ibeacon/getIbeaconShop 门店ibeacon和上报时间查询
     */
    public void requestGetIbeaconShop(final String code1,
                                      ResultData.BusinessCallback callback) {
        BaseRequest request = new BaseRequest();
        request.taskID = BusinessID.IbeanconReport.MSG_ON_GET_IBEACON_SHOP;
        request.callback = new WeakReference<>(callback);
        request.url = NetworkParams.URL_GET_IBEACON_SHOP + "?"
                + "code1="
                + code1;
        Log.d(TAG, "请求地址：" + request.url);
        sendGetRequest(request);
    }

    /**
     * GET /ibeacon/getIbeacon ibeacon上报查询
     */
    public void requestGetIbeacon(final String shopId,
                                  ResultData.BusinessCallback callback) {
        BaseRequest request = new BaseRequest();
        request.taskID = BusinessID.IbeanconReport.MSG_ON_GET_IBEACON;
        request.callback = new WeakReference<>(callback);
        request.url = NetworkParams.URL_GET_IBEACON + "?"
                + "shopId="
                + shopId;
        Log.d(TAG, "请求地址：" + request.url);
        sendGetRequest(request);
    }

    /**
     * POST /ibeacon/saveIbeacon ibeacon上报
     */
    public void requestSaveIbeacon(final String json,
                                   ResultData.BusinessCallback callback) {
        BaseRequest request = new BaseRequest();
        request.taskID = BusinessID.IbeanconReport.MSG_ON_SAVE_IBEACON;
        request.callback = new WeakReference<>(callback);
        request.url = NetworkParams.URL_SAVE_IBEACON;
        request.json = json;
        Log.d(TAG, "请求地址：" + request.url);
        sendPostJsonRequest(request);
    }

    @Override
    protected void onTaskDone(ResultData data) {
        if (null != data) {
            final int id = data.taskID;
            switch (id) {
                case BusinessID.IbeanconReport.MSG_ON_GET_IBEACON_SHOP:
                case BusinessID.IbeanconReport.MSG_ON_GET_IBEACON:
                case BusinessID.IbeanconReport.MSG_ON_SAVE_IBEACON: {
                    if (data.isSuccessed()) {
                        final String json = data.getInfo();
                        if (!TextUtils.isEmpty(json)) {
                            try {
                                BaseResponse mBaseResponse = new Gson().fromJson(json, BaseResponse.class);

                                Log.d(TAG, "mBaseResponse=" + mBaseResponse.toString());

                                data.setResultCode(mBaseResponse.retCode);
                                data.setResultInfo(mBaseResponse.retInfo);
                            } catch (Exception e) {
                                data.setResultInfo("未知错误！");
                            }
                        }
                    }
                    break;
                }
                default:
                    break;
            }
        }
    }
}