package com.wgmf.yxgj.module.business.reportibeacon.ui;

import android.content.Intent;
import android.os.Bundle;
import android.text.TextUtils;
import android.view.View;
import android.widget.AdapterView;
import android.widget.AdapterView.OnItemClickListener;

import com.alibaba.android.arouter.facade.annotation.Route;
import com.google.gson.Gson;
import com.google.gson.reflect.TypeToken;
import com.wgmf.library.base.ResultData;
import com.wgmf.yxgj.config.BusinessID;
import com.wgmf.yxgj.module.business.reportibeacon.service.IbeaconService;
import com.wgmf.yxgj.publics.model.ShopEntityWithTime;
import com.wgmf.yxgj.publics.service.ToFunctionByResId;
import com.wgmf.yxgj.publics.ui.SelectorBaseActivity;
import com.xp.arouter.RouterParams;

import java.lang.reflect.Type;
import java.util.ArrayList;
import java.util.LinkedList;
import java.util.List;

/**
 * ibeancon上报门店列表
 *
 * @author XiePing
 */
@Route(path = RouterParams.URL_IBEACONREPORTLISTACTIVITY)
public class IbeaconReportListActivity extends SelectorBaseActivity {

    private IbeaconShopListAdapter adapter;
    private List<ShopEntityWithTime> list;
    private List<ShopEntityWithTime> shopEntityWithTimes;
    /**
     * 0，查询1，上报
     */
    private int type;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        queryListData();
    }

    /**
     * 获取评级上报门店等级信息列表
     */
    private void queryListData() {
        if (null != userInfo) {
            showDialog();
            String code1 = userInfo.getOrganizationCode();
            IbeaconService.getInstance().requestGetIbeaconShop(code1, IbeaconReportListActivity.this);
        }
    }

    @Override
    public void initContent() {
        super.initContent();
        Long resId = getIntent().getLongExtra("branchID", 0);
        type = ToFunctionByResId.getType(resId);

        list = new ArrayList<>();
        shopEntityWithTimes = new ArrayList<>();

        adapter = new IbeaconShopListAdapter(this, shopEntityWithTimes);
        mListView.setAdapter(adapter);
        mListView.setOnItemClickListener(new OnItemClickListener() {

            @Override
            public void onItemClick(AdapterView<?> parent, View view,
                                    int position, long id) {
                Intent intent = new Intent();
                intent.putExtra("type", type);
                intent.putExtra("branchTitle", branchTitle);
                intent.putExtra("shopEntityWithTimes", shopEntityWithTimes.get(position));
                intent.setClass(IbeaconReportListActivity.this, IbeaconReportDetailActivity.class);
                startActivity(intent);
            }
        });
    }

    @Override
    public void textChanged() {
        String itemId = storeNameEt.getText().toString().trim();
        if (TextUtils.isEmpty(itemId)) {
            shopEntityWithTimes.clear();
            shopEntityWithTimes.addAll(list);
        } else {
            shopEntityWithTimes.clear();
            if (null != list) {
                for (ShopEntityWithTime p : list) {
                    if (null != p.getShop() && p.getShop().getShopName().contains(itemId)) {
                        shopEntityWithTimes.add(p);
                    }
                }
            }
        }
        adapter.notifyDataSetChanged();
    }

    @Override
    public void search() {
        if (null != shopEntityWithTimes) {
            list.addAll(shopEntityWithTimes);
            adapter.notifyDataSetChanged();
        }
    }

    @Override
    protected void onBusinessResultAtMainThread(ResultData result) {
        super.onBusinessResultAtMainThread(result);
        dismissDialog();
        if (null != result) {
            final int id = result.taskID;
            if (id == BusinessID.IbeanconReport.MSG_ON_GET_IBEACON_SHOP) {
                final String msg = result.getInfo();
                if (result.isSuccessed()) {
                    Type listType = new TypeToken<LinkedList<ShopEntityWithTime>>() {
                    }.getType();
                    ShopEntityWithTime mIbeaconShopEntity;
                    Gson gson = new Gson();
                    LinkedList<ShopEntityWithTime> resources = gson.fromJson(msg,
                            listType);
                    shopEntityWithTimes.clear();
                    for (ShopEntityWithTime resource : resources) {
                        mIbeaconShopEntity = resource;
                        if (null == mIbeaconShopEntity.getAddTime()) {
                            mIbeaconShopEntity.setAddTime();
                        }
                        shopEntityWithTimes.add(mIbeaconShopEntity);
                    }
                    adapter.notifyDataSetChanged();
                    search();
                } else {
                    showMsg(result.getResultInfo());
                }
            }
        }
    }
}