package com.wgmf.yxgj.module.business.reportmodule.service;

import android.text.TextUtils;
import android.util.Log;

import com.google.gson.Gson;
import com.wgmf.library.base.BaseRequest;
import com.wgmf.library.base.BaseResponse;
import com.wgmf.library.base.ResultData;
import com.wgmf.library.global.LocationParams;
import com.wgmf.library.utils.BaseSingleton;
import com.wgmf.yxgj.base.BaseService;
import com.wgmf.yxgj.config.BusinessID;
import com.wgmf.yxgj.global.NetworkParams;

import java.lang.ref.WeakReference;

public class ReportModuleService extends BaseService {
    private static BaseSingleton<ReportModuleService, Void> mMainService = new BaseSingleton<ReportModuleService, Void>() {
        @Override
        protected ReportModuleService create(Void var1) {
            return new ReportModuleService();
        }
    };

    public static ReportModuleService getInstance() {
        return mMainService.get(null);
    }

    private ReportModuleService() {
    }

    /**
     * get /mkt/report/getReportByProject 项目(按项目查或门店下的项目)
     */
    public void requestGetReportByProject(final String orgCode, final String reportName, final String flag, ResultData.BusinessCallback callback) {
        BaseRequest request = new BaseRequest();
        request.taskID = BusinessID.ModuleReport.MSG_ON_GET_REPORT_BY_PROJECT;
        request.callback = new WeakReference<>(callback);
        request.url = NetworkParams.URL_GET_REPORT_BY_PROJECT + "?" + "orgCode=" + orgCode + "&reportName=" + reportName
                + "&flag=" + flag+ "&lng=" + LocationParams.Longitude+ "&lat=" + LocationParams.Latitude;
        Log.d(TAG, "请求地址：" + request.url);
        sendGetRequest(request);
    }

    /**
     * get /mkt/report/getReportByShop 门店(按门店查或项目下的门店)
     */
    public void requestGetReportByShop(final String orgCode, final String shopName, final String flag, ResultData.BusinessCallback callback) {
        BaseRequest request = new BaseRequest();
        request.taskID = BusinessID.ModuleReport.MSG_ON_GET_REPORT_BY_SHOP;
        request.callback = new WeakReference<>(callback);
        request.url = NetworkParams.URL_GET_REPORT_BY_SHOP + "?" + "orgCode=" + orgCode + "&shopName=" + shopName
                + "&flag=" + flag+ "&lng=" + LocationParams.Longitude+ "&lat=" + LocationParams.Latitude;
        Log.d(TAG, "请求地址：" + request.url);
        sendGetRequest(request);
    }

    /**
     * get /mkt/report/getReportStandardModel 获取上报标准配置model
     */
    public void requestGetReportStandardModel(final String standardId, final String shopId, ResultData.BusinessCallback callback) {
        BaseRequest request = new BaseRequest();
        request.taskID = BusinessID.ModuleReport.MSG_ON_GET_REPORT_STANDARD_MODEL;
        request.callback = new WeakReference<>(callback);
        request.url = NetworkParams.URL_GET_REPORT_STANDARD_MODEL + "?" + "standardId=" + standardId + "&shopId=" + shopId;
        Log.d(TAG, "请求地址：" + request.url);
        sendGetRequest(request);
    }

    /**
     * POST /reportmodule/saveModuleReport 保存专项配置上报
     */
    public void requestSaveModuleReport(final String json, ResultData.BusinessCallback callback) {
        BaseRequest request = new BaseRequest();
        request.taskID = BusinessID.ModuleReport.MSG_ON_SAVE_MODULE_REPORT;
        request.callback = new WeakReference<>(callback);
        request.url = NetworkParams.URL_SAVE_REPORT_STANDARD_DETAIL;
        request.json = json;
        Log.d(TAG, "请求地址：" + request.url);
        sendPostJsonRequest(request);
    }

    @Override
    protected void onTaskDone(ResultData data) {
        if (null != data) {
            final int id = data.taskID;
            switch (id) {
                case BusinessID.ModuleReport.MSG_ON_GET_REPORT_BY_PROJECT:
                case BusinessID.ModuleReport.MSG_ON_GET_REPORT_BY_SHOP:
                case BusinessID.ModuleReport.MSG_ON_GET_REPORT_STANDARD_MODEL:
                case BusinessID.ModuleReport.MSG_ON_SAVE_MODULE_REPORT: {
                    if (data.isSuccessed()) {
                        final String json = data.getInfo();
                        if (!TextUtils.isEmpty(json)) {
                            BaseResponse mBaseResponse = new Gson().fromJson(json, BaseResponse.class);
                            Log.d(TAG, "id:" + id + ";mBaseResponse=" + mBaseResponse.toString());
                            data.setResultCode(mBaseResponse.retCode);
                            data.setResultInfo(mBaseResponse.retInfo);
                        }
                    }
                    break;
                }
                default:
                    break;
            }
        }
    }
}