package com.wgmf.yxgj.module.business.reportmodule.ui.level2list;

import android.content.Intent;
import android.os.Bundle;
import android.text.Editable;
import android.text.TextUtils;
import android.text.TextWatcher;
import android.util.Log;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.ListView;
import android.widget.TextView;

import com.google.gson.Gson;
import com.wgmf.library.base.ResultData;
import com.wgmf.yxgj.base.BaseBackHandledFragment;
import com.wgmf.yxgj.config.BusinessID;
import com.wgmf.yxgj.global.ConstantParams;
import com.wgmf.yxgj.module.business.reportmodule.R;
import com.wgmf.yxgj.module.business.reportmodule.model.ReportProjectListResultEntity;
import com.wgmf.yxgj.module.business.reportmodule.model.ReportShopListEntity;
import com.wgmf.yxgj.module.business.reportmodule.service.ReportModuleService;
import com.wgmf.yxgj.module.business.reportmodule.service.ReportStaticData;
import com.wgmf.yxgj.module.business.reportmodule.ui.ReportModuleDetailActivity;
import com.wgmf.yxgj.widgets.EditText.ClearEditText;

import org.jetbrains.annotations.NotNull;

import java.util.ArrayList;
import java.util.List;

public class ReportModuleShopListFragment2 extends BaseBackHandledFragment implements ReportModuleShopListAdapter2.ClickListener {
    private ClearEditText storeNameEt;
    private ListView mListView;
    private ReportModuleShopListAdapter2 reportModuleShopListAdapter;
    private List<ReportShopListEntity> reportShopListEntities;
    private List<ReportShopListEntity> reportShopListEntitiesShow;

    private int position;
    private Long branchID;

    @Override
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        position = getArguments().getInt("position", 0);
        branchID = getArguments().getLong("branchID", 0);
    }

    @Override
    public void onResume() {
        super.onResume();
        getData();
    }

    private void getData() {
        //查询最新的数据，拿第二层列表内容
        if (null != userInfo) {
            showDialog();
            ReportModuleService.getInstance().requestGetReportByProject(userInfo.getOrganizationCode(), "", ReportStaticData.getFlag(branchID), this);
        }
    }

    @Override
    public View onCreateView(@NotNull LayoutInflater inflater, ViewGroup container, Bundle savedInstanceState) {
        View view = inflater.inflate(R.layout.fragment_report_module_project_list, container, false);
        // 防止点击穿透，底层的fragment响应上层点击触摸事件
        view.setClickable(true);
        initView(view);
        return view;
    }

    private void initView(View view) {
        mListView = (ListView) view.findViewById(R.id.public_list_view_lv);
        storeNameEt = (ClearEditText) view.findViewById(R.id.store_name_et);
        TextView dataEmpty = (TextView) view.findViewById(R.id.public_list_view_empty_tv);
        mListView.setEmptyView(dataEmpty);
        mListView.setVisibility(View.VISIBLE);
        storeNameEt.setVisibility(View.VISIBLE);
        storeNameEt.setHint(getString(R.string.report_module_by_shop_search));
        setListener();
    }

    protected void setListener() {
        storeNameEt.addTextChangedListener(new TextWatcher() {

            @Override
            public void onTextChanged(CharSequence s, int start, int before,
                                      int count) {
            }

            @Override
            public void beforeTextChanged(CharSequence s, int start, int count,
                                          int after) {
            }

            @Override
            public void afterTextChanged(Editable s) {
                textChanged();
            }
        });
    }

    public void textChanged() {
        if (null == reportShopListEntitiesShow) {
            reportShopListEntitiesShow = new ArrayList<>();
        }
        String itemId = storeNameEt.getText().toString().trim();
        if (TextUtils.isEmpty(itemId)) {
            reportShopListEntitiesShow.clear();
            if (null != reportShopListEntities) {
                reportShopListEntitiesShow.addAll(reportShopListEntities);
            }

        } else {
            reportShopListEntitiesShow.clear();
            if (null != reportShopListEntities) {
                for (ReportShopListEntity p : reportShopListEntities) {
                    if (null != p.getShopName()) {
                        if (p.getShopName().contains(itemId)) {
                            reportShopListEntitiesShow.add(p);
                        }
                    }
                }
            }
        }
        reportModuleShopListAdapter = new ReportModuleShopListAdapter2(getActivity(), this, reportShopListEntitiesShow);
        mListView.setAdapter(reportModuleShopListAdapter);
    }

    @Override
    public boolean onBackPressed() {
        return false;
    }

    @Override
    protected void onBusinessResultAtMainThread(ResultData result) {
        super.onBusinessResultAtMainThread(result);
        dismissDialog();
        if (null != result) {
            final int id = result.taskID;
            if (id == BusinessID.ModuleReport.MSG_ON_GET_REPORT_BY_PROJECT) {
                final String msg = result.getInfo();
                if (result.isSuccessed()) {
                    ReportProjectListResultEntity reportModuleProjectListResultEntity = new Gson().fromJson(msg, ReportProjectListResultEntity.class);
                    Log.d(TAG, "reportModuleProjectListResultEntity" + reportModuleProjectListResultEntity);
                    if (null != reportModuleProjectListResultEntity && null != reportModuleProjectListResultEntity.getResult() && ConstantParams.CONSTANT_PARAMS_0.equals(reportModuleProjectListResultEntity.retCode)) {
                        reportShopListEntities = reportModuleProjectListResultEntity.getResult().get(position).getReportShopList();
                        reportModuleShopListAdapter = new ReportModuleShopListAdapter2(getActivity(), this, reportShopListEntities);
                        mListView.setAdapter(reportModuleShopListAdapter);
                    }
                }
            }
        }
    }

    @Override
    public void menberDayAdapterClick(ReportShopListEntity reportShopListEntity) {        //updateFlag (string, optional):修改标识：1/不可修改，0/可修改
        // 状态为不可修改时，点击不能进入详情页；状态为可修改时，可进入详情页提交数据。
        if(1 == reportShopListEntity.getUpdateFlag()) {
            showMsg(reportShopListEntity.getStatusStr()+",不可修改!");
        }else {
            Long branchID = getArguments().getLong("branchID", 0);
            Intent intent = new Intent(getActivity(), ReportModuleDetailActivity.class);
            intent.putExtra("standardId", reportShopListEntity.getStandardId());
            intent.putExtra("shopId", reportShopListEntity.getShopId());
            intent.putExtra("shopName", reportShopListEntity.getShopName());
            intent.putExtra("branchID", branchID);
            startActivity(intent);
        }
    }
}