package com.wgmf.yxgj.module.business.reportmonthly.service;

import android.text.TextUtils;
import android.util.Log;

import com.google.gson.Gson;
import com.wgmf.library.base.BaseRequest;
import com.wgmf.library.base.BaseResponse;
import com.wgmf.library.base.ResultData;
import com.wgmf.library.utils.BaseSingleton;
import com.wgmf.yxgj.base.BaseService;
import com.wgmf.yxgj.config.BusinessID;
import com.wgmf.yxgj.global.NetworkParams;

import java.lang.ref.WeakReference;

/**
 * 月计划与总结网络请求封装
 *
 * @author XiePing
 * 2016/6/24 11:32
 */
public class MonthlyReportService extends BaseService {
    private static BaseSingleton<MonthlyReportService, Void> mMainService = new BaseSingleton<MonthlyReportService, Void>() {
        @Override
        protected MonthlyReportService create(Void var1) {
            return new MonthlyReportService();
        }
    };

    public static MonthlyReportService getInstance() {
        return mMainService.get(null);
    }

    private MonthlyReportService() {
    }

    /**
     * 获取全面绩效
     */
    public void requestTotalPerfomance(final String month, final String organizationCode, final String url,
                                       ResultData.BusinessCallback callback) {
        BaseRequest request = new BaseRequest();
        request.taskID = BusinessID.MonthlyWeekReport.MSG_ON_TOTAL_PERFOMANCE;
        request.callback = new WeakReference<>(callback);
        request.url = url + "?" + "month=" + month
                + "&organizationCode=" + organizationCode;
        Log.d(TAG, "请求地址：" + request.url);
        sendGetRequest(request);
    }
    /**
     * 新增月报前查询
     * GET /monthlyWeekReport/getPerformaceMonthlyReport
     */
    public void requestMonthlyReport(final String yearMonth, final String staffId, final String code,
                                     ResultData.BusinessCallback callback) {
        BaseRequest request = new BaseRequest();
        request.taskID = BusinessID.MonthlyWeekReport.MSG_ON_GETPERFORMACE_MONTHLYREPORT;
        request.callback = new WeakReference<>(callback);
        request.url = NetworkParams.URL_GETPERFORMACE_MONTHLYREPORT + "?"
                + "yearMonth="
                + yearMonth
                + "&staffId="
                + staffId
                + "&code="
                + code;
        Log.d(TAG, "请求地址：" + request.url);
        sendGetRequest(request);
    }

    /**
     * 新增/修改月报总结
     * POST /monthlyWeekReport/saveMonthlyReportSummaly
     */
    public void requestsaveMonthlyReportSummaly(final String json, ResultData.BusinessCallback callback) {
        BaseRequest request = new BaseRequest();
        request.taskID = BusinessID.MonthlyWeekReport.MSG_ON_SAVE_MONTHLYREPORT_SUMMALY;
        request.callback = new WeakReference<>(callback);
        request.url = NetworkParams.URL_SAVE_MONTHLYREPORT_SUMMALY;
        request.json = json;
        Log.d(TAG, "请求地址：" + request.url);
        sendPostJsonRequest(request);
    }

    /**
     * 新增/修改月报
     * POST /monthlyWeekReport/saveMonthlyReport
     */
    public void requestsaveMonthlyReport(final String json, ResultData.BusinessCallback callback) {
        BaseRequest request = new BaseRequest();
        request.taskID = BusinessID.MonthlyWeekReport.MSG_ON_SAVE_MONTHLYREPORT;
        request.callback = new WeakReference<>(callback);
        request.url = NetworkParams.URL_SAVE_MONTHLYREPORT;
        request.json = json;
        Log.d(TAG, "请求地址：" + request.url);
        sendPostJsonRequest(request);
    }

    /**
     * GET /monthlyWeekReport/queryUserInfo 月报周报下级人员信息查询
     */
    public void requestQueryUserInfo(final String staffId, final String roleStatus,
                                     ResultData.BusinessCallback callback) {
        BaseRequest request = new BaseRequest();
        request.taskID = BusinessID.MonthlyWeekReport.MSG_ON_QUERY_USERINFO;
        request.callback = new WeakReference<>(callback);
        request.url = NetworkParams.URL_QUERY_USERINFO + "?"
                + "&staffId="
                + staffId
                + "&roleStatus="
                + roleStatus;
        Log.d(TAG, "请求地址：" + request.url);
        sendGetRequest(request);
    }

    /**
     * 批复
     * POST /monthlyWeekReport/appriaseMonthlyReport
     */
    public void requestAppriaseMonthlyReport(final String json,
                                             ResultData.BusinessCallback callback) {
        BaseRequest request = new BaseRequest();
        request.taskID = BusinessID.MonthlyWeekReport.MSG_ON_APPRIASE_MONTHLYREPORT;
        request.callback = new WeakReference<>(callback);
        request.url = NetworkParams.URL_APPRIASE_MONTHLYREPORT;
        request.json = json;
        Log.d(TAG, "请求地址：" + request.url);
        sendPostJsonRequest(request);
    }

    @Override
    protected void onTaskDone(ResultData data) {
        if (null != data) {
            final int id = data.taskID;
            switch (id) {
                case BusinessID.MonthlyWeekReport.MSG_ON_TOTAL_PERFOMANCE:
                case BusinessID.MonthlyWeekReport.MSG_ON_QUERY_USERINFO:
                case BusinessID.MonthlyWeekReport.MSG_ON_GETPERFORMACE_MONTHLYREPORT:
                case BusinessID.MonthlyWeekReport.MSG_ON_SAVE_MONTHLYREPORT_SUMMALY:
                case BusinessID.MonthlyWeekReport.MSG_ON_SAVE_MONTHLYREPORT:
                case BusinessID.MonthlyWeekReport.MSG_ON_APPRIASE_MONTHLYREPORT: {
                    if (data.isSuccessed()) {
                        final String json = data.getInfo();
                        if (!TextUtils.isEmpty(json)) {
                            BaseResponse mBaseResponse = new Gson().fromJson(json, BaseResponse.class);
                            Log.d(TAG, "id:" + id + ";mBaseResponse=" + mBaseResponse.toString());
                            data.setResultCode(mBaseResponse.retCode);
                            data.setResultInfo(mBaseResponse.retInfo);
                        }
                    }
                    break;
                }
                default:
                    break;
            }
        }
    }
}