package com.wgmf.yxgj.module.business.reportproblem.ui

import android.content.Intent
import android.os.Bundle
import android.support.v4.content.ContextCompat
import android.support.v7.widget.LinearLayoutManager
import android.support.v7.widget.RecyclerView
import android.view.View
import android.view.ViewGroup
import android.widget.ListView
import android.widget.RadioButton
import android.widget.TextView
import com.wgmf.yxgj.base.BaseParentAct
import com.wgmf.yxgj.dialog.LoadWaitDominator
import com.wgmf.yxgj.global.AppConstants
import com.wgmf.yxgj.global.ConstantParams
import com.wgmf.yxgj.module.business.reportproblem.R
import com.wgmf.yxgj.module.business.reportproblem.model.DispatchProductEntity
import com.wgmf.yxgj.module.business.reportproblem.ui.adapter.DispatchBillChooseAdapter
import com.wgmf.yxgj.module.business.reportproblem.ui.adapter.DispatchBillProductChooseAdapter
import com.wgmf.yxgj.utils.isNotNullOrSize
import com.wgmf.yxgj.widgets.decoration.DividerItemDecoration

/**
 * 到货误差 选择波次号/产品
 */
class DispatchProductChooseActivity : BaseParentAct() {

    lateinit var mLoadWait: LoadWaitDominator

    private var mDispatchBillChooseAdapter: DispatchBillChooseAdapter? = null

    private var mDispatchBillProductChooseAdapter: DispatchBillProductChooseAdapter? = null

    private var mDispatchProductList =
        mutableListOf<DispatchProductEntity.DispatchProductBean>()

    private var mDispatchDetailList =
        mutableListOf<DispatchProductEntity.DispatchProductBean.DispatchDetailBean>()


    private val mDispatchProductEntity: DispatchProductEntity? by lazy {
        intent.getSerializableExtra(AppConstants.ExtraKeys.DISPATCH_PRODUCT_DATA) as DispatchProductEntity?
    }

    private val mDispatchProductPos: Int by lazy {
        intent.getIntExtra(AppConstants.ExtraKeys.DISPATCH_PRODUCT_POS, -1)
    }

    private val mDispathProductType: String by lazy {
        intent.getStringExtra(AppConstants.ExtraKeys.DISPATCH_PRODUCT_TYPE)
    }

    private var mCurrentPos: Int = -1

    companion object {
        const val DELIVERY_BILL: String = "DELIVERY_BILL"

        const val DELIVERY_BILL_PRODUCT: String = "DELIVERY_BILL_PRODUCT"
    }

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        setContentView(R.layout.public_list_view)
        initTitle()
        initView()
    }

    override fun initTitle() {
        super.initTitle()
        if (mDispathProductType == DELIVERY_BILL) {
            homeTitleText.text = getString(R.string.problem_escalation_chose_delivery_bill)
        } else if (mDispathProductType == DELIVERY_BILL_PRODUCT) {
            homeTitleText.text = getString(R.string.choose_product)
        }
        homeTitleBackLl.visibility = View.VISIBLE

        if (mDispathProductType == DELIVERY_BILL_PRODUCT) {
            homeTitleMoreLl.visibility = View.VISIBLE
            homeTitleMore.text = getString(R.string.confirm_btn_txt)
        }
    }

    private fun initView() {
        mLoadWait = LoadWaitDominator(this, findViewById(R.id.public_container_fl))

        findViewById<ListView>(R.id.public_list_view_lv).visibility = View.GONE
        val publicListViewRy = findViewById<RecyclerView>(R.id.public_list_view_rv).apply {
            visibility = View.VISIBLE
        }

        mCurrentPos = mDispatchProductPos
        mLoadWait.show(LoadWaitDominator.DISMISS)
        if (mDispathProductType == DELIVERY_BILL) {
            mDispatchProductList = mDispatchProductEntity?.resultInfo?.toMutableList()
                ?: mutableListOf()
            if (mDispatchProductList.isNotNullOrSize()) {
                mDispatchBillChooseAdapter =
                    DispatchBillChooseAdapter(
                        mContext,
                        mDispatchProductPos,
                        mDispatchProductList
                    ).apply {
                        setOnItemClickListener { _, _, position ->
                            if (mDispatchProductPos >= 0) {
                                mDispatchProductEntity?.resultInfo?.get(mDispatchProductPos)
                                    ?.dispatchDetailList?.forEach {
                                        it.chooseStatus = false
                                    }
                            }

                            mCurrentPos = position
                            choseItemJumpLogic()
                        }
                    }
            } else {
                mLoadWait.show(LoadWaitDominator.NO_DATA)
            }
        } else if (mDispathProductType == DELIVERY_BILL_PRODUCT) {
            var dispatchProductBean: DispatchProductEntity.DispatchProductBean? = null

            mDispatchDetailList = if (mDispatchProductPos >= 0) {
                dispatchProductBean = mDispatchProductEntity?.resultInfo?.get(mDispatchProductPos)
                dispatchProductBean?.dispatchDetailList?.toMutableList()
                    ?: mutableListOf()
            } else {
                mutableListOf()
            }
            if (mDispatchDetailList.isNotNullOrSize()) {
                val deliveryBillChooseView =
                    layoutInflater.inflate(
                        R.layout.item_delivery_bill_choose,
                        publicListViewRy.getParent() as ViewGroup,
                        false
                    ).apply {
                        findViewById<RadioButton>(R.id.select_item_radio).visibility = View.GONE

                        findViewById<TextView>(R.id.delivery_bill).text =
                            mContext.getString(
                                R.string.problem_escalation_delivery_bill,
                                dispatchProductBean?.waveNo
                            )

                        findViewById<TextView>(R.id.delivery_date).text =
                            mContext.getString(
                                R.string.problem_escalation_delivery_date,
                                dispatchProductBean?.dispatchDate
                            )

                        findViewById<TextView>(R.id.delivery_total_amount).text =
                            mContext.getString(
                                R.string.problem_escalation_total_amount,
                                dispatchProductBean?.allProSumAmount
                            )

                        findViewById<TextView>(R.id.delivery_total_number).text =
                            mContext.getString(
                                R.string.problem_escalation_total_number,
                                dispatchProductBean?.allProSumQty
                            )
                    }
                mDispatchBillProductChooseAdapter =
                    DispatchBillProductChooseAdapter(mContext, mDispatchDetailList).apply {
                        setOnItemClickListener { baseQuickAdapter, view, position ->
                            val dispatchDetailBean =
                                baseQuickAdapter.getItem(position) as DispatchProductEntity.DispatchProductBean.DispatchDetailBean
                            dispatchDetailBean.chooseStatus = !dispatchDetailBean.chooseStatus
                            baseQuickAdapter.notifyDataSetChanged()
                        }
                    }
                mDispatchBillProductChooseAdapter?.addHeaderView(deliveryBillChooseView)
            } else {
                mLoadWait.show(mContext.getString(R.string.choose_product_emtry_tip))
            }
        }

        publicListViewRy.apply {
            layoutManager = LinearLayoutManager(mContext, RecyclerView.VERTICAL, false)
            addItemDecoration(
                DividerItemDecoration(
                    DividerItemDecoration.HORIZONTAL_LIST,
                    1,
                    ContextCompat.getColor(mContext, R.color.divider_line_deep)
                )
            )
            if (mDispathProductType == DELIVERY_BILL) {
                adapter = mDispatchBillChooseAdapter
            } else if (mDispathProductType == DELIVERY_BILL_PRODUCT) {
                adapter = mDispatchBillProductChooseAdapter
            }
        }

    }

    override fun more() {
        choseItemJumpLogic()
    }

    /**
     * 选择列表逻辑处理
     */
    private fun choseItemJumpLogic() {
        setResult(ConstantParams.CONSTANT_STARTS_1, Intent().apply {
            putExtra(
                AppConstants.ExtraKeys.DISPATCH_PRODUCT_DATA,
                mDispatchProductEntity
            )
            putExtra(
                AppConstants.ExtraKeys.DISPATCH_PRODUCT_POS,
                mCurrentPos
            )
            putExtra(
                AppConstants.ExtraKeys.DISPATCH_PRODUCT_TYPE,
                mDispathProductType
            )
        })
        this.finish()
    }
}