package com.wgmf.yxgj.module.business.reportproblem.ui;

import android.content.Intent;
import android.os.Bundle;
import android.text.TextUtils;
import android.util.Log;
import android.view.View;
import android.widget.AdapterView;
import android.widget.AdapterView.OnItemClickListener;

import com.google.gson.Gson;
import com.wgmf.library.base.ResultData;
import com.wgmf.yxgj.config.BusinessID;
import com.wgmf.yxgj.global.ConstantParams;
import com.wgmf.yxgj.global.NetworkParams;
import com.wgmf.yxgj.module.business.reportproblem.R;
import com.wgmf.yxgj.module.business.reportproblem.model.ProductListEntity;
import com.wgmf.yxgj.module.business.reportproblem.model.ReportResultEntity;
import com.wgmf.yxgj.module.business.reportproblem.service.ReportFeedbackService;
import com.wgmf.yxgj.module.business.reportproblem.ui.adapter.SelectorProductsAdapter;
import com.wgmf.yxgj.publics.ui.SelectorBaseActivity;

import org.greenrobot.eventbus.EventBus;
import org.greenrobot.eventbus.Subscribe;

import java.util.ArrayList;
import java.util.List;

/**
 * 反馈直通车：查询产品列表
 */
public class SelectorProductsActivity extends SelectorBaseActivity {
    /**
     * 选择成功后返回的code
     */
    public static final String activityResultData = "activityResultData";
    private List<ProductListEntity> productListShow = new ArrayList<>();
    private List<ProductListEntity> productList = new ArrayList<>();
    private SelectorProductsAdapter adapter;
    private String storeNo;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
    }

    @Override
    public void initTitle() {
        super.initTitle();
        homeTitleText.setText("选择产品");
        storeNo = getIntent().getStringExtra("storeid");
    }

    @Override
    public void initContent() {
        super.initContent();
        EventBus.getDefault().register(this);
        storeNameEt.setHint(R.string.search_product_hint_txt);
        adapter = new SelectorProductsAdapter(this, productListShow);
        mListView.setAdapter(adapter);
        mListView.setOnItemClickListener(new OnItemClickListener() {

            @Override
            public void onItemClick(AdapterView<?> parent, View view,
                                    int position, long id) {
                Intent intent = new Intent();
                intent.putExtra(activityResultData, productListShow.get(position));
                setResult(RESULTCODE, intent);
                SelectorProductsActivity.this.finish();
            }
        });
        search();
    }

    @Override
    public void search() {
        showDialog();
        ReportFeedbackService.getInstance().requestReportProblemProductList(NetworkParams.URL_PRODUCT_LIST, storeNo, SelectorProductsActivity.this);
    }

    /**
     * 接收到事件后更新详情
     */
    @Subscribe
    public void onEventMainThread(ReportResultEntity item) {
        if (null != item) {
            productList.addAll(item.getProduct());
            productListShow.addAll(productList);
            adapter.notifyDataSetChanged();
        }
    }

    @Override
    protected void onBusinessResultAtMainThread(ResultData result) {
        super.onBusinessResultAtMainThread(result);
        dismissDialog();
        if (null != result) {
            final int id = result.taskID;
            switch (id) {
                case BusinessID.ReportFeedback.MSG_ON_QUESTION_GET_SELECTLIST: {
                    final String msg = result.getInfo();
                    if (result.isSuccessed()) {
                        try {
                            ReportResultEntity mReportResultBean = new Gson().fromJson(msg,
                                    ReportResultEntity.class);
                            // 存入数据库
                            if (null != mReportResultBean) {
                                Log.d(TAG, "mReportResultBean=" + mReportResultBean.toString());
                                if (!ConstantParams.CONSTANT_PARAMS_0.equals(mReportResultBean.retCode)) {
                                    showMsg(getString(R.string.request_data_fail));
                                } else {
                                    EventBus.getDefault().post(mReportResultBean);
                                }
                            }
                        } catch (Exception e) {
                            showMsg(getString(R.string.request_data_fail));
                        }
                    } else {
                        if (!TextUtils.isEmpty(msg)) {
                            showMsg(result.getResultInfo());
                        }
                    }
                }
                break;
                default:
                    break;
            }
        }
    }

    @Override
    public void textChanged() {
        String itemId = storeNameEt.getText().toString().trim();
        if (TextUtils.isEmpty(itemId)) {
            productListShow.clear();
            productListShow.addAll(productList);
        } else {
            productListShow.clear();
            if (null != mListStore) {
                for (ProductListEntity p : productList) {
                    if (null != p.getName()) {
                        if (p.getName().contains(itemId)) {
                            productListShow.add(p);
                        }
                    }
                }
            }
        }
        adapter.notifyDataSetChanged();
    }

    @Override
    public void onDestroy() {
        super.onDestroy();
        EventBus.getDefault().unregister(this);
    }
}