package com.wgmf.yxgj.module.business.reportproblem.ui.fragment

import android.os.Bundle
import android.view.LayoutInflater
import android.view.View
import android.widget.CheckBox
import android.widget.EditText
import android.widget.LinearLayout
import android.widget.TextView
import com.github.yoojia.inputs.AndroidNextInputs
import com.github.yoojia.inputs.StaticScheme
import com.wgmf.library.base.ResultData
import com.wgmf.yxgj.base.BaseParentFra
import com.wgmf.yxgj.module.business.reportproblem.R
import com.wgmf.yxgj.module.business.reportproblem.model.LogisticsDelivery
import com.wgmf.yxgj.module.business.reportproblem.model.LogisticsDeliveryEntity
import com.wgmf.yxgj.module.business.reportproblem.model.LogisticsDeliveryProblemEntity
import com.wgmf.yxgj.module.business.reportproblem.ui.DispatchProblemsContract
import com.wgmf.yxgj.utils.AddressPickerDominator
import com.wgmf.yxgj.utils.helper.DialogHelper
import com.wgmf.yxgj.widgets.MMessageDisplay
import com.wgmf.yxgj.widgets.flowlayout.FlowLayout
import com.wgmf.yxgj.widgets.flowlayout.TagAdapter
import kotlinx.android.synthetic.main.include_qback_report_complaint_show.*
import kotlinx.android.synthetic.main.include_qback_report_receipt_show.*
import kotlinx.android.synthetic.main.include_qback_report_user_phone_show.*
import java.util.*

/**
 * 物流派送问题投诉
 * @author LW
 */
class LogisticsDeliveryFragment : BaseParentFra(), View.OnClickListener,
    DispatchProblemsContract.IView {

    private var mReportStore: TextView? = null

    private var mReportEdit: EditText? = null

    private var mTitleLayout: LinearLayout? = null

    private var mShopId: String = ""

    private var mAddressPickerDominator: AddressPickerDominator? = null

    private var mLogisticsDeliveryProblemList: MutableList<LogisticsDeliveryProblemEntity> =
        mutableListOf()

    override fun rootLayoutId(): Int = R.layout.fragment_logistics_delivery

    override fun onViewCreated(view: View, savedInstanceState: Bundle?) {
        super.onViewCreated(view, savedInstanceState)

        activity?.apply {
            mReportStore = findViewById(R.id.report_store)
            mReportEdit = findViewById(R.id.report_edit)
            mTitleLayout = findViewById(R.id.title)
        }

        userInfo?.let {
            problems_user.setText(it.name)
        }

        initComplaintProblemType()
    }

    /**
     * 初始化物流派送问题投诉反馈
     */
    private fun initComplaintProblemType() {
        val complaintProblemTypeLists =
            Arrays.asList(*resources.getStringArray(R.array.complaintProblemType))
        val inflater = LayoutInflater.from(mContext)
        tfl_flow_layout.setAdapter(object : TagAdapter<String>(complaintProblemTypeLists) {
            override fun getView(parent: FlowLayout, position: Int, s: String?): View {
                val checkBox = inflater.inflate(
                    R.layout.view_complaint_problem_type,
                    tfl_flow_layout, false
                ) as CheckBox
                checkBox.text = s
                return checkBox
            }
        })
        tfl_flow_layout.setOnSelectListener { selectPosSet ->
            mLogisticsDeliveryProblemList.clear()
            if (selectPosSet != null) {
                for (select in selectPosSet) {
                    mLogisticsDeliveryProblemList.add(LogisticsDeliveryProblemEntity((select + 1).toString()))
                }
            }
        }
        activity?.let {
            mAddressPickerDominator = AddressPickerDominator(
                mContext,
                it.window.decorView
            ) { dominator: AddressPickerDominator ->
                if (dominator.province != null && dominator.city != null && dominator.district != null) {
                    val sb = StringBuilder()
                    sb.append(dominator.province?.regionName)
                    sb.append(dominator.city?.regionName)
                    sb.append(dominator.district?.regionName)
                    tv_receipt_city_show.text = sb.toString()
                }
            }
        }
        tv_receipt_date_show.setOnClickListener(this)
        tv_receipt_city_show.setOnClickListener(this)

    }

    override fun onBusinessResultAtMainThread(result: ResultData?) {
        super.onBusinessResultAtMainThread(result)
    }

    override fun ruleCheckDataIntegrity(): Boolean {
        val inputs = AndroidNextInputs()
        inputs.add(mReportStore, StaticScheme.Required())
        inputs.add(problems_user, StaticScheme.Required())
        inputs.add(problems_phone, StaticScheme.Required(), StaticScheme.ChineseMobile())
        inputs.add(tv_receipt_date_show, StaticScheme.Required())
        inputs.add(tv_receipt_city_show, StaticScheme.Required())
        inputs.add(mReportEdit, StaticScheme.Required())

        val messageDisplay = MMessageDisplay()
        inputs.setMessageDisplay(messageDisplay)

        return if (inputs.test()) {
            // 校验通过
            inputs.clear()
            true
        } else {
            showMsg("填写有误，请检查")
            inputs.clear()
            false
        }
    }

    override fun logisticsDeliveryEntityData(
        shopName: String,
        shopId: String,
        staffId: String?
    ): LogisticsDelivery {
        val describe: String = mReportEdit?.text.toString()
        val phone: String = problems_phone.text.toString()
        val receiptTime: String = tv_receipt_date_show.text.toString()
        val userName: String = problems_user.text.toString()
        val logisticsDelivery = LogisticsDeliveryEntity(
            mAddressPickerDominator?.city?.regionName,
            describe,
            "1",
            phone,
            mAddressPickerDominator?.province?.regionName,
            receiptTime,
            mAddressPickerDominator?.district?.regionName,
            shopId,
            shopName,
            staffId,
            userName
        )
        return LogisticsDelivery(logisticsDelivery, mLogisticsDeliveryProblemList)
    }

    override fun setShopId(shopId: String) {
        this.mShopId = shopId
    }

    override fun getLogisticsDeliveryProblemList(): MutableList<LogisticsDeliveryProblemEntity> {
        return mLogisticsDeliveryProblemList
    }

    override fun onClick(v: View?) {
        when (v?.id) {
            R.id.tv_receipt_date_show -> {
                DialogHelper.AlertDatePicker(mContext, this, tv_receipt_date_show)
            }
            R.id.tv_receipt_city_show -> {
                selectorCity()
            }
        }
    }

    /**
     * 选择城市
     */
    private fun selectorCity() {
        mAddressPickerDominator?.show()
    }

    override fun onDestroy() {
        super.onDestroy()

        mAddressPickerDominator?.dismiss()
        mAddressPickerDominator = null
    }

}