package com.wgmf.yxgj.module.business.reportrating.service;

import android.text.TextUtils;
import android.util.Log;

import com.google.gson.Gson;
import com.wgmf.library.base.BaseRequest;
import com.wgmf.library.base.BaseResponse;
import com.wgmf.library.base.ResultData;
import com.wgmf.library.utils.BaseSingleton;
import com.wgmf.yxgj.base.BaseService;
import com.wgmf.yxgj.config.BusinessID;
import com.wgmf.yxgj.global.ConstantParams;
import com.wgmf.yxgj.global.NetworkParams;

import java.lang.ref.WeakReference;

/**
 * 作者：XiePing on 2016/5/31 16:31
 * 邮箱：2975837870@qq.com
 */
public class RatingsService extends BaseService {
    private static BaseSingleton<RatingsService, Void> mMainService = new BaseSingleton<RatingsService, Void>() {
        @Override
        protected RatingsService create(Void var1) {
            return new RatingsService();
        }
    };

    public static RatingsService getInstance() {
        return mMainService.get(null);
    }

    private RatingsService() {
    }

    /**
     * 评级上报门店等级列表查询
     */
    public void requestQueryRatings(final String saleOrgId,
                                    ResultData.BusinessCallback callback) {
        BaseRequest request = new BaseRequest();
        request.taskID = BusinessID.RatingsReport.MSG_ON_QUERY_SHOPRATINGSRANK;
        request.callback = new WeakReference<>(callback);
        request.url = NetworkParams.URL_QUERY_RATINGS_REPORT_LIST + "?"
                + "saleOrgId="
                + saleOrgId;
        Log.d(TAG, "请求地址：" + request.url);
        sendGetRequest(request);
    }

    /**
     * 评级上报详细信息查询
     */
    public void requestQueryRatingsDetail(final String storeId,
                                          ResultData.BusinessCallback callback) {
        BaseRequest request = new BaseRequest();
        request.taskID = BusinessID.RatingsReport.MSG_ON_QUERY_RATINGSREPORT;
        request.callback = new WeakReference<>(callback);
        request.url = NetworkParams.URL_QUERY_RATINGS_REPORT_DETAIL + "?"
                + "storeId="
                + storeId;
        Log.d(TAG, "请求地址：" + request.url);
        sendGetRequest(request);
    }

    /**
     * POST 评级上报
     */
    public void requestSaveRatingsReport(final String json, ResultData.BusinessCallback callback) {
        BaseRequest request = new BaseRequest();
        request.taskID = BusinessID.RatingsReport.MSG_ON_SAVE_RATINGS_REPORT;
        request.callback = new WeakReference<>(callback);
        request.url = NetworkParams.URL_SAVE_RATINGS_REPORT + "?";
        request.json = json;
        Log.d(TAG, "请求地址：" + request.url);
        sendPostJsonRequest(request);
    }

    /**
     * POST /RatingsReport/approveRatingsReport 评级上报审核
     */
    public void requestApproveRatingsReport(final String json, ResultData.BusinessCallback callback) {
        BaseRequest request = new BaseRequest();
        request.taskID = BusinessID.RatingsReport.MSG_ON_APPROVE_RATINGS_REPORT;
        request.callback = new WeakReference<>(callback);
        request.url = NetworkParams.URL_APPROVE_RATINGS_REPORT + "?";
        request.json = json;
        Log.d(TAG, "请求地址：" + request.url);
        sendPostJsonRequest(request);
    }

    @Override
    protected void onTaskDone(ResultData data) {
        if (null != data) {
            final int id = data.taskID;
            switch (id) {
                case BusinessID.RatingsReport.MSG_ON_QUERY_RATINGSREPORT:
                case BusinessID.RatingsReport.MSG_ON_SAVE_RATINGS_REPORT:
                case BusinessID.RatingsReport.MSG_ON_APPROVE_RATINGS_REPORT: {
                    if (data.isSuccessed()) {
                        final String json = data.getInfo();
                        if (!TextUtils.isEmpty(json)) {
                            BaseResponse mBaseResponse = new Gson().fromJson(json, BaseResponse.class);
                            Log.d(TAG, "id:" + id + ";mBaseResponse=" + mBaseResponse.toString());
                            data.setResultCode(mBaseResponse.retCode);
                            data.setResultInfo(mBaseResponse.retInfo);
                        }
                    }
                    break;
                }
                default:
                    break;
            }
        }
    }
}