package com.wgmf.yxgj.module.business.reportrating.ui;

import android.os.Bundle;
import android.util.Log;
import android.view.View;

import com.alibaba.android.arouter.facade.annotation.Route;
import com.google.gson.Gson;
import com.google.gson.reflect.TypeToken;
import com.wgmf.library.base.ResultData;
import com.wgmf.library.global.LocationParams;
import com.wgmf.yxgj.config.BusinessID;
import com.wgmf.yxgj.global.ConstantParams;
import com.wgmf.yxgj.global.NetworkParams;
import com.wgmf.yxgj.model.ShopRatingsRankEntity;
import com.wgmf.yxgj.module.business.reportrating.service.RatingsService;
import com.wgmf.yxgj.publics.model.ShopDataEntity;
import com.wgmf.yxgj.publics.model.ShopDataListEntity;
import com.wgmf.yxgj.publics.service.PublicService;
import com.wgmf.yxgj.publics.ui.SelectorBaseActivity;
import com.xp.arouter.RouterCommonUtil;
import com.xp.arouter.RouterParams;

import java.lang.reflect.Type;
import java.util.ArrayList;
import java.util.LinkedList;
import java.util.List;

/**
 * 评级上报：查询门店列表
 *
 * @author XiePing
 */
@SuppressWarnings("all")
@Route(path = RouterParams.URL_RATINGSSHOPLISTACTIVITY)
public class RatingsShopListActivity extends SelectorBaseActivity {

    private RatingsShopListAdapter adapter;
    private List<ShopRatingsRankEntity> queryRatingsListShow;

    @Override
    protected void onResume() {
        super.onResume();
        queryListData();
    }

    /**
     * 获取评级上报门店等级信息列表
     */
    private void queryListData() {
        if (null != userInfo) {
            if (ConstantParams.CONSTANT_PARAMS_1.equals(userInfo.getUserPostLevel())) {
                //总部人员(oeRole==14)使用华琪门店查询接口
                showDialog();
                String pageNo = ConstantParams.CONSTANT_PARAMS_1;
                //全国门店约3000多家，取4000
                String pageSize = "4000";
                String keyWords = "";
                String city = LocationParams.city;
                String lat = LocationParams.Latitude;
                String lng = LocationParams.Longitude;
                PublicService.getInstance().requestgetNearestShopByCity(NetworkParams.URL_SHOP_GET_NEAREST, city, keyWords, userInfo.getOrganizationCode(), pageNo, pageSize, lng, lat, this);
            } else {
                //除总部人员以外其他人员使用平平评级查询接口
                showDialog();
                String saleOrgId = userInfo.getOrganizationId();
                RatingsService.getInstance().requestQueryRatings(saleOrgId, RatingsShopListActivity.this);
            }
        }
    }

    @Override
    public void initTitle() {
        super.initTitle();
        homeTitleText.setText("专柜位置上报");
    }

    @Override
    public void initContent() {
        super.initContent();
        queryRatingsListShow = new ArrayList<>();

        adapter = new RatingsShopListAdapter(this, queryRatingsListShow);
        mListView.setAdapter(adapter);
    }

    @Override
    protected void setListener() {
        storeNameEt.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                Bundle mBundle = new Bundle();
                if (ConstantParams.CONSTANT_PARAMS_5.equals(userInfo.getUserPostLevel()) || ConstantParams.CONSTANT_PARAMS_4.equals(userInfo.getUserPostLevel())) {
                    //点击搜索按钮，若是主管或经理选择门店后进入上报页
                    mBundle.putLong("branchID", -513L);
                    mBundle.putString("branchTitle", branchTitle);
                    RouterCommonUtil.startFunctionActivity(RatingsShopListActivity.this, -2, -513L, mBundle);
                } else {
                    //点击搜索按钮，除主管和经理以外选择门店后进入查询页面
                    mBundle.putLong("branchID", -122L);
                    mBundle.putString("branchTitle", branchTitle);
                    RouterCommonUtil.startFunctionActivity(RatingsShopListActivity.this, -2, -122L, mBundle);
                }
            }
        });
    }

    @Override
    protected void onBusinessResultAtMainThread(ResultData result) {
        super.onBusinessResultAtMainThread(result);
        dismissDialog();
        if (null != result) {
            final int id = result.taskID;
            switch (id) {
                case BusinessID.Publics.MSG_ON_SHOP_GET_NEAREST: {
                    final String msg = result.getInfo();
                    if (result.isSuccessed()) {
                        ShopDataListEntity mGetNearestShopDataListEntity = new Gson().fromJson(msg, ShopDataListEntity.class);
                        Log.d(TAG, "mGetNearestShopDataListEntity=" + mGetNearestShopDataListEntity.toString());
                        if (!mGetNearestShopDataListEntity.getData().isEmpty()) {
                            queryRatingsListShow.clear();
                            for (ShopDataEntity mGetNearestShopDataEntity : mGetNearestShopDataListEntity.getData()) {
                                ShopRatingsRankEntity mShopRatingsRankEntity = new ShopRatingsRankEntity();
                                mShopRatingsRankEntity.setStoreId(mGetNearestShopDataEntity.getStoreId());
                                mShopRatingsRankEntity.setStoreName(mGetNearestShopDataEntity.getStoreName());
                                queryRatingsListShow.add(mShopRatingsRankEntity);
                            }
                            adapter.notifyDataSetChanged();
                        }
                    }
                }
                break;
                case BusinessID.RatingsReport.MSG_ON_QUERY_SHOPRATINGSRANK: {
                    final String msg = result.getInfo();
                    if (result.isSuccessed()) {
                        Type listType = new TypeToken<LinkedList<ShopRatingsRankEntity>>() {
                        }.getType();
                        LinkedList<ShopRatingsRankEntity> resources = new Gson().fromJson(msg, listType);
                        if (null != resources) {
                            queryRatingsListShow.clear();
                            queryRatingsListShow.addAll(resources);
                            adapter.notifyDataSetChanged();
                        } else {
                            showMsg(result.getResultInfo());
                        }
                    }
                }
                break;
                default:
                    break;
            }
        }
    }
}