package com.wgmf.yxgj.module.business.reportrating.ui;

import android.content.Context;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.BaseAdapter;
import android.widget.CheckBox;
import android.widget.LinearLayout;
import android.widget.RadioButton;
import android.widget.TextView;

import com.wgmf.yxgj.global.ConstantParams;
import com.wgmf.yxgj.module.business.reportrating.R;
import com.wgmf.yxgj.module.business.reportrating.model.RatingsReportGroupList;
import com.xp.pro.imagepickerlib.bean.ImageItem;
import com.xp.pro.imagepickerlib.widgets.ImagePickerLayout;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;

/**
 * 作者：xiep on 2017/7/3 13:36
 * 邮箱：2975837870@qq.com
 */
class ReportRatingsDetailDataAdapter extends BaseAdapter implements ImagePickerLayout.ImagePicker {
    /**
     * 用来保存单选主题当前选中的项目，这样用户在切换选择同一个主题下其它选项时能够将之前选中的项目的状态设置为未选状态
     */
    private HashMap<String, String> radioButtonSelectedMaps;
    /**
     * 存储所有主题的项目的选中状态，遍历这个容器可以获取选中的项目信息
     */
    private HashMap<String, Boolean> subjectItemMap;

    private LayoutInflater inflater;
    private List<RatingsReportGroupList> ratingsReportGroupLists;
    private LvListener lvListener;

    ReportRatingsDetailDataAdapter(String userPostLevel, List<RatingsReportGroupList> list, Context context, LvListener lvListener) {
        this.inflater = LayoutInflater.from(context);
        this.ratingsReportGroupLists = list;
        this.lvListener = lvListener;
        this.subjectItemMap = new HashMap<>();
        this.radioButtonSelectedMaps = new HashMap<>();

        // 初始化subjectItemMap，默认所有项目为未选中状态
        for (RatingsReportGroupList item:list) {
            this.subjectItemMap.put(item.getOptions().getItemId(), false);
            //如果是主管上报，状态为待审核；如果是经理上报，状态直接变为为已审核
            if (ConstantParams.CONSTANT_PARAMS_5.equals(userPostLevel)) {
                item.getOptions().setShopRatingFlag("2");
            } else if (ConstantParams.CONSTANT_PARAMS_4.equals(userPostLevel)) {
                item.getOptions().setShopRatingFlag("3");
            }
        }
    }

    @Override
    public void setSelectDialog(int selectType, View view) {
        lvListener.setSelectDialog(selectType, view);
    }

    @Override
    public void toPhotoPreview(int i, ArrayList<ImageItem> arrayList) {
        lvListener.toPhotoPreview(i, arrayList);
    }

    interface LvListener {
        void setSelectDialog(int selectType, View view);

        void toPhotoPreview(int i, ArrayList<ImageItem> arrayList);

        void showRank();

        void showSelectValues();
    }

    void refreshAfterTakePicture(ArrayList<ImageItem> mImageselectList, ImagePickerLayout idImagePickerContainer) {
        int position = (int) idImagePickerContainer.getTag();
        //在对应位置图片集合里加入拍照返回图片
        ratingsReportGroupLists.get(position).setStoreImageselectList(mImageselectList);
    }

    /**
     * 获取所有主题的项目的选中状态容器
     */
    HashMap<String, Boolean> getSubjectItemMap() {
        return this.subjectItemMap;
    }

    @Override
    public int getCount() {
        return ratingsReportGroupLists.size();
    }

    @Override
    public Object getItem(int position) {
        return ratingsReportGroupLists.get(position);
    }

    @Override
    public long getItemId(int position) {
        return position;
    }

    @Override
    public View getView(final int position, View convertView, ViewGroup parent) {
        final RatingsReportGroupList ratingsReportGroupList = ratingsReportGroupLists.get(position);
        final ViewHolder holder;
        convertView = null;
        if (convertView == null) {
            convertView = inflater.inflate(R.layout.litst_item_rate_view, null);
            holder = new ViewHolder(convertView);
            convertView.setTag(holder);
        } else {
            holder = (ViewHolder) convertView.getTag();
        }
        holder.tvSubjectName.setText(ratingsReportGroupList.getOptions().getGroupName());
        // 如果当前项目名称与前一项目名称相同则不显示，即所有子项目只允许第一个子项目出现产品名称
        if (position >= 1 && null != ratingsReportGroupList.getOptions().getGroupName()) {
            if (ratingsReportGroupList.getOptions().getGroupName().equals(ratingsReportGroupLists.get(position - 1).getOptions().getGroupName())) {
                holder.tvSubjectName.setVisibility(View.GONE);
            } else {
                holder.tvSubjectName.setVisibility(View.VISIBLE);
            }
        }
        holder.tvSubjectItemId.setText(ratingsReportGroupList.getOptions().getItemId());
        holder.tvSubjectId.setText(ratingsReportGroupList.getOptions().getSubjectId());
        holder.tvSubjectItemName.setText(ratingsReportGroupList.getOptions().getName());
        holder.tvSubjectItemStandard.setText("得分标准：" + ratingsReportGroupList.getOptions().getStandard() + "分");
        holder.tvSubjectItemWeight.setText("权重：" + ratingsReportGroupList.getOptions().getWeight());
        holder.tvSubjectItemScore.setText("本项得分：" + ratingsReportGroupList.getOptions().getPoints() + "分");
        holder.reportRateItemDetailMore.setText(ratingsReportGroupList.getOptions().getDiscrption());
        holder.tvIsMultiChoice.setText(String.valueOf(ratingsReportGroupList.getOptions().isMultiChoice()));

        // 当前项目为多选项目
        if (ratingsReportGroupList.getOptions().isMultiChoice()) {
            holder.cbSubjectItem.setVisibility(View.VISIBLE);
            holder.rbSubjectItem.setVisibility(View.GONE);
            holder.cbSubjectItem.setChecked(this.subjectItemMap.get(ratingsReportGroupList.getOptions().getItemId()));
            if (!holder.cbSubjectItem.isChecked()) {
                holder.idImagePickerContainerImg.setVisibility(View.GONE);
            } else {
                holder.idImagePickerContainerImg.setVisibility(View.VISIBLE);
            }
        }
        // 当前项目为单选项目
        else {
            holder.cbSubjectItem.setVisibility(View.GONE);
            holder.rbSubjectItem.setVisibility(View.VISIBLE);
            holder.rbSubjectItem.setChecked(this.subjectItemMap.get(ratingsReportGroupList.getOptions().getItemId()));

            if (!holder.rbSubjectItem.isChecked()) {
                holder.idImagePickerContainerImg.setVisibility(View.GONE);
            } else {
                holder.idImagePickerContainerImg.setVisibility(View.VISIBLE);
            }
        }
        holder.cbSubjectItem.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                // 如果当前行是多选项目
                setCheckedView(holder.tvIsMultiChoice, holder.cbSubjectItem, holder.tvSubjectItemId, holder.tvSubjectId, holder.rbSubjectItem, position, ratingsReportGroupList);
            }
        });
        holder.rbSubjectItem.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                setCheckedView(holder.tvIsMultiChoice, holder.cbSubjectItem, holder.tvSubjectItemId, holder.tvSubjectId, holder.rbSubjectItem, position, ratingsReportGroupList);

            }
        });
        holder.reportRateItemLl.setOnClickListener(new View.OnClickListener() {

            @Override
            public void onClick(View v) {
                setCheckedView(holder.tvIsMultiChoice, holder.cbSubjectItem, holder.tvSubjectItemId, holder.tvSubjectId, holder.rbSubjectItem, position, ratingsReportGroupList);
            }
        });
        holder.idImagePickerContainerImg.setmImageselectList(ratingsReportGroupList.getStoreImageselectList());
        holder.idImagePickerContainerImg.setImagePickerView(holder.idImagePickerContainerImg);
        holder.idImagePickerContainerImg.setTip("（最多添加" + ratingsReportGroupList.getNum() + "张）");
        holder.idImagePickerContainerImg.setMaxPhotoNum(ratingsReportGroupList.getNum());
        holder.idImagePickerContainerImg.setOlnyViewMode(holder.idImagePickerContainerImg.isOlnyViewMode());
        holder.idImagePickerContainerImg.refreshPhotoContentView(ratingsReportGroupList.getStoreImageselectList());
        holder.idImagePickerContainerImg.setTag(position);
        return convertView;
    }

    private void setCheckedView(TextView tvIsMultiChoice, CheckBox cbSubjectItem, TextView tvSubjectItemId, TextView tvSubjectId, RadioButton rbSubjectItem, int position, RatingsReportGroupList item) {
        if (tvIsMultiChoice.getText().equals("true")) {
            // 如果当前行是多选项目
            setCbCheckedView(cbSubjectItem, tvSubjectItemId);
        } else {
            // 如果当前行为单选项目，注意单选项目选中后需要将同一主题下已经选中的项目设置为未选中状态
            setRbChekedView(tvSubjectId, tvSubjectItemId, rbSubjectItem);
        }
        ratingsReportGroupLists.get(position).getOptions().setPoints(item.getOptions().getPoints());
        lvListener.showRank();
        lvListener.showSelectValues();
    }

    private void setRbChekedView(TextView tvSubjectId, TextView tvSubjectItemId, RadioButton rbSubjectItem) {
        String currentSubjectIdSelected = tvSubjectId.getText().toString();
        String currentSubjectItemId = tvSubjectItemId.getText().toString();
        // 判断该单选主题是否有已经选中项目，如果有需要将它的选中状态设置为未选中
        if (radioButtonSelectedMaps.containsKey(currentSubjectIdSelected)) {
            getSubjectItemMap().put(radioButtonSelectedMaps.get(currentSubjectIdSelected), false);
        }
        // 将当前选中的项目设置为该单选主题的选中项目
        radioButtonSelectedMaps.put(currentSubjectIdSelected, currentSubjectItemId);
        rbSubjectItem.toggle();
        getSubjectItemMap().put(currentSubjectItemId, rbSubjectItem.isChecked());
        notifyDataSetChanged();
    }

    private void setCbCheckedView(CheckBox cbSubjectItem, TextView tvSubjectItemId) {
        cbSubjectItem.toggle();
        getSubjectItemMap().put(tvSubjectItemId.getText().toString(), cbSubjectItem.isChecked());
        notifyDataSetChanged();
    }

    class ViewHolder {
        TextView tvSubjectName;
        TextView tvSubjectItemName;
        TextView tvSubjectItemStandard;
        TextView tvSubjectItemWeight;
        TextView tvSubjectItemScore;
        TextView reportRateItemDetailMore;
        CheckBox cbSubjectItem;
        RadioButton rbSubjectItem;
        TextView tvSubjectId;
        TextView tvSubjectItemId;
        TextView tvIsMultiChoice;
        LinearLayout reportRateItemLl;
        ImagePickerLayout idImagePickerContainerImg;

        ViewHolder(View convertView) {
            tvSubjectName = (TextView) convertView.findViewById(R.id.report_rate_item_title);
            tvSubjectItemName = (TextView) convertView.findViewById(R.id.report_rate_item_detail);
            tvSubjectItemStandard = (TextView) convertView.findViewById(R.id.report_rate_item_standard);
            tvSubjectItemWeight = (TextView) convertView.findViewById(R.id.report_rate_item_weight);
            tvSubjectItemScore = (TextView) convertView.findViewById(R.id.report_rate_item_score);
            reportRateItemDetailMore = (TextView) convertView.findViewById(R.id.report_rate_item_detail_more);
            cbSubjectItem = (CheckBox) convertView.findViewById(R.id.report_rate_item_cb);
            rbSubjectItem = (RadioButton) convertView.findViewById(R.id.report_rate_item_rb);
            tvSubjectId = (TextView) convertView.findViewById(R.id.tv_subject_id);
            tvSubjectItemId = (TextView) convertView.findViewById(R.id.tv_subject_item_id);
            tvIsMultiChoice = (TextView) convertView.findViewById(R.id.tv_is_multi_choice);
            reportRateItemLl = (LinearLayout) convertView.findViewById(R.id.report_rate_item_ll);
            idImagePickerContainerImg = (ImagePickerLayout) convertView.findViewById(R.id.id_image_picker_container_img);
            ArrayList<ImageItem> mImageselectList = new ArrayList();
            idImagePickerContainerImg.setmImageselectList(mImageselectList);
            idImagePickerContainerImg.setTitleVisibility(View.GONE);
            idImagePickerContainerImg.setOlnyViewMode(false);
            idImagePickerContainerImg.setImagePicker(ReportRatingsDetailDataAdapter.this);
            idImagePickerContainerImg.setSizePhotoNum(3);
            idImagePickerContainerImg.setImagePickerView(idImagePickerContainerImg);
        }
    }
}