package com.wgmf.yxgj.module.business.reporttourshop.service;

import android.text.TextUtils;
import android.util.Log;

import com.google.gson.Gson;
import com.wgmf.library.base.BaseRequest;
import com.wgmf.library.base.BaseResponse;
import com.wgmf.yxgj.base.BaseService;
import com.wgmf.library.base.ResultData;
import com.wgmf.library.utils.BaseSingleton;
import com.wgmf.yxgj.config.BusinessID;
import com.wgmf.yxgj.global.ConstantParams;
import com.wgmf.yxgj.global.NetworkParams;

import java.lang.ref.WeakReference;

public class TourShopService extends BaseService {
    private static BaseSingleton<TourShopService, Void> mMainService = new BaseSingleton<TourShopService, Void>() {
        @Override
        protected TourShopService create(Void var1) {
            return new TourShopService();
        }
    };

    public static TourShopService getInstance() {
        return mMainService.get(null);
    }

    private TourShopService() {
    }

    /**
     * GET /tourShop/findTourShop 从入口进入时显示界面调用
     */
    public void requestGetTourShop(final String shopId, final String type,
                                   ResultData.BusinessCallback callback) {
        BaseRequest request = new BaseRequest();
        request.taskID = BusinessID.TourShopReport.MSG_ON_FIND_TOURSHOP;
        request.callback = new WeakReference<>(callback);
        request.url = NetworkParams.URL_FIND_TOURSHOP + "?" + "shopId=" + shopId + "&type=" + type;
        Log.d(TAG, "请求地址：" + request.url);
        sendGetRequest(request);
    }

    /**
     * GET /tourShop/findTourShop 从入口进入时显示界面调用
     */
    public void requestGetTourShopByStaff(final String shopId, final String staffId, final String type, ResultData.BusinessCallback callback) {
        BaseRequest request = new BaseRequest();
        request.taskID = BusinessID.TourShopReport.MSG_ON_FIND_TOURSHOP;
        request.callback = new WeakReference<>(callback);
        request.url = NetworkParams.URL_FIND_TOURSHOP + "?" + "staffId=" + staffId + "&type=" + type + "&shopId=" + shopId;
        Log.d(TAG, "请求地址：" + request.url);
        sendGetRequest(request);
    }

    /**
     * POST /tourShop/saveTourShop 保存巡店上报
     */
    public void requestSaveTourShop(final String json,
                                    ResultData.BusinessCallback callback) {
        BaseRequest request = new BaseRequest();
        request.taskID = BusinessID.TourShopReport.MSG_ON_SAVE_TOURSHOP;
        request.callback = new WeakReference<>(callback);
        request.url = NetworkParams.URL_SAVE_TOURSHOP;
        request.json = json;
        Log.d(TAG, "请求地址：" + request.url);
        sendPostJsonRequest(request);
    }

    /**
     * GET /tourShop/findTourShopType 查询巡店辅导类型
     */
    public void requestFindTourShopType(final String shopId, ResultData.BusinessCallback callback) {
        BaseRequest request = new BaseRequest();
        request.taskID = BusinessID.TourShopReport.MSG_ON_FIND_TOURSHOP_TYPE;
        request.callback = new WeakReference<>(callback);
        request.url = NetworkParams.URL_FIND_TOURSHOP_TYPE + "?"
                + "shopId=" + shopId;
        Log.d(TAG, "请求地址：" + request.url);
        sendGetRequest(request);
    }

    @Override
    protected void onTaskDone(ResultData data) {
        if (null != data) {
            final int id = data.taskID;
            switch (id) {
                case BusinessID.TourShopReport.MSG_ON_SAVE_TOURSHOP:
                case BusinessID.TourShopReport.MSG_ON_FIND_TOURSHOP:
                case BusinessID.TourShopReport.MSG_ON_FIND_TOURSHOP_TYPE: {
                    if (data.isSuccessed()) {
                        final String json = data.getInfo();
                        if (!TextUtils.isEmpty(json)) {
                            BaseResponse mBaseResponse = new Gson().fromJson(json, BaseResponse.class);
                            Log.d(TAG, "id:" + id + ";mBaseResponse=" + mBaseResponse.toString());
                            data.setResultCode(mBaseResponse.retCode);
                            data.setResultInfo(mBaseResponse.retInfo);
                        }
                    }
                    break;
                }
                default:
                    break;
            }
        }
    }
}