package com.wgmf.yxgj.module.business.reporttourshop.ui;

import android.content.Intent;
import android.os.Bundle;
import android.text.TextUtils;
import android.util.Log;
import android.view.View;
import android.widget.AdapterView;
import android.widget.AdapterView.OnItemClickListener;

import com.alibaba.android.arouter.facade.annotation.Route;
import com.google.gson.Gson;
import com.wgmf.library.base.ResultData;
import com.wgmf.yxgj.config.BusinessID;
import com.wgmf.yxgj.global.ConstantParams;
import com.wgmf.yxgj.module.business.reporttourshop.R;
import com.wgmf.yxgj.module.business.reporttourshop.model.TourShopTypeEntity;
import com.wgmf.yxgj.module.business.reporttourshop.model.TourShopTypeListEntity;
import com.wgmf.yxgj.module.business.reporttourshop.service.TourShopService;
import com.wgmf.yxgj.publics.model.BaseSelectorEntity;
import com.wgmf.yxgj.publics.ui.SelectorBaseActivity;
import com.xp.arouter.RouterParams;


/**
 * 巡店辅导列表
 *
 * @author XiePing
 */
@Route(path = RouterParams.URL_TOURSHOPREPORTLISTACTIVITY)
public class TourShopReportListActivity extends SelectorBaseActivity {

    private String shopName;
    private String shopId;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        getData();
    }

    private void getData() {
        if (null != userInfo) {
            showDialog();
            TourShopService.getInstance().requestFindTourShopType(shopId, TourShopReportListActivity.this);
        }
    }

    @Override
    public void initTitle() {
        super.initTitle();
        homeTitleText.setText("巡店辅导");
        homeTitleMoreLl.setVisibility(View.INVISIBLE);
        homeTitleBackLl.setVisibility(View.VISIBLE);
    }

    @Override
    public void initContent() {
        super.initContent();
        shopName = getIntent().getStringExtra("shopName");
        shopId = getIntent().getStringExtra("shopId");
        storeNameEt.setVisibility(View.GONE);
        mListView.setOnItemClickListener(new OnItemClickListener() {

            @Override
            public void onItemClick(AdapterView<?> parent, View view,
                                    int position, long id) {
                click(position);
            }
        });
    }

    @Override
    protected void onBusinessResultAtMainThread(ResultData result) {
        super.onBusinessResultAtMainThread(result);
        dismissDialog();
        if (null != result) {
            final int id = result.taskID;
            if (id== BusinessID.TourShopReport.MSG_ON_FIND_TOURSHOP_TYPE) {
                    final String msg = result.getInfo();
                    if (result.isSuccessed()) {
                        try {
                            TourShopTypeListEntity mTourShopTypeListEntity = new Gson().fromJson(msg,
                                    TourShopTypeListEntity.class);
                            Log.d(TAG, "mTourShopTypeListEntity=" + mTourShopTypeListEntity.toString());
                            if (!ConstantParams.CONSTANT_PARAMS_0.equals(mTourShopTypeListEntity.retCode)) {
                                showMsg(mTourShopTypeListEntity.retInfo);
                            } else {
                                if (!mTourShopTypeListEntity.getResultList().isEmpty()) {
                                    listShow.clear();
                                    for (TourShopTypeEntity mTourShopTypeEntity : mTourShopTypeListEntity.getResultList()) {
                                        BaseSelectorEntity mBaseSelectorEntity = new BaseSelectorEntity();
                                        mBaseSelectorEntity.setSelectorId(String.valueOf(mTourShopTypeEntity.getId()));
                                        mBaseSelectorEntity.setSelectorName(mTourShopTypeEntity.getTypeName());
                                        mBaseSelectorEntity.setSelectorCode(String.valueOf(mTourShopTypeEntity.getType()));
                                        listShow.add(mBaseSelectorEntity);
                                    }
                                    mAdapter.notifyDataSetChanged();
                                    search();
                                }
                            }
                        } catch (Exception e) {
                            showMsg(getString(R.string.request_data_fail));
                        }
                    } else {
                        if (!TextUtils.isEmpty(msg)) {
                            showMsg(result.getResultInfo());
                        }
                    }
            }

        }
    }

    private void click(int position) {
        switch (Integer.valueOf(mListStore.get(position).getSelectorCode())) {
            case 1:
                //"顾问形象部分"
            case 3:
                // "销售服务流程"
                //先进入顾问选择列表，再上报
                toActivity(position, SelectorStaffActivity.class);
                break;
            case 2:
                // "柜台标准部分"
            case 4:
                // "4S柜台陈列"
            case 5:
                // "非4S柜台陈列"
                toActivity(position, TourShopReportDetailActivity.class);
                break;
            default:
                break;
        }
    }

    private void toActivity(int position, Class<?> cls) {
        Intent intent = new Intent();
        intent.setClass(this, cls);
        intent.putExtra("branchTitle", mListStore.get(position).getSelectorName());
        intent.putExtra("shopName", shopName);
        intent.putExtra("shopId", shopId);
        intent.putExtra("typeID", Integer.valueOf(mListStore.get(position).getSelectorCode()));
        startActivity(intent);
    }
}