package com.wgmf.yxgj.bussiness.talentpool.service;

import android.text.TextUtils;
import android.util.Log;

import com.google.gson.Gson;
import com.wgmf.library.base.BaseRequest;
import com.wgmf.library.base.BaseResponse;
import com.wgmf.library.base.ResultData;
import com.wgmf.library.utils.BaseSingleton;
import com.wgmf.yxgj.base.BaseService;
import com.wgmf.yxgj.config.BusinessID;
import com.wgmf.yxgj.global.NetworkParams;

import java.lang.ref.WeakReference;
@SuppressWarnings("all")
public class TalentPoolService extends BaseService {
    private static BaseSingleton<TalentPoolService, Void> mMainService = new BaseSingleton<TalentPoolService, Void>() {
        @Override
        protected TalentPoolService create(Void var1) {
            return new TalentPoolService();
        }
    };

    public static TalentPoolService getInstance() {
        return mMainService.get(null);
    }

    private TalentPoolService() {
    }

    /**
     * GET /talentPool/findOrgTalentNum 组织下门店储备人数查询
     * orgId (required) 组织Id query	long
     */
    public void requestFindOrgTalentNum(final String orgId, ResultData.BusinessCallback callback) {
        BaseRequest request = new BaseRequest();
        request.taskID = BusinessID.TalentPoolReport.MSG_ON_FIND_ORG_TALENT_NUM;
        request.callback = new WeakReference<>(callback);
        request.url = NetworkParams.URL_FIND_ORG_TALENT_NUM + "?" + "orgId=" + orgId;
        Log.d(TAG, "请求地址：" + request.url);
        sendGetRequest(request);
    }

    /**
     * GET /talentPool/findShopTalent 门店储备人才
     * shopId (required) 门店Id query	string
     * talentFlag 1 人才状态标识：1正常；4已入职/已删除 query	string
     */
    public void requestFindShopTalent(final String shopId, final String talentFlag, ResultData.BusinessCallback callback) {
        BaseRequest request = new BaseRequest();
        request.taskID = BusinessID.TalentPoolReport.MSG_ON_FIND_SHOP_TALENT;
        request.callback = new WeakReference<>(callback);
        request.url = NetworkParams.URL_FIND_SHOP_TALENT + "?"
                + "shopId=" + shopId + "&talentFlag=" + talentFlag;
        Log.d(TAG, "请求地址：" + request.url);
        sendGetRequest(request);
    }

    /**
     * GET /talentPool/getTalentPoolByPhone 人才库查询-手机校验
     * telephone (required) 手机号码 query	string
     */
    public void requestGetTalentPoolByPhone(final String telephone, ResultData.BusinessCallback callback) {
        BaseRequest request = new BaseRequest();
        request.taskID = BusinessID.TalentPoolReport.MSG_ON_GET_TALENT_POOL_BY_PHONE;
        request.callback = new WeakReference<>(callback);
        request.url = NetworkParams.URL_GET_TALENT_POOL_BY_PHONE + "?" + "telephone=" + telephone;
        Log.d(TAG, "请求地址：" + request.url);
        sendGetRequest(request);
    }

    /**
     * GET /talentPool/findShopTalentDetail 门店储备人才详情
     * tletenId 2098863 人员信息Id
     * talentFlag 1 人才状态标识：1正常；4已入职/已删除
     */
    public void requestFindShopTalentDetail(final String tletenId, final String talentFlag, ResultData.BusinessCallback callback) {
        BaseRequest request = new BaseRequest();
        request.taskID = BusinessID.TalentPoolReport.MSG_ON_FIND_SHOP_TALENT_DETAIL;
        request.callback = new WeakReference<>(callback);
        request.url = NetworkParams.URL_FIND_SHOP_TALENT_DETAIL + "?"
                + "tletenId=" + tletenId + "&talentFlag=" + talentFlag;
        Log.d(TAG, "请求地址：" + request.url);
        sendGetRequest(request);
    }

    /**
     * GET /talentPool/deleteTalentPool 删除储备人才
     * id (required) TalentPool人才库的ID query	long
     * deleteOperId (required) 删除操作人的工号 query	string
     */
    public void requestDeleteTalentPool(final String id, final String deleteOperId, ResultData.BusinessCallback callback) {
        BaseRequest request = new BaseRequest();
        request.taskID = BusinessID.TalentPoolReport.MSG_ON_DELETE_TALENT_POOL;
        request.callback = new WeakReference<>(callback);
        request.url = NetworkParams.URL_DELETE_TALENT_POOL + "?"
                + "id=" + id + "&deleteOperId=" + deleteOperId;
        Log.d(TAG, "请求地址：" + request.url);
        sendGetRequest(request);
    }

    /**
     * POST /talentPool/saveTalentPool 新增/更新人才库
     */
    public void requestSaveTalentPool(final String json, ResultData.BusinessCallback callback) {
        BaseRequest request = new BaseRequest();
        request.taskID = BusinessID.TalentPoolReport.MSG_ON_SAVE_TALENT_POOL;
        request.callback = new WeakReference<>(callback);
        request.url = NetworkParams.URL_SAVE_TALENT_POOL;
        request.json = json;
        Log.d(TAG, "请求地址：" + request.url);
        sendPostJsonRequest(request);
    }

    @Override
    protected void onTaskDone(ResultData data) {
        if (null != data) {
            final int id = data.taskID;
            switch (id) {
                case BusinessID.TalentPoolReport.MSG_ON_FIND_ORG_TALENT_NUM:
                case BusinessID.TalentPoolReport.MSG_ON_FIND_SHOP_TALENT:
                case BusinessID.TalentPoolReport.MSG_ON_GET_TALENT_POOL_BY_PHONE:
                case BusinessID.TalentPoolReport.MSG_ON_FIND_SHOP_TALENT_DETAIL:
                case BusinessID.TalentPoolReport.MSG_ON_DELETE_TALENT_POOL:
                case BusinessID.TalentPoolReport.MSG_ON_SAVE_TALENT_POOL: {
                    if (data.isSuccessed()) {
                        final String json = data.getInfo();
                        if (!TextUtils.isEmpty(json)) {
                            BaseResponse mBaseResponse = new Gson().fromJson(json, BaseResponse.class);
                            Log.d(TAG, "id:" + id + ";mBaseResponse=" + mBaseResponse.toString());
                            data.setResultCode(mBaseResponse.retCode);
                            data.setResultInfo(mBaseResponse.retInfo);
                        }
                    }
                    break;
                }
                default:
                    break;
            }
        }
    }
}