package com.wgmf.yxgj.bussiness.talentpool.ui;

import android.content.Context;
import android.util.SparseArray;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.ImageView;
import android.widget.LinearLayout;
import android.widget.TextView;

import com.wgmf.yxgj.bussiness.talentpool.R;

/**
 * 作者：xiep on 2016/7/20 16:32
 * 邮箱：2975837870@qq.com
 */
@SuppressWarnings("all")
public class BaseViewHolder {
    private final SparseArray<View> mViews;
    private int mPosition;
    private View mConvertView;

    private BaseViewHolder(Context context, ViewGroup parent, int layoutId,
                           int position) {
        this.mPosition = position;
        this.mViews = new SparseArray<>();
        mConvertView = LayoutInflater.from(context).inflate(layoutId, parent,
                false);
        // setTag
        mConvertView.setTag(this);
    }

    /**
     * 拿到一个ViewHolder对象
     *
     * @param context
     * @param convertView
     * @param parent
     * @param layoutId
     * @param position
     * @return
     */
    public static BaseViewHolder get(Context context, View convertView,
                                     ViewGroup parent, int layoutId, int position) {
        if (convertView == null) {
            return new BaseViewHolder(context, parent, layoutId, position);
        }
        return (BaseViewHolder) convertView.getTag();
    }

    public View getConvertView() {
        return mConvertView;
    }

    /**
     * 通过控件的Id获取对于的控件，如果没有则加入views
     *
     * @param viewId
     * @return
     */
    private <T extends View> T getView(int viewId) {
        View view = mViews.get(viewId);
        if (view == null) {
            view = mConvertView.findViewById(viewId);
            mViews.put(viewId, view);
        }
        return (T) view;
    }

    /**
     * 为TextView设置字符串
     *
     * @param text
     * @return
     */
    public BaseViewHolder setText1(String text) {
        TextView view = getView(R.id.base_list_item_1);
        view.setText(text);
        return this;
    }

    /**
     * 为TextView设置字符串
     *
     * @param text
     * @return
     */
    public BaseViewHolder setText2(String text) {
        TextView view = getView(R.id.base_list_item_1);
        view.setVisibility(View.VISIBLE);
        view.setText(text);
        return this;
    }

    public BaseViewHolder setLL2() {
        LinearLayout view = getView(R.id.base_list_item_2_ll);
        view.setVisibility(View.VISIBLE);
        return this;
    }

    /**
     * 为TextView设置字符串
     *
     * @param text
     * @return
     */
    public BaseViewHolder setText3(String text) {
        TextView view = getView(R.id.base_list_item_3);
        view.setText(text);
        return this;
    }

    /**
     * 为TextView设置字符串
     *
     * @param text
     * @return
     */
    public BaseViewHolder setText4(String text) {
        TextView view = getView(R.id.base_list_item_4);
        view.setText(text);
        return this;
    }

    /**
     * 右箭头显示与隐藏
     *
     * @param visible
     * @return
     */
    public BaseViewHolder setImageResourceGone(int visible) {
        ImageView view = getView(R.id.base_list_item_go);
        view.setVisibility(visible);
        return this;
    }

    /**
     * 为ImageView设置图片
     *
     * @param drawableId
     * @return
     */
    public BaseViewHolder setImageResource1(int drawableId) {
        ImageView view = getView(R.id.base_list_item_2_iv1);
        view.setImageResource(drawableId);
        return this;
    }

    /**
     * 为ImageView设置图片
     *
     * @param drawableId
     * @return
     */
    public BaseViewHolder setImageResource2(int drawableId) {
        ImageView view = getView(R.id.base_list_item_2_iv2);
        view.setImageResource(drawableId);
        return this;
    }

    /**
     * 为ImageView设置图片
     *
     * @param drawableId
     * @return
     */
    public BaseViewHolder setImageResource3(int drawableId) {
        ImageView view = getView(R.id.base_list_item_2_iv3);
        view.setImageResource(drawableId);
        return this;
    }

    /**
     * 为ImageView设置图片
     *
     * @param drawableId
     * @return
     */
    public BaseViewHolder setImageResource4(int drawableId) {
        ImageView view = getView(R.id.base_list_item_2_iv4);
        view.setImageResource(drawableId);
        return this;
    }

    /**
     * 为ImageView设置图片
     *
     * @param drawableId
     * @return
     */
    public BaseViewHolder setImageResource5(int drawableId) {
        ImageView view = getView(R.id.base_list_item_2_iv5);
        view.setImageResource(drawableId);
        return this;
    }

    public int getPosition() {
        return mPosition;
    }

}

