package com.wgmf.yxgj.module.bussiness.targetcoefficient.server

import android.util.Log
import com.google.gson.Gson
import com.wgmf.library.base.BaseRequest
import com.wgmf.library.base.BaseResponse
import com.wgmf.library.base.ResultData
import com.wgmf.yxgj.base.BaseService
import com.wgmf.yxgj.config.BusinessID
import com.wgmf.yxgj.global.NetworkParams
import com.wgmf.yxgj.utils.notNullAndEmpty
import java.lang.ref.WeakReference

/**
 * 目标参数 Service
 */
class TargetCoefficientService private constructor() : BaseService() {

    companion object {
        @JvmStatic
        val instance: TargetCoefficientService by lazy(mode = LazyThreadSafetyMode.PUBLICATION) {
            TargetCoefficientService()
        }
    }

    /**
     * post /crm-api/mkt/customer/monthlyTarget/queryList 查询月度目标系数列表
     */
    fun requestQueryMonthlyTargetList(
        json: String,
        callback: ResultData.BusinessCallback
    ) {
        val request = BaseRequest().apply {
            this.taskID = BusinessID.TargetCoefficient.MSG_ON_QUERY_MONTHLY_TARGET_LIST
            this.callback = WeakReference(callback)
            this.url = NetworkParams.URL_QUERY_MONTHLY_TARGET_LIST
            this.json = json
        }
        Log.d(TAG, "请求地址：" + request.url)
        sendPostJsonRequest(request)
    }

    /**
     * post /crm-api/mkt/customer/monthlyTarget/update 修改月度目标系数
     */
    fun requestUploadMonthlyTarget(json: String, callback: ResultData.BusinessCallback) {
        val request = BaseRequest().apply {
            this.taskID = BusinessID.TargetCoefficient.MSG_ON_UPDATE_MONTHLY_TARGET
            this.callback = WeakReference(callback)
            this.url = NetworkParams.URL_UPDATE_MONTHLY_TARGET
            this.json = json
        }
        Log.d(TAG, "请求地址：" + request.url)
        sendPostJsonRequest(request)
    }

    override fun onTaskDone(data: ResultData?) {
        data?.let {
            when (it.taskID) {
                BusinessID.TargetCoefficient.MSG_ON_UPDATE_MONTHLY_TARGET,
                BusinessID.TargetCoefficient.MSG_ON_QUERY_MONTHLY_TARGET_LIST -> {
                    if (it.isSuccessed) {
                        val json = it.info
                        if (json.notNullAndEmpty()) {
                            val response = Gson().fromJson(
                                json,
                                BaseResponse::class.java
                            )
                            Log.d(TAG, "id:${it.taskID};mBaseResponse=$response")
                            it.resultCode = response.retCode
                            it.resultInfo = response.retInfo
                        }
                    }
                }
                else -> {
                }
            }
        }
    }
}