package com.wgmf.yxgj.module.bussiness.targetcoefficient.ui

import android.os.Bundle
import android.support.v7.widget.LinearLayoutManager
import android.support.v7.widget.RecyclerView
import android.util.Log
import android.view.View
import android.view.ViewGroup
import android.widget.*
import com.alibaba.android.arouter.facade.annotation.Route
import com.google.gson.Gson
import com.wgmf.library.base.BaseResponse
import com.wgmf.library.base.ResultData
import com.wgmf.library.utils.DateUtil
import com.wgmf.yxgj.base.BaseParentAct
import com.wgmf.yxgj.config.BusinessID
import com.wgmf.yxgj.dialog.LoadWaitDominator
import com.wgmf.yxgj.global.ConstantParams
import com.wgmf.yxgj.module.bussiness.targetcoefficient.R
import com.wgmf.yxgj.module.bussiness.targetcoefficient.model.MonthlyTargetEntity
import com.wgmf.yxgj.module.bussiness.targetcoefficient.model.MonthlyTargetRequest
import com.wgmf.yxgj.module.bussiness.targetcoefficient.model.MonthlyTargetSubmitRequest
import com.wgmf.yxgj.module.bussiness.targetcoefficient.server.TargetCoefficientService
import com.wgmf.yxgj.module.bussiness.targetcoefficient.ui.adapter.MonthlyTargetCoefficientListAdapter
import com.wgmf.yxgj.utils.DensityUtil
import com.wgmf.yxgj.utils.MyToast
import com.wgmf.yxgj.utils.convertDefaultValue
import com.wgmf.yxgj.utils.helper.DialogHelper
import com.wgmf.yxgj.utils.isNotNullOrSize
import com.wgmf.yxgj.widgets.decoration.SpacesFrameDecoration
import com.xp.arouter.RouterParams
import xp.timepicker.com.widget.bean.DateType
import java.util.*


/**
 *  目标系数: 月度目标系数
 * @author LW
 */
@Route(path = RouterParams.URL_MONTHLY_TARGET_COEFFICIENT_ACTIVITY)
class MonthlyTargetCoefficientActivity : BaseParentAct() {

    private var mMonthlyTargetCoefficientListAdapter: MonthlyTargetCoefficientListAdapter? = null

    private var mTargetList: List<MonthlyTargetEntity.MonthlyTargetBean.TargetBean>? = null

    private var mMonthlyTargetConfirmFl: FrameLayout? = null

    private var mMonthlyTargetTotalTv: TextView? = null

    private var mMonthlyTargetDateTv: TextView? = null

    private var mMonthlyTargetDateLastIv: ImageView? = null

    private var mMonthlyTargetDateNextIv: ImageView? = null

    lateinit var mLoadWait: LoadWaitDominator

    private var mIsEditStatus: Boolean = false

    private var mIsTargetDate: Boolean = false

    private val mBranchTitle: String? by lazy {
        intent.getStringExtra("branchTitle")
    }

    /**
     * 选择月份(默认下个月)
     */
    private var mSelectDate: Date = DateUtil.getNewNowMonthNext()

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        setContentView(R.layout.activity_monthly_target_coefficient)
        initTitle()
        initView()
    }

    override fun initTitle() {
        super.initTitle()
        homeTitleText.text = mBranchTitle
        homeTitleBackLl.visibility = View.VISIBLE
    }

    /**
     * 时间切换逻辑
     */
    private fun dateSwitchLogic() {
        val selectYear = DateUtil.getYearForDate(mSelectDate)
        val selectMonth = DateUtil.getMonthForDate(mSelectDate)

        if (selectMonth <= 1) {
            mMonthlyTargetDateLastIv?.setImageResource(R.mipmap.icon_date_last)
            mMonthlyTargetDateLastIv?.isClickable = false
        } else {
            mMonthlyTargetDateLastIv?.setImageResource(R.mipmap.icon_date_last_click)
            mMonthlyTargetDateLastIv?.isClickable = true
        }

        if (selectMonth >= 12) {
            mMonthlyTargetDateNextIv?.setImageResource(R.mipmap.icon_date_next)
            mMonthlyTargetDateNextIv?.isClickable = false
        } else {
            mMonthlyTargetDateNextIv?.setImageResource(R.mipmap.icon_date_next_click)
            mMonthlyTargetDateNextIv?.isClickable = true
        }

        val normalYear = DateUtil.getYearForDate(DateUtil.getNewNowMonthNext())
        val normalMonth = DateUtil.getMonthForDate(DateUtil.getNewNowMonthNext())

        mIsTargetDate = selectYear == normalYear && selectMonth == normalMonth

        val selectTime = "$selectYear-" + DateUtil.makeZero(selectMonth)
        mMonthlyTargetDateTv?.text = selectTime

        //根据年月份获取列表数据
        queryMonthlyTargetList(selectYear.toString(), DateUtil.makeZero(selectMonth))
    }

    /**
     * 查询任务详情
     */
    private fun queryMonthlyTargetList(year: String, month: String) {
        userInfo?.let {
            //showDialog()
            mLoadWait.show(LoadWaitDominator.LOADING)
            val json = Gson().toJson(MonthlyTargetRequest(it.officeId, year + month))
            TargetCoefficientService.instance.requestQueryMonthlyTargetList(
                json, this@MonthlyTargetCoefficientActivity
            )
        }
    }

    /**
     * 修改月度目标系数
     */
    private fun uploadMonthlyTarget() {
        mTargetList?.let {
            showDialog()
            val monthlyTargetSubmitList = mutableListOf<MonthlyTargetSubmitRequest>()
            var updateData: Boolean = false
            it.forEach {
                if (it.editSettingCoefficient != null) {
                    updateData = true
                }
                monthlyTargetSubmitList.add(
                    MonthlyTargetSubmitRequest(
                        it.id,
                        it.editSettingCoefficient ?: it.settingCoefficient,
                        it.target
                    )
                )
            }

            if (!updateData) {
                MyToast.show(mContext.getString(R.string.monthly_target_submit_tip))
                dismissDialog()
                return
            }

            val json = Gson().toJson(monthlyTargetSubmitList)
            TargetCoefficientService.instance.requestUploadMonthlyTarget(
                json, this@MonthlyTargetCoefficientActivity
            )
        }
    }

    private fun initView() {
        mLoadWait = LoadWaitDominator(this, findViewById(R.id.monthly_target_content_fl)).apply {
            setStatusImg(R.mipmap.icon_msg_empty_data)
            setBackgroundColor(R.color.region_two_bg)
        }

        findViewById<ViewGroup>(R.id.monthly_target_header_ic).apply {
            userInfo?.let {
                findViewById<TextView>(R.id.monthly_target_district_tv).text = it.officeName
            }
            mMonthlyTargetTotalTv = findViewById(R.id.monthly_target_total_tv)
            mMonthlyTargetDateLastIv =
                findViewById<ImageView>(R.id.monthly_target_date_last_iv).apply {
                    setOnClickListener {
                        mSelectDate = DateUtil.getMonthTop(mSelectDate)
                        dateSwitchLogic()
                    }
                }

            mMonthlyTargetDateTv = findViewById<TextView>(R.id.monthly_target_date_tv).apply {
                setOnClickListener {
                    DialogHelper.showDatePickDialog(
                        this@MonthlyTargetCoefficientActivity,
                        DateType.TYPE_YM
                    ).apply {
                        setCanceledOnTouchOutside(false)
                        setOnSureLisener {
                            if (it != null) {
                                mSelectDate = it
                                dateSwitchLogic()
                            }
                        }
                    }.show()
                }
            }

            mMonthlyTargetDateNextIv =
                findViewById<ImageView>(R.id.monthly_target_date_next_iv).apply {
                    setOnClickListener {
                        mSelectDate = DateUtil.getMonthNext(mSelectDate)
                        dateSwitchLogic()
                    }
                }
        }

        mMonthlyTargetConfirmFl =
            findViewById(R.id.monthly_target_confirm_fl)
        findViewById<Button>(R.id.monthly_target_confirm_btn).apply {
            setOnClickListener {
                if (mIsEditStatus) {
                    //请求保存数据
                    uploadMonthlyTarget()
                    mIsEditStatus = false
                    setText(R.string.edit_btn_txt)
                } else {
                    mIsEditStatus = true
                    setText(R.string.save_btn_txt)
                }
                mMonthlyTargetCoefficientListAdapter?.setEditStatus(mIsEditStatus)
            }
        }

        mMonthlyTargetCoefficientListAdapter = MonthlyTargetCoefficientListAdapter(arrayListOf())
        findViewById<RecyclerView>(R.id.monthly_target_list_rv).apply {
            layoutManager = LinearLayoutManager(mContext)
            adapter = mMonthlyTargetCoefficientListAdapter
            addItemDecoration(
                SpacesFrameDecoration(
                    0,
                    DensityUtil.dip2px(mContext, 60f)
                )
            )
        }
        dateSwitchLogic()
    }

    override fun onBusinessResultAtMainThread(result: ResultData?) {
        super.onBusinessResultAtMainThread(result)
        dismissDialog()
        mLoadWait.show(LoadWaitDominator.DISMISS)
        result?.let {
            if (it.taskID == BusinessID.TargetCoefficient.MSG_ON_QUERY_MONTHLY_TARGET_LIST) {
                if (!isFinishing && it.isSuccessed) {
                    val entity = Gson().fromJson(it.info, MonthlyTargetEntity::class.java)
                    Log.d(TAG, "MonthlyTargetEntity=$entity")
                    if (ConstantParams.CONSTANT_PARAMS_0 == entity.retCode) {
                        val data = entity.payload
                        monthlyTargetToView(data)
                    } else {
                        mLoadWait.show(entity.retInfo)
                    }
                } else {
                    mLoadWait.show(LoadWaitDominator.NET_ERROR)
                }
            } else if (it.taskID == BusinessID.TargetCoefficient.MSG_ON_UPDATE_MONTHLY_TARGET) {
                if (!isFinishing && it.isSuccessed) {
                    val entity = Gson().fromJson(it.info, BaseResponse::class.java)
                    Log.d(TAG, "BaseResponse=$entity")
                    if (ConstantParams.CONSTANT_PARAMS_0 == entity.retCode) {
                        queryMonthlyTargetList(
                            DateUtil.getYearForDate(mSelectDate).toString(),
                            DateUtil.makeZero(DateUtil.getMonthForDate(mSelectDate))
                        )
                    } else {
                        MyToast.show(entity.retInfo)
                    }
                } else {
                    MyToast.show(getString(R.string.request_data_fail))
                }
            }
        }
    }

    private fun monthlyTargetToView(bean: MonthlyTargetEntity.MonthlyTargetBean?) {
        bean?.apply {
            mMonthlyTargetTotalTv?.text = getString(
                R.string.monthly_target_calculated_target_value,
                monthlyTarget.toString().convertDefaultValue()
            )

            mTargetList = targetList
            if (mTargetList.isNotNullOrSize()) {
                mMonthlyTargetCoefficientListAdapter?.setNewData(mTargetList)
                mMonthlyTargetCoefficientListAdapter?.setMonthlyTarget(monthlyTarget)
                mIsEditStatus = false
                mMonthlyTargetCoefficientListAdapter?.setEditStatus(mIsEditStatus)
                if (mIsTargetDate) {
                    mMonthlyTargetConfirmFl?.visibility = View.VISIBLE
                } else {
                    mMonthlyTargetConfirmFl?.visibility = View.GONE
                }

                return
            }
        }
        mMonthlyTargetTotalTv?.text = getString(
            R.string.monthly_target_calculated_target_value,
            "".convertDefaultValue()
        )
        mLoadWait.showNoData(R.string.no_data)
        mMonthlyTargetConfirmFl?.visibility = View.GONE

    }
}