package com.wgmf.yxgj.module.bussiness.targetcoefficient.ui.adapter

import android.text.Editable
import android.text.TextWatcher
import android.view.View
import android.widget.TextView
import com.chad.library.adapter.base.BaseQuickAdapter
import com.chad.library.adapter.base.BaseViewHolder
import com.wgmf.library.utils.Arith
import com.wgmf.yxgj.module.bussiness.targetcoefficient.R
import com.wgmf.yxgj.module.bussiness.targetcoefficient.model.MonthlyTargetEntity
import com.wgmf.yxgj.utils.convertDefaultValue
import com.wgmf.yxgj.widgets.EditText.EditTextDecimal
import java.lang.Exception

/**
 * 月度目标系数列表适配器
 * @author LW
 */
class MonthlyTargetCoefficientListAdapter(
    entity: List<MonthlyTargetEntity.MonthlyTargetBean.TargetBean>,
    private var isEditStatus: Boolean = false
) : BaseQuickAdapter<MonthlyTargetEntity.MonthlyTargetBean.TargetBean, BaseViewHolder>(
    R.layout.item_monthly_target_view,
    entity
) {

    private var mMonthlyTarget: Double = 0.0

    fun setEditStatus(isEditStatus: Boolean) {
        this.isEditStatus = isEditStatus
        notifyDataSetChanged()
    }

    override fun convert(
        helper: BaseViewHolder?,
        item: MonthlyTargetEntity.MonthlyTargetBean.TargetBean?
    ) {

        helper?.apply {
            if (layoutPosition % 2 == 0) {
                itemView.setBackgroundResource(R.color.region_three_bg)
            } else {
                itemView.setBackgroundResource(R.color.normal_bg)
            }

            if (isEditStatus) {
                getView<TextView>(R.id.monthly_target_setting_coefficient_tv).visibility =
                    View.GONE
                getView<EditTextDecimal>(R.id.monthly_target_setting_coefficient_et).apply {
                    if (item?.editSettingCoefficient == null) {
                        setText(item?.settingCoefficient.toString().convertDefaultValue())
                    } else {
                        setText(item.editSettingCoefficient.toString().convertDefaultValue())
                    }
                    setSelectAllOnFocus(true)
                    //clearFocus()
                    //onFocusChangeListener = View.OnFocusChangeListener { view, hasFocus ->
                    //    if (!hasFocus && layoutPosition >= 0 && data.size > layoutPosition) {
                    //        data.forEachIndexed { index, bean ->
                    //            val d = bean.editSettingCoefficient
                    //            if (d == null) {
                    //                bean.target =
                    //                    calculateCalculatedTarget(bean.settingCoefficient)
                    //            } else {
                    //                bean.target = calculateCalculatedTarget(d)
                    //            }

                    //            try {
                    //                notifyItemRangeChanged(0, data.size)
                    //            }catch (e:Exception){
                    //               e.printStackTrace()
                    //            }
                    //        }
                    //    }
                    //}

                    //setOnClickListener {
                    //    it.requestFocus()
                    //}
                    addTextChangedListener(object : TextWatcher {
                        override fun beforeTextChanged(
                            s: CharSequence,
                            start: Int,
                            count: Int,
                            after: Int
                        ) {
                        }

                        override fun onTextChanged(
                            s: CharSequence,
                            start: Int,
                            before: Int,
                            count: Int
                        ) {
                        }

                        override fun afterTextChanged(s: Editable) {
                            if (layoutPosition >= 0 && data.size > layoutPosition) {
                                getItem(layoutPosition)?.let {
                                    val input = s.toString()
                                    var d: Double? = try {
                                        input.toDouble()
                                    } catch (e: NumberFormatException) {
                                        null
                                    }
                                    if (d != it.editSettingCoefficient) {
                                        it.editSettingCoefficient = d
                                        if (d == null) {
                                            it.target =
                                                calculateCalculatedTarget(it.settingCoefficient)
                                        } else {
                                            it.target = calculateCalculatedTarget(d)
                                        }
                                        setText(
                                            R.id.monthly_target_calculated_target_tv,
                                            it.target.toString().convertDefaultValue()
                                        )

                                        data.forEachIndexed { index, bean ->
                                            if (layoutPosition == index) return@forEachIndexed
                                            d = bean.editSettingCoefficient
                                            if (d == null) {
                                                bean.target =
                                                    calculateCalculatedTarget(bean.settingCoefficient)
                                            } else {
                                                bean.target = calculateCalculatedTarget(d)
                                            }
                                        }

                                        try {
                                            notifyItemRangeChanged(0, layoutPosition)
                                            if (layoutPosition + 1 < data.size) {
                                                notifyItemRangeChanged(
                                                    layoutPosition + 1,
                                                    data.size - (layoutPosition + 1)
                                                )
                                            }
                                        } catch (e: Exception) {
                                            e.printStackTrace()
                                        }
                                    }
                                }
                            }
                        }
                    })
                    visibility = View.VISIBLE
                }
            } else {
                getView<TextView>(R.id.monthly_target_setting_coefficient_tv).visibility =
                    View.VISIBLE
                getView<EditTextDecimal>(R.id.monthly_target_setting_coefficient_et).visibility =
                    View.GONE
            }

            item?.let {
                setText(
                    R.id.monthly_target_date_tv, it.dateTime.convertDefaultValue()
                )
                setText(
                    R.id.monthly_target_week_tv,
                    it.dayOfWeek.convertDefaultValue()
                )
                setText(
                    R.id.monthly_target_reference_coefficient_tv,
                    it.referenceCoefficient.toString().convertDefaultValue()
                )

                setText(
                    R.id.monthly_target_setting_coefficient_tv,
                    it.settingCoefficient.toString().convertDefaultValue()
                )

                setText(
                    R.id.monthly_target_calculated_target_tv,
                    it.target.toString().convertDefaultValue()
                )
            }
        }
    }

    /**
     * 计算测量目标
     */
    private fun calculateCalculatedTarget(settingCoefficient: Double?): Double {
        var settingCoefficientTotal = 0.0
        data.forEach {
            settingCoefficientTotal += (if (it.editSettingCoefficient != null) {
                it.editSettingCoefficient
            } else {
                it.settingCoefficient
            }) ?: 0.0
        }
        if (settingCoefficientTotal > 0.0 && settingCoefficient != null) {
            return Arith.round(
                ((mMonthlyTarget / settingCoefficientTotal) *
                        settingCoefficient), 1
            )
        }
        return 0.0
    }

    fun setMonthlyTarget(monthlyTarget: Double) {
        this.mMonthlyTarget = monthlyTarget
    }

}