package com.wgmf.yxgj.bussiness.terminaldisplay.service;

import android.text.TextUtils;
import android.util.Log;

import com.google.gson.Gson;
import com.wgmf.library.base.BaseRequest;
import com.wgmf.library.base.BaseResponse;
import com.wgmf.library.base.ResultData;
import com.wgmf.library.utils.BaseSingleton;
import com.wgmf.yxgj.base.BaseService;
import com.wgmf.yxgj.bussiness.terminaldisplay.service.request.AddMissionRequest;
import com.wgmf.yxgj.bussiness.terminaldisplay.service.request.QueryMissionByStoreNoRequest;
import com.wgmf.yxgj.bussiness.terminaldisplay.service.request.SubmitionMissionRequest;
import com.wgmf.yxgj.config.BusinessID;
import com.wgmf.yxgj.global.NetworkParams;

import java.lang.ref.WeakReference;

/**
 * @author xiep on 2020/6/29 9:29
 */
public class TerminalDisplayService extends BaseService {
    private static BaseSingleton<TerminalDisplayService, Void> mMainService = new BaseSingleton<TerminalDisplayService, Void>() {
        @Override
        protected TerminalDisplayService create(Void var1) {
            return new TerminalDisplayService();
        }
    };

    public static TerminalDisplayService getInstance() {
        return mMainService.get(null);
    }

    private TerminalDisplayService() {
    }
    /**
     * get /terminalDisCorrective/findTerminalDisShop 查询终端陈列整改门店
     * orgId (required) 组织Id query	long
     */
    public void requestFindTerminalDisShop(final String orgId, ResultData.BusinessCallback callback) {
        BaseRequest request = new BaseRequest();
        request.taskID = BusinessID.TerminalDisplay.MSG_ON_FIND_TERMINAL_DISSHOP;
        request.callback = new WeakReference<>(callback);
        request.url = NetworkParams.URL_FIND_TERMINAL_DISSHOP + "?" + "orgId=" + orgId;
        Log.d(TAG, "请求地址：" + request.url);
        sendGetRequest(request);
    }
    /**
     * post /exhibit/queryMissionByStoreNo 查询门店陈列任务
     */
    public void queryMissionByStoreNo(final String storeNo,  ResultData.BusinessCallback callback) {
        QueryMissionByStoreNoRequest request = new QueryMissionByStoreNoRequest(storeNo);
        request.taskID = BusinessID.TerminalDisplay.MSG_ON_QUERY_MISSION_BY_STORENO;
        request.callback = new WeakReference<>(callback);
        request.url = NetworkParams.URL_QUERY_MISSION_BY_STORENO;
        Log.d(TAG, "请求地址：" + request.url);
        sendPostRequest(request);
    }

    /**
     * post /exhibit/addSubmition 新增提报数据
     */
    public void postAddSubmition(final String detailId,final String userNo
            ,final String userName,final String remark
            ,final String submitUrl,  ResultData.BusinessCallback callback) {
        AddMissionRequest request = new AddMissionRequest(detailId, userNo
            ,userName, remark,submitUrl);
        request.taskID = BusinessID.TerminalDisplay.MSG_ON_ADD_SUBMITION;
        request.callback = new WeakReference<>(callback);
        request.url = NetworkParams.URL_ADD_SUBMITION;
        Log.d(TAG, "请求地址：" + request.url);
        sendPostRequest(request);
    }

    /**
     * post /exhibit/updateSubmition 修改提报数据
     */
    public void postUpdateSubmition(final String submitId,final String userNo
            ,final String userName,final String remark
            ,final String submitUrl,  ResultData.BusinessCallback callback) {
        SubmitionMissionRequest request = new SubmitionMissionRequest(submitId, userNo
                ,userName, remark,submitUrl);
        request.taskID = BusinessID.TerminalDisplay.MSG_ON_UPDATE_SUBMITION;
        request.callback = new WeakReference<>(callback);
        request.url = NetworkParams.URL_UPDATE_SUBMITION;
        Log.d(TAG, "请求地址：" + request.url);
        sendPostRequest(request);
    }


    @Override
    protected void onTaskDone(ResultData data) {
        if (null != data) {
            final int id = data.taskID;
            switch (id) {
                case BusinessID.TerminalDisplay.MSG_ON_FIND_TERMINAL_DISSHOP:
                case BusinessID.TerminalDisplay.MSG_ON_ADD_SUBMITION:
                case BusinessID.TerminalDisplay.MSG_ON_UPDATE_SUBMITION:
                case BusinessID.TerminalDisplay.MSG_ON_QUERY_MISSION_BY_STORENO: {
                    if (data.isSuccessed()) {
                        final String json = data.getInfo();
                        if (!TextUtils.isEmpty(json)) {
                            BaseResponse mBaseResponse = new Gson().fromJson(json, BaseResponse.class);
                            Log.d(TAG, "id:" + id + ";mBaseResponse=" + mBaseResponse.toString());
                            data.setResultCode(mBaseResponse.retCode);
                            data.setResultInfo(mBaseResponse.retInfo);
                        }
                    }
                    break;
                }
                default:
                    break;
            }
        }
    }
}