package com.wgmf.yxgj.bussiness.terminaldisplay.ui;

import android.app.AlertDialog;
import android.content.Context;
import android.content.Intent;
import android.support.v4.content.ContextCompat;
import android.text.TextUtils;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.BaseAdapter;
import android.widget.TextView;

import com.wgmf.yxgj.bussiness.terminaldisplay.R;
import com.wgmf.yxgj.bussiness.terminaldisplay.model.TerminalDisplayBean;
import com.wgmf.yxgj.bussiness.terminaldisplay.service.DataTransform;
import com.wgmf.yxgj.global.ConstantParams;

import java.util.List;

/**
 * 作者：xiep on 2020/6/29 9:29
 * 邮箱：2975837870@qq.com
 */
class TerminalDisplayShopAdapter extends BaseAdapter {
    private Context context;
    private List<TerminalDisplayBean> list;

    TerminalDisplayShopAdapter(Context context, List<TerminalDisplayBean> list) {
        this.context = context;
        this.list = list;
    }

    @Override
    public int getCount() {
        return list == null ? 0 : list.size();
    }

    @Override
    public TerminalDisplayBean getItem(int position) {
        if (position >= list.size()) {
            return null;
        } else {
            return list.get(position);
        }
    }

    @Override
    public long getItemId(int position) {
        return 0;
    }

    class ViewHolder {
        TextView name;
        TextView rank;
        TextView status;
        TextView storeEndTime;
    }

    @Override
    public View getView(final int position, View convertView, ViewGroup arg2) {
        final ViewHolder holder = new ViewHolder();
        convertView = LayoutInflater.from(context).inflate(R.layout.list_item_terminal_display_shop_view, null);
        holder.name = (TextView) convertView.findViewById(R.id.store_name);
        holder.rank = (TextView) convertView.findViewById(R.id.store_rank);
        holder.status = (TextView) convertView.findViewById(R.id.store_status);
        holder.storeEndTime = (TextView) convertView.findViewById(R.id.store_end_time);
        convertView.setTag(holder);

        final TerminalDisplayBean data = list.get(position);
        holder.name.setText(data.getShopName());
        if(!TextUtils.isEmpty(data.getMissionType())) {
            holder.rank.setText(DataTransform.getMissionType(data.getMissionType()));
        }
        if(!TextUtils.isEmpty(data.getEndTime())){
            holder.storeEndTime.setText("截止时间："+data.getEndTime());
        }

        //  1待提交、2待审核可修改、3已审核可整改、4可再次整改、5免提交、6已截止 ,
        String shopRatingFlag = data.getShopStatus();
        if (ConstantParams.CONSTANT_PARAMS_1.equals(shopRatingFlag)) {
            holder.status.setText("待提交");
            holder.status.setTextColor(ContextCompat.getColor(context, R.color.red));
        } else if (ConstantParams.CONSTANT_PARAMS_2.equals(shopRatingFlag)) {
            holder.status.setText("待审核可修改");
            holder.status.setTextColor(ContextCompat.getColor(context, R.color.red));
        } else if (ConstantParams.CONSTANT_PARAMS_3.equals(shopRatingFlag)) {
            holder.status.setText("已审核可整改");
            holder.status.setTextColor(ContextCompat.getColor(context, R.color.red));
        }else if (ConstantParams.CONSTANT_PARAMS_4.equals(shopRatingFlag)) {
            holder.status.setText("可再次整改");
            holder.status.setTextColor(ContextCompat.getColor(context, R.color.red));
        }else if (ConstantParams.CONSTANT_PARAMS_5.equals(shopRatingFlag)) {
            holder.status.setText("免提交");
            holder.status.setTextColor(ContextCompat.getColor(context, R.color.green));
            // 不显示右侧按钮
            holder.status.setCompoundDrawables(null, null, null, null);
        }else if (ConstantParams.CONSTANT_PARAMS_6.equals(shopRatingFlag)) {
            holder.status.setText("已截止");
            holder.status.setTextColor(ContextCompat.getColor(context, R.color.green));
            holder.status.setCompoundDrawables(null, null, null, null);
        }else if (ConstantParams.CONSTANT_PARAMS_7.equals(shopRatingFlag)) {
            holder.status.setText("没任务");
            holder.status.setVisibility(View.INVISIBLE);
        }else {
            holder.status.setText("未知");
        }
        //‘免提交’‘已截止’‘没有陈列任务’的处理：点击门店，如果检测到这三个状态，给出弹窗提示，不能进入页面；
        convertView.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                Intent intent = new Intent();
                if (!ConstantParams.CONSTANT_PARAMS_5.equals(data.getShopStatus())) {
                    if(ConstantParams.CONSTANT_PARAMS_1.equals(data.getShopStatus())){
                        intent.putExtra("shopId", data.getShopId());
                        intent.putExtra("shopName", data.getShopName());
                        intent.putExtra("shopStatus", data.getShopStatus());
                        intent.setClass(context, TerminalDisplayEditActivity.class);
                        context.startActivity(intent);
                    }else if(ConstantParams.CONSTANT_PARAMS_2.equals(data.getShopStatus())
                            ||ConstantParams.CONSTANT_PARAMS_3.equals(data.getShopStatus())
                            ||ConstantParams.CONSTANT_PARAMS_4.equals(data.getShopStatus())){
                        intent.putExtra("shopId", data.getShopId());
                        intent.putExtra("shopName", data.getShopName());
                        intent.putExtra("shopStatus", data.getShopStatus());
                        intent.setClass(context, TerminalDisplayDetailActivity.class);
                        context.startActivity(intent);
                    }else if(ConstantParams.CONSTANT_PARAMS_6.equals(data.getShopStatus())){
                        //‘已截止’状态提示文案‘陈列提交任务已截止’，
                        new AlertDialog.Builder(context)
                                .setMessage("陈列提交任务已截止")
                                .setPositiveButton("我知道了",null)
                                .show();
                    }else if(ConstantParams.CONSTANT_PARAMS_7.equals(data.getShopStatus())){
                        //‘没有陈列任务’状态提示文案‘门店目前没有陈列提交任务’
                        new AlertDialog.Builder(context)
                                .setMessage("门店目前没有陈列提交任务")
                                .setPositiveButton("我知道了",null)
                                .show();
                    }else{
                        new AlertDialog.Builder(context)
                                .setMessage("门店目前状态未知")
                                .setPositiveButton("我知道了",null)
                                .show();
                    }
                }else{
                    //‘免提交’状态提示文案‘陈列提交任务不用提交’
                    new AlertDialog.Builder(context)
                            .setMessage("陈列提交任务不用提交")
                            .setPositiveButton("我知道了",null)
                            .show();
                }
            }
        });
        return convertView;
    }
}