package com.wgmf.library.utils

import android.content.Context
import android.graphics.Bitmap
import android.support.v4.graphics.drawable.RoundedBitmapDrawableFactory
import android.widget.ImageView
import com.bumptech.glide.Glide
import com.bumptech.glide.request.target.BitmapImageViewTarget

/**
 * 图片工具类
 * @author LW
 */
object ImageUtils {
    /**
     * 加载图片
     */
    fun loadImage(context: Context, url: String?,  view: ImageView) {
        Glide.with(context).load(url).into(view)
    }

    /**
     * 加载图片
     */
    fun loadImage(context: Context, url: String?,  view: ImageView,placeHolderRes:Int, errorRes:Int) {
        Glide.with(context).load(url)
            .placeholder(placeHolderRes).error(errorRes).into(view)
    }

    /**
     * 加载Gif图片
     */
    fun loadGifImage(context: Context, url: String?, view: ImageView) {
        Glide.with(context).load(url).asGif().into(view)
    }

    /**
     * 加载圆形头像
     */
    fun loadCircleImage(context: Context, url: String?, view: ImageView) {
        Glide.with(context)
            .load(url).asBitmap()
            .centerCrop().into(object : BitmapImageViewTarget(view) {
                override fun setResource(resource: Bitmap?) {
                    val circularBitmapDrawable = RoundedBitmapDrawableFactory.create(
                        context.resources,
                        resource
                    )
                    circularBitmapDrawable.isCircular = true
                    view.setImageDrawable(circularBitmapDrawable)
                }
            })
    }

    /**
     * 加载圆形头像
     */
    fun loadCircleImage(context: Context, url: String?, view: ImageView,placeHolderRes:Int, errorRes:Int) {
        Glide.with(context)
            .load(url).asBitmap().placeholder(placeHolderRes).error(errorRes)
            .centerCrop().into(object : BitmapImageViewTarget(view) {
                override fun setResource(resource: Bitmap?) {
                    val circularBitmapDrawable = RoundedBitmapDrawableFactory.create(
                        context.resources,
                        resource
                    )
                    circularBitmapDrawable.isCircular = true
                    view.setImageDrawable(circularBitmapDrawable)
                }
            })
    }
}