package com.wgmf.library.utils;

import android.text.TextUtils;
import android.util.Log;
import java.text.DecimalFormat;
import java.util.Locale;

/**
 * 字符串工具类
 *
 * @author xiep on 2016/1/18 9:26
 */
public class StringUtil {

    private StringUtil() {
    }

    /**
     * 不为null，也不是全是空白字符
     */
    public static boolean isNotNullAndNotEmpty(String string) {
        return string != null && string.trim().length() > 0;
    }

    /**
     * null或空字符串判断
     */
    public static boolean isNullOrEmpty(String string) {
        return string == null || string.trim().length() == 0;
    }

    /**
     * null或空字符串判断
     */
    public static boolean isNullString(String string) {
        return string == null || string.trim().length() == 0 || "null".equals(string);
    }

    public static boolean isUrl(final String url) {
        return url.startsWith("http://") || url.startsWith("https://") || url.startsWith("ftp://");
    }

    /**
     * 对象转整数
     *
     * @return 转换异常返回 0
     */
    public static double toDouble(String obj) {
        try {
            return Double.parseDouble(obj);
        } catch (Exception e) {
            Log.e("StringUtil", "toDouble: ", e);
            return 0;
        }
    }

    /**
     * 格式化double
     */
    public static String formatDouble(double num, String format) {
        DecimalFormat df = new DecimalFormat(format);
        return df.format(num);
    }
    /**
     * 格式化String
     */
    public static String formatString(String content, Object... args) {
        return String.format(
                Locale.CHINA,
                content, args);
    }

    /**
     * 默认转换字符串
     */
    public static String convertDefaultValue(String value) {
        if (value != null && !TextUtils.isEmpty(value)) {
            return value;
        } else {
            return "--";
        }
    }
}