package com.wgmf.library.utils

import android.graphics.Typeface
import android.text.SpannableString
import android.text.SpannableStringBuilder
import android.text.Spanned
import android.text.style.*
import java.util.regex.Pattern

object TextColorDominator {

    fun styleTextkeywordColor(
        foregroundColor: Int,
        backgroundColor: Int,
        content: String,
        keyword: String
    ): SpannableString {
        val span = SpannableString(content)
        val pattern = Pattern.compile(keyword)
        val matcher = pattern.matcher(span)
        while (matcher.find()) {
            val start = matcher.start()
            val end = matcher.end()
            if (foregroundColor != 0) {
                span.setSpan(
                    ForegroundColorSpan(foregroundColor),
                    start,
                    end,
                    Spanned.SPAN_EXCLUSIVE_EXCLUSIVE
                )
            }
            if (backgroundColor != 0) {
                span.setSpan(
                    BackgroundColorSpan(backgroundColor),
                    start,
                    end,
                    Spanned.SPAN_EXCLUSIVE_EXCLUSIVE
                )
            }
        }
        return span
    }

    /**
     * 修改字符串中纯数值的颜色
     * @param  content String
     * @param foregroundColor Int
     */
    fun styleTextNumberColor(content: String, foregroundColor: Int): SpannableStringBuilder {
        return SpannableStringBuilder(content).apply {
            content.toCharArray().withIndex().forEach { (index, chars) ->
                if (chars in '0'..'9') {
                    setSpan(
                        ForegroundColorSpan(
                            foregroundColor
                        ), index, index + 1, Spanned.SPAN_EXCLUSIVE_EXCLUSIVE
                    )
                }
            }
        }
    }

    /**
     * 修改字符串中纯数值的加粗
     * @param  content String
     */
    fun styleTextNumberBold(content: String): SpannableStringBuilder {
        return SpannableStringBuilder(content).apply {
            content.toCharArray().withIndex().forEach { (index, chars) ->
                if (chars in '0'..'9') {
                    setSpan(
                        StyleSpan(Typeface.BOLD),
                        index,
                        index + 1,
                        Spanned.SPAN_EXCLUSIVE_EXCLUSIVE
                    )
                }
            }
        }
    }

    /**
     * 修改字符串中纯数值的大小
     * @param  content String
     * @param typeface Int
     */
    fun styleTextNumberSize(content: String, typeface: Int): SpannableStringBuilder {
        return SpannableStringBuilder(content).apply {
            content.toCharArray().withIndex().forEach { (index, chars) ->
                if (chars in '0'..'9') {
                    setSpan(
                        AbsoluteSizeSpan(typeface),
                        index,
                        index + 1,
                        Spanned.SPAN_EXCLUSIVE_EXCLUSIVE
                    )
                }
            }
        }
    }

    /**
     * 修改字符串中纯数值的大小 ,加粗,颜色
     * @param  content String
     * @param foregroundColor Int
     * @param typeface Int
     */
    fun styleTextNumber(
        content: String,
        foregroundColor: Int,
        typeface: Int
    ): SpannableStringBuilder {

        return SpannableStringBuilder(content).apply {
            content.toCharArray().withIndex().forEach { (index, chars) ->
                if (chars in '0'..'9') {
                    setSpan(
                        ForegroundColorSpan(
                            foregroundColor
                        ), index, index + 1, Spanned.SPAN_EXCLUSIVE_EXCLUSIVE
                    )
                    setSpan(
                        StyleSpan(Typeface.BOLD),
                        index,
                        index + 1,
                        Spanned.SPAN_EXCLUSIVE_EXCLUSIVE
                    )
                    setSpan(
                        AbsoluteSizeSpan(typeface),
                        index,
                        index + 1,
                        Spanned.SPAN_EXCLUSIVE_EXCLUSIVE
                    )
                }
            }
        }
    }

    /**
     * 修改字符串中标识的颜色
     * @param  content String
     * @param foregroundColor Int
     */
    @JvmStatic
    fun styleTextTagColor(
        content: String,
        tag: Char,
        foregroundColor: Int
    ): SpannableStringBuilder {
        return SpannableStringBuilder(content).apply {
            content.toCharArray().withIndex().forEach { (index, chars) ->
                if (chars == tag) {
                    setSpan(
                        ForegroundColorSpan(
                            foregroundColor
                        ), index, index + 1, Spanned.SPAN_EXCLUSIVE_EXCLUSIVE
                    )
                }
            }
        }
    }

    /**
     * 修改字符串颜色，增加下划线
     * @param  content String
     * @param foregroundColor Int
     */
    fun styleTextUnderlineColor(content: String, foregroundColor: Int): SpannableStringBuilder {
        return SpannableStringBuilder(content).apply {
            setSpan(
                ForegroundColorSpan(
                    foregroundColor
                ), 0, content.length, Spanned.SPAN_EXCLUSIVE_EXCLUSIVE
            )
            setSpan(UnderlineSpan(), 0, content.length, Spanned.SPAN_EXCLUSIVE_EXCLUSIVE)
        }
    }

    /**
     * 修改字符串颜色，加粗
     * @param  content String
     * @param foregroundColor Int
     */
    fun styleTextBoldColor(content: String, foregroundColor: Int): SpannableStringBuilder {
        return SpannableStringBuilder(content).apply {
            setSpan(
                ForegroundColorSpan(
                    foregroundColor
                ), 0, content.length, Spanned.SPAN_EXCLUSIVE_EXCLUSIVE
            )
            setSpan(
                StyleSpan(Typeface.BOLD),
                0,
                content.length,
                Spanned.SPAN_EXCLUSIVE_EXCLUSIVE
            );
        }
    }

    /**
     * 修改字符串颜色，加粗
     * @param  content String
     * @param foregroundColor Int
     */
    fun styleTextBoldColor(
        content: String,
        foregroundColor: Int,
        start: Int,
        end: Int
    ): SpannableStringBuilder {
        return SpannableStringBuilder(content).apply {
            setSpan(
                ForegroundColorSpan(
                    foregroundColor
                ), 0, content.length, Spanned.SPAN_EXCLUSIVE_EXCLUSIVE
            )
            setSpan(
                StyleSpan(Typeface.BOLD),
                if (start >= 0) start else 0,
                if (end >= 0) end else 0,
                Spanned.SPAN_EXCLUSIVE_EXCLUSIVE
            );
        }
    }

    /**
     * 修改字符串颜色
     * @param  content String
     * @param foregroundColor Int
     */
    fun styleTextColor(content: String, foregroundColor: Int): SpannableStringBuilder {
        return SpannableStringBuilder(content).apply {
            setSpan(
                ForegroundColorSpan(
                    foregroundColor
                ), 0, content.length, Spanned.SPAN_EXCLUSIVE_EXCLUSIVE
            )
        }
    }


    /**
     * 修改字符串颜色
     * @param  content String
     * @param foregroundColor Int
     */
    fun styleTextColor(
        content: String, foregroundColor: Int, start: Int,
        end: Int
    ): SpannableStringBuilder {
        return SpannableStringBuilder(content).apply {
            setSpan(
                ForegroundColorSpan(
                    foregroundColor
                ),
                if (start >= 0) start else 0,
                if (end >= 0) end else 0,
                Spanned.SPAN_EXCLUSIVE_EXCLUSIVE
            )
        }
    }

    /**
     * 修改字符串加粗
     * @param  content String
     */
    fun styleTextBold(content: String): SpannableStringBuilder {
        return SpannableStringBuilder(content).apply {
            setSpan(
                StyleSpan(Typeface.BOLD),
                0,
                content.length,
                Spanned.SPAN_EXCLUSIVE_EXCLUSIVE
            );
        }
    }

    /**
     * 修改字符串加粗
     * @param  content String
     */
    fun styleTextBold(
        content: String,
        start: Int,
        end: Int
    ): SpannableStringBuilder {
        return SpannableStringBuilder(content).apply {
            setSpan(
                StyleSpan(Typeface.BOLD),
                if (start >= 0) start else 0,
                if (end >= 0) end else 0,
                Spanned.SPAN_EXCLUSIVE_EXCLUSIVE
            );
        }
    }
}